<?php
// File Security Check
if ( ! defined( 'ABSPATH' ) ) exit;
/**
 * wooFramework Setup.
 *
 * All functionality used for setting up the wooFramework.
 *
 * @package WordPress
 * @subpackage  wooFramework
 * @category  Core
 * @author  templatation
 * @since  1.0.0
 *
 * TABLE OF CONTENTS
 *
 * - Redirect to the wooFramework theme options screen on theme activation.
 * - Flush the WordPress rewrite rules to refresh permalinks with updated rewrite rules.
 * - Optionally add markup in the header of the WordPress admin.
 * - Output the default wooFramework "head" markup in the "head" section.
 * 		- Output alternative stylesheet
 *   	- Output custom favicon
 *    	- Load textdomains
 *     	- Output CSS from standarized styling options
 *      - Output shortcodes stylesheet
 *      - Output custom.css
 * - Output the alternative stylesheet.
 * - Output the favicon HTML.
 * - Load the theme's textdomain, as well as an optional child theme textdomain.
 * - Output CSS from standardized theme options.
 * - Output the HTML for the "custom.css" file.
 * - Add theme support for post thumbnails, and integrate the size settings.
 * - Enqueue the comment reply JavaScript on singular entry screens.
 */

define( 'THEME_FRAMEWORK', 'templatation' );

if ( ! function_exists( 'woo_themeoptions_redirect' ) ) {
/**
 * Redirect to the wooFramework theme options screen on theme activation.
 * Hooked onto "woo_theme_activate" at priority 10.
 * @since  4.0.0
 * @return void
 */
function woo_themeoptions_redirect () {
	header( 'Location: ' . admin_url( 'themes.php?page=tgmpa-install-plugins' ) );
} // End woo_themeoptions_redirect()
}
if( get_option('envato_setup_complete', false) ) {}
else {
	add_action( 'woo_theme_activate', 'woo_themeoptions_redirect', 10 );
}
if ( ! function_exists( 'woo_flush_rewriterules' ) ) {
/**
 * Flush the WordPress rewrite rules to refresh permalinks with updated rewrite rules.
 * @since  4.0.0
 * @return void
 */
function woo_flush_rewriterules () {
	flush_rewrite_rules();
} // End woo_flush_rewriterules()
}

/**
 * Add default options and show Options Panel after activate
 * @since  4.0.0
 */
global $pagenow;
if ( is_admin() && isset( $_GET['activated'] ) && $pagenow == 'themes.php' ) {
	// Call action that sets.
//	add_action( 'admin_head','woo_option_setup' );
	// Flush rewrite rules.
	add_action( 'admin_head', 'woo_flush_rewriterules', 9 );
	// Custom action for theme-setup (redirect is at priority 10).
	do_action( 'woo_theme_activate' );
}

if ( ! function_exists( 'woo_option_setup' ) ) {
/**
 * Update theme options in database with options as stored in theme.
 * @since  1.0.0
 * @return void
 */
function woo_option_setup () { // no longer needed.
} // End woo_option_setup()
}


if ( ! function_exists( 'templatation_admin_head' ) ) {
/**
 * Optionally add markup in the header of the WordPress admin.
 * @since  4.0.0
 * @return void
 */
function templatation_admin_head() {} // End templatation_admin_head()
}
add_action( 'admin_head', 'templatation_admin_head', 10 );


if ( ! function_exists( 'templatation_wp_head' ) ) {
/**
 * Output the default wooFramework "head" markup in the "head" section.
 * @since  2.0.0
 * @return void
 */
function templatation_wp_head() {
	do_action( 'templatation_wp_head_before' );
	// Output alternative stylesheet
	if ( function_exists( 'woo_output_alt_stylesheet' ) )
		woo_output_alt_stylesheet();
	// Output custom favicon
	if ( function_exists( 'woo_output_custom_favicon' ) )
		woo_output_custom_favicon();
	// Output shortcodes stylesheet
	if ( function_exists( 'woo_shortcode_stylesheet' ) )
		woo_shortcode_stylesheet();
	// Output custom.css
	if ( function_exists( 'woo_output_custom_css' ) )
		woo_output_custom_css();
	do_action( 'templatation_wp_head_after' );
} // End templatation_wp_head()
}
add_action( 'woo_head', 'templatation_wp_head', 11 );


if ( ! function_exists( 'woo_output_alt_stylesheet' ) ) {
/**
 * Output the alternative stylesheet.
 * @since  2.0.0
 * @return void
 */
function woo_output_alt_stylesheet() {
	global $tt_options;
	$style = '';

	if ( isset( $_REQUEST['style'] ) ) {
		$requested_style = esc_attr( strtolower( strip_tags( trim( $_REQUEST['style'] ) ) ) );
		$style = $requested_style;
	}

	echo "\n" . '<!-- Alt Stylesheet -->' . "\n";
	// If we're using the query variable, be sure to check for /css/layout.css as well.
	if ( $style != '' ) {
		if ( strtolower( $style ) == 'default' ) {
			if ( file_exists( get_template_directory() . '/css/layout.css' ) ) {
				echo '<link href="' . esc_url( get_template_directory_uri() . '/css/layout.css' ) . '" rel="stylesheet" type="text/css" />' . "\n";
			}
			echo '<link href="' . esc_url( get_stylesheet_uri() ) . '" rel="stylesheet" type="text/css" />' . "\n";
		} else {
			echo '<link href="' . esc_url( get_template_directory_uri() . '/styles/' . $style . '.css' ) . '" rel="stylesheet" type="text/css" />' . "\n";
		}
	} else {
		$style = $tt_options['tt_alt_stylesheet'];
		$style = esc_attr( strtolower( strip_tags( trim( $style ) ) ) );
		if( $style != '' ) {
			$style = $style.'.css';
			echo '<link href="'. esc_url( get_template_directory_uri() . '/styles/'. $style ) . '" rel="stylesheet" type="text/css" />' . "\n";
			$settings = tt_get_dynamic_values( array( 'disable_responsive' => '0' ) );
			if( $settings['disable_responsive'] == '1' ) {
				echo '<link href="'. esc_url( get_template_directory_uri() . '/styles/non-responsive/'. $style ) . '" rel="stylesheet" type="text/css" />' . "\n";
			}
		} else {
			echo '<link href="'. esc_url( get_template_directory_uri() . '/styles/default.css' ) . '" rel="stylesheet" type="text/css" />' . "\n";
		}
	}
} // End woo_output_alt_stylesheet()
}

if ( ! function_exists( 'woo_output_custom_favicon' ) ) {
/**
 * Output the favicon HTML.
 * @since  2.0.0
 * @return void
 */
function woo_output_custom_favicon () {
	global $tt_options;
	// Get options
	$settings = array(
					'custom_favicon' => array( 'url' => '' ),
					'fvcn_57x57' => array( 'url' => '' ),
					'fvcn_114x114' => array( 'url' => '' ),
					'fvcn_72x72' => array( 'url' => '' ),
					'fvcn_144x144' => array( 'url' => '' ),
	);
	$settings = tt_get_dynamic_values( $settings );
	$favicon = apply_filters( 'woo_custom_favicon', $settings['custom_favicon']['url'] );
	ob_start();
	if( '' != $favicon ) echo "\n" . '<link rel="shortcut icon" href="' .  esc_url( $favicon )  . '"/>' . "\n";
	
	if( '' != $settings['fvcn_57x57']['url'] ): ?>
	<!-- For iPhone -->
	<link rel="apple-touch-icon-precomposed" href="<?php echo $settings['fvcn_57x57']['url']; ?>">
	<?php endif;

	if( '' != $settings['fvcn_114x114']['url'] ): ?>
	<!-- For iPhone 4 Retina display -->
	<link rel="apple-touch-icon-precomposed" sizes="114x114" href="<?php echo $settings['fvcn_114x114']['url']; ?>">
	<?php endif;

	if( '' != $settings['fvcn_72x72']['url'] ): ?>
	<!-- For iPad -->
	<link rel="apple-touch-icon-precomposed" sizes="72x72" href="<?php echo $settings['fvcn_72x72']['url']; ?>">
	<?php endif;

	if( '' != $settings['fvcn_144x144']['url'] ): ?>
	<!-- For iPad Retina display -->
	<link rel="apple-touch-icon-precomposed" sizes="144x144" href="<?php echo $settings['fvcn_144x144']['url']; ?>">
	<?php endif; 
	$favicon = ob_get_clean();
	echo '<!-- Custom Favicon -->' .$favicon;

} // End woo_output_custom_favicon()
}

if ( ! function_exists( 'woo_load_textdomain' ) ) {
/**
 * Load the theme's textdomain, as well as an optional child theme textdomain.
 * @since  2.0.0
 * @return void
 */
function woo_load_textdomain () {
	load_theme_textdomain( 'templatation' );
	load_theme_textdomain( 'templatation', get_template_directory() . '/lang' );
	if ( function_exists( 'load_child_theme_textdomain' ) )
		load_child_theme_textdomain( 'templatation' );
} // End woo_load_textdomain()
}

add_action( 'init', 'woo_load_textdomain', 10 );


if ( ! function_exists( 'woo_output_custom_css' ) ) {
/**
 * Output the HTML for the "custom.css" file.
 * @since  2.0.0
 * @return void
 */
function woo_output_custom_css() {
	$theme_dir = get_template_directory();	$theme_dir_uri = $custfile = "";
	if ( is_child_theme() ) { $theme_dir = get_stylesheet_directory(); }
	$custfile = $theme_dir . '/custom.css';
	if ( ! file_exists( $custfile ) ) { return; } // return if custom.css doesnt exists.
	
	$theme_dir_uri = get_template_directory_uri();	
	if ( is_child_theme() && file_exists( get_stylesheet_directory() . '/custom.css' ) )
	$theme_dir_uri = get_stylesheet_directory_uri();

	echo "\n" . '<!-- Custom Stylesheet -->' . "\n" . '<link href="'. esc_url( $theme_dir_uri . '/custom.css' ) . '" rel="stylesheet" type="text/css" />' . "\n";
} // End woo_output_custom_css()
}

/**
 * Add theme support for post thumbnails, and integrate the size settings.
 * @since  4.0.0
 */
if( function_exists( 'add_theme_support' ) ) {
	global $tt_options;
	add_theme_support( 'post-thumbnails' );
	add_theme_support( "title-tag" );

	if ( is_array( $tt_options )) {
		if ( $tt_options['tt_post_image_support'] == '1' ) {
			// set height, width and crop if dynamic resize functionality isn't enabled
			if ( $tt_options['tt_pis_resize'] != '1' ) {
				$thumb_width   = $tt_options['tt_thumb_w']['width'];
				$thumb_height  = $tt_options['tt_thumb_h']['height'];
				$single_width  = $tt_options['tt_single_w']['width'];
				$single_height = $tt_options['tt_single_h']['height'];
				$hard_crop     = $tt_options['tt_pis_hard_crop'];
				if ( $hard_crop == '1' ) {
					$hard_crop = true;
				} else {
					$hard_crop = false;
				}
				set_post_thumbnail_size( $thumb_width, $thumb_height, $hard_crop ); // Normal post thumbnails
			}
		}
	}

}

if ( ! function_exists( 'woo_comment_reply' ) ) {
/**
 * Enqueue the comment reply JavaScript on singular entry screens.
 * @since  3.0.0
 * @return void
 */
function woo_comment_reply() {
	if ( is_singular() ) wp_enqueue_script( 'comment-reply','',false,true ); //@cakery1.0 making it load on bottom.
} // End woo_comment_reply()
}

add_action( 'get_header', 'woo_comment_reply', 10 );
?>