<?php

    /**
     * For full documentation, please visit: http://docs.reduxframework.com/
     * For a more extensive sample-config file, you may look at:
     * https://github.com/reduxframework/redux-framework/blob/master/sample/sample-config.php
     */

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }

    // This is your option name where all the Redux data is stored.
    $opt_name = "tt_options";
    $shortname = "tt";
    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        'opt_name'             => $opt_name,
        'use_cdn' => TRUE,
        'display_name'         => $theme->get( 'Name' ),
        'display_version'      => $theme->get( 'Version' ),
        'page_slug' => '_templatation',
        'page_title' => 'Theme Options',
        'update_notice' => TRUE,
        'dev_mode'     => FALSE,
        'intro_text' => '<p>You can modify theme settings and click Save Settings</p>',
        'footer_text' => '',
        'admin_bar' => TRUE,
        'menu_type' => 'submenu', // depends if we have panel in active theme or not.
		'page_parent'    => 'templatation_dashboard',
        'menu_icon'            => get_template_directory_uri().'/functions/images/woo-icon.png',
        'menu_title' => 'Theme Options',
        'page_priority'        => '34.811',
        'allow_sub_menu' => false,
        'page_parent_post_type' => 'your_post_type',
        'customizer' => TRUE,
        'default_mark' => '*',
        'hints' => array(
            'icon_position' => 'right',
            'icon_color' => 'lightgray',
            'icon_size' => 'normal',
            'tip_style' => array(
                'color' => 'light',
            ),
            'tip_position' => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect' => array(
                'show' => array(
                'duration' => '500',
                'event' => 'mouseover',
                ),
                'hide' => array(
                'duration' => '500',
                'event' => 'mouseleave unfocus',
                ),
            ),
        ),
        'output' => TRUE,
        'output_tag' => TRUE,
        'settings_api' => TRUE,
        'cdn_check_time' => '1440',
        'compiler' => TRUE,
        'page_permissions' => 'manage_options',
        'save_defaults' => TRUE,
        'show_import_export' => TRUE,
        'database' => 'options',
        'transient_time' => '3600',
        'network_sites' => TRUE,
    );

    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */


    // Background Patterns Reader
    $sample_patterns_path = get_template_directory() . '/images/bodybg/';
    $sample_patterns_url = get_template_directory_uri() . '/images/bodybg/';
    //$sample_patterns_path = ReduxFramework::$_dir . '../sample/patterns/';
    //$sample_patterns_url  = ReduxFramework::$_url . '../sample/patterns/';
    $sample_patterns      = array();
    if ( is_dir( $sample_patterns_path ) ) {
        if ( $sample_patterns_dir = opendir( $sample_patterns_path ) ) {
            $sample_patterns = array();
            while ( ( $sample_patterns_file = readdir( $sample_patterns_dir ) ) !== false ) {
                if ( stristr( $sample_patterns_file, '.png' ) !== false || stristr( $sample_patterns_file, '.jpg' ) !== false ) {
                    $name              = explode( '.', $sample_patterns_file );
                    $name              = str_replace( '.' . end( $name ), '', $sample_patterns_file );
                    $sample_patterns[] = array(
                        'alt' => $name,
                        'img' => $sample_patterns_url . $sample_patterns_file
                    );
                }
            }
        }
    }

    //Stylesheets Reader
    $alt_stylesheet_path = get_template_directory() . '/styles/';
    $alt_stylesheets = array();
    if ( is_dir($alt_stylesheet_path) ) {
        if ($alt_stylesheet_dir = opendir($alt_stylesheet_path) ) {
            while ( ($alt_stylesheet_file = readdir($alt_stylesheet_dir)) !== false ) {
                if(stristr($alt_stylesheet_file, '.css') !== false) {
	                $alt_stylesheet = str_replace('.css', '', $alt_stylesheet_file);
                    $alt_stylesheets[$alt_stylesheet] = $alt_stylesheet_file;
                }
            }
        }
    }


    /*
     *
     * ---> START SECTIONS
     *
     */

/*-----------------------------------------------------------------------------------*/
/* General Settings                                                                  */
/*-----------------------------------------------------------------------------------*/
    Redux::setSection( $opt_name, array(
        'title'  => __( 'General Settings', 'templatation' ),
        'id'     => 'general',
        'desc'   => __( 'General Settings.', 'templatation' ),
        //'icon'   => 'el el-home ',
        'customizer_width' => '400px',
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => __( 'Quick Start', 'templatation' ),
        'id'               => 'general-quickstart',
        'subsection'       => true,
        'customizer_width' => '450px',
        'fields'           => array(

            array(
                'id' => $shortname . '_alt_stylesheet',
                'type'     => 'select',
                'title' => __( 'Theme Stylesheet/Theme Color', 'templatation' ),
                'subtitle' => __( 'Select your themes alternative color scheme.', 'templatation' ),
                'desc' => __( 'These are prebuilt colors, you can create your own color scheme too, by going to Theme-options/Styling. Note: If you plan to create your own scheme, select default.css here.' ),
                'default' => 'default',
                //'default_show' => 'false',
                'options' => $alt_stylesheets
            ),
            array(
    			'id' => $shortname . '_logo',
                'type'     => 'media',
                'url'      => true,
                'title'    => __( 'Upload Logo', 'templatation' ),
                'readonly'    => false,
                'subtitle'     => __( 'Upload a logo for your theme, or specify an image URL directly. For retina friendliness you can upload 2x logo and set desired dimension in retina ready graphics option below.', 'templatation' ),
                'desc' => __( 'Ideal size of the logo depends on the header layout you are using.' ),
            ),
            array(
    			'id' => $shortname . '_logo_top_offset',
                'type'           => 'dimensions',
                'units'          => array( 'px' ),    // You can specify a unit value. Possible: px, em, %
                'units_extended' => 'true',  // Allow users to select any type of unit
                'title'          => __( 'Vertical Logo Offset', 'templatation' ),
                'subtitle'       => __( 'If the logo you uploaded is misplaced, you can move logo vertically by providing the values below. If you put 10 in top offset, logo will move to top side by 10px, -10 in top offset will move the logo down 10px. Enter values without px eg: 10, 20, -15 etc.', 'templatation' ),
                'width'         => false,
                'default'        => array(
                    'width'  => 0,
                    'height' => 0,
                )
            ),
            array(
    			'id' => $shortname . '_logo_left_offset',
                'type'           => 'dimensions',
                'units'          => array( 'px' ),    // You can specify a unit value. Possible: px, em, %
                'units_extended' => 'true',  // Allow users to select any type of unit
                'title'          => __( 'Horizontal Logo Offset', 'templatation' ),
                'subtitle'       => __( 'If the logo you uploaded is misplaced, you can move logo horizontally by providing the values below. If you put 10 in top offset, logo will move to right side by 10px, -10 in top offset will move the logo to left 10px. Enter values without px eg: 10, 20, -15 etc.', 'templatation' ),
                'height'         => false,
                'default'        => array(
                    'width'  => 0,
                    'height' => 0,
                )
            ),
            array(
                'id' => $shortname . '_favicon_info',
                'type'   => 'info',
               // 'notice' => false,
                'style'  => 'info',
                'title' => __( 'Favicon Icon', 'templatation' ),
                'desc'   =>  sprintf( __( 'Since WordPress 4.3, favicon now can be managed from Appearance -> Customize -> Site Identity. %1$s.', 'templatation' ), '<a href="' . esc_url( home_url() ) . '/wp-admin/customize.php">' . __( 'Go to Live Customizer (Appearance-Customize) by clicking here', 'templatation' ) . '</a>' ),
            ),
            array(
                'id'   => 'opt-divide',
                'type' => 'divide'
            ),
            array(
    			'id' => $shortname . '_retina_favicon',
                'type'     => 'switch',
                'title'    => 'Retina Ready Graphics ?',
                'subtitle'       => __( 'If you worry about Retina ready devices, please check this and you will find options to upload favicon for high resolution devices.', 'templatation' ),
                'desc'       => __( 'If you are not sure what this means leave it off.', 'templatation' ),
                'default'  => false
            ),
            array(
    			'id' => $shortname . '_fvcn_57x57',
                'type'     => 'media',
                'url'      => true,
                'title'    => __( 'Apple iPhone Icon', 'templatation' ),
                'readonly'    => false,
    			'subtitle' => __( 'Icon for Apple iPhone (57px x 57px)', 'templatation' ),
                'default'  => array( 'url' => '' ),
                'required' => array( $shortname . '_retina_favicon', '=', true )
            ),
            array(
    			'id' => $shortname . '_fvcn_57x57',
                'type'     => 'media',
                'url'      => true,
                'title'    => __( 'Apple iPhone Icon', 'templatation' ),
                'readonly'    => false,
    			'subtitle' => __( 'Icon for Apple iPhone (57px x 57px)', 'templatation' ),
                'default'  => array( 'url' => '' ),
                'required' => array( $shortname . '_retina_favicon', '=', true )
            ),
            array(
    			'id' => $shortname . '_fvcn_114x114',
                'type'     => 'media',
                'url'      => true,
                'title'    => __( 'Apple iPhone Retina', 'templatation' ),
                'readonly'    => false,
    			'subtitle' => __( 'Icon for Apple iPhone Retina Version (114px x 114px) and other high-resolution Retina display', 'templatation' ),
                'default'  => array( 'url' => '' ),
                'required' => array( $shortname . '_retina_favicon', '=', true )
            ),
            array(
    			'id' => $shortname . '_fvcn_72x72',
                'type'     => 'media',
                'url'      => true,
                'title'    => __( 'Apple iPad Icon', 'templatation' ),
                'readonly'    => false,
    			'subtitle' => __( 'Icon for Apple iPad (72px x 72px)', 'templatation' ),
                'default'  => array( 'url' => '' ),
                'required' => array( $shortname . '_retina_favicon', '=', true )
            ),
            array(
    			'id' => $shortname . '_fvcn_144x144',
                'type'     => 'media',
                'url'      => true,
                'title'    => __( 'Apple iPad Retina Icon', 'templatation' ),
                'readonly'    => false,
    			'subtitle' => __( 'Icon for Apple iPad Retina Version (144px x 144px) and other high-resolution Retina display.', 'templatation' ),
                'default'  => array( 'url' => '' ),
                'required' => array( $shortname . '_retina_favicon', '=', true )
            ),
            array(
                'id' => $shortname . '_retina_logo_wh',
                'type'           => 'dimensions',
                'units'          => array( 'px' ),    // You can specify a unit value. Possible: px, em, %
                'units_extended' => 'true',  // Allow users to select any type of unit
                'title'          => __( 'Dimensions (Width/Height) Option', 'templatation' ),
                'subtitle'       => __( 'Enter desired Width and height for your retina logo. If you want logo to be retina ready, please upload double size version of logo above and enter the dimensions you want it to appear in.', 'templatation' ),
                'desc'       => __( ' Normally it will be half of actual retina logo image dimensions. Enter values without px eg: 50, 70 etc. Note: Try keeping the height blank if your logo is distorted.', 'templatation' ),
                'required' => array( $shortname . '_retina_favicon', '=', true ),
                 'default'        => array(
                    'width'  => 0,
                    'height' => 0,
                )
            ),
/* no longer applicable as in new version user can define custom wrapper border and body bg.
            array(
    			'id' => $shortname . '_widescreen',
                'type'     => 'switch',
                'title'    => 'Enable Widescreen Mode ?',
    			'subtitle' => __( 'If you check this , the main container with white background will flow to full available width horizontally(by default its 950px fixed width).', 'templatation' ),
    			'desc' => __( 'Note that content will still be inside 950px width, only background will be full width. If you enable it, also see bottom option of Styling -> Body Background. If you are not sure, try it :).', 'templatation' ),
                'default'  => false
            ),*/
            array(
    			'id' => $shortname . '_sticky_menu',
                'type'     => 'switch',
                'title'    => 'Enable Sticky Menu ?',
    			'subtitle' => __( 'If you check this , navigation bar sticks to top even if you scroll down on any page.', 'templatation' ),
                'default'  => true
            ),
            array(
    			'id' => $shortname . '_google_analytics',
                'type'     => 'text',
                'title'    => __( 'Google analytics', 'templatation' ),
    			'subtitle' => __( 'Paste your Google Analytics Tracking ID here. This will be added into the footer template of your theme. eg : UA-00000000-0 . NOTE: ONLY ENTER TRACKING ID, NOT FULL CODE.', 'templatation' ),
                'default'  => '',
            ),
            array(
    			'id' => $shortname . '_jsanim_no',
                'type'     => 'switch',
                'title'    => 'Disable Default Animations.',
    			'subtitle' => __( 'Check this to disable Default animations. Note that Animations triggered by Page builder will not be turned off, they can be managed from Page Builder itself. Recommended: Unchecked.', 'templatation' ),
                'default'  => false
            ),
           array(
                'id' => $shortname . '_enable_preloader',
                'type'     => 'switch',
                'title' => esc_html__( 'Enable Preloader', 'templatation' ),
                'subtitle' => esc_html__( 'If enabled, website shows a preloader icon before the page loads.', 'templatation' ),
                'default'  => true
           ),
/*            array(
    			'id' => $shortname . '_disable_responsive',
                'type'     => 'switch',
                'title'    => 'Disable Responsiveness.',
    			'subtitle' => __( 'The theme adjust itself automatically to the width of the device/browser. Do you want to disable it and open desktop version on all devices instead ? Check to disable.', 'templatation' ),
                'default'  => false
            ),*/
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => __( 'Subscription Settings', 'templatation' ),
        'id'               => 'subscription-Settings',
        'subsection'       => true,
        'customizer_width' => '450px',
/*        'desc'             => __( 'For full documentation on this field, visit: ', 'templatation' ) . '<a href="//docs.reduxframework.com/core/fields/checkbox/" target="_blank">docs.reduxframework.com/core/fields/checkbox/</a>',*/
        'fields'           => array(

            array(
    			'id' => $shortname . '_feed_url',
                'type'     => 'text',
                'title'    => __( 'RSS URL', 'templatation' ),
    			'subtitle' => __( 'Enter your preferred RSS URL. (Feedburner or other)', 'templatation' ),
            ),


        )
    ) );



    Redux::setSection( $opt_name, array(
        'title'            => __( 'Display Options/CSS', 'templatation' ),
        'id'               => 'display-options',
        'subsection'       => true,
        'customizer_width' => '450px',
/*        'desc'             => __( 'For full documentation on this field, visit: ', 'templatation' ) . '<a href="//docs.reduxframework.com/core/fields/checkbox/" target="_blank">docs.reduxframework.com/core/fields/checkbox/</a>',*/
        'fields'           => array(

            array(
    			'id' => $shortname . '_custom_css',
                'type'     => 'ace_editor',
                'title'    => __( 'Custom CSS', 'templatation' ),
    			'subtitle' => __( 'Quickly add some CSS to your theme by adding it to this block.', 'templatation' ),
                'mode'     => 'css',
                'theme'    => 'monokai',
                'default'  => ''
            ),

            array(
    			'id' => $shortname . '_comments',
                'type'     => 'select',
                'title'    => __( 'Post/Page Comments', 'templatation' ),
    			'subtitle' => __( 'Select if you want to enable/disable comments on posts and/or pages.', 'templatation' ),
    			'options' => array( 'post' => __( 'Posts Only', 'templatation' ), 'page' => __( 'Pages Only', 'templatation' ), 'both' => __( 'Pages / Posts', 'templatation' ), 'none' => __( 'None', 'templatation' ) ) ,
                'default'  => 'both',
            ),

            array(
                'id' => $shortname . '_post_content',
                'type'     => 'select',
                'title'    => __( 'Post Content', 'templatation' ),
                'subtitle' => __( 'Select if you want to show the full content or the excerpt on blog posts list page. Note it doesnt apply on single pages which always show full post.', 'templatation' ),
                'options' => array( 'excerpt' => __( 'The Excerpt', 'templatation' ), 'content' => __( 'Full Content', 'templatation' ) )
            ),


           array(
                'id' => $shortname . '_post_author',
                'type'     => 'switch',
                'title'    => 'Post Author Box.',
                'subtitle' => sprintf( __( 'This will enable the post author box on the single posts page. Edit description in %1$s.', 'templatation' ), '<a href="' . esc_url( home_url() ) . '/wp-admin/profile.php">' . __( 'Profile', 'templatation' ) . '</a>' ),
                'default'  => true
            ),

           array(
                'id' => $shortname . '_breadcrumbs_show',
                'type'     => 'switch',
                'title'    => 'Display Breadcrumbs.',
                'subtitle' => __( 'Display dynamic breadcrumbs on each page of your website.', 'templatation' ),
                'default'  => true
            ),

           array(
                'id' => $shortname . '_pagenav_show',
                'type'     => 'switch',
                'title'    => 'Display Pagination.',
                'subtitle' => __( 'Display pagination on the blog.', 'templatation' ),
                'default'  => true
            ),

            array(
                'id' => $shortname . '_pagination_type',
                'type'     => 'select',
                'title'    => __( 'Pagination Style', 'templatation' ),
                'subtitle' => __( 'Select the style of pagination you would like to use on the blog.', 'templatation' ),
                'options' => array( 'paginated_links' => __( 'Numbers', 'templatation' ), 'simple' => __( 'Next/Previous', 'templatation' ) )
            ),

        )
    ));


/*-----------------------------------------------------------------------------------*/
/* Style Settings                                                                  */
/*-----------------------------------------------------------------------------------*/
    Redux::setSection( $opt_name, array(
        'title'            => __( 'Styling', 'templatation' ),
        'id'               => 'body-options',
        'customizer_width' => '450px',
        'icon'   => 'el el-icon-brush',
/*        'desc'             => __( 'For full documentation on this field, visit: ', 'templatation' ) . '<a href="//docs.reduxframework.com/core/fields/checkbox/" target="_blank">docs.reduxframework.com/core/fields/checkbox/</a>',*/
        'fields'           => array(

            array(
                'id' => $shortname . '_style_warn',
                'type'  => 'info',
                'style' => 'info',
                'title' => __( 'Please Note.', 'templatation' ),
                'desc'   =>  sprintf( __( 'If you plan to alter theme colors, its suggested that you use default.css first, in Themeoptions/General Options Theme stylesheet. Also be informed that for complete color customization, sprite-a.png will need to be changed too. %1$s.', 'templatation' ), '<a href="https://www.dropbox.com/s/ideivm7sq1dwfk7/Sprite%20PSD.zip?dl=1">' . __( 'Download sprite PSD here', 'templatation' ) . '</a>' ),
            ),

            array(
                'id' => $shortname . '_live_cust_info',
                'type'   => 'info',
                'notice' => false,
                'style'  => 'info',
                'title' => __( 'Live Customizer', 'templatation' ),
                'desc'   =>  sprintf( __( 'Please note that theme main colors settings can also be done using Live customizer, you can see live preview if you use live customizer. %1$s.', 'templatation' ), '<a href="' . esc_url( home_url() ) . '/wp-admin/customize.php">' . __( 'Go to Live Customer (Appearance-Customize) by clicking here', 'templatation' ) . '</a>' ),
            ),
           array(
                'id' => $shortname . '_live_cust',
                'type'     => 'switch',
                'title' => __( 'Enable live customizer ?', 'templatation' ),
                'subtitle' => sprintf( __( 'Enable live customizer to change colors of the theme with live preview. Not recommended unless you really need it. Once checked and saved using above button, %1$s. (Yes you can disable it later, so nothing wrong in giving it a try.)', 'templatation' ), '<a href="' . esc_url( home_url() ) . '/wp-admin/customize.php">' . __( 'Access by clicking here', 'templatation' ) . '</a>' ),
                'default'  => false
            ),
           array(
                'id' => $shortname . '_main_acnt_clr',
                'type'     => 'color',
                'title'    => __( 'Main Accent Color', 'templatation' ),
                'subtitle' => __( 'Main accent color of the theme. This is most used color throughout.', 'templatation' ),
                'desc'     => __( 'Defaults: Orange: #e75a39 , Purple: #b08fbb, Blue: #68b5d3, Green: #80b243, Brown: #9d563a, Pink: #c95980', 'templatation' ),
                'default'  => '#e75a39'
           ),

           array(
                'id' => $shortname . '_sec_acnt_clr',
                'type'     => 'color',
                'title'    => __( 'Secondary Accent Color', 'templatation' ),
                'subtitle' => __( 'Secondary accent color of the theme. Normally darker version of Main accent color. Used in button shadows etc.', 'templatation' ),
                'desc'     => __( 'Defaults: Orange: #917460 , Purple: #4F3754, Blue: #53a7c7, Green: #64883F, Brown: #4f2b2d, Pink: #A0375B', 'templatation' ),
                'default'  => '#917460',
                'default_show'  => 'false'
           ),

           array(
                'id' => $shortname . '_light_clr',
                'type'     => 'color',
                'title'    => __( 'Light Color', 'templatation' ),
                'subtitle' => __( 'This is lighter version of primary color, used on background of Post meta. Recommended: Extreme lighter version of primary color.' ),
                'desc'     => __( 'Defaults: Orange: #faded8, Purple: #f1e0f9, Blue: #b3e7fb, Green: #b3e7fb, Brown: #f3d1c3, Pink: #fbdbe6', 'templatation' ),
                'default'  => '#faded8'
           ),

           array(
                'id' => $shortname . '_body_bg',
                'type'     => 'image_select',
                'tiles'    => true,
                'title'    => __( 'Preset Body Background Images.', 'templatation' ),
                'subtitle'    => __( 'Select Body Background from available patterns. You can also upload your own below.', 'templatation' ),
                'desc'    => __( 'Note: If you upload background image below in Body Background Setting, that image will override setting here. Note : The first image is the default background image. The box shows white color, is actually transparent image', 'templatation' ),
                'output'   => array( 'body' ),
                'default'  => 0,
                'options'  => $sample_patterns
           ),

           array(
                'id' => $shortname . '_body_stng',
                'type'     => 'background',
                'output'   => array( 'body' ),
                'title' => __( 'Body Background Setting', 'templatation' ),
                'subtitle' => __( 'You can customize body section here. Choose a color or an image and setup as per your liking.', 'templatation' ),
                'desc'    => __( 'Note: If you upload background image here , the above Body background image setting is overidden. Trick: If you want to use color(not image) only for body background, select  transparent image in above setting and choose color here.', 'templatation' ),
           ),

           array(
                'id' => $shortname . '_hdr_stng',
                'type'     => 'background',
                'output'   => array( '#header.b,#header.e,#header.f,#header.g' ),
                'title' => __( 'Header Settings', 'templatation' ),
                'subtitle' => __( 'You can customize header area here. Note : This customization will not reflect on homepage of layout 3, layout 4, because of their special structure.', 'templatation' ),
                //'default'   => '#FFFFFF',
           ),

           array(
                'id'       => 'wrapper-section-start',
                'type'     => 'section',
                'title'    => __( 'Content Area Style', 'templatation' ),
                'subtitle' => __( 'This is the area where the actual website content stays inside. You can change its appearance if you want to. No change
                 recommended if you are not sure what you are doing.', 'templatation' ),
                'indent'   => true, // Indent all options below until the next 'section' option is set.
           ),
           array(
                'id' => $shortname . '_wpr_stng',
                'type'     => 'background',
                'output'   => array( '#content' ),
                'title' => __( 'Content Area Background', 'templatation' ),
                'subtitle' => __( 'select background image or color for Content area. Default is White(#ffffff).', 'templatation' ),
           ),
           array(
                'id' => $shortname . '_wpr_bdr_clr',
                'type'     => 'border',
                'title'    => __( 'Content area Border Color', 'templatation' ),
                'subtitle' => __( 'Pick a border color and size for Content area (default: 1px solid #d7d4d4).', 'templatation' ),
                'output'   => array( '#content' ),
                'all'      => true,
                // An array of CSS selectors to apply this font style to
                //'desc'     => __( 'This is the description field, again good for additional info.', 'templatation' ),
           ),
           array(
                'id' => $shortname . '_wpr_bdr_rdus',
                'type'          => 'slider',
                'title'         => __( 'Content area border radius', 'templatation' ),
                'subtitle'      => __( 'Change border radius for Content area. Default: 5', 'templatation' ),
                //'desc'          => __( 'Slider description. Min: 0, max: 1, step: .1, default value: .5', 'templatation' ),
                'default'       => 5,
                'min'           => 0,
                'step'          => 1,
                'max'           => 10,
               // 'resolution'    => 0.1,
                'display_value' => 'text',
                'output'   => array( '#content' )
           ),
           array(
                'id'     => 'section-end',
                'type'   => 'section',
                'indent' => false, // Indent all options below until the next 'section' option is set.
           ),
           array(
                'id' => $shortname . '_no_cont_shadow',
                'type'     => 'switch',
                'title' => __( 'Disable content area Shadow?', 'templatation' ) ,
                'subtitle' => __( 'Incase you want single tone body and content area backgrounds, check to disable shadows that appear on start and end of content area on widescreen mode. ', 'templatation' ) ,
                'desc'   =>  __( 'Recommended: Off.', 'templatation' ),
                'default'  => false
           ),
           array(
                'id' => $shortname . '_no_bdcmp_shadow',
                'type'     => 'switch',
                'title' => __( 'Disable headline background Shadow?', 'templatation' ) ,
                'subtitle' => __( 'Again, incase you want single tone body and content area backgrounds, check to disable breadcrumb shadow. Recommended: unchecked.', 'templatation' ) ,
                'desc'   =>  __( 'Recommended: Off.', 'templatation' ),
                'default'  => false
           ),
        )
        ));

/*-----------------------------------------------------------------------------------*/
/* Typography Settings                                                                  */
/*-----------------------------------------------------------------------------------*/
    Redux::setSection( $opt_name, array(
        'title'            => __( 'Typography', 'templatation' ),
        'id'               => 'typography-options',
        'customizer_width' => '450px',
        'icon'   => 'el el-icon-fontsize',
/*        'desc'             => __( 'For full documentation on this field, visit: ', 'templatation' ) . '<a href="//docs.reduxframework.com/core/fields/checkbox/" target="_blank">docs.reduxframework.com/core/fields/checkbox/</a>',*/
        'fields'           => array(

            array(
                'id' => $shortname . '_js_typography_notice',
                'type'   => 'info',
                'notice' => false,
                'style'  => 'info',
                'title' => __( 'Typography Settings', 'templatation' ),
                'desc'   =>  __( 'Theme is already designed very well, but in-case you want to change some fonts , you can do it here. Please be careful with this as it might messup the fonts. You can revert your changes easily here as well by clicking Reset clicking button on above. If you are unsure, you can skip this section totally. :)', 'templatation' ),
            ),
            array(
                'id' => $shortname . '_font_body',
                'type'     => 'typography',
                'title' => __( 'General Typography', 'templatation' ) ,
                'subtitle' => __( 'Change the general font. Default  color: #706a64, font-size: 13px, line-height: 21px, font-family::Tahoma', 'templatation' ) ,
                'google'   => true,
                'output' => array('body'), // An array of CSS selectors to apply this font style to dynamically
                'font-weight'   => false,
                'default'  => array(
                    'color'       => '',
                    'font-size'   => '',
                    'line-height'   => '',
                    'font-family' => '',
                    'google'      => true,
                ),
            ),
            array(
                'id' => $shortname . '_font_nav',
                'type'     => 'typography',
                'title' => __( 'Navigation', 'templatation' ) ,
                'subtitle' => __( 'Change the navigation font. The color of navigation text adopts the Main accent color you choose in Styling. Default font-size: 16px , font-family: Philosopher', 'templatation' ),
                'output' => array('#navigation ul li a'), // An array of CSS selectors to apply this font style to dynamically
                'color'=>false,
                'google'   => true,
                'default'  => array(
                    'color'       => '',
                    'font-size'   => '',
                    'font-family' => '',
                    'font-weight' => '',
                    'google'      => true,
                ),
            ),
            array(
                'id' => $shortname . '_h1_font',
                'type' => 'typography',
                'title' => __('H1 Font.', 'templatation'),
                'subtitle' => __('Specify the H1 font properties. Default  color: #e75a39, font-size: 26px, line-height: 38px, font-family: Philosopher, font-weight: 700', 'templatation'),
                'google'=> true,
                'font-backup'=>true,
                'text-align'=>false,
                'color'=>false,
                'letter-spacing'=>true,
                'all_styles' => true, // Enable all Google Font style/weight variations to be added to the page
                'output' => array('h1'), // An array of CSS selectors to apply this font style to dynamically
                'units'=>'px', // Defaults to px
                'default' => array(
                    'font-size'=>'',
                    'line-height'=>'',
                    'font-family'=>'',
                    'font-weight'=>'',
                    ),
                ),
            array(
                'id' => $shortname . '_h2_font',
                'type' => 'typography',
                'title' => __('H2 Font.', 'templatation'),
                'subtitle' => __('Specify the H2 font properties. Default  color: #e75a39, font-size: 18px, line-height: 24px, font-family: Philosopher, font-weight:700', 'templatation'),
                'google'=> true,
                'font-backup'=>true,
                'text-align'=>false,
                'color'=>false,
                'letter-spacing'=>true,
                'all_styles' => true, // Enable all Google Font style/weight variations to be added to the page
                'output' => array('h2,.blog-item .quote-excerpt'), // An array of CSS selectors to apply this font style to dynamically
                'units'=>'px', // Defaults to px
                'default' => array(
                    'font-size'=>'',
                    'line-height'=>'',
                    'font-family'=>'',
                    'font-weight'=>'',
                    ),
                ),
            array(
                'id' => $shortname . '_h3_font',
                'type' => 'typography',
                'title' => __('H3 Font.', 'templatation'),
                'subtitle' => __('Specify the H3 font properties. Default  color: #e75a39, font-size: 18px, line-height: 24px, font-family: Philosopher, font-weight:700', 'templatation'),
                'google'=> true,
                'font-backup'=>true,
                'text-align'=>false,
                'color'=>false,
                'letter-spacing'=>true,
                'all_styles' => true, // Enable all Google Font style/weight variations to be added to the page
                'output' => array('h3'), // An array of CSS selectors to apply this font style to dynamically
                'units'=>'px', // Defaults to px
                'default' => array(
                    'font-size'=>'',
                    'line-height'=>'',
                    'font-family'=>'',
                    'font-weight'=>'',
                    ),
                ),
            array(
                'id' => $shortname . '_h4_font',
                'type' => 'typography',
                'title' => __('H4 Font.', 'templatation'),
                'subtitle' => __('Specify the H4 font properties. Default  color: #e75a39, font-size: 18px, line-height: 24px, font-family: Philosopher, font-weight: 700', 'templatation'),
                'google'=> true,
                'font-backup'=>true,
                'text-align'=>false,
                'color'=>false,
                'letter-spacing'=>true,
                'all_styles' => true, // Enable all Google Font style/weight variations to be added to the page
                'output' => array('h4'), // An array of CSS selectors to apply this font style to dynamically
                'units'=>'px', // Defaults to px
                'default' => array(
                    'font-size'=>'',
                    'line-height'=>'',
                    'font-family'=>'',
                    'font-weight'=>'',
                    ),
                ),
            array(
                'id' => $shortname . '_h5_font',
                'type' => 'typography',
                'title' => __('H5 Font.', 'templatation'),
                'subtitle' => __('Specify the H5 font properties. Default  color: #e75a39, font-size: 12px, line-height: 16px, font-family: Philosopher, font-weight:700', 'templatation'),
                'google'=> true,
                'font-backup'=>true,
                'text-align'=>false,
                'color'=>false,
                'letter-spacing'=>true,
                'all_styles' => true, // Enable all Google Font style/weight variations to be added to the page
                'output' => array('h5'), // An array of CSS selectors to apply this font style to dynamically
                'units'=>'px', // Defaults to px
                'default' => array(
                    'font-size'=>'',
                    'line-height'=>'',
                    'font-family'=>'',
                    'font-weight'=>'',
                    ),
                ),
            array(
                'id' => $shortname . '_h6_font',
                'type' => 'typography',
                'title' => __('H6 Font.', 'templatation'),
                'subtitle' => __('Specify the H6 font properties. Default  color: #e75a39, font-size: 12px, line-height: 16px, font-family: Philosopher, font-weight:400', 'templatation'),
                'google'=> true,
                'font-backup'=>true,
                'text-align'=>false,
                'color'=>false,
                'letter-spacing'=>true,
                'all_styles' => true, // Enable all Google Font style/weight variations to be added to the page
                'output' => array('h6'), // An array of CSS selectors to apply this font style to dynamically
                'units'=>'px', // Defaults to px
                'default' => array(
                    'font-size'=>'',
                    'line-height'=>'',
                    'font-family'=>'',
                    'font-weight'=>'',
                    ),
                ),
				),

        ));

/*-----------------------------------------------------------------------------------*/
/* Layout Settings                                                                  */
/*-----------------------------------------------------------------------------------*/
    Redux::setSection( $opt_name, array(
        'title' => __( 'Layout (Header/Sidebar)', 'templatation' ),
        'id'               => 'layout-options',
        'desc'   => __( 'Layout Settings for Sidebar and Header.', 'templatation' ),
        'icon'   => 'el el-photo ',
        'customizer_width' => '400px',
        'fields'           => array(

            array(
               'id' => $shortname . '_js_layout',
               'type'     => 'button_set',
               'title'    => __( 'Select FrontEnd Layout', 'templatation' ),
               'subtitle' => __( 'Prior to v6.0 Theme width was 950px. Now as per Modern design trends, this option is added. You can now choose to keep the old 950px width, make it wider to 1170px width.', 'templatation' ),
               'desc'     => __( 'Note : If you updated theme from previous version and decide to change layout width, then you might need to change image sizes in Dynamic images/Thumbnail setting below, and then regenerate thumbnails.', 'templatation' ),
                //Must provide key => value pairs for radio options
                'options'  => array(
                    'js_950' => '950px - Default',
                    'js_1170' => '1170px'
                ),
                'default'  => 'js_1170'
            ),
            array(
                'id' => $shortname . '_site_layout',
                'type'     => 'image_select',
                'title' => __( 'Main Layout', 'templatation' ),
                'subtitle' => __( 'Select which layout you want for your site.', 'templatation' ),
                'desc'     => __( 'Select default sidebar position for the website, you can override this setting on per post/page level too.', 'templatation' ),
                //Must provide key => value(array:title|img) pairs for radio options
                'options'  => array(
                    'layout-right-content' => array(
                        'alt' => '2 Column Left',
                        'img' => ReduxFramework::$_url . 'assets/img/2cl.png'
                    ),
                    'layout-left-content' => array(
                        'alt' => '2 Column Right',
                        'img' => ReduxFramework::$_url . 'assets/img/2cr.png'
                    ),
                ),
                'default'  => 'layout-left-content'
            ),
            array(
                'id' => $shortname . '_header_section_layout',
                'type'     => 'select',
                'title' => __( 'Header layout', 'templatation' ),
                'subtitle' => __( 'Select which header layout you wish for header/menu items area. Please check demo website for example of layouts or you can try changing it. You can always revert back the change easily.', 'templatation' ),
                'default'  => 'layout2',
                'options' => array(
                     'layout2' => __( 'Header Layout 2', 'templatation' ),
                     'layout3' => __( 'Header Layout 3', 'templatation' ),
                     'layout4' => __( 'Header Layout 4', 'templatation' ),
                     'layout5' => __( 'Header Layout 5', 'templatation' ),
                     'layout6' => __( 'Header Layout 6', 'templatation' ),
                     'layout7' => __( 'Header Layout 7', 'templatation' )
                     )
            ),
/*           array(
                'id' => $shortname . '_trans_lay4',
                'type'     => 'switch',
                'title' => __( 'Transparent Layout4 header', 'templatation' ),
                'subtitle' => __( 'Enable transparent header and menus. This only applies if you are using layout 4.', 'templatation' ),
                'default'  => false
           ),*/
           array(
                'id' => $shortname . '_header_height',
                'type'     => 'text',
                'title' => __( 'Header Height', 'templatation' ),
                'subtitle' => __( 'If you want to set your own header height, please enter value. ', 'templatation' ),
                'desc'     => __( 'IMPORTANT NOTE: Please leave it blank if you are not sure what it means. The value you enter here over-rides all other header height values. It only increases header height, you will still need to take care of placement of logo(by logo offset in general settings) and navigation(manually). (Enter 0 or leave blank to return to default). Enter value without px, eg : 100, 150 etc. px automatically added by script. ', 'templatation' )
           ),
           array(
                'id' => $shortname . '_enable_hdr_search',
                'type'     => 'switch',
                'title' => __( 'Show Header Search', 'templatation' ),
                'subtitle' => __( 'Enable/Disable the search bar on right side of Header. It does not fit to all header layouts. It will only show up if you are using layout 6 or layout7.', 'templatation' ),
                'default'  => false
           ),
           array(
                'id' => $shortname . '_js_topbar_notice',
                'type'   => 'info',
                'notice' => false,
                'style'  => 'info',
                'title' => __( 'Toppest Bar Settings', 'templatation' ),
                'desc'   => __( 'Below settings are for the top most navigation bar which is optional. It adds some usual user interface items. There is limited space on this bar , so be careful in choosing what part you really need. You can try it out and disable things later if bar goes out of space.', 'templatation' )
           ),
           array(
                'id' => $shortname . '_enable_topbar',
                'type'     => 'switch',
                'title' => __( 'Enable Top Nav Bar', 'templatation' ),
                'subtitle' => __( 'Enable/Disable the Top most nav bar globally.', 'templatation' ),
                'default'  => true
           ),
           array(
                'id' => $shortname . '_enable_showhide',
                'type'     => 'switch',
                'title' => __( 'Show Hide/Show icon', 'templatation' ),
                'subtitle' => __( 'This icon appears on right corner of the top bar and it enables user to show/hide the bar when clicked. If disabled, top bar will always show.', 'templatation' ),
                'default'  => true,
                'required' => array( $shortname . '_enable_topbar', '=', true )
           ),
           array(
    			'id' => $shortname . '_top_nav_color',
                'type'     => 'color',
                'output'   => array( '.site-title' ),
			 	'title' => __( 'Top Nav Bar Color', 'templatation' ),
                'subtitle' => __( 'Pick a custom color for Top nav bar or add a hex color code. Default: #999999', 'templatation' ),
                'default'  => '#999999',
                'required' => array( $shortname . '_enable_topbar', '=', true )
           ),
           array(
                'id' => $shortname . '_enable_ttext',
                'type'     => 'switch',
                'title' => __( 'Enable Teaser Text', 'templatation' ),
                'subtitle' => __( 'Teaser text is short sentence that you want to highlight. It comes on left most area of top navigation. If you turn it off below 2 settings makes no difference. Default is checked.', 'templatation' ),
                'default'  => true,
                'required' => array( $shortname . '_enable_topbar', '=', true )

           ),
           array(
                'id' => $shortname . '_ttext_icon',
                'type'     => 'media',
                'readonly'    => false,
                'url'      => true,
			 	'title' => __( 'Teaser Text Icon', 'templatation' ),
                'subtitle' => __( 'This icon appears on left side of teaser text. Recommended size : 21 x 21 px.', 'templatation' ),
                'required' => array( $shortname . '_enable_topbar', '=', true )
           ),
           array(
                'id' => $shortname . '_ttext_text',
                'type'     => 'text',
                'title' => __( 'Teaser Text', 'templatation' ),
                'subtitle' => __( 'Teaser text is short sentence that you want to highlight. eg : Our helpline number : xyz. This text appears on left most side of top bar.', 'templatation' ),
                'required' => array( $shortname . '_enable_topbar', '=', true )
           ),
           array(
                'id' => $shortname . '_welcome_text_icon',
                'type'     => 'media',
                'readonly'    => false,
                'url'      => true,
                'title' => __( 'Welcome Text Icon', 'templatation' ),
                'subtitle' => __( 'This icon appears on left side of Login/Register or Welcome. Recommended size : 21 x 21 px.', 'templatation' ),
                'required' => array( $shortname . '_enable_topbar', '=', true )
           ),
           array(
                'id' => $shortname . '_enable_top_social',
                'type'     => 'switch',
                'title' => __( 'Show Social icons', 'templatation' ),
                'subtitle' => __( 'Show social icons on top bar, you can control value of these from Subscribe -> Connect below.', 'templatation' ),
                'default'  => true,
                'required' => array( $shortname . '_enable_topbar', '=', true )
           ),
           array(
                'id' => $shortname . '_enable_lang_dropdown',
                'type'     => 'switch',
                'title' => __( 'Show Language Dropdown', 'templatation' ),
                'subtitle' => __( 'Show lang dropdown, at this time it supports WPML only. It will only work if you have WPML plugin installed and langauges setup in it.', 'templatation' ),
                'default'  => true,
                'required' => array( $shortname . '_enable_topbar', '=', true )
           ),
           array(
                'id' => $shortname . '_enable_top_search',
                'type'     => 'switch',
                'title' => __( 'Show Search', 'templatation' ),
                'subtitle' => __( 'Enable/Disable the search bar on right side of Top nav bar.', 'templatation' ),
                'default'  => true,
                'required' => array( $shortname . '_enable_topbar', '=', true )
           ),
           array(
                'id' => $shortname . '_sc_icons_right',
                'type'     => 'switch',
                'title' => __( 'Stick social icons to right', 'templatation' ),
                'subtitle' => __( 'If you disable search box above , you might want to move social icons to right to avoid blank space on right side of the bar. Leave it unchecked if you are not sure.', 'templatation' ),
                'default'  => true,
                'required' => array( $shortname . '_enable_topbar', '=', true )
           ),

        )
    ));


/*-----------------------------------------------------------------------------------*/
/* Slider & Headline Settings                                                        */
/*-----------------------------------------------------------------------------------*/
    Redux::setSection( $opt_name, array(
        'title'            => __( 'Slider & Headline', 'templatation' ),
        'id'               => 'slider-options1',
        'desc'   => __( 'Slider & Headline Settings.', 'templatation' ),
        'icon'   => 'el el-screen',
        'customizer_width' => '400px',
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => __( 'Slider Settings', 'templatation' ),
        'id'               => 'slider-options2',
        'subsection'       => true,
        'customizer_width' => '450px',
/*        'desc'             => __( 'For full documentation on this field, visit: ', 'templatation' ) . '<a href="//docs.reduxframework.com/core/fields/checkbox/" target="_blank">docs.reduxframework.com/core/fields/checkbox/</a>',*/
        'fields'           => array(

            array(
                'id' => $shortname . '_js_slider_notice',
                'type'   => 'info',
                'notice' => false,
                'style'  => 'info',
                'title' => __( 'Slider & Headline Settings', 'templatation' ),
                'desc'   => __( 'The slider area (or HERO area) is the main highlighted area in the header. You can place slider or any html in this. You can also define separate slider area for each page/post/product from bottom of its editor page.', 'templatation' )
            ),
            array(
                'id' => $shortname . '_enable_slider',
                'type'     => 'switch',
                'title' => __( 'Enable Slider', 'templatation' ),
                'subtitle' => __( 'Enable/Disable the slider globally.', 'templatation' ),
                'default'  => true,
            ),
            array(
                'id' => $shortname . '_slider_area_content',
                'type'     => 'textarea',
                'title' => __( 'Slider area content', 'templatation' ),
                'subtitle' => __( 'Please enter the content you want to show on slider area. Usually you will enter shortcode given by revolution slider here. eg: [rev_slider home]. ', 'templatation' ),
                'desc'     => __( '(For advanced users/developers) if you want, you can use any kind of data/html here and it will be shown on the slider section (Hero Area) instead.', 'templatation' ),
                'validate' => 'html', //see http://codex.wordpress.org/Function_Reference/wp_kses_post
                'default'  => '[rev_slider alias="main"]'
            ),
/*            array(
                'id' => $shortname . '_slider_whole_site',
                'type'     => 'switch',
                'title' => __( 'Show above slider on whole website ?', 'templatation' ),
                'subtitle' => __( 'Do you want to show above slider/Hero area code only on homepage, or on whole website instead. By default this appears only on page with page-template set as "Custom Homepage".', 'templatation' ),
                'desc' => __( 'You can define separate slider/Hero area for particular page from bottom of page editor.', 'templatation' ),
                'default'  => false,
            ),*/

        )
        ));

    Redux::setSection( $opt_name, array(
        'title'            => __( 'Headline Settings', 'templatation' ),
        'id'               => 'slider-options3',
        'subsection'       => true,
        'customizer_width' => '450px',
/*        'desc'             => __( 'For full documentation on this field, visit: ', 'templatation' ) . '<a href="//docs.reduxframework.com/core/fields/checkbox/" target="_blank">docs.reduxframework.com/core/fields/checkbox/</a>',*/
        'fields'           => array(

            array(
                'id' => $shortname . '_headline_notice',
                'type'   => 'info',
                'notice' => false,
                'style'  => 'info',
                'title' => __( 'Headline Setup', 'templatation' ),
                'desc'   => __( 'Headline is the area after header block and before content block. Below are the defaults for Headline area for whole website, these settings can be override by particular page or post editor page settings. ( Feel free to play with it , you can always revert back. ).', 'templatation' )
            ),
            array(
                'id' => $shortname . '_show_headline_global',
                'type'     => 'switch',
                'title' => __( 'Show Headline Section Globally ?', 'templatation' ),
                'subtitle' => __( 'Default: checked, Uncheck to disable. If globally disabled the headline area will not appear anywhere. The settings below and the Headline and heading message setting in single post pages will not make any appearance. If disabled here, it will not show in any case, but if enabled here, you can disable it on single page basis on single post pages too.', 'templatation' ),
                'default'  => true,
            ),
            array(
                'id' => $shortname . '_hdline_bg',
                'type'     => 'background',
                'output'   => array( '#headline' ),
                'title' => __( 'Global Headline background', 'templatation' ),
                'subtitle' => __( 'If you select background here, this will appear in background of headline image on whole website. Note that content appears on this section so background should not be too dominant. recommended: leave blank.', 'templatation' ),
                //'default'   => '#FFFFFF',
            ),
            array(
                'id' => $shortname . '_enable_default_headline',
                'type'     => 'switch',
                'title' => __( 'Enable Default Headline title and message ?', 'templatation' ),
                'subtitle' => __( 'If you enable it you will see boxes to enter default title and message for Headline area. These Title and Message will be show on whole website where specific Title and Message is not defined from single page editor. If you disable it , Breadcrumb will be shown on headline area instead. ( False is recommended if you are not sure about it.) .', 'templatation' ),
                'default'  => true,
            ),
            array(
                'id' => $shortname . '_headline_default_title',
                'type'     => 'text',
                'title' => __( 'Default Headline Title', 'templatation' ),
                'subtitle' => __( 'If you enable Headline and enter title here, it will be shown if no other title is specified in single post/pages.', 'templatation' ),
                'default' => 'Taste our yummy Cakes',
                'required' => array( $shortname . '_enable_default_headline', '=', true )
            ),
            array(
                'id' => $shortname . '_headline_default_message',
                'type'     => 'textarea',
                'title' => __( 'Default Headline Message', 'templatation' ),
                'subtitle' => __( 'If you enable Headline and enter Message here, it will be shown if no other Message is specified in single post/pages.', 'templatation' ),
                'desc'     => __( 'Html is allowed here.', 'templatation' ),
                'validate' => 'html', //see http://codex.wordpress.org/Function_Reference/wp_kses_post
                'default'  => 'All kind of cakes and pastries ready within minutes. Try once. Call xxx-x-xxx Today !',
                'required' => array( $shortname . '_enable_default_headline', '=', true )
            ),
        )
        ));

    Redux::setSection( $opt_name, array(
        'title'            => __( 'Homepage', 'templatation' ),
        'id'               => 'homepage-options1',
        'desc'   => __( 'Homepage Settings.', 'templatation' ),
        'icon'   => 'el el-website',
        'customizer_width' => '400px',
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => __( 'Homepage Settings', 'templatation' ),
        'id'               => 'homepage-options2',
        'subsection'       => true,
        'customizer_width' => '450px',
/*        'desc'             => __( 'For full documentation on this field, visit: ', 'templatation' ) . '<a href="//docs.reduxframework.com/core/fields/checkbox/" target="_blank">docs.reduxframework.com/core/fields/checkbox/</a>',*/
        'fields'           => array(

            array(
                'id' => $shortname . '_homepage_notice',
                'type'   => 'info',
                'notice' => false,
                'style'  => 'info',
                'title' => __( 'Homepage Setup', 'templatation' ),
                'desc'   =>  sprintf( __( 'Note: Below settings only works if you create a page with page template "Custom Homepage" and set it as front page from Settings->Reading. You can optionally customise the homepage product categories section by adding widgets to the "Homepage" widgetized area on the "%sWidgets%s" screen. If you add widgets to "Homepage" widgetized area, it will override "product categories" section of homepage.', 'templatation' ), '<a href="' . esc_url( admin_url( 'widgets.php' ) ) . '">', '</a>' ) ,
            ),
            array(
                'id' => $shortname . '_homepage_enable_product_categories',
                'type'     => 'switch',
                'title' => __( 'Enable Product Categories', 'templatation' ),
                'subtitle' => __( 'Display product categories on the homepage.', 'templatation' ),
                'default'  => true,
            ),
            array(
                'id' => $shortname . '_homepage_about_home_section',
                'type'     => 'switch',
                'title' => __( 'Enable About / Testimonial section', 'templatation' ),
                'subtitle' => __( 'Display About / Testimonial section.', 'templatation' ),
                'default'  => true,
            ),
            array(
                'id' => $shortname . '_homepage_enable_featured_products',
                'type'     => 'switch',
                'title' => __( 'Enable Featured Products', 'templatation' ),
                'subtitle' => __( 'Display featured products on the homepage.', 'templatation' ),
                'default'  => true,
            ),
            array(
                'id' => $shortname . '_homepage_enable_content',
                'type'     => 'switch',
                'title' => __( 'Enable Content Area(Deprecated)', 'templatation' ),
                'subtitle' => __( 'Display the content area with either page content or a list of blog posts.', 'templatation' ),
                'desc' => __( 'Note : From v6.5 you can put content inside the page editor itself ( on the page that is set as Homepage with Custom Homepage page template). Its recommended you keep it off, and use the new page editor option instead.', 'templatation' ),
                'default'  => false,
            ),
            array(
                'id' => $shortname . '_homepage_vc_bottom',
                'type'     => 'switch',
                'title' => __( 'Move Content on bottom.', 'templatation' ),
                'subtitle' => __( 'From v6.5 the Custom Homepage page template also displays the content you put into the page editor. This makes it easy for you to put any Visual composer or custom content on homepage.', 'templatation' ),
                'desc' => __( 'By default, this page editor content shows on the top, Turn it on to show it on bottom instead.', 'templatation' ),
                'default'  => false,
            ),
        )
   ));

    Redux::setSection( $opt_name, array(
        'title'            => __( 'Product Categories', 'templatation' ),
        'id'               => 'product-category',
        'subsection'       => true,
        'customizer_width' => '450px',
/*        'desc'             => __( 'For full documentation on this field, visit: ', 'templatation' ) . '<a href="//docs.reduxframework.com/core/fields/checkbox/" target="_blank">docs.reduxframework.com/core/fields/checkbox/</a>',*/
        'fields'           => array(

            array(
                'id' => $shortname . '_homepage_product_categories_limit',
                'type'          => 'slider',
                'title' => __( 'Number of Product Categories', 'templatation' ),
                'subtitle' => __( 'Select the number of product categories to display on the homepage. Multiples of 3 recommended, eg: 3,6,9', 'templatation' ),
                'default'       => 3,
                'min'           => 1,
                'step'          => 1,
                'max'           => 12,
                'display_value' => 'label'
            ),

        )
   ));

    Redux::setSection( $opt_name, array(
        'title' => __( 'Featured Products', 'templatation' ),
        'id'               => 'featured-products',
        'subsection'       => true,
        'customizer_width' => '450px',
        'fields'           => array(

            array(
                'id' => $shortname . '_homepage_featured_products_title',
                'type'     => 'text',
		        'title' => __( 'Title', 'templatation' ),
                'subtitle' => __( 'Enter the title to display above the Featured products on the homepage.', 'templatation' ),
                'default'  => '',
            ),
            array(
                'id' => $shortname . '_homepage_featured_products_limit',
                'type'          => 'slider',
                'title' => __( 'Number of Products', 'templatation' ),
                'subtitle' => __( 'Select the number of featured products to display on the homepage.', 'templatation' ),
                'default'       => 5,
                'min'           => 1,
                'step'          => 1,
                'max'           => 20,
                'display_value' => 'label'
            ),
        )
   ));


    Redux::setSection( $opt_name, array(
        'title' => __( 'About us / Testimonials', 'templatation' ),
        'id'               => 'aboutus-section',
        'subsection'       => true,
        'customizer_width' => '450px',
        'fields'           => array(

            array(
                'id' => $shortname . '_homepage_about_title',
                'type'     => 'text',
                'title' => __( 'About Title', 'templatation' ),
                'subtitle' => __( 'Enter the title to display in the about us section on homepage.', 'templatation' ),
                'default' => sprintf( __( 'About %s', 'templatation' ), get_bloginfo( 'title' ) ),
            ),
            array(
                'id' => $shortname . '_homepage_about_message',
                'type'     => 'textarea',
                'title' => __( 'About box content', 'templatation' ),
                'subtitle' => __( 'Enter some information about your business here.', 'templatation' ),
                'validate' => 'html', //see http://codex.wordpress.org/Function_Reference/wp_kses_post
                'default' => 'About some information about your business here. You can edit this content from Theme-options -> Homepage settings. <br>Sed diam non ummy nibh in euismod tincidunt ut liber tempor laoreet. Lorem ipsum dolor sit amet, consect etuer adipisc in elit, samo em ipsum dolor sit amet, con in hendrerit in vulputate velit at sectetuer adipisc in elit. Ut wisi enim ad minim veniam, quis nostrud exerci tation ullamcorper suscipit lobortis nisl ut aliquip ex ea comm odo consequat. Duis autem vel eum iriure dolor in hendrerit in vulputate velit esse molestie consequat, vel illum dolore eu feugiat nulla facilisis at vero eros et accumsan et iusto odio dignissim qui blandit praesent luptatum zzril delenit augue duis dolore te feugait nulla facilisi. ittera gothica, quam nunc putamus parumclar am, anteposuerit litterarum formas humanitatis per seacula quarta decima et quinta decima.',
            ),
            array(
                'id' => $shortname.'_homepage_show_testi',
                'type'     => 'switch',
                'title' => __( 'Show Testimonials', 'templatation' ),
                'subtitle' => __( 'Display the Testimonials on the right side of this, if disabled about section flows to full container.', 'templatation' ),
                'default'  => true,
            ),
            array(
                'id' => $shortname . '_homepage_testimonials_area_title',
                'type'     => 'text',
                'title' => __( 'Testimonials Title', 'templatation' ),
                'subtitle' => __( 'Enter the title to display above the testimonials on the homepage.', 'templatation' ),
                'default' => sprintf( __( 'What people say about %s', 'templatation' ), get_bloginfo( 'title' ) ),
            )
        )
   ));


    Redux::setSection( $opt_name, array(
	        'title' => __( 'Content Area', 'templatation' ),
	        'id'               => 'content-area',
	        'subsection'       => true,
	        'customizer_width' => '450px',
	        'fields'           => array(

            array(
                'id' => $shortname . '_homepage_content_type',
                'type'     => 'select',
		        'title' => __( 'Content Type', 'templatation' ),
                'subtitle' => __( 'Determine whether to display the content of a specified page, or your recent blog posts.', 'templatation' ),
	            'options' => array( 'posts' => __( 'Blog Posts', 'templatation' ), 'page' => __( 'Page Content', 'templatation' ) ),
                'default' => 'posts',
            ),
	        array(
                'id' => $shortname . '_homepage_page_id',
                'type'     => 'select',
                'data'     => 'pages',
		        'title' => __( 'Page Content', 'templatation' ),
                'subtitle' => __( 'Select the page to display content from if the homepage content area is enabled.', 'templatation' ),
            ),
            array(
                'id' => $shortname . '_homepage_number_of_posts',
                'type'          => 'slider',
		        'title' => __( 'Number of Blog Posts', 'templatation' ),
                'subtitle' => __( 'Select the number of posts to display if the content type is set to "Blog Posts".', 'templatation' ),
                'default'       => 4,
                'min'           => 0,
                'step'          => 1,
                'max'           => 20,
                'display_value' => 'label'
            ),
            array(
                'id' => $shortname . '_homepage_posts_category',
                'type'     => 'select',
                'data'     => 'categories',
                'multi'    => true,
		        'title' => __( 'Posts Category', 'templatation' ),
                'subtitle' => __( 'Optionally select categories of posts to display if the content type is set to "Blog Posts".', 'templatation' ),
            ),
            array(
                'id' => $shortname.'_homepage_posts_sidebar',
                'type'     => 'switch',
		        'title' => __( 'Show Sidebar', 'templatation' ),
                'subtitle' => __( 'Display the sidebar on the homepage.', 'templatation' ),
                'default'  => false
            ),
        )
   ));

/*-----------------------------------------------------------------------------------*/
/* Portfolio Settings                                                                  */
/*-----------------------------------------------------------------------------------*/
    Redux::setSection( $opt_name, array(
        'title'            => __( 'Portfolio/Cakes', 'templatation' ),
        'id'               => 'portfolio-settings',
        'icon'   => 'el el-braille',
        'customizer_width' => '450px',
        'fields'           => array(

            array(
                'id' => $shortname.'_portfolio_title',
                'type'     => 'text',
		        'title' => __( 'Portfolio Page Title', 'templatation' ),
                'subtitle' => __('The title of your Portfolio Page.', 'templatation'),
                'default' => __( 'Portfolio', 'templatation' ),
            ),
            array(
                'id' => $shortname.'_portfolioitems_rewrite',
                'type'     => 'text',
		        'title' => __( 'Portfolio Items URL Base', 'templatation' ),
                'subtitle' => sprintf( __( 'The base of all portfolio item URLs (re-save the %s after changing this setting).', 'templatation' ), '<a href="' . admin_url( 'options-permalink.php' ) . '">' . __( 'Permalinks', 'templatation' ) . '</a>' ),
                'default' => 'portfolio-items',
            ),
            array(
                'id' => $shortname.'_portfolio_excludenav',
                'type'     => 'text',
		        'title' => __( 'Exclude Galleries from the Portfolio Navigation', 'templatation' ),
	            'subtitle' => __( 'Optionally exclude portfolio galleries from the portfolio gallery navigation switcher. Place the gallery slugs here, separated by commas <br />(eg: one, two, three)', 'templatation' ),
                'default' => '',
            ),
            array(
                'id' => $shortname.'_portfolio_excludesearch',
                'type'     => 'switch',
		        'title' => __( 'Exclude Portfolio Items from Search Results', 'templatation' ),
                'subtitle' => __( 'Exclude portfolio items from results when searching your website.', 'templatation' ),
                'default'  => false
            ),
            array(
                'id' => $shortname.'_portfolio_linkto',
                'type'     => 'select',
		        'title' => __( 'Portfolio Items Link To', 'templatation' ),
                'subtitle' => __( 'Do the portfolio items link to the lightbox, or to the single portfolio item screen?', 'templatation' ),
                'options' => array( 'lightbox' => __( 'Lightbox', 'templatation' ), 'post' => __( 'Portfolio Item', 'templatation' ) ),
                'default' => 'lightbox',
            ),
            array(
                'id' => $shortname.'_portfolio_posts_per_page',
                'type'     => 'text',
		        'title' => __( 'Number of posts to display on "Portfolio" page template', 'templatation' ),
                'subtitle' => __( 'The number of posts to display per page, when pagination is enabled, in the "Portfolio" page template.', 'templatation' ),
                'default' => get_option( 'posts_per_page' ),
            ),
        )
    ));

if ( class_exists( 'woocommerce' ) ) {

    Redux::setSection( $opt_name, array(
        'title'            => __( 'WooCommerce', 'templatation' ),
        'id'               => 'woocommerce-options1',
        'desc'             => __( 'WooCommerce Settings.', 'templatation' ),
        'icon'             => 'el el-shopping-cart-sign',
        'customizer_width' => '400px',
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => __( 'General', 'templatation' ),
        'id'               => 'General-wcsettings',
        'subsection'       => true,
        'customizer_width' => '450px',
/*        'desc'             => __( 'For full documentation on this field, visit: ', 'templatation' ) . '<a href="//docs.reduxframework.com/core/fields/checkbox/" target="_blank">docs.reduxframework.com/core/fields/checkbox/</a>',*/
        'fields'           => array(
            array(
                'id' => $shortname.'_enable_catalog',
                'type'     => 'switch',
                'title' => __( 'Enable Catalog Mode', 'templatation' ),
                'subtitle' => __( 'If enabled, price and cart buttons will not show up. Website will behave like a catalog only with no purchase functionality.', 'templatation' ),
                'default'  => false
            ),
            array(
                'id' => $shortname . '_placeholder_url',
                'type'     => 'media',
                'url'      => true,
                'title' => __( 'Custom Placeholder', 'templatation' ),
                'subtitle' => __( 'Upload a custom placeholder to be displayed when there is no product image.', 'templatation' ),
            ),
            array(
                'id' => $shortname.'_woocommerce_header_cart_link',
                'type'     => 'switch',
                'title' => __( 'Header Cart Icon', 'templatation' ),
                'subtitle' => __( 'If disabled, price and cart buttons will not show up in the Header area. Note: Makes no difference if catalog mode is on above.', 'templatation' ),
                'default'  => false
            ),
            array(
                'id' => $shortname.'_no_hdrcart_popup',
                'type'     => 'switch',
                'title' => __( 'Disable Header Cart Popup', 'templatation' ),
                'subtitle' => __( 'By default, on mouse on, cart icon shows popup of cart items in a popup, check to disable popup.', 'templatation' ),
                'default'  => false
            ),
        )
    ));

    Redux::setSection( $opt_name, array(
        'title' => __( 'Product Archives', 'templatation' ),
        'id'               => 'productarc-wcsettings',
        'subsection'       => true,
        'customizer_width' => '450px',
        'fields'           => array(

            array(
                'id' => $shortname.'_woocommerce_archives_fullwidth',
                'type'     => 'switch',
                'title' => __( 'Shop archives full width?', 'templatation' ),
                'subtitle' => __( 'Display the product archive in a full-width single column format? (The sidebar is removed). Please make sure you have Default page template selected and full width layout selected on bottom of page editor for Shop page.', 'templatation' ),
                'default'  => false
            ),
            array(
                'id' => $shortname . '_woocommerce_product_columns',
                'type'     => 'select',
                'title' => __( 'Product columns', 'templatation' ),
                'subtitle' => __( 'Select how many columns of products you want on product archive pages. Default is 3 and styled well. If you change it, some styling issues  might arise.', 'templatation' ),
                'options' => array( '2', '3', '4', '5' ) ,
                'default'  => '3',
            ),
            array(
                'id' => $shortname.'_woocommerce_products_per_page',
                'type'     => 'text',
                'title' => __( 'Products per page', 'templatation' ),
                'subtitle' => __( 'How many products do you want to display on product archive pages?', 'templatation' ),
                'default' => '12',
            ),
            array(
                'id' => $shortname.'_link_prod_thumb',
                'type'     => 'switch',
                'title' => __( 'Link product thumbnail to product details page too', 'templatation' ),
                'subtitle' => __( 'By default product thumbnail is not linked to product details page, do you want to link it ? Check to link.', 'templatation' ),
                'default'  => false
            ),
            array(
                'id' => $shortname.'_woocommerce_archives_infinite_scroll',
                'type'     => 'switch',
                'title' => __( 'Enable infinite scroll?', 'templatation' ),
                'subtitle' => __( 'Automatically loads the next set of products via AJAX when the user scrolls to the bottom of the page', 'templatation' ),
                'default'  => true
            ),
        )
    ));

    Redux::setSection( $opt_name, array(
        'title' => __( 'Product Details', 'templatation' ),
        'id'               => 'productdet-wcsettings',
        'subsection'       => true,
        'customizer_width' => '450px',
        'fields'           => array(

           array(
                'id' => $shortname.'_woocommerce_related_products',
                'type'     => 'switch',
                'title' => __( 'Display related products', 'templatation' ),
                'subtitle' => __( 'Display related products on the product details page', 'templatation' ),
                'default'  => true
           ),
           array(
                'id' => $shortname . '_woocommerce_related_products_maximum',
                'type'     => 'select',
                'title' => __( 'Maximum related products', 'templatation' ),
                'subtitle' => __( 'The maximum number of related products to display.', 'templatation' ),
                'options' => array( '2', '3', '4', '5', '6', '7', '8' ),
                'default'  => '3',
           ),
           array(
                'id' => $shortname.'_woocommerce_products_fullwidth',
                'type'     => 'switch',
                'title' => __( 'Product details pages full width?', 'templatation' ),
                'subtitle' => __( 'Display the product details in a full-width single column format? (The sidebar is removed)', 'templatation' ),
                'default'  => false
           ),
           array(
                'id' => $shortname.'_default_sharing_button',
                'type'     => 'switch',
                'title' => __( 'Show default sharing button?', 'templatation' ),
                'subtitle' => __( 'Show default Twitter and facebook sharing buttons on single product display page.', 'templatation' ),
                'default'  => true
           ),

        )
    ));
}

/*-----------------------------------------------------------------------------------*/
/* Dynamic Images Settings                                                                  */
/*-----------------------------------------------------------------------------------*/
    Redux::setSection( $opt_name, array(
        'title' => __( 'Dynamic Images', 'templatation' ),
        'id'               => 'dynamic-images',
        'desc'   => __( 'Dynamic Images.', 'templatation' ),
        'icon'   => 'el el-edit',
        'customizer_width' => '400px',
    ) );

    Redux::setSection( $opt_name, array(
        'title' => __( 'Resizer Settings', 'templatation' ),
        'id'               => 'resizer-settings',
        'subsection'       => true,
        'customizer_width' => '450px',
        'fields'           => array(

           array(
                'id' => $shortname . '_post_image_support',
                'type'     => 'switch',
                'title' => __( 'WP Post Thumbnail', 'templatation' ),
                'subtitle' => __( 'Use WordPress post thumbnail to assign a post thumbnail. Will enable the <strong>Featured Image panel</strong> in your post sidebar where you can assign a post thumbnail.', 'templatation' ),
                'default'  => true
            ),
           array(
                'id' => $shortname . '_pis_resize',
                'type'     => 'switch',
                'title' => __( 'WP Post Thumbnail - Dynamic Image Resizing', 'templatation' ),
                'subtitle' => __( 'The post thumbnail will be dynamically resized using native WP resize functionality. <em>(Requires PHP 5.2+)</em>', 'templatation' ),
                'default'  => true
            ),

           array(
                'id' => $shortname . '_pis_hard_crop',
                'type'     => 'switch',
                'title' => __( 'WP Post Thumbnail - Hard Crop', 'templatation' ),
                'subtitle' => __( 'The post thumbnail will be cropped to match the target aspect ratio (only used if "Dynamic Image Resizing" is enabled).', 'templatation' ),
                'default'  => true
            ),

           array(
                'id' => $shortname . '_auto_img',
                'type'     => 'switch',
                'title' => __( 'Automatic Image Thumbnail', 'templatation' ),
                'subtitle' => __( 'If no thumbnail is specifified then the first uploaded image in the post is used. (If you have used full size images as first attachment some styling issues may arise.)', 'templatation' ),
                'default'  => true
            ),
        )
    ));

    Redux::setSection( $opt_name, array(
        'title' => __( 'Thumbnail Settings', 'templatation' ),
        'id'               => 'thumbnail-settings',
        'subsection'       => true,
        'customizer_width' => '450px',
        'fields'           => array(

            array(
                'id' => $shortname . '_thumb_w',
                'type'           => 'dimensions',
                'units'          => array( 'px' ),    // You can specify a unit value. Possible: px, em, %
                'units_extended' => 'true',  // Allow users to select any type of unit
                'title' => __( 'Thumbnail Image Width', 'templatation' ),
                'subtitle' => __( 'Enter an integer value i.e. 610 for the desired image width which will be used when dynamically creating the images. Recommended : keep it default', 'templatation' ),
                'desc' => __( 'Defaults: 610 if using 950px layout, and 775 if using 1170px layout.', 'templatation' ),
                'height'         => false,
                'default'        => array(
                    'width'  => 610,
                    'height' => 100,
                )
            ),
            array(
                'id' => $shortname . '_thumb_h',
                'type'           => 'dimensions',
                'units'          => array( 'px' ),    // You can specify a unit value. Possible: px, em, %
                'units_extended' => 'true',  // Allow users to select any type of unit
                'title' => __( 'Thumbnail Image Height', 'templatation' ),
                'subtitle' => __( 'Enter an integer value i.e. 208 for the desired image height which will be used when dynamically creating the images. Recommended : keep it default', 'templatation' ),
                'width'         => false,
                'default'        => array(
                    'width'  => 200,
                    'height' => 208,
                )
            ),
            array(
                'id' => $shortname . '_thumb_align',
                'type'     => 'select',
                'title' => __( 'Thumbnail Alignment', 'templatation' ),
                'subtitle' => __( 'Select how to align your thumbnails with blog posts listing page.', 'templatation' ),
                'options' => array( 'alignleft' => __( 'Left', 'templatation' ), 'alignright' => __( 'Right', 'templatation' ), 'aligncenter' => __( 'Center', 'templatation' ) ),
                'default' => 'aligncenter',
            ),

            array(
                'id' => $shortname . '_thumb_single',
                'type'     => 'switch',
                'title' => __( 'Single Post - Show Thumbnail', 'templatation' ),
                'subtitle' => __( 'Show the thumbnail in the single post page.', 'templatation' ),
                'default'  => true
            ),
            array(
                'id' => $shortname . '_single_w',
                'type'           => 'dimensions',
                'units'          => array( 'px' ),    // You can specify a unit value. Possible: px, em, %
                'units_extended' => 'true',  // Allow users to select any type of unit
                'title' => __( 'Single Post - Thumbnail Width', 'templatation' ),
                'subtitle' => __( 'Enter an integer value for single post image width. Recommended : keep it default', 'templatation' ),
                'desc' => __( 'Defaults: 610 if using 950px layout, and 775 if using 1170px layout.', 'templatation' ),
                'height'         => false,
                'default'        => array(
                    'width'  => 610,
                    'height' => 100,
                )
            ),
            array(
                'id' => $shortname . '_single_h',
                'type'           => 'dimensions',
                'units'          => array( 'px' ),    // You can specify a unit value. Possible: px, em, %
                'units_extended' => 'true',  // Allow users to select any type of unit
                'title' => __( 'Single Post - Thumbnail Height', 'templatation' ),
                'subtitle' => __( 'Enter an integer value for single post image height. Recommended : keep it default', 'templatation' ),
                'width'         => false,
                'default'        => array(
                    'width'  => 200,
                    'height' => 208,
                )
            ),
            array(
                'id' => $shortname . '_thumb_single_align',
                'type'     => 'select',
                'title' => __( 'Single Post - Thumbnail Alignment', 'templatation' ),
                'subtitle' => __( 'Select how to align your thumbnail with single posts.', 'templatation' ),
                'options' => array( 'alignleft' => __( 'Left', 'templatation' ), 'alignright' => __( 'Right', 'templatation' ), 'aligncenter' => __( 'Center', 'templatation' ) ),
                'default' => 'aligncenter',
            ),
            array(
                'id' => $shortname . '_rss_thumb',
                'type'     => 'switch',
                'title' => __( 'Add thumbnail to RSS feed', 'templatation' ),
                'subtitle' => __( 'Add the the image uploaded via your Custom Settings panel to your RSS feed', 'templatation' ),
                'default'  => false
            ),
            array(
    				'id' => $shortname . '_enable_lightbox',
                'type'     => 'switch',
			 		'title' => __( 'Enable Lightbox', 'templatation' ),
    				'subtitle' => __( 'Enable the PrettyPhoto lighbox script on images within your website\'s content.', 'templatation' ),
                'default'  => false
            ),
        )
    ));

/*-----------------------------------------------------------------------------------*/
/* Footer Settings                                                                  */
/*-----------------------------------------------------------------------------------*/
    Redux::setSection( $opt_name, array(
        'title' => __( 'Footer Customization', 'templatation' ),
        'id'               => 'footer-settings1',
        'customizer_width' => '450px',
        'fields'           => array(

            array(
                'id' => $shortname . '_footer_sidebars',
                'type'     => 'image_select',
                'title' => __( 'Footer Widget Areas', 'templatation' ),
                'subtitle' => __( 'Select how many footer widget areas you want to display.', 'templatation' ),
                'desc'     => __( 'Select default sidebar position for the website, you can override this setting on per post/page level too.', 'templatation' ),
                //Must provide key => value(array:title|img) pairs for radio options
                'options'  => array(
                    '0' => array(
                        'img' => get_template_directory_uri().'/includes/images/footer-widgets-0.png',
                    ),
                    '1' => array(
                        'img' => get_template_directory_uri().'/includes/images/footer-widgets-1.png',
                    ),
                    '2' => array(
                        'img' => get_template_directory_uri().'/includes/images/footer-widgets-2.png',
                    ),
                    '3' => array(
                        'img' => get_template_directory_uri().'/includes/images/footer-widgets-3.png',
                    ),
                    '4' => array(
                        'img' => get_template_directory_uri().'/includes/images/footer-widgets-4.png',
                    ),
                ),
                'default'  => '4'
            ),
            array(
                'id' => $shortname . '_extreme_footer_notice',
                'type'   => 'info',
                'notice' => false,
                'style'  => 'info',
                'title' => __( 'Footer showcase content', 'templatation' ),
                'desc'   => __( 'Below settings are for the showcase area of the footer. Which appears half in the content section and half in the footer section. Separate settings are there for left and right side box. Note: Footer showcase area only appears if footer widgets are present.', 'templatation' )
            ),
            array(
                'id' => $shortname . '_ft_enable_hero',
                'type'     => 'switch',
                'title' => __( 'Enable footer showcase area', 'templatation' ),
                'subtitle' => __( 'Uncheck this if you do not want the footer showcase area (round corner area just above footer widgets area).', 'templatation' ),
                'default'  => true
            ),
            array(
                'id' => $shortname . '_ft_title_left',
                'type'     => 'text',
                'title' => __( 'Title (Left side)', 'templatation' ),
                'subtitle' => __( 'Enter the title to show in Left footer showcase area.', 'templatation' ),
                'default' => 'Title (Left side)',
                'required' => array( $shortname . '_ft_enable_hero', '=', true )
            ),
            array(
                'id' => $shortname . '_ft_icon_bg_left',
                'type'     => 'switch',
                'title' => __( 'Show icon background (Left side)', 'templatation' ),
                'subtitle' => __( 'Do you want to show the icon background ? You might need to disable it if the background doesnt fit well with the image you use below.', 'templatation' ),
                'default'  => true,
                'required' => array( $shortname . '_ft_enable_hero', '=', true )
            ),
            array(
                'id' => $shortname . '_ft_icon_left',
                'type'     => 'media',
                'url'      => true,
                'title' => __( 'Upload icon (Left side)', 'templatation' ),
                'subtitle' => __( 'Upload a icon for left side of footer showcase area. 59x59 px size recommended.', 'templatation' ),
                                'required' => array( $shortname . '_ft_enable_hero', '=', true )

            ),
            array(
                'id' => $shortname . '_ft_content_left',
                'type'     => 'textarea',
                'title' => __( 'Text (Left side)', 'templatation' ),
                'subtitle' => __( 'Enter the content for Left footer showcase area.', 'templatation' ),
                'validate' => 'html', //see http://codex.wordpress.org/Function_Reference/wp_kses_post
                'default' => 'Edit this text and title in Theme-options -> Footer Customization -> Footer showcase content section. Lorem ipsum dolor sit amet, consectetuer adipisc in elit, sed diam non ummy nibh in euismod tincidunt ut liber tempor laoreet.',
                                'required' => array( $shortname . '_ft_enable_hero', '=', true )

            ),
            array(
                'id' => $shortname . '_ft_title_right',
                'type'     => 'text',
                'title' => __( 'Title (Right side)', 'templatation' ),
                'subtitle' => __( 'Enter the title to show in Right footer showcase area.', 'templatation' ),
                'default' => 'Title (Right side)',
                'required' => array( $shortname . '_ft_enable_hero', '=', true )

            ),
            array(
                'id' => $shortname . '_ft_icon_bg_right',
                'type'     => 'switch',
                'title' => __( 'Show icon background (Right side)', 'templatation' ),
                'subtitle' => __( 'Do you want to show the icon background ? You might need to disable it if the background doesnt fit well with the image you use below.', 'templatation' ),
                'default'  => true,
               'required' => array( $shortname . '_ft_enable_hero', '=', true )

            ),
            array(
                'id' => $shortname . '_ft_icon_right',
                'type'     => 'media',
                'url'      => true,
                'title' => __( 'Upload icon (Right side)', 'templatation' ),
                'desc'     => __( 'Basic media uploader with disabled URL input field.', 'templatation' ),
                'subtitle' => __( 'Upload a icon for right side of footer showcase area. 59x59 px size recommended.', 'templatation' ),
                'required' => array( $shortname . '_ft_enable_hero', '=', true )

            ),
            array(
                'id' => $shortname . '_ft_content_right',
                'type'     => 'textarea',
                'title' => __( 'Text (Right side)', 'templatation' ),
                'subtitle' => __( 'Enter the content for Right footer showcase area.', 'templatation' ),
                'validate' => 'html', //see http://codex.wordpress.org/Function_Reference/wp_kses_post
                'default' => 'Edit this text and title in Theme-options -> Footer Customization -> Footer showcase content section. Lorem ipsum dolor sit amet, consectetuer adipisc in elit, sed diam non ummy nibh in euismod tincidunt ut liber tempor laoreet.',
                'required' => array( $shortname . '_ft_enable_hero', '=', true )
            ),

            array(
                'id' => $shortname . '_extreme_footer_notice',
                'type'   => 'info',
                'notice' => false,
                'style'  => 'info',
                'title' => __( 'Extreme footer content', 'templatation' ),
                'desc'   => __( 'Below settings are for the extreme bottom bar content.', 'templatation' )
            ),

           array(
                'id' => $shortname . '_footer_left',
                'type'     => 'switch',
                'title' => __( 'Enable Custom Footer (Left)', 'templatation' ),
                'subtitle' => __( 'Activate to add the custom text below to the theme footer.', 'templatation' ),
                'desc'   => __( 'If turned off, default text will appear.', 'templatation' ),
                'default'  => false
            ),

            array(
                'id' => $shortname . '_footer_left_text',
                'type'     => 'textarea',
                'title' => __( 'Custom Text (Left)', 'templatation' ),
                'subtitle' => __( 'Custom HTML and Text that will appear in the footer of your theme.', 'templatation' ),
                'validate' => 'html', //see http://codex.wordpress.org/Function_Reference/wp_kses_post
                'default'  => ''
            ),

           array(
                'id' => $shortname . '_footer_right',
                'type'     => 'switch',
                'title' => __( 'Enable Custom Footer (Right)', 'templatation' ),
                'subtitle' => __( 'Activate to add the custom text below to the theme footer.', 'templatation' ),
                'desc'   => __( 'If turned off, default text will appear.', 'templatation' ),
                'default'  => false
            ),

            array(
                'id' => $shortname . '_footer_right_text',
                'type'     => 'textarea',
                'title' => __( 'Custom Text (Right)', 'templatation' ),
                'subtitle' => __( 'Custom HTML and Text that will appear in the footer of your theme.', 'templatation' ),
                'validate' => 'html', //see http://codex.wordpress.org/Function_Reference/wp_kses_post
                'default'  => ''
            ),
            array(
                'id' => $shortname . '_extreme_ft_bg',
                'type'     => 'background',
                'output'   => array( '#footer' ),
                'title'    => __( 'Exreme footer Background', 'templatation' ),
                'subtitle' => __( 'Select background image or color for extreme bottom image, the section which is used for copyright info etc.', 'templatation' ),
                'desc' => __( 'Note: If you want to use color only and no image, then you would also need to turn on the option below.', 'templatation' ),
                //'default'   => '#FFFFFF',
            ),

           array(
                'id' => $shortname . '_extreme_ft_trans_bg',
                'type'     => 'switch',
                'title' => __( 'Remove current extreme footer image.)', 'templatation' ),
                'subtitle' => __( 'In case you want to use a color (chosen above) for the extreme footer section, you will need to remove the current bg image to let the color appear.', 'templatation' ),
                'default'  => false
            ),
        )
    ));


/*-----------------------------------------------------------------------------------*/
/* Subscribe Settings                                                                  */
/*-----------------------------------------------------------------------------------*/
    Redux::setSection( $opt_name, array(
        'title' => __( 'Subscribe & Connect', 'templatation' ),
        'id'     => 'subscribe-setting',
        'desc'   => __( 'Subscribe & Connect Settings.', 'templatation' ),
        'icon'   => 'el el-twitter',
        'customizer_width' => '400px',
    ) );

    Redux::setSection( $opt_name, array(
        'title' => __( 'Setup', 'templatation' ),
        'id'               => 'setup-settings',
        'subsection'       => true,
        'customizer_width' => '450px',
        'fields'           => array(

            array(
                'id' => $shortname . '_connect',
                'type'     => 'switch',
                'title' => __( 'Enable Subscribe & Connect - Single Post', 'templatation' ),
                'subtitle' => sprintf( __( 'Enable the subscribe & connect area on single posts. You can also add this as a %1$s in your sidebar.', 'templatation' ), '<a href="' . esc_url( home_url() ) . '/wp-admin/widgets.php">widget</a>' ),
                'default'  => false
            ),
            array(
                'id' => $shortname . '_connect_title',
                'type'     => 'text',
                'title' => __( 'Subscribe Title', 'templatation' ),
                'subtitle' => __( 'Enter the title to show in your subscribe & connect area.', 'templatation' ),
                'default'  => '',
            ),
            array(
                'id' => $shortname . '_connect_content',
                'type'     => 'textarea',
                'title' => __( 'Text', 'templatation' ),
                'subtitle' => __( 'Change the default text in this area.', 'templatation' ),
                'validate' => 'html', //see http://codex.wordpress.org/Function_Reference/wp_kses_post
                'default'  => ''
            ),
/*           array(
                'id' => $shortname . '_connect_related',
                'type'     => 'switch',
                'title' => __( 'Enable Related Posts', 'templatation' ),
                'subtitle' => __( 'Enable related posts in the subscribe area. Uses posts with the same <strong>tags</strong> to find related posts. Note: Will not show in the Subscribe widget.', 'templatation' ),
                'default'  => true
            ),*/
        )
    ));



    Redux::setSection( $opt_name, array(
        'title' => __( 'Subscribe Settings', 'templatation' ),
        'id'               => 'subscribe-settings',
        'subsection'       => true,
        'customizer_width' => '450px',
        'fields'           => array(

            array(
                'id' => $shortname . '_connect_newsletter_id',
                'type'     => 'text',
                'title' => __( 'Subscribe By E-mail ID (Feedburner)', 'templatation' ),
                'subtitle' => sprintf( __( 'Enter your %1$s for the e-mail subscription form.', 'templatation' ), '<a href="http://www.templatation.com/tutorials/how-to-find-your-feedburner-id-for-email-subscription/">'.__( 'Feedburner ID', 'templatation' ).'</a>' ),
                'default'  => '',
            ),
            array(
                'id' => $shortname . '_connect_mailchimp_list_url',
                'type'     => 'text',
                'title' => __( 'Subscribe By E-mail to MailChimp', 'templatation', 'templatation' ),
                'subtitle' => sprintf( __( 'If you have a MailChimp account you can enter the MailChimp Signup Form URL. It can be found in Mailchimp / Lists / Select list / Signup forms / General Forms. eg:  http://eepurl.com/bShnOb.', 'templatation' ), '<a href="http://woochimp.heroku.com" target="_blank">'.__( 'MailChimp List Subscribe URL', 'templatation' ).'</a>' ),
                'default'  => '',
            ),
        )
    ));


/*-----------------------------------------------------------------------------------*/
/* Social Settings                                                                  */
/*-----------------------------------------------------------------------------------*/
    Redux::setSection( $opt_name, array(
        'title' => __( 'Social / Connect Settings', 'templatation' ),
        'id'               => 'connect-settings',
        'subsection'       => true,
        'customizer_width' => '450px',
        'fields'           => array(

            array(
                'id' => $shortname . '_connect_rss',
                'type'     => 'switch',
                'title' => __( 'Enable RSS', 'templatation' ),
                'subtitle' => __( 'Enable the subscribe and RSS icon.', 'templatation' ),
                 'default'  => true
            ),
            array(
                'id' => $shortname . '_connect_twitter',
                'type'     => 'text',
                'title' => __( 'Twitter URL', 'templatation' ),
                'subtitle' => sprintf( __( 'Enter your %1$s URL e.g. http://www.twitter.com/templatation', 'templatation' ), '<a href="http://www.twitter.com/">'.__( 'Twitter', 'templatation' ).'</a>' ),
                'default'  => '',
            ),
            array(
                'id' => $shortname . '_connect_facebook',
                'type'     => 'text',
                'title' => __( 'Facebook URL', 'templatation' ),
                'subtitle' => sprintf( __( 'Enter your %1$s URL e.g. http://www.facebook.com/templatation', 'templatation' ), '<a href="http://www.facebook.com/">'.__( 'Facebook', 'templatation' ).'</a>' ),
                'default'  => '',
            ),
            array(
                'id' => $shortname . '_connect_youtube',
                'type'     => 'text',
                'title' => __( 'YouTube URL', 'templatation' ),
                'subtitle' => sprintf( __( 'Enter your %1$s URL e.g. http://www.youtube.com/templatation', 'templatation' ), '<a href="http://www.youtube.com/">'.__( 'YouTube', 'templatation' ).'</a>' ),
                'default'  => '',
            ),
            array(
                'id' => $shortname . '_connect_flickr',
                'type'     => 'text',
                'title' => __( 'Flickr URL', 'templatation' ),
                'subtitle' => sprintf( __( 'Enter your %1$s URL e.g. http://www.flickr.com/templatation', 'templatation' ), '<a href="http://www.flickr.com/">'.__( 'Flickr', 'templatation' ).'</a>' ),
                'default'  => '',
            ),
            array(
                'id' => $shortname . '_connect_linkedin',
                'type'     => 'text',
                'title' => __( 'LinkedIn URL', 'templatation' ),
                'subtitle' => sprintf( __( 'Enter your %1$s URL e.g. http://www.linkedin.com/in/templatation', 'templatation' ), '<a href="http://www.www.linkedin.com.com/">'.__( 'LinkedIn', 'templatation' ).'</a>' ),
                'default'  => '',
            ),
            array(
                'id' => $shortname . '_connect_pinterest',
                'type'     => 'text',
                'title' => __( 'Pinterest URL', 'templatation' ),
                'subtitle' => sprintf( __( 'Enter your %1$s URL e.g. http://www.pinterest.com/templatation', 'templatation' ), '<a href="http://www.pinterest.com/">'.__( 'Pinterest', 'templatation' ).'</a>' ),
                'default'  => '',
            ),
            array(
                'id' => $shortname . '_connect_instagram',
                'type'     => 'text',
                'title' => __( 'Instagram URL', 'templatation' ),
                'subtitle' => sprintf( __( 'Enter your %1$s URL e.g. http://www.instagram.com/templatation', 'templatation' ), '<a href="http://www.instagram.com/">'.__( 'Instagram', 'templatation' ).'</a>' ),
                'default'  => '',
            ),
            array(
                'id' => $shortname . '_connect_googleplus',
                'type'     => 'text',
                'title' => __( 'Google+ URL', 'templatation' ),
                'subtitle' => sprintf( __( 'Enter your %1$s URL e.g. https://plus.google.com/104560124403688998123/', 'templatation' ), '<a href="http://plus.google.com/">'.__( 'Google+', 'templatation' ).'</a>' ),
                'default'  => '',
            ),
        )
    ));


/*-----------------------------------------------------------------------------------*/
/* Contact Settings                                                                  */
/*-----------------------------------------------------------------------------------*/
    Redux::setSection( $opt_name, array(
        'title' => __( 'Contact Page', 'templatation' ),
        'id'               => 'contact-setting',
        'desc'   => __( 'Contact Settings.', 'templatation' ),
        'icon'   => 'el el-envelope',
        'customizer_width' => '400px',
    ) );

    Redux::setSection( $opt_name, array(
        'title' => __( 'Contact Information', 'templatation' ),
        'id'               => 'contact-settings1',
        'subsection'       => true,
        'customizer_width' => '450px',
        'fields'           => array(

            array(
                'id' => $shortname.'_contact_panel',
                'type'     => 'switch',
                'title' => __( 'Enable Contact Information Panel', 'templatation' ),
                'subtitle' => __( 'Enable the contact informal panel', 'templatation' ),
                'default'  => false
            ),
            array(
                'id' => $shortname . '_contact_title',
                'type'     => 'text',
                'title' => __( 'Location Name', 'templatation' ),
                'subtitle' => __( 'Enter the location name. Example: London Office', 'templatation' ),
                'default'  => '',
                'required' => array( $shortname . '_contact_panel', '=', true )
            ),
            array(
                'id' => $shortname . '_contact_address',
                'type'     => 'textarea',
                'title' => __( 'Location Address', 'templatation' ),
                'subtitle' => __( "Enter your company's address", 'templatation' ),
                'validate' => 'html', //see http://codex.wordpress.org/Function_Reference/wp_kses_post
                'default'  => '',
                'required' => array( $shortname . '_contact_panel', '=', true )

            ),
            array(
                'id' => $shortname . '_contact_number',
                'type'     => 'text',
                'title' => __( 'Telephone', 'templatation' ),
                'subtitle' => __( 'Enter your telephone number', 'templatation' ),
                'default'  => '',
                'required' => array( $shortname . '_contact_panel', '=', true )


            ),
            array(
                'id' => $shortname . '_contact_fax',
                'type'     => 'text',
                'title' => __( 'Fax', 'templatation' ),
                'subtitle' => __( 'Enter your fax number', 'templatation' ),
                'default'  => '',
                'required' => array( $shortname . '_contact_panel', '=', true )

            ),
            array(
                'id' => $shortname.'_contactform_email',
                'type'     => 'text',
                'title' => __( 'Contact Form E-Mail', 'templatation' ),
                'subtitle' => __( "Enter your E-mail address to use on the 'Contact Form' page Template.", 'templatation' ),
                'default'  => '',
            ),
            array(
                'id' => $shortname . '_contact_twitter',
                'type'     => 'text',
                'title' => __( 'Your Twitter Shortcode(since version 5.3)', 'templatation' ),
                'subtitle' => __( 'The inbuilt twitter facility has been discountinued due to security reasons. You can use any plugin for twitter needs and enter the supplied shortcode to display tweets here.(recommended plugin: Twitter Widget Pro) enter shortcode eg : [twitter-widget username="yourTwitterUsername"]. Note: This will not work if shortcode is not valid. Contact support for more info.', 'templatation' ),
                'default'  => '',
            ),
            array(
                'id' => $shortname.'_contact_subscribe_and_connect',
                'type'     => 'switch',
                'title' => __( 'Enable Subscribe and Connect', 'templatation' ),
                'subtitle' => __( 'Enable the subscribe and connect functionality on the contact page template', 'templatation' ),
                'default'  => false
            ),
           array(
                'id' => $shortname . '_contact_pluginSC1',
                'type'     => 'switch',
                'title' => esc_html__( 'Use External Form Plugin?', 'templatation' ),
                'subtitle' => esc_html__( 'If you have trouble making the default form work or want more flexibility. Its recommended you use external plugin for contact form. You can try Ninja form plugin or Visual form builder. (Just google the name to get them). Recommended Ninja Form', 'templatation' ),
                'default'  => true,
                'required' => array( $shortname . '_enable_topbar', '=', true )
           ),
            array(
                'id' => $shortname . '_contact_pluginSC',
                'type'     => 'text',
                'title' => esc_html__( 'Enter Shortcode', 'templatation' ),
                'subtitle' => esc_html__( 'Enter Shortcode here provided by plugin.', 'templatation' ),
                'desc' => esc_html__( 'eg: [ninja_forms id=1] for ninja forms, or [vfb id=1] for visual form builder. Change the 1 with the form id. Note: This will not work if shortcode is not valid. Contact support for more info.', 'templatation' ),
                'default'  => '',
            ),
        )
    ));


    Redux::setSection( $opt_name, array(
        'title' => __( 'Maps', 'templatation' ),
        'id'               => 'map-settings1',
        'subsection'       => true,
        'customizer_width' => '450px',
        'fields'           => array(

            array(
                'id' => $shortname.'_headline_gmap',
                'type'     => 'switch',
                'title' => __( 'Show map in headline area.', 'templatation' ),
                'subtitle' => __( 'If checked, google map will show up in headline area behind the header. If unchecked google map will show up in the middle of the page. Note google map shows up only if you enter coordinates below.', 'templatation' ),
                'default'  => true,
            ),
           array(
                'id' => $shortname . '_gmap_api',
                'type'     => 'text',
                'title' => esc_html__( 'Google Map API Text', 'templatation' ),
                'desc'  => sprintf( esc_html__( '%1$s for complete instructions to get an API key from Google itself.', 'templatation' ), '<a href="https://developers.google.com/maps/documentation/javascript/get-api-key">' . esc_html__( 'Click here', 'templatation' ) . '</a>' ),
                'subtitle' => esc_html__( 'Since June 2016, Google requires an API key for displaying maps.', 'templatation' ),
           ),
            array(
                'id' => $shortname . '_contactform_map_coords',
                'type'     => 'text',
                'title' => __( 'Contact Form Google Maps Coordinates', 'templatation' ),
                'subtitle' => sprintf( __( 'Enter your Google Map coordinates to display a map on the Contact Form page template. You can get coordinates details from %1$s', 'templatation' ), '<a href="http://www.mapcoordinates.net/en/" target="_blank">'.__( 'Here', 'templatation' ).'</a>' ),
                'default'  => '',
            ),
            array(
                'id' => $shortname . '_maps_scroll',
                'type'     => 'switch',
                'title' => __( 'Disable Mousescroll', 'templatation' ),
                'subtitle' => __( 'Turn off the mouse scroll action for all the Google Maps on the site. This could improve usability on your site.', 'templatation' ),
                'default'  => true
            ),
            array(
                'id' => $shortname . '_maps_single_height',
                'type'     => 'text',
                'title' => __( 'Map Height', 'templatation' ),
                'subtitle' => __( 'Height in pixels for the maps displayed on Single.php pages.', 'templatation' ),
                'default' => '250',
            ),
            array(
                'id' => $shortname . '_maps_default_mapzoom',
                'type'          => 'slider',
                'title' => __( 'Default Map Zoom Level', 'templatation' ),
                'subtitle' => __( 'Set this to adjust the default in the post & page edit backend.', 'templatation' ),
                'default'       => 9,
                'min'           => 1,
                'step'          => 1,
                'max'           => 20,
                'display_value' => 'label'
            ),
            array(
                'id' => $shortname . '_maps_default_maptype',
                'type'     => 'select',
                'title' => __( 'Default Map Type', 'templatation' ),
                'subtitle' => __( 'Set this to the default rendered in the post backend.', 'templatation' ),
                'options' => array( 'G_NORMAL_MAP' => __( 'Normal', 'templatation' ), 'G_SATELLITE_MAP' => __( 'Satellite', 'templatation' ),'G_HYBRID_MAP' => __( 'Hybrid', 'templatation' ), 'G_PHYSICAL_MAP' => __( 'Terrain', 'templatation' ) ),
                'default' => 'G_NORMAL_MAP',
            ),
            array(
                'id' => $shortname . '_maps_callout_text',
                'type'     => 'textarea',
                'title' => __( 'Map Callout Text', 'templatation' ),
                'subtitle' => __( 'Text or HTML that will be output when you click on the map marker for your location.', 'templatation' ),
                'validate' => 'html', //see http://codex.wordpress.org/Function_Reference/wp_kses_post
                'default'  => ''
            ),
        )
    ));

/*-----------------------------------------------------------------------------------*/
/* Included Plugins                                                                 */
/*-----------------------------------------------------------------------------------*/
    Redux::setSection( $opt_name, array(
        'title' => __( 'Included Plugins', 'templatation' ),
        'id'               => 'included-plugins',
        'customizer_width' => '450px',
        'fields'           => array(

            array(
                'id' => $shortname . '_inc_plugins',
                'type'   => 'info',
                'notice' => false,
                'style'  => 'info',
                'title' => __( 'Included Plugins', 'templatation' ),
                'desc'   => sprintf( __( 'The theme requires/recommends some plugin to function properly. Theme also includes some premium plugins with your purchase, to manage plugins, please %1$s. (or find them in Appearance -> Install plugins ).', 'templatation' ), '<a href="' . esc_url( home_url() ) . '/wp-admin/themes.php?page=tgmpa-install-plugins">'.__( 'Click Here', 'templatation' ).'</a>' ),
            ),
        )
    ));

    Redux::setSection( $opt_name, array(
        'title' => __( 'Plugin Updates', 'templatation' ),
        'id'               => 'included-plugins-updates',
        'subsection'       => true,
        'customizer_width' => '450px',
        'fields'           => array(

            array(
                'id' => $shortname . '_inc_plugin_updates',
                'type'   => 'info',
                'notice' => false,
                'style'  => 'info',
                'title' => __( 'Updates of Included Plugins', 'templatation' ),
                'desc'   => sprintf( __( 'Sometimes you will see notices of update available for included plugins. Please note, the license key you have for the theme, will not work with included plugin updates. They are packaged with the theme with their author permission. Its my responsibility to provide you update and support for those plugins too. I try to update theme too as soon as plugin gets updated. So all you need to do to update included plugins is, Update the theme, Go to Appearance -> Install plugins, Click update link on relevant plugin.', 'templatation' ), '<a href="' . esc_url( home_url() ) . '/wp-admin/themes.php?page=tgmpa-install-plugins">'.__( 'Click Here', 'templatation' ).'</a>' ),
            ),
        )
    ));

   Redux::setSection( $opt_name, array(
        'title'  => __( 'Theme Updates', 'templatation' ),
        'id'     => 'theme-update',
        'icon'   => 'el el-refresh',
        'customizer_width' => '450px',
/*        'desc'             => __( 'For full documentation on this field, visit: ', 'templatation' ) . '<a href="//docs.reduxframework.com/core/fields/checkbox/" target="_blank">docs.reduxframework.com/core/fields/checkbox/</a>',*/
        'fields' => array(

            array(
                'id' => $shortname . '_theme_update',
                'type'   => 'info',
                'notice' => false,
                'style'  => 'info',
                'title' => __( 'Theme Update', 'templatation' ),
                'desc'   => sprintf( __( 'The theme is regularly updated with new features and other bug fixes and improvement. Note if you modified any theme files, it will be overwritten with update. Again, make sure to keep regular backups. You can use awesome free plugin named updraftplus ( %1$s ) to create backups periodically(automatically) without hassles.', 'templatation' ), '<a href="https://wordpress.org/plugins/updraftplus/">'.__( 'Click Here', 'templatation' ).'</a>' ),
            ),
            array(
                'id' => $shortname . '_theme_update1',
                'type'   => 'info',
                'notice' => false,
                'style'  => 'alert',
                'title' => __( 'How to Update!', 'templatation' ),
                'desc'   => sprintf( __( 'Earlier I used a third party service for automatic updates once setup. But Recently Themeforest created their own plugin to streamline theme/plugin updates on whole Envato system. You need to activate/setup Envato plugin once and then can always update in future with 1 click.  <br />Have not purchased yet ? It took over an year to build this theme and its still being worked on. Please support the development if you like it and use it. It doesnt cost much. :). Precious customers and  fans, if you are very happy and want to support us even more, you can purchase again as well. %1s', 'templatation' ), '<a href="http://themeforest.net/item/justshop-cake-bakery-wordpress-theme/4747148?ref=templatation">'.__( 'Go to Justshop Home', 'templatation' ).'</a>' ),
            ),
/*            array(
                'id' => $shortname . '_lic_key',
                'type'     => 'text',
                'title'    => __( 'Themeforest Purchase Key', 'templatation' ),
                'subtitle'    => __( 'Once you enter valid purchase code and save. You can update theme easily in future with 1 click by going to Dashboard > Updates. No more downloading from Themeforest required.', 'templatation' ),
                'desc' => sprintf( __( 'Enter your purchase key here, if you are unsure how to find it, please check video below. <p>e.g. xxxx-xxxx-xxxx-xxxx-xxxx</p><p></p> %1$s', 'templatation' ), '<iframe width="420" height="315" src="https://www.youtube.com/embed/Sv5VaORIS3A" frameborder="0" allowfullscreen></iframe>' ),
                'default'  => '',
            ),*/
            array(
                'id' => $shortname . '_theme_update3',
                'type'   => 'info',
                'notice' => false,
                'style'  => 'info',
                'title' => __( 'Envato plugin', 'templatation' ),
                'desc'   => sprintf( __( '%1s download envato plugin, once you activate it, you will see Envato Market link on left bar. Its easy to setup thereafter. Once setup you can manage all your Envato market purchases and 1 click install/update.', 'templatation' ), '<a href="http://envato.github.io/wp-envato-market/dist/envato-market.zip">'.__( 'Click Here to download', 'templatation' ).'</a>' ),
            ),
        ),
    ));

/*-----------------------------------------------------------------------------------*/
/* System page template                                                              */
/*-----------------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------------*/
/*    Redux::setSection( $opt_name, array(
        'title' => __( 'System Page Templates', 'templatation' ),
        'id'               => 'sys-page-templates',
        'customizer_width' => '450px',
        'fields'           => array(
            array(
                'id' => $shortname . '_sys_templates',
                'type'   => 'info',
                'notice' => false,
                'style'  => 'info',
                'title' => __( 'System Page Templates', 'templatation' ),
                'desc'   => sprintf( __( 'In this theme, you can customize system pages as well. System pages like 404, search page, archive page etc. You can create structure of them using drag and drop front end page builder( live composer ). You can create your own template by going %1$s. After that you can define that newly constructed page below on this page. For example, if you want your customized Search page, go %1$s create a new page develop its content in front end. Then come here and select that page in Search page below.', 'templatation' ), '<a href="' . esc_url( home_url() ) . '/wp-admin/edit.php?post_type=tt_misc">'.__( 'here', 'templatation' ).'</a>' ),
            ),

            array(
                'id' => $shortname . '_lic_key',
                'type'     => 'select',
                'data'     => 'tt_misc',
                'title'    => __( 'Search Page template', 'templatation' ),
                'label'     => __( 'This is the template for Search page.', 'templatation' ),
            ),
        )
    ));*/

        /*
     * <--- END SECTIONS
     */

