<?php
if ( ! defined( 'ABSPATH' ) ) exit;
$tt_options = get_option( 'tt_options' );

/*-----------------------------------------------------------------------------------

TABLE OF CONTENTS

- Theme Setup
- Load style.css in the <head>
- Load responsive <meta> tags in the <head>
- Add custom styling to HEAD
- Add custom typograhpy to HEAD
- Add layout to body_class output
- woo_feedburner_link
- Optionally load top ad section into the header.
- Optionally load top navigation.
- Optionally load custom logo.
- Add custom CSS class to the <body> tag if the lightbox option is enabled.
- Load PrettyPhoto JavaScript and CSS if the lightbox option is enabled.
- Customise the default search form
- Load responsive IE scripts
- Control homepage content

-----------------------------------------------------------------------------------*/

/*-----------------------------------------------------------------------------------*/
/* Theme Setup */
/*-----------------------------------------------------------------------------------*/
/**
 * Theme Setup
 *
 * This is the general theme setup, where we add_theme_support(), create global variables
 * and setup default generic filters and actions to be used across our theme.
 *
 * @package wooFramework
 * @subpackage Logic
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 *
 * Used to set the width of images and content. Should be equal to the width the theme
 * is designed for, generally via the style.css stylesheet.
 */

if ( ! isset( $content_width ) ) $content_width = 1170;

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support for post thumbnails.
 *
 * To override templatation_setup() in a child theme, add your own templatation_setup to your child theme's
 * functions.php file.
 *
 * @uses add_theme_support() To add support for automatic feed links.
 * @uses add_editor_style() To style the visual editor.
 */

add_action( 'after_setup_theme', 'templatation_setup' );

if ( ! function_exists( 'templatation_setup' ) ) {
	function templatation_setup () {

		// This theme styles the visual editor with editor-style.css to match the theme style.
		if ( locate_template( 'editor-style.css' ) != '' ) { add_editor_style(); }

		// Add default posts and comments RSS feed links to head
		add_theme_support( 'automatic-feed-links' );

		if ( is_child_theme() ) {
			$theme_data = wp_get_theme();
			define( 'CHILD_THEME_URL', trailingslashit( get_stylesheet_directory_uri() ) );
			define( 'CHILD_THEME_NAME', $theme_data->name );
		}
		
		// @justshop function hooking.
		add_action( 'woo_content_before', 'templatation_headline_area', 10 ); // adding custom style for headline area
		add_action( 'wp_head', 'justshop_slider_cont', 10 ); // hooking function for slider setup.
		// Register js_contactwidget shortcode
		add_shortcode('contactwidget', 'js_contactwidget');
		add_shortcode('rmc-menu', 'rmc_display_menu'); // Menucard shortcode
		add_shortcode('sidenav', 'templatation_sidenav'); // Sidebar nav
		add_shortcode('sidenav_content', 'templatation_sidenav_content'); // Sidebar content SC
		add_shortcode('TT-teaser', 'templatation_teaser'); // Teaser text.
		add_shortcode('TT-latestproducts', 'templatation_latestproducts'); // Latest products shortcode.
		add_shortcode('TT-featuredproducts', 'templatation_featuredproducts'); // Featured products shortcode.
		//add_shortcode('TT-team', 'templatation_team'); // Team text.
		add_shortcode('TT-headline', 'templatation_headline');
		add_shortcode('TT-productcategories', 'templatation_productcategories'); // extending woocommerce's [product_categories] SC
		add_shortcode('TT-productcategory', 'templatation_productcategory'); // extending woocommerce's [product_category] SC
		add_shortcode('TT-carouselproducts', 'templatation_carouselproducts'); 
		add_shortcode('TT-fa', 'fa_shortcode_icon');
        add_shortcode( 'related_posts', 'woo_shortcode_related_posts' );
	}
}

/*-----------------------------------------------------------------------------------*/
/* Visual Composer Stuff */
/*-----------------------------------------------------------------------------------*/
define('BSF_6892199_NOTICES', false);
define('ULTIMATE_USE_BUILTIN', 'true');
add_action( 'init', 'tt_vcSetAsTheme' );
function tt_vcSetAsTheme() {
	if (function_exists('vc_set_as_theme')) vc_set_as_theme( true ) ;
}

function templatation_vc_row_and_vc_column($class_string, $tag) { return $class_string; }

// Filter to Replace default css class for vc_row shortcode and vc_column
add_filter('vc_shortcodes_css_class', 'templatation_vc_row_and_vc_column', 10, 2);

// Ext VC
if (class_exists('WPBakeryVisualComposerAbstract')) {
	require_once locate_template('/includes/tt-vc-extend/tt-vc-extend.php');
}



/**
 * Set the default Google Fonts used in theme.
 *
 * Used to set the default Google Fonts used in the theme, when Custom Typography is disabled.
 */

global $default_google_fonts;
$default_google_fonts = array( 'Droid Serif', 'Droid Sans' );

/*-----------------------------------------------------------------------------------*/
/* CS meta boxes override                                                            */
/*-----------------------------------------------------------------------------------*/
// framework options filter example
function tt_meta_boxes_options( $options ) {

  $options      = array(); // remove old options

// -----------------------------------------
// Page Metabox Options                    -
// -----------------------------------------

$options[]    = array(
  'id'        => '_tt_meta_page_opt',
  'title'     => 'Page Options',
  'post_type' => 'page',
  'context'   => 'normal',
  'priority'  => 'default',
  'sections'  => array(

    // begin: a section
    array(
      'name'  => 'section_1',
      'title' => 'General Settings',
      'icon'  => 'fa fa-cog',

      // begin: fields
      'fields' => array(

        array(
          'id'    => '_hide_title_display',
          'type'  => 'switcher',
          'title' => __( 'Hide default title display in middle content area.', 'templatation' ),
          'label' => __( 'In some case, you might want to hide the default title display. Check this to hide title. If you are not sure about it , leave it unchecked. N/A for woocommerce products.', 'templatation' ),
          'default' => false
        ),

						array(
							'id'      => '_single_enable_hero',
							'type'    => 'switcher',
							'title'   => esc_html__( 'Enable Hero section on this page (Since v7.0)', 'templatation' ),
							'label'   => esc_html__( 'Hero section appears after header and before content area. If you choose Custom Homepage template, please note then the Hero section is controlled from Themeoptions/Slider', 'templatation' ),
							'default' => false
						),
						array(
							'id'         => '_single_headline_title',
							'type'       => 'text',
							'title'      => esc_html__( 'Main Title.', 'templatation' ),
							'desc'      => esc_html__( 'Appears as highlight text in Hero section. If left blank, displays page title as default.', 'templatation' ),
							'dependency' => array( '_single_enable_hero', '==', 'true' ),
						),
						array(
							'id'         => '_single_headline_desc',
							'type'       => 'textarea',
							'title'      => esc_html__( 'Description(Optional).', 'templatation' ),
							'desc'      => esc_html__( 'Appears below highlight text in Hero section.', 'templatation' ),
							'dependency' => array( '_single_enable_hero', '==', 'true' ),
						),
						array(
							'id'    => '_single_page_img',
							'type'  => 'upload',
							'title' => esc_html__( 'Hero area background', 'templatation' ),
							'desc'  => esc_html__( 'This image appears in background of hero section above. As the text is light, dark image is suggested. Recommended image size is 1300x400 px.', 'templatation' ),
							'dependency' => array( '_single_enable_hero', '==', 'true' ),
						),
						array(
						  'id'      => '_single_page_color',
						  'type'    => 'color_picker',
						  'title'   => esc_html__( 'Background color.', 'templatation' ),
						  'desc'    => esc_html__( 'You can choose to have background color, also, if you make this color transparent, it will work as overlay color on the image chosen above.', 'templatation' ),
						  'default' => '',
						  'rgba'    => true,
						  'dependency' => array( '_single_enable_hero', '==', 'true' ),
						),

        array(
          'id'    => '_single_page_slider',
          'type'  => 'textarea',
          'title' => __( 'Hero/Slider Area Content(backword compatibility).', 'templatation' ),
          'desc' => __( 'This content appears on the header area, you can use it to place slider particular for this page/post/product or any other image or content. Shortcodes allowed. IF YOU ENTER ANYTHING HERE, THE ABOVE HERO SETTINGS WILL BE OVERWRITTEN. e.g. [rev_slider portfolio-slider].', 'templatation' ),
        ),

      array(
        'id'        => '_layout',
        'type'      => 'image_select',
        'title'     => 'Content Layout',
        'desc' => __( 'Select content area and sidebar layout for this perticular page. This overrides the global setting in themeoptions/layout.', 'templatation' ),
        'options'   => array(
          'layout-default'    => get_template_directory_uri() .'/functions/images/layout-off.png',
          'layout-full'    => get_template_directory_uri() .'/functions/images/1c.png',
          'layout-left-content'    => get_template_directory_uri() .'/functions/images/2cl.png',
          'layout-right-content'    => get_template_directory_uri() .'/functions/images/2cr.png',
        ),
        'default'   => 'layout-left-content',
      ),


      ), // end: fields
    ), // end: a section

    // begin: a section
    array(
      'name'  => 'section_2',
      'title' => 'Headline Settings',
      'icon'  => 'fa fa-cog',

      // begin: fields
      'fields' => array(

        array(
          'id'    => '_single_disable_headline',
          'type'  => 'switcher',
          'title' => __( 'Disable headline area from this page', 'templatation' ),
          'label' => __( 'Headline is some intro text on the top of the page. If disabled the headline area will not appear on this post/page. The settings below will not make any difference if this is globally disabled from theme options panel. Check to disable. If disabled , breadcrumb will be shown on headline area instead.', 'templatation' ),
          'default' => false
        ),

        array(
          'id'    => '_single_headline_heading',
          'type'  => 'text',
          'title' => __( 'Heading Title.', 'templatation' ),
          'desc' =>  __( 'Enter the headline which appears on the top in headline area as heading. Leave blank to show default that has been entered in Theme-options.', 'templatation' ),
          'dependency'   => array( '_single_disable_headline', '==', 'false' ),
        ),


        array(
          'id'    => '_single_headline_message',
          'type'  => 'textarea',
          'title' => __( 'Headline text', 'templatation' ),
          'desc' => __( 'This text appears in headline area below heading. Leave blank to show default that has been entered in Theme-options.(If you dont want any headline subtext particularly for this page, enter blank space. )', 'templatation' ),
          'dependency'   => array( '_single_disable_headline', '==', 'false' ),
        ),


        array(
          'id'    => '_single_disable_breadcrumbs',
          'type'  => 'switcher',
          'title' => __( 'Disable Breadcrumbs', 'templatation' ),
          'label' => __( 'If checked, Breadcrumbs will not show up on this page. This can be globally turned off from admin too. ', 'templatation' ),
          'default' => false
        ),

      ), // end: fields
    ), // end: a section


  ),
);

// -----------------------------------------
// Page Metabox Options                    -
// -----------------------------------------

$options[]    = array(
  'id'        => '_tt_meta_page_opt',
  'title'     => 'Page Options',
  'post_type' => 'product',
  'context'   => 'normal',
  'priority'  => 'default',
  'sections'  => array(

    // begin: a section
    array(
      'name'  => 'section_1',
      'title' => 'General Settings',
      'icon'  => 'fa fa-cog',

      // begin: fields
      'fields' => array(

        array(
          'id'    => '_single_disable_headline',
          'type'  => 'switcher',
          'title' => __( 'Disable headline area from this page', 'templatation' ),
          'label' => __( 'If disabled the headline area will not appear on this post/page. The settings below will not make any difference if this is globally disabled from theme options panel. Check to disable. If disabled , breadcrumb will be shown on headline area instead.', 'templatation' ),
          'default' => false
        ),

        array(
          'id'    => '_single_headline_heading',
          'type'  => 'text',
          'title' => __( 'Heading Title.', 'templatation' ),
          'desc' =>  __( 'Enter the headline which appears on the top in headline area as heading. Leave blank to show default that has been entered in Theme-options.', 'templatation' ),
          'dependency'   => array( '_single_disable_headline', '==', 'false' ),
        ),


        array(
          'id'    => '_single_headline_message',
          'type'  => 'textarea',
          'title' => __( 'Headline text', 'templatation' ),
          'desc' => __( 'This text appears in headline area below heading. Leave blank to show default that has been entered in Theme-options.(If you dont want any headline subtext particularly for this page, enter blank space.)', 'templatation' ),
          'dependency'   => array( '_single_disable_headline', '==', 'false' ),
        ),


        array(
          'id'    => '_hide_title_display',
          'type'  => 'switcher',
          'title' => __( 'Hide default title display in middle content area.', 'templatation' ),
          'label' => __( 'In some case, you might want to hide the default title display. Check this to hide title. If you are not sure about it , leave it unchecked. N/A for woocommerce products.', 'templatation' ),
          'default' => false
        ),

        array(
          'id'    => '_single_disable_breadcrumbs',
          'type'  => 'switcher',
          'title' => __( 'Disable Breadcrumbs', 'templatation' ),
          'label' => __( 'If checked, Breadcrumbs will not show up on this page. This can be globally turned off from admin too.', 'templatation' ),
          'default' => false
        ),

        array(
          'id'    => '_single_page_img',
          'type'  => 'upload',
          'title' => __( 'Hero Image', 'templatation' ),
          'desc' => __( 'This image appears below header and above content block. Note that if you put anything in below field(Hero Area Content), this settings will not reflect. Ideal image size is 1400x400 px.', 'templatation' )
        ),

        array(
          'id'    => '_single_page_slider',
          'type'  => 'textarea',
          'title' => __( 'Hero/Slider Area Content.', 'templatation' ),
          'desc' => __( 'This content appears on the header area, you can use it to place slider particular for this page/post/product or any other image or content. Shortcodes allowed. e.g. [rev_slider portfolio-slider].', 'templatation' )
        ),

      array(
        'id'        => '_layout',
        'type'      => 'image_select',
        'title'     => 'Content Layout',
        'desc' => __( 'Select content area and sidebar layout for this perticular page. This overrides the global setting in themeoptions/layout.', 'templatation' ),
        'options'   => array(
          'layout-default'    => get_template_directory_uri() .'/functions/images/layout-off.png',
          'layout-full'    => get_template_directory_uri() .'/functions/images/1c.png',
          'layout-left-content'    => get_template_directory_uri() .'/functions/images/2cl.png',
          'layout-right-content'    => get_template_directory_uri() .'/functions/images/2cr.png',
        ),
        'default'   => 'layout-left-content',
      ),


      ), // end: fields
    ), // end: a section


  ),
);

// -----------------------------------------
// Portfolio Metabox Options                    -
// -----------------------------------------
$options[]    = array(
  'id'        => '_tt_meta_portfolio_opt',
  'title'     => 'Portfolio Page Options',
  'post_type' => 'portfolio',
  'context'   => 'normal',
  'priority'  => 'default',
  'sections'  => array(

    // begin: a section
    array(
      'name'  => 'section_1',
      'title' => 'General Settings',
      'icon'  => 'fa fa-cog',

      // begin: fields
      'fields' => array(

/*        array(
          'id'    => 'embed',
          'type'  => 'textarea',
          'title' => __(  'Enter the video embed code for your video (YouTube, Vimeo or similar)',  'templatation' )
        ),*/

        array(
          'id'    => '_portfolio_url',
          'type'  => 'text',
          'title' => 'Portfolio URL',
          'desc' => __( 'Enter an alternative URL for your Portfolio item. By default it will link to your portfolio post or lightbox. Its useful if you want to link portfolio item to external link. It links to View Project button in one column portfolio page template.', 'templatation')
        ),

        array(
          'id'    => 'lightbox-url',
          'type'  => 'text',
          'title' => 'Lightbox URL',
          'desc' => sprintf( __( 'Enter an optional URL to show in the %s for this portfolio item.', 'templatation' ), '<a href="http://www.no-margin-for-errors.com/projects/prettyphoto-jquery-lightbox-clone/">' . __( 'PrettyPhoto lightbox', 'templatation' ) . '</a>' )
        ),

      array(
        'id'        => '_layout',
        'type'      => 'image_select',
        'title'     => 'Content Layout',
        'desc' => __( 'Select content area and sidebar layout for this perticular page. This overrides the global setting in themeoptions/layout.', 'templatation' ),
        'options'   => array(
          'layout-default'    => get_template_directory_uri() .'/functions/images/layout-off.png',
          'layout-full'    => get_template_directory_uri() .'/functions/images/1c.png',
          'layout-left-content'    => get_template_directory_uri() .'/functions/images/2cl.png',
          'layout-right-content'    => get_template_directory_uri() .'/functions/images/2cr.png',
        ),
        'default'   => 'layout-right-content',
      ),

/*
        array(
          'id'    => 'section_1_textarea',
          'type'  => 'textarea',
          'title' => 'Textarea Field',
        ),

        array(
          'id'    => 'section_1_upload',
          'type'  => 'upload',
          'title' => 'Upload Field',
        ),

        array(
          'id'    => 'section_1_switcher',
          'type'  => 'switcher',
          'title' => 'Switcher Field',
          'label' => 'Yes, Please do it.',
        ),*/

      ), // end: fields
    ), // end: a section


  ),
);

// -----------------------------------------
// Portfolio Metabox Options                    -
// -----------------------------------------
$options[]    = array(
  'id'        => '_tt_meta_post_opt',
  'title'     => 'Post Options',
  'post_type' => 'post',
  'context'   => 'normal',
  'priority'  => 'default',
  'sections'  => array(

    // begin: a section
    array(
      'name'  => 'section_1',
      'title' => 'General Settings',
      'icon'  => 'fa fa-cog',

      // begin: fields
      'fields' => array(

        array(
          'id'    => '_hide_title_display',
          'type'  => 'switcher',
          'title' => __( 'Hide default title display in middle content area.', 'templatation' ),
          'label' => __( 'In some case, you might want to hide the default title display. Check this to hide title. If you are not sure about it , leave it unchecked. N/A for woocommerce products.', 'templatation' ),
          'default' => false
        ),

        array(
          'id'        => '_layout',
          'type'      => 'image_select',
          'title'     => 'Content Layout',
          'desc' => __( 'Select content area and sidebar layout for this perticular page. This overrides the global setting in themeoptions/layout.', 'templatation' ),
          'options'   => array(
            'layout-default'    => get_template_directory_uri() .'/functions/images/layout-off.png',
            'layout-full'    => get_template_directory_uri() .'/functions/images/1c.png',
            'layout-left-content'    => get_template_directory_uri() .'/functions/images/2cl.png',
            'layout-right-content'    => get_template_directory_uri() .'/functions/images/2cr.png',
          ),
          'default'   => 'layout-right-content',
        ),

      ), // end: fields
    ), // end: a section


  ),
);
  return $options;

}
add_filter( 'cs_metabox_options', 'tt_meta_boxes_options' );

/*-----------------------------------------------------------------------------------*/
/* Load style.css in the <head> */
/*-----------------------------------------------------------------------------------*/

if ( ! is_admin() ) { 
	add_action( 'wp_enqueue_scripts', 'woo_load_frontend_css', 20 );
	add_action( 'wp_enqueue_scripts', 'tt_load_responsive_css', 21 ); // made another call for it because need to load woocommerce.css btwn these two
}

if ( ! function_exists( 'justshop_tt_g_fonts' ) ) {
	/**
	 * @return string Google fonts URL for the theme.
	 */
	function justshop_tt_g_fonts() {

		$fonts_url = '';
		$fonts     = array();
		$subsets   = 'latin,latin-ext';

		/* translators: If there are characters in your language that are not supported by Merriweather, translate this to 'off'. Do not translate into your own language. */
		if ( 'off' !== _x( 'on', 'Google font: on or off', 'fitzeous' ) ) {
			$fonts[] = 'Roboto:400,400italic,700italic';
			$fonts[] = 'PT Sans:400,400italic,700italic';
			$fonts[] = 'Philosopher:400,700,400italic,700italic';
		}

		if ( $fonts ) {
			$fonts_url = add_query_arg( array(
				'family' => urlencode( implode( '|', $fonts ) ),
				'subset' => urlencode( $subsets ),
			), 'https://fonts.googleapis.com/css' );
		}

		return $fonts_url;
	}
}

if ( ! function_exists( 'woo_load_frontend_css' ) ) {
	function woo_load_frontend_css () {
		global $tt_options; $woo_layout_style = '';

		wp_enqueue_style( 'justshop-fonts', justshop_tt_g_fonts(), array(), null );

		wp_register_style( 'theme-stylesheet', get_stylesheet_uri() );

		if (is_rtl()) $woo_layout_style = "layout-rtl"; else $woo_layout_style = "layout";
		wp_register_style( 'tt-layout', get_template_directory_uri() . '/css/'.$woo_layout_style.'.css' );

		if ( is_child_theme() && file_exists( get_stylesheet_directory() . '/css/'. $woo_layout_style .'.css' ) ) {
			wp_register_style( 'tt-child-layout', get_stylesheet_directory_uri() . '/css/' . $woo_layout_style . '.css' );
		}
		wp_enqueue_style( 'theme-stylesheet' );
		wp_enqueue_style( 'tt-layout' );
		wp_enqueue_style( 'tt-child-layout' );

	} // End woo_load_frontend_css()
}

if ( ! function_exists( 'tt_load_responsive_css' ) ) {
	function tt_load_responsive_css () {
		global $tt_options; $woo_responsive_style = '';
		
		if (is_rtl()) $woo_responsive_style = "responsive-rtl"; else $woo_responsive_style = "responsive";
		wp_register_style( 'temp-responsive', get_template_directory_uri() . '/css/'.$woo_responsive_style.'.css' );
		if ( file_exists( get_stylesheet_directory() . '/css/'. $woo_responsive_style .'.css' ) ) {
			wp_register_style( 'tt-child-layout', get_stylesheet_directory_uri() . '/css/' . $woo_responsive_style . '.css' );
		}
		wp_enqueue_style( 'temp-responsive' );
		wp_enqueue_style( 'temp-child-responsive' );
	} // End woo_load_frontend_css()
}


/*-----------------------------------------------------------------------------------*/
/* Load responsive <meta> tags in the <head> */
/*-----------------------------------------------------------------------------------*/

add_action( 'wp_head', 'woo_load_responsive_meta_tags', 10 );

if ( ! function_exists( 'woo_load_responsive_meta_tags' ) ) {
	function woo_load_responsive_meta_tags () {
		$html = '';

		$html .= "\n" . '<!-- Always force latest IE rendering engine (even in intranet) & Chrome Frame -->' . "\n";
		$html .= '<meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1" />' . "\n";

		/* Remove this if not responsive design */
		$html .= "\n" . '<!--  Mobile viewport scale | Disable user zooming as the layout is optimised -->' . "\n";
		$html .= '<meta content="initial-scale=1.0, maximum-scale=1.0, user-scalable=no" name="viewport"/>' . "\n";

		echo $html;
	} // End woo_load_responsive_meta_tags()
}


/*-----------------------------------------------------------------------------------*/
/* Add Custom Styling to HEAD */
/*-----------------------------------------------------------------------------------*/

add_action( 'woo_head', 'woo_custom_styling', 10 ); // Add custom styling to HEAD

if ( ! function_exists( 'woo_custom_styling' ) ) {
	function woo_custom_styling() {
		global $tt_options;
		$output = $woo_hdr_class = $body_image = '';
		// Get options
		$settings = array(
						'button_color' => '',
						'top_nav_color' => '',
						'sc_icons_right' => '0',
						'no_white_bg' => '0',
						'no_bdcmp_shadow' => '0',
						'hdline_bg' => '',
						'main_acnt_clr' => '#e75a39',
						'sec_acnt_clr' => '#917460',
						'light_clr' => '#FADED8',
						'texttitle' => '0',
						'custom_css' => '',
						'wpr_bdr_rdus' => '',
						'extreme_ft_trans_bg' => '0'
						);
		$settings = tt_get_dynamic_values( $settings );

        //TODO: do we still need below.
/*		if ( !isset( $tt_options['tt_header_section_layout'] ) || $tt_options['tt_header_section_layout'] == 'layout2' ) {
		$woo_hdr_class = "b";
		}
		elseif( $tt_options['tt_header_section_layout'] == 'layout3' ) $woo_hdr_class = "c";
		elseif( $tt_options['tt_header_section_layout'] == 'layout4' ) $woo_hdr_class = "d";
		elseif( $tt_options['tt_header_section_layout'] == 'layout5' ) $woo_hdr_class = "e";
		elseif( $tt_options['tt_header_section_layout'] == 'layout6' ) $woo_hdr_class = "f";
		elseif( $tt_options['tt_header_section_layout'] == 'layout7' ) $woo_hdr_class = "f";
		//elseif( $tt_options['tt_header_section_layout'] == 'layout8' ) $woo_hdr_class = "e";
		else  $woo_hdr_class = "b";*/

		// Type Check for Array
		if ( is_array($settings) ) {

			if ( ! ( $settings['main_acnt_clr'] == '#e75a39' || $settings['main_acnt_clr'] == '#b08fbb' || $settings['main_acnt_clr'] == '#68b5d3' || $settings['main_acnt_clr'] == '#80b243' || $settings['main_acnt_clr'] == '#9d563a' || $settings['main_acnt_clr'] == '#c95980' )) { // if usr changed!
				$output .= 'span.onsale,span.onsale:after,a.remove,#header.d,input[type="checkbox"]:checked,a.button,#commentform #submit,.submit,input[type=submit],input.button,button.button,#wrapper .woo-sc-button,	.added_to_cart,.ns_button.wpb_button,.woo_cta_button.wpb_button,.yith-wcwl-add-button a.add_to_wishlist,.yith-wcwl-add-button .add_to_wishlist,	.yith-wcwl-wishlistexistsbrowse a,	.yith-wcwl-wishlistaddedbrowse a,ul.products li.product.product-category span.view-more,#sidebar .woocommerce .product_list_widget li:hover,article.hentry header h1, article.hentry header h2, article.type-post header h1, article.type-post header h2, article.type-page header h1, article.type-page header h2, .search #main article header h1, .search #main article header h2, h1.page-title, h2.page-title,.nav-a > ul > li > a:hover > .shade-a, .nav-a > ul > li > a:focus > .shade-a, .nav-a > ul > li > a:active > .shade-a, .nav-a > ul > li.active > a > .shade-a, .nav-a > ul > li:hover > a > .shade-a,.wpb_tour.templatation ul.wpb_tabs_nav li.ui-tabs-active a .shade-a, .wpb_tour.templatation ul.wpb_tabs_nav li a:hover .shade-a, .wpb_tour.templatation ul.wpb_tabs_nav li a:focus .shade-a, .wpb_tour.templatation ul.wpb_tabs_nav li a:active .shade-a,.products-carousel ul.products .bx-wrapper .bx-controls .bx-next:hover,.home-showcase ul.products .bx-wrapper .bx-controls .bx-next:hover,.templatation.wpb_carousel .next:hover,.products-carousel ul.products .bx-wrapper .bx-controls .bx-prev:hover,.home-showcase ul.products .bx-wrapper .bx-controls .bx-prev:hover,.templatation.wpb_carousel .prev:hover,.widget_price_filter .ui-slider .ui-slider-handle,.widget_price_filter .ui-slider .ui-slider-range,.templatation.vc_progress_bar .vc_single_bar.bar_orange .vc_bar,#footer-wrap,#footer-wrap.contact,#footer-widgets .button,.woo-pagination a,span.onsalespan.onsale:after,ul.products li.product.sale .img-wrap .price,.tt_Sscreen #navigation ul.nav li a:hover,.tt_Sscreen #navigation ul.nav li a:focus,.tt_Sscreen #navigation ul.nav li a:active,.tt_Lscreen #navigation ul.nav ul.sub-menu li a:hover,.tt_Lscreen #navigation ul.nav li.parent:hover ul.sub-menu a:hover,.tt_Lscreen #header.b #navigation > ul > li > a:hover,#header.b #navigation > ul > li > a:focus,#header.b #navigation > ul > li > a:active,.tt_Lscreen #header.e #navigation > ul > li > a:hover,#header.e #navigation > ul > li > a:focus,#header.e #navigation > ul > li > a:active,.tt_Lscreen #header.f #navigation > ul > li > a:hover,#header.f #navigation > ul > li > a:focus,#header.f #navigation > ul > li > a:active,.tt_Lscreen #header.b #navigation > ul > li:active > a,.tt_Lscreen #header.e #navigation > ul > li:active > a,.tt_Lscreen #header.f #navigation > ul > li:active > a,.tt_Lscreen #header.b #navigation > ul > li:hover > a,.tt_Lscreen #header.e #navigation > ul > li:hover > a,.tt_Lscreen #header.f #navigation > ul > li:hover > a,.tt_Lscreen #header.b #navigation ul.nav > li.current_page_item > a,.tt_Lscreen #header.b #navigation ul.nav li.current_page_parent > a,.tt_Lscreen #header.b #navigation ul.nav li.current-cat a,.tt_Lscreen #header.b #navigation ul.nav li.current-menu-ancestor > a,.tt_Lscreen #header.b #navigation ul.nav li.li.current-menu-item > a,#header.e #navigation ul.nav > li.current-menu-item a,#header.e #navigation ul.nav > li.current_page_item a,#header.e #navigation ul.nav li.current_page_parent > a, #header.e #navigation ul.nav li.current-cat a, #header.e #navigation ul.nav li.current-menu-ancestor a, #header.e #navigation ul.nav li.li.current-menu-item > a, #header.f #navigation ul.nav > li.current_page_item a,.tt_Lscreen #header.f #navigation ul.nav li.current_page_parent > a,.tt_Lscreen #header.f #navigation ul.nav li.current-cat a,.tt_Lscreen #header.f #navigation ul.nav li.current-menu-ancestor a,.tt_Lscreen #header.f #navigation ul.nav li.li.current-menu-item > a,.tt_Lscreen #header.b #navigation ul.nav > li.parent > a:hover,.tt_Lscreen #header.e #navigation ul.nav > li.parent > a:hover,.tt_Lscreen #header.f #navigation ul.nav > li.parent > a:hover,.tt_Lscreen #header.b #navigation ul.nav > li.parent:hover > a,.tt_Lscreen #header.e #navigation ul.nav > li.parent:hover > a,.tt_Lscreen #header.f #navigation ul.nav > li.parent:hover > a,.tt_Lscreen #header.b #navigation ul.nav > li.parent:hover li a:hover,.tt_Lscreen #header.e #navigation ul.nav > li.parent:hover li a:hover,.tt_Lscreen #header.f #navigation ul.nav > li.parent:hover li a:hover,.tt_Lscreen #header.c #navigation > ul > li > a:hover,.tt_Lscreen #header.c #navigation > ul > li > a:focus,.tt_Lscreen #header.c #navigation > ul > li > a:active,.tt_Lscreen #header.c #navigation > ul > li:active > a,.tt_Lscreen #header.c #navigation > ul > li:hover > a,.tt_Lscreen #header.c #navigation > ul > li > a:hover,.tt_Lscreen #header.c #navigation ul.nav > li.current_page_item a,.tt_Lscreen #header.c #navigation ul.nav li.current_page_parent > a,.tt_Lscreen #header.c #navigation ul.nav li.current-cat a,.tt_Lscreen #header.c #navigation ul.nav li.current-menu-ancestor > a,.tt_Lscreen #header.c #navigation ul.nav > li.parent > a:hover, .tt_Lscreen #header.c #navigation ul.nav > li.parent:hover > a, .tt_Lscreen #header.c #navigation ul.nav > li.parent:hover li a:hover, .post-header.lc_tt_title h1, .widget_templatation_testimonials .bx-prev, .widget_templatation_testimonials .bx-next, .home-featured .widget .bx-prev, .home-featured .widget .bx-next, .slider-layout2, .slider-layout3,  .tt_Lscreen #header.f.h #navigation, .home-featured .bx-prev, .home-featured .bx-next { background-color: ' . $settings['main_acnt_clr'] . '}

::selection { background: ' . $settings['main_acnt_clr'] . '}
::-moz-selection { background: ' . $settings['main_acnt_clr'] . '}

#header.f.h #navigation > ul > li > a:hover, #header.f.h #navigation > ul > li > a:focus, #header.f.h #navigation > ul > li > a:active, #header.f.h #navigation > ul > li:active > a, #header.f.h #navigation > ul > li:hover > a, #header.f.h #navigation ul.nav > li.parent > a:hover, #header.f.h #navigation ul.nav > li.parent:hover a, #header.f.h #navigation ul.nav > li.current_page_item a, #header.f.h #navigation ul.nav > li.current_page_parent > a, #header.f.h #navigation ul.nav > li.current-cat a, #header.f.h #navigation ul.nav > li.current-menu-ancestor a, #header.f.h #navigation ul.nav > li.current-menu-item > a, #header.f.h #navigation ul.nav > li.li.current-menu-item > a {
    background: #ffffff none repeat scroll 0 0;
}

@media only screen and (min-width: 769px){
#header #navigation ul#main-nav > li.megamenu > ul.sub-menu { border-top: 3px solid' . $settings['main_acnt_clr'] .'; }
#header #navigation ul#main-nav > li.megamenu > ul.sub-menu > li a { border-right: 1px dotted' . $settings['main_acnt_clr'] .'; }
}
ul.products li.product.product-category span.view-more{background-image: none;}

@media only screen and (min-width: 769px){
    #header.b #navigation ul.nav > li.parent:hover li a, #header.c #navigation ul.nav > li.parent:hover li a, #header.e #navigation ul.nav > li.parent:hover li a, #header.f #navigation ul.nav > li.parent:hover li a{ color: ' . $settings['main_acnt_clr'] . '}
}
				 a,h1,h2,h3,h4,h5,h6,h1 a:hover,h2 a:hover,h3 a:hover,h4 a:hover,h5 a:hover,h6 a:hover,#navigation .nav a,#yith-wcwl-popup-message,#header .nav-toggle span,#reviews #comments li.comment .comment_container .verified:before,#respond h3 #cancel-comment-reply-link,#post-entries a:hover,.single article.post > footer .list-f li.post-tags:before,.single article.post > footer .list-f li.posted_in:before,.post-meta ul li:before,#comments li.comment .comment_container .comment-text .name,.jssidebar .widget h3,	#sidebar .widget h3,.jssidebar.templatation .widgettitle,#sidebar .woocommerce ul li .amount,.price .amount,del .amount,article.hentry header ul li,article.hentry header ul li a,.search #main article header ul li,.search #main article header ul li a,.nav-a > ul > li > a:hover, .nav-a > ul > li > a:focus, .nav-a > ul > li > a:active, .nav-a > ul > li.active > a, .nav-a > ul > li:hover > a,.wpb_tour.templatation.wpb_content_element .wpb_tabs_nav li.ui-tabs-active, .wpb_tour.templatation.wpb_content_element .wpb_tabs_nav li:hover,.nav-a > ul > li > ul > li a:hover, .nav-a > ul > li > ul > li a:focus, .nav-a > ul > li > ul > li a:active,.wpb_tour.templatation.wpb_content_element .wpb_tabs_nav li.ui-tabs-active a, .wpb_tour.templatation.wpb_content_element .wpb_tabs_nav li:hover a,.widget .product_list_widget li .quantity .amount,.widget_templatation_testimonials .testimonials .quote .testimonials-text cite.author,.templatation.wpb_teaser_grid .categories_filter li a, .templatation.wpb_categories_filter li a,.single-product .summary .yith-wcwl-add-button .add_to_wishlist,.single-product .summary .yith-wcwl-wishlistexistsbrowse a,.single-product .summary .yith-wcwl-wishlistaddedbrowse a,#portfolio-gallery #port-tags li:hover,#portfolio-gallery #port-tags li.current a,.woo-pagination a:hover,	.woo-pagination .page-numbers.current,.woocommerce-message:before,.woocommerce_message:before,.star-rating span:before,p.stars a.star-1:hover:after,p.stars a.star-2:hover:after,p.stars a.star-3:hover:after,p.stars a.star-4:hover:after,p.stars a.star-5:hover:after,p.stars a.star-1.active:after,p.stars a.star-2.active:after,p.stars a.star-3.active:after,p.stars a.star-4.active:after,p.stars a.star-5.active:after,.woocommerce-info:before,	.woocommerce_info:before,.noreviews:before,.create-account p:first-child:before,.nocomments:before,.stock:before,.tt_Lscreen ul.nav ul.sub-menu li a,.tt_Lscreen #navigation ul.nav ul.sub-menu li a,.tt_Lscreen #navigation ul.nav li.parent:hover ul.sub-menu a,.tt_Lscreen #header.f.h #navigation > ul > li > a:hover,.tt_Lscreen #header.f.h #navigation > ul > li > a:focus,.tt_Lscreen #header.f.h #navigation > ul > li > a:active,.tt_Lscreen #header.f.h #navigation > ul > li:active > a,.tt_Lscreen #header.f.h #navigation > ul > li:hover > a,.tt_Lscreen #header.f.h #navigation ul.nav > li.parent > a:hover,.tt_Lscreen #header.f.h #navigation ul.nav > li.parent:hover a,.tt_Lscreen #header.f.h #navigation ul.nav > li.current_page_item a,	.tt_Lscreen #header.f.h #navigation ul.nav > li.current_page_parent > a,.tt_Lscreen #header.f.h #navigation ul.nav > li.current-cat a,	.tt_Lscreen #header.f.h #navigation ul.nav > li.current-menu-ancestor a,.tt_Lscreen #header.f.h #navigation ul.nav > li.li.current-menu-item > a,	.tt_Lscreen table.cart .woo_cart_table_item .product-price,	.tt_Lscreen table.cart .woo_cart_table_item .product-subtotal,.tt_Lscreen .cart-collaterals .cart_totals table tbody .total, .tt_Lscreen table.cart .woo_cart_table_item .product-price,.tt_Lscreen table.cart .woo_cart_table_item .product-subtotal, header.post-header.lc_tt_title ul li { color: ' . $settings['main_acnt_clr'] . '}
				.tt_Lscreen #navigation ul.nav li.parent:hover ul.sub-menu a:hover  {color: #FFF!important;	}
				 .tt_Lscreen #navigation ul.nav ul.sub-menu li a:hover,
				.tt_Lscreen #header.b #navigation > ul > li > a:hover,#header.b #navigation > ul > li > a:focus,#header.b #navigation > ul > li > a:active,
				.tt_Lscreen #header.e #navigation > ul > li > a:hover,#header.e #navigation > ul > li > a:focus,#header.e #navigation > ul > li > a:active,
				.tt_Lscreen #header.f #navigation > ul > li > a:hover,#header.f #navigation > ul > li > a:focus,#header.f #navigation > ul > li > a:active,
				.tt_Lscreen #header.b #navigation > ul > li:active > a,
				.tt_Lscreen #header.e #navigation > ul > li:active > a,
				.tt_Lscreen #header.f #navigation > ul > li:active > a,
				.tt_Lscreen #header.b #navigation > ul > li:hover > a,
				.tt_Lscreen #header.e #navigation > ul > li:hover > a,
				.tt_Lscreen #header.f #navigation > ul > li:hover > a,
				.tt_Lscreen #header.b #navigation ul.nav > li.current_page_item a,
				.tt_Lscreen #header.b #navigation ul.nav li.current_page_parent > a,
				.tt_Lscreen #header.b #navigation ul.nav li.current-cat a,
				.tt_Lscreen #header.b #navigation ul.nav li.current-menu-ancestor a,
				.tt_Lscreen #header.b #navigation ul.nav li.li.current-menu-item > a,
				.tt_Lscreen #header.e #navigation ul.nav > li.current_page_item a,
				.tt_Lscreen #header.e #navigation ul.nav li.current_page_parent > a,
				.tt_Lscreen #header.e #navigation ul.nav li.current-cat a,
				.tt_Lscreen #header.e #navigation ul.nav li.current-menu-ancestor a,
				.tt_Lscreen #header.e #navigation ul.nav li.li.current-menu-item > a,
				.tt_Lscreen #header.f #navigation ul.nav > li.current_page_item a,
				.tt_Lscreen #header.f #navigation ul.nav li.current_page_parent > a,
				.tt_Lscreen #header.f #navigation ul.nav li.current-cat a,
				.tt_Lscreen #header.f #navigation ul.nav li.current-menu-ancestor a,
				.tt_Lscreen #header.f #navigation ul.nav li.li.current-menu-item > a,
				.tt_Lscreen #header.b #navigation ul.nav > li.parent > a:hover,
				.tt_Lscreen #header.e #navigation ul.nav > li.parent > a:hover,
				.tt_Lscreen #header.f #navigation ul.nav > li.parent > a:hover,
				.tt_Lscreen #header.b #navigation ul.nav > li.parent:hover > a,
				.tt_Lscreen #header.e #navigation ul.nav > li.parent:hover > a,
				.tt_Lscreen #header.f #navigation ul.nav > li.parent:hover > a,
				.tt_Lscreen #header.b #navigation ul.nav > li.parent:hover li a:hover,
				.tt_Lscreen #header.e #navigation ul.nav > li.parent:hover li a:hover,
				.tt_Lscreen #header.f #navigation ul.nav > li.parent:hover li a:hover {color: #FFF;	}

				.tt-object {
					border-top: 5px solid ' . $settings['main_acnt_clr'] . ';
					border-left: 5px solid ' . $settings['main_acnt_clr'] . ';
				}


				';

			}

			if ( ! ( $settings['sec_acnt_clr'] == '#917460' || $settings['sec_acnt_clr'] == '#4F3754' || $settings['sec_acnt_clr'] == '#53a7c7' || $settings['sec_acnt_clr'] == '#64883F' || $settings['sec_acnt_clr'] == '#4f2b2d' || $settings['sec_acnt_clr'] == '#A0375B' )) { // if usr changed!
				$output .= '
				a.button,
				#commentform #submit,
				.submit,
				input[type=submit],
				input.button,
				button.button,
				#wrapper .woo-sc-button,
				.added_to_cart,
				.ns_button.wpb_button,
				.woo_cta_button.wpb_button,
				.yith-wcwl-add-button a.add_to_wishlist,
				.yith-wcwl-add-button .add_to_wishlist,
				.yith-wcwl-wishlistexistsbrowse a,
				.yith-wcwl-wishlistaddedbrowse a,
				ul.products li.product.product-category span.view-more {
				  box-shadow: 0 2px 0 ' . $settings['sec_acnt_clr'] . ';
				  -moz-box-shadow: 0 2px 0 ' . $settings['sec_acnt_clr'] . ';
				  -webkit-box-shadow: 0 2px 0 ' . $settings['sec_acnt_clr'] . ';
				}
				a.button:hover,
				a.comment-reply-link:hover,
				#commentform #submit:hover,
				.submit:hover,
				input[type=submit]:hover,
				input.button:hover,
				button.button:hover,
				#wrapper .woo-sc-button:hover,
				.added_to_cart:hover,
				.ns_button.wpb_button:hover,
				.woo_cta_button.wpb_button:hover,
				.yith-wcwl-add-button.show .add_to_wishlist:hover,
				.yith-wcwl-wishlistexistsbrowse a,
				.yith-wcwl-wishlistaddedbrowse a,
				a.comment-reply-link,
				.widget_templatation_testimonials .bx-prev:hover, .widget_templatation_testimonials .bx-next:hover,
				.home-featured .widget .bx-prev:hover, .home-featured .widget .bx-next:hover { background-color: ' . $settings['sec_acnt_clr'] . ' }
				#footer{
					background: none repeat scroll 0 0 ' . $settings['sec_acnt_clr'] . ';
				}
				.breadcrumbs-wrap .breadcrumbs {
				  border-left-color: ' . $settings['sec_acnt_clr'] . ';
				}
				#footer-widgets, #footer-widgets #searchform {
				    border-color: ' . $settings['sec_acnt_clr'] . ';
				}
				';
			}
			if ( ! ( $settings['light_clr'] == '#faded8' || $settings['light_clr'] == '#f1e0f9' || $settings['light_clr'] == '#b3e7fb' || $settings['light_clr'] == '#d7f8af' || $settings['light_clr'] == '#f3d1c3' || $settings['light_clr'] == '#fbdbe6' )) { // if usr changed!
				$output .= '
				article.hentry header h1, article.hentry header h2, article.type-post header h1, article.type-post header h2, article.type-page header h1, article.type-page header h2, .search #main article header h1, .search #main article header h2, h1.page-title, h2.page-title, .post-header.lc_tt_title h1 {  border-color: ' . $settings['light_clr'] . '; }
				.widget_templatation_testimonials .bx-prev, .widget_templatation_testimonials .bx-next,
				.home-featured .widget .bx-prev, .home-featured .widget .bx-next,
				.wpb_carousel .prev, .wpb_carousel .next,
				.templatation.wpb_carousel .prev, .templatation.wpb_carousel .next { background-color: ' . $settings['light_clr'] . ' }
				header.post-header.lc_tt_title ul, article.hentry header ul, .search #main article header ul { background: ' . $settings['light_clr'] . ' }
				.jsfooter-hr {
				border-bottom: 1px solid ' . $settings['light_clr'] . ';
				#footer-widgets {
				  border-top: 1px solid ' . $settings['light_clr'] . ';
				}
				}


			';
			}

			if ( $settings['texttitle'] == '1' ) {
				$output .= '#logo img { display:none; } .site-title { display:block !important; }.site-description { display:block !important; }' . "\n";
			}

			if ( $settings['sc_icons_right'] == '1' ) {
				$output .= '#tools ul { float: right; }' . "\n";
			}

			if ( $settings['no_bdcmp_shadow'] == '1' ) {
				$output .= '#headline { background: none repeat scroll 0 0 transparent;}' . "\n";
			}

			if ( $settings['top_nav_color'] != '' ) {
				$output .= '#tools, #tools > .fit-a { background: ' . $settings['top_nav_color'] . ' }' . "\n";
			}
			if ( $settings['wpr_bdr_rdus'] != '' ) {
				$output .= '#content { -moz-border-radius: ' . $settings['wpr_bdr_rdus'] . 'px; -webkit-border-radius: ' . $settings['wpr_bdr_rdus'] . 'px; border-radius: ' . $settings['wpr_bdr_rdus'] . 'px }' . "\n";

			}
			if ( $settings['extreme_ft_trans_bg'] == '1' ) {
				$output .= '#footer { background-image: url('. get_template_directory_uri() . '/images/bodybg/zTransparent.png);}' . "\n";

			}

		} // End If Statement

			if ( $settings['custom_css'] != '' ) {
				$output .= $settings['custom_css'];
			}

        // add header height css
        if ( function_exists( 'templatation_header_height' ) ) {
          $output .= templatation_header_height();
        }
        // add logo offset css
        if ( function_exists( 'templatation_logo_offset' ) ) {
          $output .= templatation_logo_offset();
        }

		// Output styles
		if ( isset( $output ) && $output != '' ) {
			$output = strip_tags( $output );
			// Remove space after colons
			$output = str_replace(': ', ':', $output);
			// Remove whitespace
			$output = str_replace(array("\r\n", "\r", "\n", "\t", '  ', '   ', '    '), '', $output);

			$output = "\n" . "<!-- Theme Custom Styling -->\n<style type=\"text/css\">\n" . $output . "</style>\n";
			echo $output;
		}

	} // End woo_custom_styling()
}

/*-----------------------------------------------------------------------------------*/
/* Add custom typograhpy to HEAD */
/*-----------------------------------------------------------------------------------*/
/*
add_action( 'woo_head','woo_custom_typography', 10 ); // Add custom typography to HEAD

if ( ! function_exists( 'woo_custom_typography' ) ) {
	function woo_custom_typography() {
}*/

// Returns proper font css output
/*if (!function_exists( 'woo_generate_font_css')) {
	function woo_generate_font_css($option, $em = '1') {
}*/

/*-----------------------------------------------------------------------------------*/
/* Add layout to body_class output */
/*-----------------------------------------------------------------------------------*/

add_filter( 'body_class','woo_layout_body_class', 10 );		// Add layout to body_class output

if ( ! function_exists( 'woo_layout_body_class' ) ) {
	function woo_layout_body_class( $classes ) {

		global $tt_options; $single = '';

		$layout = 'two-col-left';

		if ( isset( $tt_options['tt_site_layout'] ) && ( $tt_options['tt_site_layout'] != '' ) ) {
			$layout = $tt_options['tt_site_layout'];
		}

		// Set main layout on post or page
		if ( is_singular() ) {
			global $post;
			$single2 = get_post_meta( $post->ID, '_tt_meta_page_opt', true );
			if( is_array($single2) && isset($single2['_layout']) ) $single = $single2['_layout'];
			if ( $single != "" AND $single != "layout-default" )

				$layout = $single;
		}

		// Add layout to $tt_options array for use in theme
		$tt_options['tt_layout'] = $layout;

		// Add classes to body_class() output
		$classes[] = $layout;
		return $classes;

	} // End woo_layout_body_class()
}


/*-----------------------------------------------------------------------------------*/
/* woo_feedburner_link() */
/*-----------------------------------------------------------------------------------*/
/**
 * woo_feedburner_link()
 *
 * Replace the default RSS feed link with the Feedburner URL, if one
 * has been provided by the user.
 *
 * @package wooFramework
 * @subpackage Filters
 */

add_filter( 'feed_link', 'woo_feedburner_link', 10 );

function woo_feedburner_link ( $output, $feed = null ) {

	global $tt_options;

	$default = get_default_feed();

	if ( ! $feed ) $feed = $default;

	if ( isset($tt_options[ 'woo_feed_url']) && $tt_options['tt_feed_url' ] && ( $feed == $default ) && ( ! stristr( $output, 'comments' ) ) ) $output = esc_url( $tt_options['tt_feed_url' ] );

	return $output;

} // End woo_feedburner_link()

  add_action( 'woo_header_inside', 'templatation_topnav_content', 9 ); // adding custom style in body tag
  add_action( 'woo_header_inside', 'tt_logo', 10 );
  add_action( 'woo_header_inside', 'tt_hdr_search', 11 );
/*-----------------------------------------------------------------------------------*/
/* Optionally load custom logo. */
/*-----------------------------------------------------------------------------------*/

if ( ! function_exists( 'tt_logo' ) ) {
function tt_logo () {
	global $tt_options;
	$width = $height = $style = $logo = '';
	$settingsl = array(
					'retina_favicon' => '0',
					'texttitle' => '0',
					'logo' => '',
					'retina_logo_wh' => '',
				);
	$settingsl = tt_get_dynamic_values( $settingsl );

	if ( $settingsl['texttitle'] == '1' ) return; // Get out if we're not displaying the logo.

	$logo = esc_url( get_template_directory_uri() . '/images/logo.jpg' );
	if ( isset( $tt_options['tt_logo']['url'] ) && $tt_options['tt_logo']['url'] != '' ) { $logo = $tt_options['tt_logo']['url'] ; }
	if ( is_ssl() ) { $logo = str_replace( 'http://', 'https://', $logo ); }
?>

	<a id="logo" href="<?php echo esc_url( home_url( '/' ) ); ?>" title="<?php echo esc_attr( get_bloginfo( 'description' ) ); ?>">
	 <?php if ( '0' == $settingsl['retina_favicon'] ) { ?>
		<img src="<?php echo esc_url( $logo ); ?>" alt="<?php echo esc_attr( get_bloginfo( 'name' ) ); ?>" />
	 <?php } else {
       if( $settingsl['retina_logo_wh']['width'] != '0' ) {
         if ( ! empty( $settingsl['retina_logo_wh']['width'] ) ) {
           if ( strpos( $settingsl['retina_logo_wh']['width'], 'px' ) !== false ) {
             $width = 'width:' . $settingsl['retina_logo_wh']['width'] . ';';
           } else {
             $width = 'width:' . $settingsl['retina_logo_wh']['width'] . 'px;';
           }
         }
       }
        if ($settingsl['retina_logo_wh']['height'] != '0') {
          if ( ! empty( $settingsl['retina_logo_wh']['height'] ) ) {
            if ( strpos( $settingsl['retina_logo_wh']['height'], 'px' ) !== false ) {
              $height = 'height:' . $settingsl['retina_logo_wh']['height'] . ';';
            } else {
              $height = 'height:' . $settingsl['retina_logo_wh']['height'] . 'px;';
            }
          }
        }
		if ( !empty($width) ) $style .= $width;
		if ( !empty($height) ) $style .= $height ;
		if ( !empty($style) ) $style = 'style="'.$style.'"';
		?>
		<img src="<?php echo esc_url( $logo ); ?>" <?php echo $style; ?> alt="<?php echo esc_attr( get_bloginfo( 'name' ) ); ?>" />
	 <?php } ?>
	</a>
<?php
} // End tt_logo()
}

/*-----------------------------------------------------------------------------------*/
/* Add search box on right side of the header.                                       */
/*-----------------------------------------------------------------------------------*/

if ( ! function_exists( 'tt_hdr_search' ) ) {
	function tt_hdr_search() {
		global $tt_options;
		$settingsl5 = array(
			'header_section_layout' => 'layout2',
			'enable_hdr_search'     => '0',
		);
		$settingsl5 = tt_get_dynamic_values( $settingsl5 );
		if ( ( $settingsl5['enable_hdr_search'] == '1' ) && ( $settingsl5['header_section_layout'] == 'layout6' || $settingsl5['header_section_layout'] == 'layout7' ) ) {
			if ( is_woocommerce_activated() ) {
				get_product_search_form();
			} else {
				get_search_form();
			}
		}
	} // End tt_hdr_search()
}

/*-----------------------------------------------------------------------------------*/
/* Add custom CSS class to the <body> tag if the lightbox option is enabled. */
/*-----------------------------------------------------------------------------------*/

add_filter( 'body_class', 'woo_add_lightbox_body_class', 10 );

function woo_add_lightbox_body_class ( $classes ) {
	global $tt_options;

	if ( isset( $tt_options['tt_enable_lightbox'] ) && $tt_options['tt_enable_lightbox'] == '1' ) {
		$classes[] = 'has-lightbox';
	}

	return $classes;
} // End woo_add_lightbox_body_class()

/*-----------------------------------------------------------------------------------*/
/* Load PrettyPhoto JavaScript and CSS if the lightbox option is enabled. */
/*-----------------------------------------------------------------------------------*/

add_action( 'templatation_add_javascript', 'woo_load_prettyphoto', 10 );
add_action( 'templatation_add_css', 'woo_load_prettyphoto', 10 );

function woo_load_prettyphoto () {
	global $tt_options;

	if ( (! isset( $tt_options['tt_enable_lightbox'] ) || $tt_options['tt_enable_lightbox'] == '0')  || ( is_singular() && get_post_type() == 'product' ) ) { return; }

	$filter = current_filter();

	switch ( $filter ) {
		case 'templatation_add_javascript':
			wp_enqueue_script( 'enable-lightbox' );
		break;

		case 'templatation_add_css':
			wp_enqueue_style( 'prettyPhoto' );
		break;

		default:
		break;
	}
} // End woo_load_prettyphoto()

/*-----------------------------------------------------------------------------------*/
/* Customise the default search form */
/*-----------------------------------------------------------------------------------*/

if ( ! function_exists( 'woo_customise_search_form' ) ) {
function woo_customise_search_form ( $html ) {
  // Add the "search_main" and "fix" classes to the wrapping DIV tag.
  $html = str_replace( '<form', '<div class="search_main fix"><form', $html );
  // Add the "searchform" class to the form.
  $html = str_replace( ' method=', ' class="searchform" method=', $html );
  // Add the placeholder attribute and CSS classes to the input field.
  $html = str_replace( ' name="s"', ' name="s" class="field s" placeholder="' . esc_attr( __( 'Search...', 'templatation' ) ) . '"', $html );
  // Wrap the end of the form in a closing DIV tag.
  $html = str_replace( '</form>', '</form></div>', $html );
  // Add the "search-submit" class to the button.
  $html = str_replace( ' id="searchsubmit"', ' class="search-submit" id="searchsubmit"', $html );

  return $html;
} // End woo_customise_search_form()
}

add_filter( 'get_search_form', 'woo_customise_search_form' );

/*-----------------------------------------------------------------------------------*/
/* Load responsive IE scripts */
/*-----------------------------------------------------------------------------------*/

add_action( 'wp_footer', 'woo_load_responsive_IE_footer', 10 );

if ( ! function_exists( 'woo_load_responsive_IE_footer' ) ) {
	function woo_load_responsive_IE_footer () {
		$html = '';
		echo '<!--[if lt IE 9]>'. "\n";
		echo '<script src="' . get_template_directory_uri() . '/includes/js/respond.js"></script>'. "\n";
		echo '<![endif]-->'. "\n";

		echo $html;
	} // End ()
}

/*-----------------------------------------------------------------------------------*/
/* Customise the display of the testmonials */
/*-----------------------------------------------------------------------------------*/

if ( ! function_exists( 'woo_customise_testimonials_template' ) ) {
function woo_customise_testimonials_template ( $template ) {
	return '<div class="%%CLASS%% quote-%%ID%%"><blockquote class="testimonials-text">%%AUTHOR%% %%AVATAR%% <p>%%TEXT%%</p></blockquote><div class="fix"></div></div>';
} // End woo_customise_testimonials_template()
}

add_filter( 'templatation_testimonials_item_template', 'woo_customise_testimonials_template' );

/*-----------------------------------------------------------------------------------*/
/* Control homepage content */
/*-----------------------------------------------------------------------------------*/

if ( ! function_exists( 'woo_customise_homepage_query' ) ) {
/**
 * Modify the homepage query, if set to display blog posts, based on the theme options.
 * @since  1.0.0
 * @param  object $q The query object.
 * @return object    The modified query object.
 */
function woo_customise_homepage_query ( $q ) {
	if ( $q->is_admin ) return $q; // We don't want to act in the admin.

	if ( $q->is_home && $q->is_main_query() ) {
		$settings = tt_get_dynamic_values( array( 'homepage_content_type' => 'posts', 'homepage_number_of_posts' => get_option( 'posts_per_page' ), 'homepage_posts_category' => '' ) );
		if ( 'posts' != $settings['homepage_content_type'] ) return $q; // If we're not displaying blog posts, don't modify the query.

		$q->set( 'posts_per_page', intval( $settings['homepage_number_of_posts'] ) );

		if ( 0 < intval( $settings['homepage_posts_category'] ) ) {
			$q->set( 'cat', intval( $settings['homepage_posts_category'] ) );
		}

		$q->parse_query();
	}

	return $q;
} // End woo_customise_homepage_query()
}

//add_filter( 'pre_get_posts', 'woo_customise_homepage_query' );

// fire customizer if enabled from themeoptions/styling
// depreciated since v6.0
/*if ( 'TT_OLD_VER_PRESENT' && ( isset( $tt_options['tt_live_cust'] ) && $tt_options['tt_live_cust'] == '1') ) {
	// Adding live customizer.
	 if ( function_exists('templatation_customize_register') ) add_action( 'customize_register', 'templatation_customize_register' ); redux handles it.
	if ( function_exists('tt_customizer_css') ) add_action( 'wp_head', 'tt_customizer_css' );
}*/

/*-----------------------------------------------------------------------------------*/
/* END */
/*-----------------------------------------------------------------------------------*/
?>