<?php
if ( ! defined( 'ABSPATH' ) ) exit;

/*-----------------------------------------------------------------------------------

TABLE OF CONTENTS

- Exclude categories from displaying on the "Blog" page template.
- Exclude categories from displaying on the homepage.
- Register WP Menus
- Breadcrumb display
- Page navigation
- Post Meta
- Subscribe & Connect
- Comment Form Fields
- Comment Form Settings
- Archive Description
- WooPagination markup
- Google maps (for contact template)
- Featured Slider: Post Type
- Featured Slider: Hook Into Content
- Featured Slider: Get Slides
- Is IE
- Check if WooCommerce is activated
- Contact list
- Woo Portfolio Navigation
- Woo Portfolio Item Settings
- Woo Portfolio, show portfolio galleries in portfolio item breadcrumbs

- @ Justshop Function templatation_headline_area  // adding custom style for headline area
- @ Justshop Function justshop_slider_cont // hooking function for slider setup.
//Register contactwidget shortcode
- @ Justshop Function templatation_logo_offset // adding custom style in body tag

-----------------------------------------------------------------------------------*/

/*-----------------------------------------------------------------------------------*/
/* Exclude categories from displaying on the "Blog" page template.
/*-----------------------------------------------------------------------------------*/

// Exclude categories on the "Blog" page template.
add_filter( 'woo_blog_template_query_args', 'woo_exclude_categories_blogtemplate' );

function woo_exclude_categories_blogtemplate ( $args ) {

	if ( ! function_exists( 'woo_prepare_category_ids_from_option' ) ) { return $args; }

	$excluded_cats = array();

	// Process the category data and convert all categories to IDs.
	$excluded_cats = woo_prepare_category_ids_from_option( 'woo_exclude_cats_blog' );

	// Homepage logic.
	if ( count( $excluded_cats ) > 0 ) {

		// Setup the categories as a string, because "category__not_in" doesn't seem to work
		// when using query_posts().

		foreach ( $excluded_cats as $k => $v ) { $excluded_cats[$k] = '-' . $v; }
		$cats = join( ',', $excluded_cats );

		$args['cat'] = $cats;
	}

	return $args;

} // End woo_exclude_categories_blogtemplate()

/*-----------------------------------------------------------------------------------*/
/* Exclude categories from displaying on the homepage.
/*-----------------------------------------------------------------------------------*/

// Exclude categories on the homepage.
add_filter( 'pre_get_posts', 'woo_exclude_categories_homepage' );

function woo_exclude_categories_homepage ( $query ) {

	if ( ! function_exists( 'woo_prepare_category_ids_from_option' ) ) { return $query; }

	$excluded_cats = array();

	// Process the category data and convert all categories to IDs.
	$excluded_cats = woo_prepare_category_ids_from_option( 'woo_exclude_cats_home' );

	// Homepage logic.
	if ( is_home() && ( count( $excluded_cats ) > 0 ) ) {
		$query->set( 'category__not_in', $excluded_cats );
	}

	$query->parse_query();

	return $query;

} // End woo_exclude_categories_homepage()

/*-----------------------------------------------------------------------------------*/
/* Register WP Menus */
/*-----------------------------------------------------------------------------------*/
if ( function_exists( 'wp_nav_menu') ) {
	add_theme_support( 'nav-menus' );
	register_nav_menus( array( 'primary-menu' => __( 'Primary Menu', 'templatation' ) ) );
}

/*-----------------------------------------------------------------------------------*/
/* Breadcrumb display */
/*-----------------------------------------------------------------------------------*/

/*add_action('woo_main_before','woo_display_breadcrumbs',10);
*/
if (!function_exists( 'woo_display_breadcrumbs')) {
	function woo_display_breadcrumbs() {
		global $tt_options, $wp_query ;
		$tt_post_id = '';
		// grab current post id
		$tt_post_id = justshop_get_the_id();

		$single_disable_breadcrumbs2 = get_post_meta( $tt_post_id, '_tt_meta_page_opt', true );
		if( isset($single_disable_breadcrumbs2['_single_disable_breadcrumbs']) ) $single_disable_breadcrumbs = $single_disable_breadcrumbs2['_single_disable_breadcrumbs'];
		if ( !isset($single_disable_breadcrumbs) || empty($single_disable_breadcrumbs) ) $single_disable_breadcrumbs = 'false';
		if ( $single_disable_breadcrumbs == '1') return; // do nothing if breadcrumb is disabled on page editors

		if ( function_exists('yoast_breadcrumb') ) { // if Yoast seo is enabled, output that breadcrumb.
			yoast_breadcrumb( '<section class="breadcrumbs-wrap yoast"><div class="breadcrumb breadcrumbs woo-breadcrumbs">', '</div></section>' );
		}

		elseif ( function_exists('bcn_display') ) { ?>
			<section class="breadcrumbs-wrap navxt">
				<div class="breadcrumbs" xmlns:v="http://rdf.data-vocabulary.org/#">
					<?php bcn_display(); ?>
				</div>
			</section><!--/#breadcrumbs-wrap --> <?php
		}
		else {
			if ( isset( $tt_options['tt_breadcrumbs_show'] ) && $tt_options['tt_breadcrumbs_show'] == '1' && ! is_front_page() ) {
			echo '<section class="breadcrumbs-wrap">';
				woo_breadcrumbs();
			echo '</section><!--/#breadcrumbs-wrap -->';
			}
		}

	} // End woo_display_breadcrumbs()
} // End IF Statement


/*-----------------------------------------------------------------------------------*/
/* Page navigation */
/*-----------------------------------------------------------------------------------*/
if (!function_exists( 'woo_pagenav')) {
	function woo_pagenav() {

		global $tt_options;

		// If the user has set the option to use simple paging links, display those. By default, display the pagination.
		if ( array_key_exists( 'woo_pagination_type', $tt_options ) && $tt_options['tt_pagination_type' ] == 'simple' ) {
			if ( get_next_posts_link() || get_previous_posts_link() ) {
		?>
            <nav class="nav-entries fix">
                <?php next_posts_link( '<span class="nav-prev fl">'. __( 'Older posts', 'templatation' ) . '</span>' ); ?>
                <?php previous_posts_link( '<span class="nav-next fr">'. __( 'Newer posts', 'templatation' ) . '</span>' ); ?>
            </nav>
		<?php
			}
		} else {
			woo_pagination();

		} // End IF Statement

	} // End woo_pagenav()
} // End IF Statement


/*-----------------------------------------------------------------------------------*/
/* Post Meta */
/*-----------------------------------------------------------------------------------*/

if (!function_exists( 'woo_post_meta')) {
	function woo_post_meta( ) {
?>
<div class="post-meta">
	<ul class="list-f">
		<li class="post-author a">
			<?php the_author_posts_link(); ?>
		</li>
		<li class="post-comments b">
			<?php comments_popup_link( __( 'Leave a comment', 'templatation' ), __( '1 Comment', 'templatation' ), __( '% Comments', 'templatation' ) ); ?>
		</li>
		<?php $categorri = get_the_category();
		if($categorri[0]) { ?>
		<li class="post-category">
			<?php the_category( ' '); ?>
		</li>
		<?php } ?>
	</ul>
</div>
<?php
	}
}


/*-----------------------------------------------------------------------------------*/
/* 4. Related Posts - related_posts
/*-----------------------------------------------------------------------------------*/
/*

Optional arguments:
 - limit: number of posts to show (default: 5)
 - image: thumbnail size, 0 = off (default: 0)
*/

function woo_shortcode_related_posts ( $atts ) {
	global $post, $wp_version;

		wp_reset_query(); // Make sure we have a fresh query before we start.

		$defaults = array(
					'limit' => 5,
					'image' => 0,
					'float' => 'none'
				 );

		$atts = shortcode_atts( $defaults, $atts );

		// Sanitize float attribute.
		if ( isset( $atts['float'] ) && ! in_array( $atts['float'], array( 'none', 'left', 'right' ) ) ) { $atts['float'] = 'none'; }

		// Float translation array.
		$floats = array( 'none' => '', 'left' => 'fl', 'right' => 'fr' );

		$css_class = 'woo-sc-related-posts';

		extract( $atts );

		if ( $float != 'none' ) { $css_class .= ' ' . $floats[$float]; }

		$output = '';

		$post_type = get_post_type( $post->ID );

		$post_type_obj = get_post_type_object( $post_type );

		$taxonomies_string = 'post_tag, category';
		$taxonomies = array( 'post_tag', 'category' );

		if ( isset( $post_type_obj->taxonomies ) && count( $post_type_obj->taxonomies ) > 0 ) {
			$taxonomies_string = join( ', ', $post_type_obj->taxonomies );
			$taxonomies = $post_type_obj->taxonomies;
		}

	 	// Clean up our taxonomies for use in the query.
	 	if ( count( $taxonomies ) ) {
	 		foreach ( $taxonomies as $k => $v ) {
	 			$taxonomies[$k] = trim( $v );
	 		}
	 	}

	 	// Determine which terms we're going to relate to this entry.
	 	$related_terms = array();

	 	foreach ( $taxonomies as $t ) {
	 		$terms = get_the_terms( $post->ID, $t );

	 		if ( ! empty( $terms ) ) {
	 			foreach ( $terms as $k => $v ) {
	 				$related_terms[$t][$v->term_id] = $v->slug;
	 			}
	 		}
	 	}

		$specific_terms = array();
		foreach ( $related_terms as $k => $v ) {
			foreach ( $v as $i => $j ) {
				$specific_terms[] = $j;
			}
		}

		$query_args = array(
 						'limit' => $atts['limit'],
 						'post_type' => $post_type,
 						'taxonomies' => $taxonomies_string,
 						'specific_terms' => $specific_terms,
 						'order' => 'DESC',
 						'orderby' => 'date',
 						'exclude' => array( $post->ID )
 					);

		$posts = woo_get_posts_by_taxonomy( $query_args );

		if ( count( (array)$posts ) ) {

			$output .= '<div class="' . $css_class . '">' . "\n";

			$output .= '<ul>' . "\n";

			foreach ( $posts as $post ) {
				setup_postdata( $post );

				if ( $image <= 0 ) {
					$image_html = '';
				} else {
					$image_html = '<a href="' . esc_url( get_permalink( $post->ID ) ) . '" class="thumbnail">' . woo_image( 'link=img&width=' . $image . '&height=' . esc_attr( $image ) . '&return=true&id=' . esc_attr( $post->ID ) ) . '</a>' . "\n";
				}

				$output .= '<li class="post-id-' . esc_attr( $post->ID ) . '">' . "\n" . $image_html . "\n" . '<a href="' . esc_url( get_permalink( $post->ID ) ) . '" title="' . the_title_attribute( array( 'echo' => 0 ) ) . '" class="related-title"><span>' . get_the_title( $post->ID )  . '</span></a>' . "\n" . '</li>' . "\n";
			}

			$output .= '</ul>' . "\n";
			$output .= '<div class="fix"></div><!--/.fix-->' . "\n";
			$output .= '</div><!--/.woo-sc-related-posts-->';
		}

		wp_reset_postdata();

		return apply_filters( 'woo_shortcode_related_posts', $output, $atts );

} // End woo_shortcode_related_posts()


/*-----------------------------------------------------------------------------------*/
/* woo_get_posts_by_taxonomy()
/*
/* Selects posts based on specified taxonomies.
/*
/* @since 4.5.0
/* @param array $args
/* @return array $posts
/*-----------------------------------------------------------------------------------*/

 function woo_get_posts_by_taxonomy ( $args = null ) {
 	global $wp_query;

 	$posts = array();

 	/* Parse arguments, and declare individual variables for each. */

 	$defaults = array(
 						'limit' => 5,
 						'post_type' => 'any',
 						'taxonomies' => 'post_tag, category',
 						'specific_terms' => '',
 						'relationship' => 'OR',
 						'order' => 'DESC',
 						'orderby' => 'date',
 						'operator' => 'IN',
 						'exclude' => ''
 					);

 	$args = wp_parse_args( $args, $defaults );

 	extract( $args, EXTR_SKIP );

 	// Make sure the order value is safe.
 	if ( ! in_array( $order, array( 'ASC', 'DESC' ) ) ) { $order = $defaults['order']; }

 	// Make sure the orderby value is safe.
 	if ( ! in_array( $orderby, array( 'none', 'id', 'author', 'title', 'date', 'modified', 'parent', 'rand', 'comment_count', 'menu_order' ) ) ) { $orderby = $defaults['orderby']; }

 	// Make sure the operator value is safe.
 	if ( ! in_array( $operator, array( 'IN', 'NOT IN', 'AND' ) ) ) { $orderby = $defaults['operator']; }

 	// Convert our post types to an array.
 	if ( ! is_array( $post_type ) ) { $post_type = explode( ',', $post_type ); }

 	// Convert our taxonomies to an array.
 	if ( ! is_array( $taxonomies ) ) { $taxonomies = explode( ',', $taxonomies ); }

 	// Convert exclude to an array.
 	if ( ! is_array( $exclude ) && ( $exclude != '' ) ) { $exclude = explode( ',', $exclude ); }

 	if ( ! count( (array)$taxonomies ) ) { return; }

 	// Clean up our taxonomies for use in the query.
 	if ( count( $taxonomies ) ) {
 		foreach ( $taxonomies as $k => $v ) {
 			$taxonomies[$k] = trim( $v );
 		}
 	}

 	// Determine which terms we're going to relate to this entry.
 	$related_terms = array();

 	foreach ( $taxonomies as $t ) {
 		$terms = get_terms( $t, 'orderby=id&hide_empty=1' );

 		if ( ! empty( $terms ) ) {
 			foreach ( $terms as $k => $v ) {
 				$related_terms[$t][$v->term_id] = $v->slug;
 			}
 		}
 	}

 	// If specific terms are available, use those.
 	if ( ! is_array( $specific_terms ) ) { $specific_terms = explode( ',', $specific_terms ); }

 	if ( count( $specific_terms ) ) {
 		foreach ( $specific_terms as $k => $v ) {
 			$specific_terms[$k] = trim( $v );
 		}
 	}

 	// Look for posts with the same terms.

 	// Setup query arguments.
 	$query_args = array();

 	if ( $post_type ) { $query_args['post_type'] = $post_type; }

 	if ( $limit ) {
 		$query_args['posts_per_page'] = $limit;
 		// $query_args['nopaging'] = true;
 	}

 	// Setup specific posts to exclude.
 	if ( count( $exclude ) > 0 ) {
 		$query_args['post__not_in'] = $exclude;
 	}

 	$query_args['order'] = $order;
 	$query_args['orderby'] = $orderby;

 	$query_args['tax_query'] = array();

 	// Setup for multiple taxonomies.

 	if ( count( $related_terms ) > 1 ) {
 		$query_args['tax_query']['relation'] = $args['relationship'];
 	}

 	// Add the taxonomies to the query arguments.

 	foreach ( (array)$related_terms as $k => $v ) {
 		$terms_for_search = array_values( $v );

 		if ( count( $specific_terms ) ) {
 			$specific_terms_by_tax = array();

 			foreach ( $specific_terms as $i => $j ) {
 				if ( in_array( $j, array_values( $v ) ) ) {
 					$specific_terms_by_tax[] = $j;
 				}
 			}

 			if ( count( $specific_terms_by_tax ) ) {
 				$terms_for_search = $specific_terms_by_tax;
 			}
 		}

 		$query_args['tax_query'][] = array(
			'taxonomy' => $k,
			'field' => 'slug',
			'terms' => $terms_for_search,
			'operator' => $operator
		);
 	}

 	if ( empty( $query_args['tax_query'] ) ) { return; }

 	$query_saved = $wp_query;

 	$query = new WP_Query( $query_args );

 	if ( $query->have_posts() ) {
 		while( $query->have_posts() ) {
 			$query->the_post();

 			$posts[] = $query->post;
 		}
 	}

 	$query = $query_saved;

 	wp_reset_query();

 	return $posts;
 } // End woo_get_posts_by_taxonomy()

function woo_shortcode_hr($atts, $content = null) {
   return '<div class="tt-sc-hr"></div>';
} // End woo_shortcode_hr()
add_shortcode( 'hr', 'woo_shortcode_hr' );

function woo_shortcode_divider($atts, $content = null) {
   return '<div class="tt-sc-divider"></div>';
} // End woo_shortcode_divider()
add_shortcode( 'divider', 'woo_shortcode_divider' );

function woo_shortcode_divider_flat($atts, $content = null) {
   return '<div class="tt-sc-divider flat"></div>';
} // End woo_shortcode_divider_flat()
add_shortcode( 'divider_flat', 'woo_shortcode_divider_flat' );

/*-----------------------------------------------------------------------------------*/
/* Subscribe / Connect */
/*-----------------------------------------------------------------------------------*/

if (!function_exists( 'woo_subscribe_connect')) {
	function woo_subscribe_connect($widget = 'false', $title = '', $form = '', $social = '', $contact_template = 'false') {

		//Setup default variables, overriding them if the "Theme Options" have been saved.
		$settings = array(
						'connect' => '0',
						'connect_title' => __('Subscribe' , 'templatation'),
						'connect_related' => '0',
						'connect_content' => __( 'Subscribe to our profiles on the following social networks.', 'templatation' ),
						'connect_newsletter_id' => '',
						'connect_mailchimp_list_url' => '',
						'feed_url' => '',
						'connect_rss' => '',
						'connect_twitter' => '',
						'connect_facebook' => '',
						'connect_youtube' => '',
						'connect_flickr' => '',
						'connect_linkedin' => '',
						'connect_pinterest' => '',
						'connect_instagram' => '',
						'connect_googleplus' => ''
						);
		$settings = tt_get_dynamic_values( $settings );

		// Setup title
		if ( $widget != 'true' )
			$title = $settings[ 'connect_title' ];

		// Setup related post (not in widget)
		$related_posts = '';
		if ( $settings[ 'connect_related' ] == "1" AND $widget != "true" )
			$related_posts = do_shortcode( '[related_posts limit="5"]' );

?>
	<?php if ( $settings[ 'connect' ] == "1" OR $widget == 'true' ) : ?>
	<aside id="connect" class="fix">
		<h3><?php if ( $title ) echo apply_filters( 'widget_title', $title ); else _e('Subscribe','templatation'); ?></h3>

		<div <?php if ( $related_posts != '' ) echo 'class="col-left"'; ?>>
			<?php if ($settings[ 'connect_content' ] != '' AND $contact_template == 'false') echo '<p>' . stripslashes($settings[ 'connect_content' ]) . '</p>'; ?>

			<?php if ( $settings[ 'connect_newsletter_id' ] != "" AND $form != 'on' ) : ?>
			<form class="newsletter-form<?php if ( $related_posts == '' ) echo ' fl'; ?>" action="http://feedburner.google.com/fb/a/mailverify" method="post" target="popupwindow" onsubmit="window.open( 'http://feedburner.google.com/fb/a/mailverify?uri=<?php echo $settings[ 'connect_newsletter_id' ]; ?>', 'popupwindow', 'scrollbars=yes,width=550,height=520' );return true">
				<input class="email" type="text" name="email" value="<?php esc_attr_e( 'E-mail', 'templatation' ); ?>" onfocus="if (this.value == '<?php _e( 'E-mail', 'templatation' ); ?>') {this.value = '';}" onblur="if (this.value == '') {this.value = '<?php _e( 'E-mail', 'templatation' ); ?>';}" />
				<input type="hidden" value="<?php echo $settings[ 'connect_newsletter_id' ]; ?>" name="uri"/>
				<input type="hidden" value="<?php bloginfo( 'name' ); ?>" name="title"/>
				<input type="hidden" name="loc" value="en_US"/>
				<input class="submit email-submit" type="submit" name="submit" value="<?php _e( 'Submit', 'templatation' ); ?>" />
			</form>
			<?php endif; ?>

			<?php if ( $settings['connect_mailchimp_list_url'] != "" AND $form != 'on' AND $settings['connect_newsletter_id'] == "" ) : ?>
			<!-- Begin MailChimp Signup Form -->
			<div id="mc_embed_signup">
				<form class="newsletter-form" action="<?php echo $settings['connect_mailchimp_list_url']; ?>" method="post" target="popupwindow" onsubmit="window.open('<?php echo $settings['connect_mailchimp_list_url']; ?>', 'popupwindow', 'scrollbars=yes,width=650,height=520');return true">
					<input type="text" name="EMAIL" class="required email" value="<?php _e('E-mail','templatation'); ?>"  id="mce-EMAIL" onfocus="if (this.value == '<?php _e('E-mail','templatation'); ?>') {this.value = '';}" onblur="if (this.value == '') {this.value = '<?php _e('E-mail','templatation'); ?>';}">
					<input type="submit" value="<?php _e('Submit', 'templatation'); ?>" name="subscribe" id="mc-embedded-subscribe" class="btn submit button">
				</form>
			</div>
			<!--End mc_embed_signup-->
			<?php endif; ?>

			<?php if ( $social != 'on' ) : ?>
			<div class="social<?php if ( $related_posts == '' AND $settings['connect_newsletter_id' ] != "" ) echo ' fr'; ?>">
		   		<?php if ( $settings['connect_rss' ] == "1" ) { ?>
		   		<a href="<?php if ( $settings['feed_url'] ) { echo esc_url( $settings['feed_url'] ); } else { echo get_bloginfo_rss('rss2_url'); } ?>" class="subscribe" title="RSS"></a>

		   		<?php } if ( $settings['connect_twitter' ] != "" ) { ?>
		   		<a href="<?php echo esc_url( $settings['connect_twitter'] ); ?>" class="twitter" title="Twitter"></a>

		   		<?php } if ( $settings['connect_facebook' ] != "" ) { ?>
		   		<a href="<?php echo esc_url( $settings['connect_facebook'] ); ?>" class="facebook" title="Facebook"></a>

		   		<?php } if ( $settings['connect_youtube' ] != "" ) { ?>
		   		<a href="<?php echo esc_url( $settings['connect_youtube'] ); ?>" class="youtube" title="YouTube"></a>

		   		<?php } if ( $settings['connect_flickr' ] != "" ) { ?>
		   		<a href="<?php echo esc_url( $settings['connect_flickr'] ); ?>" class="flickr" title="Flickr"></a>

		   		<?php } if ( $settings['connect_linkedin' ] != "" ) { ?>
		   		<a href="<?php echo esc_url( $settings['connect_linkedin'] ); ?>" class="linkedin" title="LinkedIn"></a>

		   		<?php } if ( $settings['connect_pinterest' ] != "" ) { ?>
		   		<a href="<?php echo esc_url( $settings['connect_pinterest'] ); ?>" class="pinterest" title="Pinterest"></a>

		   		<?php } if ( $settings['connect_instagram' ] != "" ) { ?>
		   		<a href="<?php echo esc_url( $settings['connect_instagram'] ); ?>" class="instagram" title="Instagram"></a>

		   		<?php } if ( $settings['connect_googleplus' ] != "" ) { ?>
		   		<a href="<?php echo esc_url( $settings['connect_googleplus'] ); ?>" class="googleplus" title="Google+"></a>

				<?php } ?>
			</div>
			<?php endif; ?>

		</div><!-- col-left -->

		<?php if ( $settings['connect_related' ] == "1" AND $related_posts != '' ) : ?>
		<div class="related-posts col-right">
			<h4><?php _e( 'Related Posts:', 'templatation' ); ?></h4>
			<?php echo $related_posts; ?>
		</div><!-- col-right -->
		<?php wp_reset_query(); endif; ?>

	</aside>
	<?php endif; ?>
<?php
	}
}

/*-----------------------------------------------------------------------------------*/
/* Comment Form Fields */
/*-----------------------------------------------------------------------------------*/

	add_filter( 'comment_form_default_fields', 'woo_comment_form_fields' );

	if ( ! function_exists( 'woo_comment_form_fields' ) ) {
		function woo_comment_form_fields ( $fields ) {

			$commenter = wp_get_current_commenter();

			$required_text = ' <span class="required">(' . __( 'Required', 'templatation' ) . ')</span>';

			$req = get_option( 'require_name_email' );
			$aria_req = ( $req ? " aria-required='true'" : '' );
			$fields =  array(
				'author' => '<p class="comment-form-author">' .
							'<input id="author" class="txt" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30"' . $aria_req . ' />' .
							'<label for="author">' . __( 'Name', 'templatation'  ) . ( $req ? $required_text : '' ) . '</label> ' .
							'</p>',
				'email'  => '<p class="comment-form-email">' .
				            '<input id="email" class="txt" name="email" type="text" value="' . esc_attr(  $commenter['comment_author_email'] ) . '" size="30"' . $aria_req . ' />' .
				            '<label for="email">' . __( 'Email', 'templatation'  ) . ( $req ? $required_text : '' ) . '</label> ' .
				            '</p>',
				'url'    => '<p class="comment-form-url">' .
				            '<input id="url" class="txt" name="url" type="text" value="' . esc_attr( $commenter['comment_author_url'] ) . '" size="30" />' .
				            '<label for="url">' . __( 'Website', 'templatation'  ) . '</label>' .
				            '</p>',
			);

			return $fields;

		} // End woo_comment_form_fields()
	}

/*-----------------------------------------------------------------------------------*/
/* Comment Form Settings */
/*-----------------------------------------------------------------------------------*/

	add_filter( 'comment_form_defaults', 'woo_comment_form_settings' );

	if ( ! function_exists( 'woo_comment_form_settings' ) ) {
		function woo_comment_form_settings ( $settings ) {

			$settings['comment_notes_before'] = '';
			$settings['comment_notes_after'] = '';
			$settings['label_submit'] = __( 'Submit Comment', 'templatation' );
			$settings['cancel_reply_link'] = __( 'Click here to cancel reply.', 'templatation' );

			return $settings;

		} // End woo_comment_form_settings()
	}

	/*-----------------------------------------------------------------------------------*/
	/* Misc back compat */
	/*-----------------------------------------------------------------------------------*/

	// array_fill_keys doesn't exist in PHP < 5.2
	// Can remove this after PHP <  5.2 support is dropped
	if ( !function_exists( 'array_fill_keys' ) ) {
		function array_fill_keys( $keys, $value ) {
			return array_combine( $keys, array_fill( 0, count( $keys ), $value ) );
		}
	}

/*-----------------------------------------------------------------------------------*/
/**
 * woo_archive_description()
 *
 * Display a description, if available, for the archive being viewed (category, tag, other taxonomy).
 *
 * @since V1.0.0
 * @uses do_atomic(), get_queried_object(), term_description()
 * @echo string
 * @filter woo_archive_description
 */

if ( ! function_exists( 'woo_archive_description' ) ) {
	function woo_archive_description ( $echo = true ) {
		do_action( 'woo_archive_description' );

		// Archive Description, if one is available.
		$term_obj = get_queried_object();
		$description = term_description( $term_obj->term_id, $term_obj->taxonomy );

		if ( $description != '' ) {
			// Allow child themes/plugins to filter here ( 1: text in DIV and paragraph, 2: term object )
			$description = apply_filters( 'woo_archive_description', '<div class="archive-description">' . $description . '</div><!--/.archive-description-->', $term_obj );
		}

		if ( $echo != true ) { return $description; }

		echo $description;
	} // End woo_archive_description()
}

/*-----------------------------------------------------------------------------------*/
/* WooPagination Markup */
/*-----------------------------------------------------------------------------------*/

add_filter( 'woo_pagination_args', 'woo_pagination_html5_markup', 2 );

function woo_pagination_html5_markup ( $args ) {
	$args['before'] = '<nav class="pagination woo-pagination">';
	$args['after'] = '</nav>';

	return $args;
} // End woo_pagination_html5_markup()


/*-----------------------------------------------------------------------------------*/
/* Google Maps */
/*-----------------------------------------------------------------------------------*/

function woo_maps_contact_output($args){
	global $tt_options;
	$key = get_option('woo_maps_apikey');

	// No More API Key needed

	if ( !is_array($args) )
		parse_str( $args, $args );

	extract($args);
	$mode = '';
	$streetview = 'off';
	$map_height = $tt_options['tt_maps_single_height'];
//	$featured_w = $tt_options['tt_home_featured_w']['width'];
//	$featured_h = $tt_options['tt_home_featured_h']['height'];
	$zoom = $tt_options['tt_maps_default_mapzoom'];
	$type = $tt_options['tt_maps_default_maptype'];
	$marker_title = $tt_options['tt_contact_title'];
	if ( $zoom == '' ) { $zoom = 6; }
//	$lang = $tt_options['tt_maps_directions_locale'];
	$locale = '';
	if(!empty($lang)){
		$locale = ',locale :"'.$lang.'"';
	}
	$extra_params = ',{travelMode:G_TRAVEL_MODE_WALKING,avoidHighways:true '.$locale.'}';

	if(empty($map_height)) { $map_height = 250;}

	if(is_home() && !empty($featured_h) && !empty($featured_w)){
	?>
    <div id="single_map_canvas" style="width:<?php echo $featured_w; ?>px; height: <?php echo $featured_h; ?>px"></div>
    <?php } else { ?>
    <div id="single_map_canvas" style="width:100%; height: <?php echo $map_height; ?>px"></div>
    <?php } ?>
    <script type="text/javascript">
		jQuery(document).ready(function(){
			function initialize() {


			<?php if($streetview == 'on'){ ?>


			<?php } else { ?>

			  	<?php switch ($type) {
			  			case 'G_NORMAL_MAP':
			  				$type = 'ROADMAP';
			  				break;
			  			case 'G_SATELLITE_MAP':
			  				$type = 'SATELLITE';
			  				break;
			  			case 'G_HYBRID_MAP':
			  				$type = 'HYBRID';
			  				break;
			  			case 'G_PHYSICAL_MAP':
			  				$type = 'TERRAIN';
			  				break;
			  			default:
			  				$type = 'ROADMAP';
			  				break;
			  	} ?>

			  	var myLatlng = new google.maps.LatLng(<?php echo $geocoords; ?>);
				var myOptions = {
				  zoom: <?php echo $zoom; ?>,
				  center: myLatlng,
				  mapTypeId: google.maps.MapTypeId.<?php echo $type; ?>
				};
				<?php if( $tt_options['tt_maps_scroll'] == '1'){ ?>
			  	myOptions.scrollwheel = false;
			  	<?php } ?>
			  	var map = new google.maps.Map(document.getElementById("single_map_canvas"),  myOptions);

				<?php if($mode == 'directions'){ ?>
			  	directionsPanel = document.getElementById("featured-route");
 				directions = new GDirections(map, directionsPanel);
  				directions.load("from: <?php echo $from; ?> to: <?php echo $to; ?>" <?php if($walking == 'on'){ echo $extra_params;} ?>);
			  	<?php
			 	} else { ?>

			  		var point = new google.maps.LatLng(<?php echo $geocoords; ?>);
	  				var root = "<?php echo esc_url( get_template_directory_uri() ); ?>";
	  				var callout = '<?php echo preg_replace("/[\n\r]/","<br/>", $tt_options['tt_maps_callout_text']); ?>';
	  				var the_link = '<?php echo get_permalink(get_the_id()); ?>';
	  				<?php $title = str_replace(array('&#8220;','&#8221;'),'"', $marker_title); ?>
	  				<?php $title = str_replace('&#8211;','-',$title); ?>
	  				<?php $title = str_replace('&#8217;',"`",$title); ?>
	  				<?php $title = str_replace('&#038;','&',$title); ?>
	  				var the_title = '<?php echo html_entity_decode($title) ?>';

	  			<?php
			 	if(is_page()){
/*			 		$custom = $tt_options['tt_cat_custom_marker_pages'];
					if(!empty($custom)){
						$color = $custom;
					}
					else {
						$color = $tt_options['tt_cat_colors_pages'];
						if (empty($color)) {
							$color = 'red';
						}
					}*/
					$color = 'red';
			 	?>
			 		var color = '<?php echo $color; ?>';
			 		createMarker(map,point,root,the_link,the_title,color,callout);
			 	<?php } else { ?>
			 		var color = '<?php echo $tt_options['tt_cat_colors_pages']; ?>';
	  				createMarker(map,point,root,the_link,the_title,color,callout);
				<?php
				}
					if(isset($_POST['woo_maps_directions_search'])){ ?>

					directionsPanel = document.getElementById("featured-route");
 					directions = new GDirections(map, directionsPanel);
  					directions.load("from: <?php echo htmlspecialchars($_POST['woo_maps_directions_search']); ?> to: <?php echo $address; ?>" <?php if($walking == 'on'){ echo $extra_params;} ?>);



					directionsDisplay = new google.maps.DirectionsRenderer();
					directionsDisplay.setMap(map);
    				directionsDisplay.setPanel(document.getElementById("featured-route"));

					<?php if($walking == 'on'){ ?>
					var travelmodesetting = google.maps.DirectionsTravelMode.WALKING;
					<?php } else { ?>
					var travelmodesetting = google.maps.DirectionsTravelMode.DRIVING;
					<?php } ?>
					var start = '<?php echo htmlspecialchars($_POST['woo_maps_directions_search']); ?>';
					var end = '<?php echo $address; ?>';
					var request = {
       					origin:start,
        				destination:end,
        				travelMode: travelmodesetting
    				};
    				directionsService.route(request, function(response, status) {
      					if (status == google.maps.DirectionsStatus.OK) {
        					directionsDisplay.setDirections(response);
      					}
      				});

  					<?php } ?>
				<?php } ?>
			<?php } ?>


			  }
			  function handleNoFlash(errorCode) {
				  if (errorCode == FLASH_UNAVAILABLE) {
					alert("Error: Flash doesn't appear to be supported by your browser");
					return;
				  }
				 }



		initialize();

		});
	jQuery(window).load(function(){

		var newHeight = jQuery('#featured-content').height();
		newHeight = newHeight - 5;
		if(newHeight > 300){
			jQuery('#single_map_canvas').height(newHeight);
		}

	});

	</script>

<?php
}


/*-----------------------------------------------------------------------------------*/
/* Function for color switcher and lang switcher. */
/*-----------------------------------------------------------------------------------*/
/*
 * it only works on demo websites, where its needed by the way.
 */
if( strpos(get_site_url(),'justshopwp.templatation') || strpos(get_site_url(),'justshop60.staging.wpengine') ) {
	//add_action('justshop_fw_after_body', 'justshop_fw_clr_switcher');
	add_action('woo_head', 'justshop_fw_clr_switcher_scripts');
	add_action('woo_header_before', 'justshop_clr_swit_fn');
	add_action('woo_top', 'justshop_clr_swit_cont');
	//add_action('wp_head', 'justshop_fw_clr_switcher_scripts');
}

if (!function_exists('justshop_fw_clr_switcher_scripts')) {
	function justshop_fw_clr_switcher_scripts() {
		$output = '';
		ob_start(); ?>


<!-------------------------------------------------------------------/
Color switcher for demo, to be removed from live website.
<!------------------------------------------------------------------->

<script type="text/javascript" src="<?php bloginfo( 'template_url' ); ?>/includes/jscript_styleswitcher.js"></script>
	<?php if( $_GET['default'] == 'yes') { ?>
<script type="text/javascript">
				eraseCookie("style");
				eraseCookie("tt_bodybgimg");
				eraseCookie("tt_header_layout");
				window.location = window.location.pathname;
</script>
<?php } ?>
<link rel="stylesheet" href="<?php bloginfo( 'template_url' ); ?>/includes/styleswitcher.css" />

<!-- Skins Color FOR DEMO WEBSITE -->
<link rel="alternate stylesheet" href="<?php bloginfo( 'template_url' ); ?>/styles/blue.css" title="style-blue" />
<link rel="alternate stylesheet" href="<?php bloginfo( 'template_url' ); ?>/styles/pink.css" title="style-pink" />
<link rel="alternate stylesheet" href="<?php bloginfo( 'template_url' ); ?>/styles/purple.css" title="style-purple" />
<link rel="alternate stylesheet" href="<?php bloginfo( 'template_url' ); ?>/styles/green.css" title="style-green" />
<link rel="alternate stylesheet" href="<?php bloginfo( 'template_url' ); ?>/styles/brown.css" title="style-brown" />
<!-- EOF OF DEMO WEBSITE CODE -->


<!-------------------------------------------------------------------/
EOF Color switcher for demo, to be removed from live website.
<!------------------------------------------------------------------->
		<?php
		$output = ob_get_clean();
		print $output; // its safe to output, all variables already escaped above.
}
}
/* justshop_fw_clr_switcher_scripts */

if (!function_exists('justshop_clr_swit_fn')) {
	function justshop_clr_swit_fn() {
	global $tt_options;
	$tt_header_layout = $tt_bodybgimg = '';
	if(isset($_COOKIE['tt_header_layout']))
	$tt_options['tt_header_section_layout'] = $_COOKIE['tt_header_layout'];
	add_filter( 'body_class', 'ttdemo_body_class', 10 );// Add layout to body_class output
// slider setup
	remove_action( 'woo_nav_after', 'justshop_slider', 0 );
	remove_action( 'woo_content_before', 'justshop_slider', 0 );
	if ( ! isset( $tt_options['tt_header_section_layout'] ) || $tt_options['tt_header_section_layout'] == 'layout2' || $tt_options['tt_header_section_layout'] == 'layout3' || $tt_options['tt_header_section_layout'] == 'layout5' || $tt_options['tt_header_section_layout'] == 'layout6' ) {
		add_action( 'woo_content_before', 'justshop_slider', 0 ); // hook slider after header container
	} else {
		add_action( 'woo_nav_after', 'justshop_slider', 0 ); // hook slider inside header container
	}

	if ( $tt_options['tt_header_section_layout'] == 'layout3' ) {
		$tt_options['tt_slider_area_content'] = '[rev_slider layout3]';
	}
	if ( $tt_options['tt_header_section_layout'] == 'layout4' ) {
		$tt_options['tt_slider_area_content'] = '[rev_slider layout4]';
		$tt_options['tt_enable_topbar']       = '0';
		$tt_options['tt_retina_favicon']      = '0';
		$tt_options['tt_logo']['url']         = 'http://cdn.templatation.com/images/cdn/misc/jslogo-2.png';
	}
	if ( $tt_options['tt_header_section_layout'] == 'layout5' ) {
		$tt_options['tt_slider_area_content'] = '[rev_slider layout4]';
		$tt_options['tt_retina_favicon']      = '0';
		$tt_options['tt_logo']['url']           = 'http://cdn.templatation.com/images/cdn/misc/jslogo-5.png';

	}

}
}
/* justshop_clr_swit_fn */

function ttdemo_body_class( $classes ){
	if(isset($_COOKIE['tt_bodybgimg']))
	$classes[] = $_COOKIE['tt_bodybgimg'];
	return $classes;

}

function justshop_clr_swit_cont(){
		$output = '';
		ob_start(); ?>


<!-------------------------------------------------------------------/
Color switcher for demo, to be removed from live website.
<!------------------------------------------------------------------->

    <!-- ADD Switcher -->
            <div class="demo_changer">
                <div class="demo-icon"><i class="fa fa-gear"></i></div>
                <div class="form_holder">
                    <p>THEME OPTIONS</p>

                    <div class="predefined_styles">
					 <div class="switcher-box">
						<a title="style-blue" class="styleswitch blue" rel="style-blue"></a>
						<a title="style-pink" class="styleswitch pink" rel="style-pink"></a>
						<a title="style-purple" class="styleswitch purple" rel="style-purple"></a>
						<a title="style-green" class="styleswitch green" rel="style-green"></a>
						<!-- <a title="style-orange" class="styleswitch orange" rel="style-orange"></a>-->
						<a title="style-brown" class="styleswitch brown" rel="style-brown"></a>
					</div><!-- End switcher-box -->
                    <div class="clear"></div>
                    </div>
                    <p>Customize using color pickers !</p>
                    <div class="line"></div>
                    <p>HEADER LAYOUTS</p>
                    <ul class="select-boxes">
                        <li>
                            <select name="select_header_layout">
                                <option value="layout2">Header Layout 2</option>
                                <option value="layout3">Header Layout 3</option>
                                <option value="layout4">Header Layout 4</option>
                                <option value="layout5">Header Layout 5</option>
                                <option value="layout6">Header Layout 6</option>
                                <option value="layout7">Header Layout 7</option>
                            </select>
                        </li>
                    </ul>
                    <div class="line"></div>
                    <p>BODY BACKGROUND</p>

                    <div class="predefined_styles">
					 <div class="switcher-box">
						<a title="bodybg12" class="bodybgswitch bodybg12" rel="bodybg12"><img src="<?php echo get_template_directory_uri(); ?>/images/bodybg/front/restaurant_icons.png" /> </a>
						<a title="bodybg10" class="bodybgswitch bodybg10" rel="bodybg10"><img src="<?php echo get_template_directory_uri(); ?>/images/bodybg/front/retina_wood.png" /> </a>
						<a title="bodybg1" class="bodybgswitch bodybg1" rel="bodybg1"><img src="<?php echo get_template_directory_uri(); ?>/images/bodybg/front/grunge_wall.png" /> </a>
<!--						<a title="bodybg2" class="bodybgswitch bodybg2" rel="bodybg2"><img src="<?php echo get_template_directory_uri(); ?>/images/bodybg/front/03.png" /> </a>
						<a title="bodybg6" class="bodybgswitch bodybg6" rel="bodybg6"><img src="<?php echo get_template_directory_uri(); ?>/images/bodybg/front/07.png" /> </a>
<a title="bodybg4" class="bodybgswitch bodybg4" rel="bodybg4"><img src="<?php echo get_template_directory_uri(); ?>/images/bodybg/front/05.png" /> </a>
-->
						<a title="bodybg3" class="bodybgswitch bodybg3" rel="bodybg3"><img src="<?php echo get_template_directory_uri(); ?>/images/bodybg/front/04.png" /> </a>
						<a title="bodybg5" class="bodybgswitch bodybg5" rel="bodybg5"><img src="<?php echo get_template_directory_uri(); ?>/images/bodybg/front/06.png" /> </a>
						<a title="bodybg7" class="bodybgswitch bodybg7" rel="bodybg7"><img src="<?php echo get_template_directory_uri(); ?>/images/bodybg/front/08.png" /> </a>
						<a title="bodybg8" class="bodybgswitch bodybg8" rel="bodybg8"><img src="<?php echo get_template_directory_uri(); ?>/images/bodybg/front/white_wall_hash.png" /> </a>
						<a title="bodybg9" class="bodybgswitch bodybg9" rel="bodybg9"><img src="<?php echo get_template_directory_uri(); ?>/images/bodybg/front/009.png" /> </a>
						<a title="bodybg11" class="bodybgswitch bodybg11" rel="bodybg11"><img src="<?php echo get_template_directory_uri(); ?>/images/bodybg/front/shattered.png" /> </a>
					</div><!-- End switcher-box -->
                    <div class="clear"></div>
                    </div>
	                <div class="line"></div>
<!--
	                <p>LAYOUT</p>

					<ul class="cols">
						<li><a href="#" class="boxed-layout">Boxed</a></li>
						<li><a href="#" class="widescreen-layout">Wide</a></li>
					</ul>
-->

					<span class="switcherreset clear"><a rel="stylesheet" class="styleswitch switcherreset" href="?default=true">RESET TO DEFAULT</a>
					<span class="clear"><a rel="stylesheet" class="normallink" href="http://templatation.com/justshop-wordpress-theme/">Back to landing page</a></span>
                    <span class="clear"><a rel="stylesheet" class="buy normallink" href="http://themeforest.net/item/justshop-premium-beautiful-woocommerce-theme/4747148?ref=templatation">BUY JUSTSHOP</a></span>
                   <div class="line"></div>
                </div>
            </div>
<style type="text/css">
body.bodybg1 {
    background-image: url("<?php echo get_template_directory_uri(); ?>/images/bodybg/grunge_wall.png") !important;
}
body.bodybg2 {
    background-image: url("<?php echo get_template_directory_uri(); ?>/images/bodybg/03.png") !important;
}
body.bodybg3 {
    background-image: url("<?php echo get_template_directory_uri(); ?>/images/bodybg/04.png") !important;
}
body.bodybg4 {
    background-image: url("<?php echo get_template_directory_uri(); ?>/images/bodybg/05.png") !important;
}
body.bodybg5 {
    background-image: url("<?php echo get_template_directory_uri(); ?>/images/bodybg/06.png") !important;
}
body.bodybg6 {
    background-image: url("<?php echo get_template_directory_uri(); ?>/images/bodybg/07.png") !important;
}
body.bodybg7 {
    background-image: url("<?php echo get_template_directory_uri(); ?>/images/bodybg/08.png") !important;
}
body.bodybg8 {
    background-image: url("<?php echo get_template_directory_uri(); ?>/images/bodybg/white_wall_hash.png") !important;
}
body.bodybg9 {
    background-image: url("<?php echo get_template_directory_uri(); ?>/images/bodybg/009.png") !important;
}
body.bodybg10 {
    background-image: url("<?php echo get_template_directory_uri(); ?>/images/bodybg/retina_wood.png") !important;
}
body.bodybg11 {
    background-image: url("<?php echo get_template_directory_uri(); ?>/images/bodybg/shattered.png") !important;
}
body.bodybg12 {
    background-image: url("<?php echo get_template_directory_uri(); ?>/images/bodybg/restaurant_icons.png") !important;
}
</style>
	<!-- END Switcher -->
<!-------------------------------------------------------------------/
EOF Color switcher for demo, to be removed from live website.
<!------------------------------------------------------------------->

		<?php
		$output = ob_get_clean();
		print $output; // its safe to output, all variables already escaped above.

} /* justshop_clr_swit_cont */

/*-----------------------------------------------------------------------------------*/
/* Is IE */
/*-----------------------------------------------------------------------------------*/

if ( ! function_exists( 'is_ie' ) ) {
	function is_ie ( $version = '6.0' ) {
		$supported_versions = array( '6.0', '7.0', '8.0', '9.0' );
		$agent = substr( $_SERVER['HTTP_USER_AGENT'], 25, 4 );
		$current_version = substr( $_SERVER['HTTP_USER_AGENT'], 30, 3 );
		$response = false;
		if ( in_array( $version, $supported_versions ) && 'MSIE' == $agent && ( $version == $current_version ) ) {
			$response = true;
		}

		return $response;
	} // End is_ie()
}

/*-----------------------------------------------------------------------------------*/
/* Check if WooCommerce is activated */
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'is_woocommerce_activated' ) ) {
	function is_woocommerce_activated() {
		if ( class_exists( 'woocommerce' ) ) { return true; } else { return false; }
	}
}

/*-----------------------------------------------------------------------------------*/
/* Truncate */
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'justshop_truncate' ) ) {
	function justshop_truncate($text, $limit) {
		if (str_word_count($text, 0) > $limit) {
			$words = str_word_count($text, 2);
			$pos = array_keys($words);
			$text = strip_tags( $text );
			$text = substr($text, 0, $pos[$limit]) . '...';
		}
		return $text;
	}
}

/*-----------------------------------------------------------------------------------*/
/* Infinite Scroll */
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'justshop_infinite_scroll_js' ) ) {
	function justshop_infinite_scroll_js() {
		global $tt_options;
		if ( !isset( $tt_options['tt_woocommerce_archives_infinite_scroll'] ))  $tt_options['tt_woocommerce_archives_infinite_scroll'] = '1';
	    if ( ( $tt_options['tt_woocommerce_archives_infinite_scroll'] == '1' ) && ( is_shop() || is_product_category() ) ) { ?>
	    <script>
	    if ( ! navigator.userAgent.match(/(iPod|iPhone|iPad|Android)/)) {
		    var infinite_scroll = {
		        loading: {
		            img: "<?php echo get_template_directory_uri(); ?>/images/ajax-loader.gif",
		            msgText: "<?php _e( 'Loading the next set of products...', 'templatation' ); ?>",
		            finishedMsg: "<?php _e( 'All products loaded.', 'templatation' ); ?>"
		        },
		        "nextSelector":".pagination a.next",
		        "navSelector":".pagination",
		        "itemSelector":"#main .product",
		        "contentSelector":"#main ul.products"
		    };
		    jQuery( infinite_scroll.contentSelector ).infinitescroll( infinite_scroll );
		}
	    </script>
	    <?php
	    }
	}
}
if (is_woocommerce_activated()) {
	add_action( 'wp_footer', 'justshop_infinite_scroll_js',100 );
}


/*-----------------------------------------------------------------------------------*/
/* Custom Post Type - Portfolio Item (Portfolio Component) */
/*-----------------------------------------------------------------------------------*/

if ( ! function_exists( 'woo_add_portfolio' ) ) {
	function woo_add_portfolio() {
	
		global $tt_options;
	
		// "Portfolio Item" Custom Post Type
		$labels = array(
			'name' => _x( 'Portfolio', 'post type general name', 'templatation' ),
			'singular_name' => _x( 'Portfolio Item', 'post type singular name', 'templatation' ),
			'menu_name' => __( 'Cakes/Portfolio', 'templatation' ),
			'add_new' => _x( 'Add New', 'slide', 'templatation' ),
			'add_new_item' => __( 'Add New Portfolio Item', 'templatation' ),
			'edit_item' => __( 'Edit Portfolio Item', 'templatation' ),
			'new_item' => __( 'New Portfolio Item', 'templatation' ),
			'view_item' => __( 'View Portfolio Item', 'templatation' ),
			'search_items' => __( 'Search Portfolio Items', 'templatation' ),
			'not_found' =>  __( 'No portfolio items found', 'templatation' ),
			'not_found_in_trash' => __( 'No portfolio items found in Trash', 'templatation' ), 
			'parent_item_colon' => ''
		);
		
		$portfolioitems_rewrite = get_option( 'woo_portfolioitems_rewrite' );
 		if( empty( $portfolioitems_rewrite ) ) { $portfolioitems_rewrite = 'portfolio-items'; }
		
		$args = array(
			'labels' => $labels,
			'public' => true,
			'publicly_queryable' => true,
			'show_ui' => true, 
			'query_var' => true,
			'rewrite' => array( 'slug' => $portfolioitems_rewrite ),
			'capability_type' => 'post',
			'hierarchical' => false,
			'menu_icon' => get_template_directory_uri() .'/includes/images/portfolio.png',
			'menu_position' => null, 
			'has_archive' => true, 
			'taxonomies' => array( 'portfolio-gallery','post_tag' ), 
			'supports' => array( 'title','editor','thumbnail', 'comments')
		);
		
		if ( isset( $tt_options['tt_portfolio_excludesearch'] ) && ( $tt_options['tt_portfolio_excludesearch'] == '1' ) ) {
			$args['exclude_from_search'] = true;
		}
		
		register_post_type( 'portfolio', $args );
		
		// "Portfolio Galleries" Custom Taxonomy
		$labels = array(
			'name' => _x( 'Portfolio Galleries', 'taxonomy general name', 'templatation' ),
			'singular_name' => _x( 'Portfolio Gallery', 'taxonomy singular name', 'templatation' ),
			'search_items' =>  __( 'Search Portfolio Galleries', 'templatation' ),
			'all_items' => __( 'All Portfolio Galleries', 'templatation' ),
			'parent_item' => __( 'Parent Portfolio Gallery', 'templatation' ),
			'parent_item_colon' => __( 'Parent Portfolio Gallery:', 'templatation' ),
			'edit_item' => __( 'Edit Portfolio Gallery', 'templatation' ), 
			'update_item' => __( 'Update Portfolio Gallery', 'templatation' ),
			'add_new_item' => __( 'Add New Portfolio Gallery', 'templatation' ),
			'new_item_name' => __( 'New Portfolio Gallery Name', 'templatation' ),
			'menu_name' => __( 'Portfolio Galleries', 'templatation' )
		); 	
		
		$args = array(
			'hierarchical' => true,
			'labels' => $labels,
			'show_ui' => true,
			'query_var' => true,
			'rewrite' => array( 'slug' => 'portfolio-gallery' )
		);
		
		register_taxonomy( 'portfolio-gallery', array( 'portfolio' ), $args );
	}
	
	add_action( 'init', 'woo_add_portfolio' );
}

/*-----------------------------------------------------------------------------------*/
/* Custom Post Type - Misc live composer pages                                       */
/*-----------------------------------------------------------------------------------*/
/*
// Check if Live Composer is active
if ( defined( 'DS_LIVE_COMPOSER_URL' ) ) {

	/**
	 * ----------------------------------------------------------------------
	 * Special content type for live composer archive templates
	 */

	// Register Custom Post Type
/*	add_action( 'init', 'woo_misc_cpt', 0 );
	function woo_misc_cpt() {

		$labels = array(
			'name'               => _x( 'Misc Page Templates', 'Post Type General Name', 'templatation' ),
			'singular_name'      => _x( 'Misc Page Template', 'Post Type Singular Name', 'templatation' ),
			'all_items'          => __( 'All Templates', 'templatation' ),
			'view_item'          => __( 'View Template', 'templatation' ),
			'add_new_item'       => __( 'Add New Template', 'templatation' ),
			'add_new'            => __( 'Add Template', 'templatation' ),
			'edit_item'          => __( 'Edit Template', 'templatation' ),
			'update_item'        => __( 'Update Template', 'templatation' ),
			'not_found'          => __( 'Not found', 'templatation' ),
			'not_found_in_trash' => __( 'Not found in Trash', 'templatation' ),
		);
		$args   = array(
			'label'               => __( 'woo_misc', 'templatation' ),
			'labels'              => $labels,
			'supports'            => array( 'title', 'custom-fields', ),
			'hierarchical'        => false,
			'public'              => true,
			'show_ui'             => true,
			'show_in_menu'        => false,
			'show_in_nav_menus'   => false,
			'show_in_admin_bar'   => false,
			'menu_position'       => 6,
			'menu_icon'           => '',
			'can_export'          => true,
			'has_archive'         => true,
			'exclude_from_search' => true,
			'publicly_queryable'  => true,
			'capability_type'     => 'page',
		);
		register_post_type( 'woo_misc', $args );
	}


	add_action( 'admin_menu', 'woo_misc_menu' );
	function woo_misc_menu() {
		add_theme_page( 'Misc Page Templates', 'Misc Page Templates', 'edit_theme_options', 'edit.php?post_type=woo_misc', '' );
	}
}*/


/*-----------------------------------------------------------------------------------*/
/* Custom Post Type - Footer Item  */
/*-----------------------------------------------------------------------------------*/

/*
if ( ! function_exists( 'woo_add_LC_footer' ) ) {
	function woo_add_LC_footer() {

		global $tt_options;

		// "Portfolio Item" Custom Post Type
		$labels = array(
			'name' => _x( 'Theme Footers', 'post type general name', 'templatation' ),
			'singular_name' => _x( 'Theme Footer', 'post type singular name', 'templatation' ),
			//'menu_name' => __( 'Cakes/Portfolio', 'templatation' ),
			'add_new' => _x( 'Add Footer', 'slide', 'templatation' ),
			'add_new_item' => __( 'Add New Footer', 'templatation' ),
			'all_items'           => __( 'All Footers', 'templatation' ),
			'edit_item' => __( 'Edit Footer', 'templatation' ),
			'new_item' => __( 'New Footer', 'templatation' ),
			'view_item' => __( 'View Footer', 'templatation' ),
			//'search_items' => __( 'Search Portfolio Items', 'templatation' ),
			'not_found' =>  __( 'No Footer found', 'templatation' ),
			'not_found_in_trash' => __( 'No Footer items found in Trash', 'templatation' ),
			//'parent_item_colon' => ''
		);

		$args = array(
			'label'               => __( 'woo_lc_footer', 'templatation' ),
			// 'description'         => __( 'Post Type Description', 'templatation' ),
			'labels'              => $labels,
			'supports'            => array( 'title', 'custom-fields', ),
			// 'taxonomies'          => array( 'category', 'post_tag' ),
			'hierarchical'        => false,
			'public'              => true,
			'show_ui'             => true,
			'show_in_menu'        => false,
			'show_in_nav_menus'   => false,
			'show_in_admin_bar'   => false,
			'menu_position'       => 5.1,
			'menu_icon'           => '',
			'can_export'          => true,
			'has_archive'         => true,
			'exclude_from_search' => true,
			'publicly_queryable'  => true,
			'capability_type'     => 'page',
		);

		register_post_type( 'woo_lc_footer', $args );
	}

	add_action( 'init', 'woo_add_LC_footer' );
}

	// Create custom Apperance > Footers menu item
	add_action('admin_menu', 'woo_footer_add_menu');
	function woo_footer_add_menu(){
		  add_theme_page( 'Theme Footers', 'Footers', 'edit_theme_options', 'edit.php?post_type=woo_lc_footer', '');
	}*/

/*-----------------------------------------------------------------------------------*/
/* Getting custom footer post id for given page */
/*-----------------------------------------------------------------------------------*/
/**
 * ----------------------------------------------------------------------
 * Get the custom footer post (lbmn_footer content type) id for the current page
 */
function woo_get_footerid_by_pageid ($pageid) {
	if ( is_plugin_active('ds-live-composer/ds-live-composer.php') ) {

		$footer_post_id = '';

		// If no custom footer set get default footer defined in Theme Customizer
		if ( ! $footer_post_id ) {

			// Get footer page ID defined in Theme Customizer
			$footer_post_id = get_theme_mod( 'lbmn_footer_design');

			// If no footer set in Theme Customizer check what default we have set
			// I don't want to run 'get_page_by_title' on every page load
			if ( !$footer_post_id ) {
				// Get default footer custom post id
				$footer_design_default = get_page_by_title(LBMN_FOOTER_DESIGN_TITLE_DEFAULT, 'ARRAY_A', 'lbmn_footer');
				if ( isset($footer_design_default) ) {
					$footer_design_default = $footer_design_default['ID'];
				} else {
					$footer_design_default = '';
				}

				$footer_post_id = get_theme_mod( 'lbmn_footer_design', $footer_design_default );
			}
		}

		/* WPML translated footers support */
		/* http://wpml.org/documentation/support/creating-multilingual-wordpress-themes/language-dependent-ids/ */
		if ( $footer_post_id  && function_exists('icl_object_id')) {
			$footer_post_id = icl_object_id($footer_post_id,'lbmn_footer',true);
		}

		return $footer_post_id;
	} else {
		return false;
	}
}

/*-----------------------------------------------------------------------------------*/
/* Woo Portfolio Navigation */
/*-----------------------------------------------------------------------------------*/

if ( ! function_exists( 'woo_portfolio_navigation' ) ) {
	function woo_portfolio_navigation ( $galleries, $settings = array(), $toggle_pagination = false ) {

		// Sanity check.
		if ( ! is_array( $galleries ) || ( count( $galleries ) <= 0 ) ) { return; }
		
		global $tt_options, $wp_query;
		
		$defaults = array(
						'id' => 'port-tags', 
						'label' => '', 
						'display_all' => true, 
						'current' => 'all'
						 );
		
		$settings = wp_parse_args( $settings, $defaults );
					 
		$settings = apply_filters( 'woo_portfolio_navigation_args', $settings );
		
		// Prepare the anchor tags of the various gallery items.
		$gallery_anchors = '';
		foreach ( $galleries as $g ) {
			$current_class = '';

			if ( $settings['current'] == $g->term_id ) {
				$current_class = ' current';
			}

$permalink = '#' . $g->slug;
if ( is_tax() || $toggle_pagination == true ) {
	$permalink = get_term_link( $g, 'portfolio-gallery' );
}

$gallery_anchors .= '<li><a href="' . $permalink . '" rel="' . $g->slug . '" data-option-value=".' . $g->slug . '" class="navigation-slug-' . $g->slug . ' navigation-id-' . $g->term_id . $current_class . '">' . $g->name . '</a></li>' . "\n";
		}
		
		$html = '<div id="' . $settings['id'] . '" class="port-tags">' . "\n";
				$html .= '<ul class="port-cat">' . "\n";
				
				// Display label, if one is set.
				if ( $settings['label'] != '' ) { $html .= $settings['label'] . ' '; }
				
				// Display "All", if set to "true".
				if ( $settings['display_all'] == 'all' ) {
					$all_permalink = '#';
					if ( is_tax() || $toggle_pagination == true ) {
						$all_permalink = get_post_type_archive_link( 'portfolio' );
					}
					
					$all_current = '';
					if ( $settings['current'] == 'all' ) {
						$all_current = ' class="current"';
					}
					$html .= '<li ' . $all_current . '><a href="' . $all_permalink . '" data-option-value="*" rel="all">' . __( 'All','templatation' ) . '</a></li> ';
				}
				
				// Add the gallery anchors in.
				$html .= $gallery_anchors;
				
				$html .= '</ul>' . "\n";
			$html .= '<div class="fix"></div>' . "\n";
		$html .= '</div><!--/#' . $settings['id'] . ' .port-tags-->' . "\n";
		
		
		$html = apply_filters( 'woo_portfolio_navigation', $html );
		
		echo $html;
	
	} // End woo_portfolio_navigation()
}

/*-----------------------------------------------------------------------------------*/
/* Woo Portfolio Item Settings */
/* @uses woo_portfolio_image_dimensions() */
/*-----------------------------------------------------------------------------------*/
 
if ( !function_exists( 'woo_portfolio_item_settings' ) ) {
	function woo_portfolio_item_settings ( $id ) {
		
		global $tt_options;
		
		// Sanity check.
		if ( ! is_numeric( $id ) ) { return; }
		
		$website_layout = 'two-col-left';
		$website_width = '900px';
		
		if ( isset( $tt_options['tt_layout'] ) ) { $website_layout = $tt_options['tt_layout']; }
		if ( isset( $tt_options['tt_layout_width'] ) ) { $website_width = $tt_options['tt_layout_width']; }
		
		$dimensions = woo_portfolio_image_dimensions( $website_layout, $website_width );
		
		$width = $dimensions['width'];
		$height = $dimensions['height'];
		
		
		$settings = array(
							'large' => '', 
							'caption' => '', 
							'rel' => '', 
							'gallery' => array(), 
							'css_classes' => 'group post portfolio-img', 
							'embed' => '', 
							'testimonial' => '', 
							'testimonial_author' => '', 
							'display_url' => '', 
							'width' => $width, 
							'height' => $height
						 );
		
		$meta = get_post_custom( $id );
		
		// Check if there is a gallery in post.
		// woo_get_post_images is offset by 1 by default. Setting to offset by 0 to show all images.
		
		$large = '';
		if ( isset( $meta['portfolio-image'][0] ) )
			$large = $meta['portfolio-image'][0];
			
		$caption = '';
			    
		$rel = 'rel="lightbox['. $id .']"';

		// Check if there are more than 1 image
    	$gallery = woo_get_post_images( '0' );
    	
	    // If we only have one image, disable the gallery functionality.
	    if ( isset( $gallery ) && is_array( $gallery ) && ( count( $gallery ) <= 1 ) ) {
			$rel = 'data-rel="lightbox"';
	    }
	    
	    // Check for a post thumbnail, if support for it is enabled.
	    if ( isset( $tt_options['tt_post_image_support'] ) && ( $tt_options['tt_post_image_support'] == '1' ) && current_theme_supports( 'post-thumbnails' ) ) {
	    	$image_id = get_post_thumbnail_id( $id );
	    	if ( intval( $image_id ) > 0 ) {
	    		$large_data = wp_get_attachment_image_src( $image_id, 'large' );
	    		if ( is_array( $large_data ) ) {
	    			$large = $large_data[0];
	    		}
	    	}
	    }
	    
	    // See if lightbox-url custom field has a value
	    if ( isset( $meta['lightbox-url'] ) && ( $meta['lightbox-url'][0] != '' ) ) {
	    	$large = $meta['lightbox-url'][0];
	    }
	    		
		// Create CSS classes string.
		$css = '';
		$galleries = array();
		$terms = get_the_terms( $id, 'portfolio-gallery' );
		if ( is_array( $terms ) && ( count( $terms ) > 0 ) ) { foreach ( $terms as $t ) { $galleries[] = $t->slug; } }				
		$css = join( ' ', $galleries );
		
		// If on the single item screen, check for a video.
		if ( is_singular() ) { $settings['embed'] = woo_embed( 'width=540' ); }
		
		// Add testimonial information.
		if ( isset( $meta['testimonial'] ) && ( $meta['testimonial'][0] != '' ) ) {
			$settings['testimonial'] = $meta['testimonial'][0];
		}
		
		if ( isset( $meta['testimonial_author'] ) && ( $meta['testimonial_author'][0] != '' ) ) {
			$settings['testimonial_author'] = $meta['testimonial_author'][0];
		}
		
		// Look for a custom display URL of the portfolio item (used if it's a website, for example)
		if ( isset( $meta['url'] ) && ( $meta['url'][0] != '' ) ) {
			$settings['display_url'] = $meta['url'][0];
		}
		
		// Assign the values we have to our array.
		$settings['large'] = $large;
		$settings['caption'] = $caption;
		$settings['rel'] = $rel;
		if (isset( $gallery )) { $settings['gallery'] = $gallery; } else { $settings['gallery'] = array(); }
		$settings['css_classes'] .= ' ' . $css;
				
		// Check for a custom description.
		$description = get_post_meta( $id, 'lightbox-description', true );
		if ( $description != ''  ) { $settings['caption'] = $description; }
		
		// Allow child themes/plugins to filter these settings.
		$settings = apply_filters( 'woo_portfolio_item_settings', $settings, $id );
		
		return $settings;
	} // End woo_portfolio_item_settings()
}

/*-----------------------------------------------------------------------------------*/
/* Woo Portfolio, show portfolio galleries in portfolio item breadcrumbs */
/* Modify woo_breadcrumbs() Arguments Specific to this Theme */
/*-----------------------------------------------------------------------------------*/

add_filter( 'woo_breadcrumbs_args', 'woo_portfolio_filter_breadcrumbs_args', 10 );

if ( !function_exists( 'woo_portfolio_filter_breadcrumbs_args' ) ) {
	function woo_portfolio_filter_breadcrumbs_args( $args ) {
	
		$args['singular_portfolio_taxonomy'] = 'portfolio-gallery';
	
		return $args;
	
	} // End woo_portfolio_filter_breadcrumbs_args()
}

/*-----------------------------------------------------------------------------------*/
/* Woo Portfolio, get image dimensions based on layout and website width settings. */
/*-----------------------------------------------------------------------------------*/

if ( !function_exists( 'woo_portfolio_image_dimensions' ) ) {
	function woo_portfolio_image_dimensions ( $layout = 'one-col', $width = '960' ) {
		
		$dimensions = array( 'width' => 575, 'height' => 0, 'thumb_width' => 175, 'thumb_height' => 175 );
		
		// Allow child themes/plugins to filter these dimensions.
		$dimensinos = apply_filters( 'woo_portfolio_gallery_dimensions', $dimensions );
	
		return $dimensions;
	
	} // End woo_post_gallery_dimensions()
}

/*-----------------------------------------------------------------------------------*/
/* Get Post image attachments */
/*-----------------------------------------------------------------------------------*/
/* 
Description:

This function will get all the attached post images that have been uploaded via the 
WP post image upload and return them in an array. 

*/
if ( !function_exists( 'woo_get_post_images' ) ) {
	function woo_get_post_images( $offset = 1, $size = 'large' ) {
		
		// Arguments
		$repeat = 100; 				// Number of maximum attachments to get 
		$photo_size = 'large';		// The WP "size" to use for the large image
	
		global $post;
	
		$output = array();
	
		$id = get_the_id();
		$attachments = get_children( array(
		'post_parent' => $id,
		'numberposts' => $repeat,
		'post_type' => 'attachment',
		'post_mime_type' => 'image',
		'order' => 'ASC', 
		'orderby' => 'menu_order date' )
		);
		if ( !empty($attachments) ) :
			$output = array();
			$count = 0;
			foreach ( $attachments as $awoo_id => $attachment ) {
				$count++;  
				if ($count <= $offset) continue;
				$url = wp_get_attachment_image_src($awoo_id, $photo_size, true);
					$output[] = array( 'url' => $url[0], 'caption' => $attachment->post_excerpt, 'id' => $awoo_id );
			}  
		endif; 
		return $output;
	} // End woo_get_post_images()
}

/**
 * woo_portfolio_add_post_classes function.
 * 
 * @access public
 * @param array $classes
 * @return array $classes
 */

add_filter( 'post_class', 'woo_portfolio_add_post_classes', 10 );
 
function woo_portfolio_add_post_classes ( $classes ) {
	if ( in_array( 'portfolio', $classes ) ) {
		global $post;
		
		$terms = get_the_terms( $post->ID, 'portfolio-gallery' );

		if ( $terms && ! is_wp_error( $terms ) ) {
			foreach ( $terms as $t ) {
				$classes[] = $t->slug;
			}
		}
		
		if ( ! is_singular() ) {
			foreach ( $classes as $k => $v ) {
				if ( in_array( $v, array( 'hentry', 'portfolio' ) ) ) {
					unset( $classes[$k] );
				}
			}
		}
	}
	return $classes;
} // End woo_portfolio_add_post_classes()

/*-----------------------------------------------------------------------------------*/
/* Portfolio Meta */
/*-----------------------------------------------------------------------------------*/

if (!function_exists( 'woo_portfolio_meta')) {
	function woo_portfolio_meta( ) {
?>
<aside class="portfolio-meta">
	<ul>
		<li class="portfolio-date">
			<?php the_time( get_option( 'date_format' ) ); ?>
		</li>
		<li class="portfolio-comments">
			<?php comments_popup_link( __( 'Leave a comment', 'templatation' ), __( '1 Comment', 'templatation' ), __( '% Comments', 'templatation' ), 'button' ); ?>
		</li>
		<li><?php edit_post_link( __( '{ Edit }', 'templatation' ), '<li class="edit">', '</li>' ); ?></li>
	</ul>
</aside>
<?php
	}
}

/*-----------------------------------------------------------------------------------*/
/* @ Justshop custom function from below ... */
/*-----------------------------------------------------------------------------------*/

/*-----------------------------------------------------------------------------------*/
/* Fixing the font size for the tag cloud widget.                                    */
/*-----------------------------------------------------------------------------------*/
add_filter( 'widget_tag_cloud_args', 'my_tag_cloud_args' );
if (!function_exists( 'my_tag_cloud_args')) {
	function my_tag_cloud_args($in) {
	return 'smallest=12&largest=12&number=25&orderby=name&unit=px';
}
}

/*-----------------------------------------------------------------------------------*/
/* Hooking class to <header to build the required header layout.                     */
/*-----------------------------------------------------------------------------------*/
if (!function_exists( 'jc_hdr_class')) {
	function jc_hdr_class() {
		global $tt_options;
		if ( !isset( $tt_options['tt_header_section_layout'] ) || $tt_options['tt_header_section_layout'] == 'layout2' ) {
		$hdrclass = "b";
		}
		elseif( $tt_options['tt_header_section_layout'] == 'layout3' ) $hdrclass = "c";
		elseif( $tt_options['tt_header_section_layout'] == 'layout4' ) $hdrclass = "d";
		elseif( $tt_options['tt_header_section_layout'] == 'layout5' ) $hdrclass = "e";
		elseif( $tt_options['tt_header_section_layout'] == 'layout6' ) $hdrclass = "f";
		elseif( $tt_options['tt_header_section_layout'] == 'layout7' ) $hdrclass = "f h";
		//elseif( $tt_options['tt_header_section_layout'] == 'layout8' ) $hdrclass = "e g";
		else  $hdrclass = "b";
		return $hdrclass;
}
}

/*-----------------------------------------------------------------------------------*/
/* Add a class to body_class if fullwidth slider to appear. */
/*-----------------------------------------------------------------------------------*/

add_filter( 'body_class','justshop_body_class', 10 );// Add layout to body_class output

if ( ! function_exists( 'justshop_body_class' ) ) {
function justshop_body_class( $classes ) {

	global $tt_options, $wp_query;
	$tt_post_id = $current_page_template = $hdr_layout = '';
	//setting up defaults.
	$settings6 = tt_get_dynamic_values( array( 'sticky_menu' => '0',
												'widescreen' => '0',
												'headline_gmap' => '1',
												'jsanim_no' => '1',
												'trans_lay4' => '0',
												'no_cont_shadow' => '0',
												'js_layout' => 'js_950'

												) );
	// grab current post id
	$tt_post_id = justshop_get_the_id();

	// fetching which page template is being used to render current post/page.
	if ( !empty($tt_post_id) ) { $current_page_template = get_post_meta($tt_post_id, '_wp_page_template', true); }
	if ( !is_search() && ($current_page_template == "template-fullwidth.php" )) { $classes[] = 'layout-full'; }
	if ( is_page() && ! is_front_page() && ($current_page_template == "template-home.php" )) { $classes[] = 'home'; } // force .home class in body if custom-home template is used (even if its not set as homepage), to trigger the styles written for homepage only.
	if ( $settings6['widescreen'] == "1" ) $classes[] = 'widescreen'; else $classes[] = 'boxed';
	if ( $settings6['sticky_menu'] == "1" ) { $classes[] = 'sticky-menu'; }
	if ( $settings6['jsanim_no'] == "1" ) { $classes[] = 'jsanim_no'; }
	if ( $settings6['trans_lay4'] == "1" ) { $classes[] = 'trans_layout4'; }
	if ( $settings6['no_cont_shadow'] == "1" ) { $classes[] = 'no_shadow'; }
	if ( $settings6['js_layout'] !== "" ) { $classes[] = $settings6['js_layout']; }


	if ( isset( $tt_options['tt_header_section_layout'] ) ) {
		$hdr_layout = $tt_options['tt_header_section_layout'];
		if ( $hdr_layout == 'layout5' || $hdr_layout == 'layout6' )  $hdr_layout = 'layout2';
		// Add classes to body_class() output 
		$classes[] = 'structure-'.$hdr_layout;
	}
	else $classes[] = 'structure-layout2'; // if layout not set from admin, trigger default as layout2
	return $classes;
  }
}


/*-----------------------------------------------------------------------------------*/
/* Fetching the ID                                     */
/*-----------------------------------------------------------------------------------*/

if( !function_exists('justshop_get_the_id') ) {
	function justshop_get_the_id() {
		global $wp_query;
		$tt_post_id = '';
		if ( is_404() || is_search() ) {
			return '';
		}
		if ( isset( $wp_query->post->ID ) ) {
			$tt_post_id = $wp_query->post->ID;
		}
		if ( is_home() ) {
			$tt_post_id = get_option( 'page_for_posts' );
		}
		if ( class_exists( 'woocommerce' ) ) {
			if ( is_shop() ) {
				$tt_post_id = get_option( 'woocommerce_shop_page_id' );
			}
			if ( is_account_page() ) {
				$tt_post_id = get_option( 'woocommerce_myaccount_page_id' );
			}
			if ( is_checkout() ) {
				$tt_post_id = get_option( 'woocommerce_checkout_page_id' );
			}
			if ( is_cart() ) {
				$tt_post_id = get_option( 'woocommerce_cart_page_id' );
			}
		}

		return $tt_post_id;

	}
}

/*-----------------------------------------------------------------------------------*/
/* Preloader. */
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'justshop_tt_preloader' ) ) {
function justshop_tt_preloader () {

	if ( tt_get_option( 'enable_preloader', '0' ) == '1') {
		return '
		<div id="loader-wrapper">
		 <div class="tt-loading-center">
		  <div class="tt-loading-center-absolute">
		   <div class="tt-object object_four"></div>
		   <div class="tt-object object_three"></div>
		   <div class="tt-object object_two"></div>
		   <div class="tt-object object_one"></div>
		  </div>
		 </div>
		</div>
		';
	}

} // End justshop_tt_preloader()
}
/*-----------------------------------------------------------------------------------*/
/* Function for setting up slider container									.        */
/*-----------------------------------------------------------------------------------*/
if (!function_exists( 'justshop_slider_cont')) {
	function justshop_slider_cont() {
		global $tt_options; $tt_post_id = '';

		// grab current post id
		$tt_post_id = justshop_get_the_id();

		// Enable slider
		// Show slider only on homepage
		// Which slider layout to choose out of Full width(Layout 2), Fixed width(Layout 3), Full width 2(Layout 4)...etc

		// fetching which page template is being used to render current post/page.
		if ( empty($tt_post_id) ) $current_page_template = 'no-home'; else $current_page_template = get_post_meta($tt_post_id, '_wp_page_template', true);

		if ( (!isset( $tt_options['tt_enable_slider'] ) || '0' == $tt_options['tt_enable_slider']) && ( $current_page_template == "template-home.php" ) ) { return; } // return if not enabled and is homepage.

		if ( !isset( $tt_options['tt_header_section_layout'] ) || $tt_options['tt_header_section_layout'] == 'layout2' || $tt_options['tt_header_section_layout'] == 'layout3' || $tt_options['tt_header_section_layout'] == 'layout5' || $tt_options['tt_header_section_layout'] == 'layout6' ) {
		add_action( 'woo_content_before', 'justshop_slider', 0 ); // hook slider after header container
		}
		else { 
		add_action( 'woo_nav_after', 'justshop_slider', 0 ); // hook slider inside header container
		}
	}
}

/*-----------------------------------------------------------------------------------*/
/*  function for rendering slider 													 */
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'justshop_slider' ) ) {
function justshop_slider() {
	global $tt_options, $wp_query; $tt_post_id = $single_page_slider = $main_slider_area = $tt_meta_page_opt = $single_page_img = $single_enable_hero = $single_headline_title = $single_headline_desc = $single_page_color = $block_padding = $fullyes = $hdr_section_layout = $heroyes = '';

	// grab current post id
	$tt_post_id = justshop_get_the_id();

	
	// term homepage refers to template-home.php page template in this function, not index page.
	
	// fetching which page template is being used to render current post/page.
	if ( empty($tt_post_id) ) $current_page_template = 'no-home'; else $current_page_template = get_post_meta($tt_post_id, '_wp_page_template', true);

	// fetching which layout is set in admin , if not setup , layout2 is default.
	if ( isset( $tt_options['tt_header_section_layout'] ) ) $hdr_section_layout = $tt_options['tt_header_section_layout']; else $hdr_section_layout = 'layout2';
	if ( $hdr_section_layout == 'layout5' || $hdr_section_layout == 'layout6' )  $hdr_section_layout = 'layout2';
	
	$slider_whole_site = '0'; // we no longer use it since v6.0

	// fetching value from single posts .
	$tt_meta_page_opt = get_post_meta($tt_post_id, '_tt_meta_page_opt', true);
	if( isset($tt_meta_page_opt['_single_page_slider']) ) $single_page_slider = $tt_meta_page_opt['_single_page_slider'];
	if( isset($tt_meta_page_opt['_single_enable_hero']) ) $single_enable_hero = $tt_meta_page_opt['_single_enable_hero'];
	if( isset($tt_meta_page_opt['_single_headline_title']) ) $single_headline_title = $tt_meta_page_opt['_single_headline_title'];
	if( isset($tt_meta_page_opt['_single_headline_desc']) ) $single_headline_desc = $tt_meta_page_opt['_single_headline_desc'];
	if( isset($tt_meta_page_opt['_single_page_img']) ) $single_page_img = $tt_meta_page_opt['_single_page_img'];
	if( isset($tt_meta_page_opt['_single_page_color']) ) $single_page_color = $tt_meta_page_opt['_single_page_color'];

	if ( ! empty( $single_enable_hero ) ) {

		$heroyes = 'hero';
		// if title is not entered , grab the default page title.
		if ( '' == $single_headline_title ) {
			$single_headline_title = get_the_title( $tt_post_id );
		}

		ob_start(); ?>
		<section class="breadcrumb-area " style="
		<?php if ( '' != $single_page_img ) {
			echo 'background-image: url(' . $single_page_img . ');';
		} ?>
		<?php echo esc_attr( $block_padding ); ?>
			">
			<div class="overlay-clr" style="<?php echo 'background-color: ' . $single_page_color . ';'; ?>"></div>
			<div class="breadcrumb-text-area">
				<div class="breadcrumb-text text-center">

					<?php if ( '' != $single_headline_title ) { ?>
						<h1 class="tt-title"><?php echo esc_textarea( $single_headline_title ); ?></h1>
					<?php } ?>
					<?php if ( '' != $single_headline_desc ) { ?>
						<?php echo wpautop( do_shortcode( $single_headline_desc ) ); ?>
					<?php } ?>
				</div>
			</div>
		</section>
		<div class="mbottom70 tpadd"></div>

		<?php $main_slider_area = ob_get_clean();
	}

	if ( ! empty( $single_page_slider ) ) {
		$main_slider_area = do_shortcode( $single_page_slider );
	} // slider content from single page meta, if exists.
	if (  $current_page_template == "template-home.php" )  {
		$main_slider_area = do_shortcode( $tt_options['tt_slider_area_content'] );
	} // if HP, show from theme options.
	if ( empty( $main_slider_area ) )  return; // show nothing if disabled for whole website, nothing entered in single page and its not homepage
	
	echo '<section class="'.$tt_post_id.' '.$heroyes.' col-full slider-'.$hdr_section_layout.'" id="main-slider">' . $main_slider_area . "</section>\n";
}
}

/*-----------------------------------------------------------------------------------*/
/* Function for featured headline area inside main container.                        */
/*-----------------------------------------------------------------------------------*/
 if (!function_exists('templatation_headline_area')) {
	function templatation_headline_area() {
	global $tt_options, $wp_query;
	$tt_post_id = '';
	if ( is_404() || is_search() ) return;

	// grab current post id
	$tt_post_id = justshop_get_the_id();


	// if the current page template is contact page.
	$current_page_template = get_post_meta($tt_post_id, '_wp_page_template', true);

	if ( defined( 'DS_LIVE_COMPOSER_VER' ) && ( $current_page_template == "template-HF.php" || $current_page_template == "template-H-noF.php" || $current_page_template == "template-noH-F.php" || $current_page_template == "template-no-HF.php") ) return;

	if ( !empty($current_page_template) && ($current_page_template == "template-contact.php" || $current_page_template == "template-contact-plugin.php") ) { // hook gmap in contact page
		$settings7 = tt_get_dynamic_values( array( 'headline_gmap' => '1' ) );
		if ( $settings7['headline_gmap'] == '1' ) { // hook gmap in headline section if set in admin
			add_action( 'woo_content_before', 'tt_headline_gmap', 21 );
			return; 
		}
	}

	// fetching value from theme options settings .
	if ( isset( $tt_options['tt_show_headline_global'] ) )  $show_headline_global = $tt_options['tt_show_headline_global']; else  $show_headline_global = '1';
	if ( isset( $tt_options['tt_enable_default_headline'] ) )  $enable_default_headline = $tt_options['tt_enable_default_headline']; else  $enable_default_headline = '1';
	if ( isset( $tt_options['tt_headline_default_title'] ) )  $headline_default_title = $tt_options['tt_headline_default_title']; else  $headline_default_title = 'Taste our yummy Cakes';
	if ( isset( $tt_options['tt_headline_default_message'] ) )  $headline_default_message = $tt_options['tt_headline_default_message']; else  $headline_default_message = 'All kind of cakes and pastries ready within minutes. Try once. Call xxx-x-xxx Today !';
	if ( isset( $tt_options['tt_header_section_layout'] ) ) $hdr_section_layout = $tt_options['tt_header_section_layout']; else  $hdr_section_layout = 'layout2';

	// fetching value from single posts .
	$single_data2 = get_post_meta( $tt_post_id, '_tt_meta_page_opt', true );
	if( is_array($single_data2) ) {
		if ( isset( $single_data2['_single_disable_headline'] ) ) $single_disable_headline = $single_data2['_single_disable_headline'];
		if ( isset( $single_data2['_single_headline_heading'] ) ) $single_headline_heading = esc_attr($single_data2['_single_headline_heading']);
		if ( isset( $single_data2['_single_headline_message'] ) ) $single_headline_message = esc_textarea($single_data2['_single_headline_message']);
	}

	// setting defaults
	if ( !isset($single_disable_headline) || empty($single_disable_headline) ) $single_disable_headline = 'false';
	

	// return if globally disabled in admin and single page respectively but still show breadcrumb., no other setting make difference.
	if ( $show_headline_global == '0') {
		if(isset( $tt_options['tt_breadcrumbs_show'] ) && $tt_options['tt_breadcrumbs_show'] == '1')  { ?>
		<?php woo_display_breadcrumbs(); ?>
	<?php } return; }

	if ( $single_disable_headline == '1' ) {
		if(isset( $tt_options['tt_breadcrumbs_show'] ) && ($tt_options['tt_breadcrumbs_show'] == '1'))  { ?>
		<?php woo_display_breadcrumbs(); ?>
	<?php } return; } 


	ob_start(); ?>
	<section class="headline-<?php echo $tt_post_id; ?> headline-<?php echo $hdr_section_layout; ?> col-full" id="headline">
			<div class="headline-left-side">
				<?php if( !empty($single_headline_heading) ) echo "<h2>". stripslashes( $single_headline_heading ) ."</h2>"; 
				elseif( '1' == $enable_default_headline ) echo "<h2>". stripslashes( $headline_default_title ) ."</h2>"; ?>

				<?php if( !empty($single_headline_message) ) echo '<div class="headline-message">'. stripslashes( $single_headline_message ) .'</div>'; 
				elseif( '1' == $enable_default_headline ) echo '<div class="headline-message">'. stripslashes( $headline_default_message ) .'</div>'; ?>
				
				<?php if( ('0' == $enable_default_headline) && empty($single_headline_heading) ) $bcmp_class="no-headline-bcmp"; else $bcmp_class="headline-bcmp"; ?>
				<div class="<?php echo $bcmp_class; ?>"><?php woo_display_breadcrumbs(); ?></div>
			</div>
						
				<?php if ( is_woocommerce_activated() && ( !isset($tt_options['tt_enable_catalog']) || '0' == $tt_options['tt_enable_catalog'] ) ) {
						if( isset( $tt_options['tt_woocommerce_header_cart_link'] ) && '1' == $tt_options['tt_woocommerce_header_cart_link'] ) {
							global $woocommerce;  ?>
							<div class="headline-right-side"><?php tt_mini_cart(); ?></div>
					<?php	}
					  } ?>

	</section>
	<?php
	$headline_content = ob_get_clean();
	echo $headline_content;
}  
}

/*-----------------------------------------------------------------------------------*/
/**
 * Filters wp_title to print a neat <title> tag based on what is being viewed.
 *
 * @param string $title Default title text for current view.
 * @param string $sep Optional separator.
 * @return string The filtered title.
 */
function woo_wp_title( $title, $sep ) {
	if ( is_feed() ) {
		return $title;
	}

	global $page, $paged;
	// Add the blog name
	$title .= $sep." ".get_bloginfo( 'name', 'display' );

	// Add the blog description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) ) {
		$title .= " $sep $site_description";
	}

	// Add a page number if necessary: , commenting cause below results in an warning.
/*	if ( ( $paged >= 2 || $page >= 2 ) && ! is_404() ) {
		$title .= " $sep " . sprintf( __( 'Page %s', '_s' ), max( $paged, $page ) );
	}*/

	return $title;
}
//add_filter( 'wp_title', 'woo_wp_title', 10, 2 );
/*-----------------------------------------------------------------------------------*/
/* Function for adding google map in headline section      .                        */
/*-----------------------------------------------------------------------------------*/
if (!function_exists('tt_headline_gmap')) {
	function tt_headline_gmap() {
 	global $tt_options, $wp_query;
	$settings7 = $gmap = "";
	
	$settings7 = tt_get_dynamic_values( array( 'headline_gmap' => '1' ) );
	if ( $settings7['headline_gmap'] == '0' ) return ; // do nothing if we are not showing map in the headline section.
	ob_start(); 

	   if ( isset($tt_options['tt_contactform_map_coords']) && $tt_options['tt_contactform_map_coords'] != '' ) { $geocoords = $tt_options['tt_contactform_map_coords']; }  else { $geocoords = ''; } ?>
		<?php if ($geocoords != '') { ?>
		<?php woo_maps_contact_output("geocoords=$geocoords"); ?>
		<?php }
	
	$gmap = ob_get_clean();

	echo '<section class="col-full fix gmap" id="headline">' . $gmap . "</section>\n";

}
}

/*-----------------------------------------------------------------------------------*/
/* Function for showing google map inside container.                                 */
/*-----------------------------------------------------------------------------------*/
if (!function_exists('templatation_gmap')) {
	function templatation_gmap() {
 	global $tt_options, $wp_query;
	$settings7 = $gmap = "";
	
	$settings7 = tt_get_dynamic_values( array( 'headline_gmap' => '1' ) );
	if ( $settings7['headline_gmap'] == '1' ) return ; // do nothing if we are showing map in the headline section.
	ob_start(); 

	   if ( isset($tt_options['tt_contactform_map_coords']) && $tt_options['tt_contactform_map_coords'] != '' ) { $geocoords = $tt_options['tt_contactform_map_coords']; }  else { $geocoords = ''; } ?>
		<?php if ($geocoords != '') { ?>
		<?php woo_maps_contact_output("geocoords=$geocoords"); ?>
		<div class="tt-sc-hr"></div>
		<?php }
	
	$gmap =  ob_get_clean();
	echo $gmap;
	
}
}

/*-----------------------------------------------------------------------------------*/
/* Callback function for contactwidget shortcode */
/*-----------------------------------------------------------------------------------*/

if ( ! function_exists( 'js_contactwidget' ) ) {
function js_contactwidget($atts) {
		 $defaults = array(
		'name' => 'Just Shop', // name of the firm
		'telephone' => '000-000-000',
		'email' => 'email@someemail.com', 
		'address' => 'blah street, blah country' 
		);

		extract(shortcode_atts( $defaults, $atts));
		// building the widget details.
		ob_start(); ?>
		<div class="vcard">
			<h4 class="fn org"><?php echo $name; ?></h4>
			<p class="tel"><?php echo $telephone; ?></p>
			<p><a class="email" href="mailto:<?php echo $email; ?>"><?php echo $email; ?></a></p>
			<p class="adr"><?php echo $address; ?></p>
		</div>
		<?php $contactwidget = ob_get_clean();
		return $contactwidget;
	}
}

/*-----------------------------------------------------------------------------------*/
/* Logo offset fuction. */
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'templatation_logo_offset' ) ) {
/**
 * Output CSS for logo adjustments
 */
function templatation_logo_offset() {
	global $tt_options;
    $outputlogostyle = $top = $topactive = $marginleft = '';
	//setting up defaults.
	$settings10 = array(
					'header_section_layout' => 'layout2',
					'logo_left_offset' => '0',
					'logo_top_offset' => '0'
					);

	$settings10 = tt_get_dynamic_values( $settings10 );
	$logo_right_offset = $logo_top_offset = "0"; // setting up default
	if( !empty($settings10['logo_left_offset']) ) $logo_right_offset = str_replace("px","",$settings10['logo_left_offset']['width']);
	if( !empty($settings10['logo_top_offset']) ) $logo_top_offset = str_replace("px","",$settings10['logo_top_offset']['height']);

	if( ( $logo_right_offset == "0" ) && ( $logo_top_offset == "0" ) ) return; // do nothing if 0,0 is entered == reset.
	$logo_right_offset = (int)$logo_right_offset;
	if( $settings10['header_section_layout'] == 'layout5' ) {
		$marginleft = -110-(-$logo_right_offset);
		$top = 10-(-$logo_top_offset);
		$topactive = 50-(-$logo_top_offset);
		if( $logo_right_offset <> "0" ) $outputlogostyle .= '.js_1170 #header.e #logo, #header.e #logo { margin-left: '. $marginleft .'px; }' . "\n"; // setting up left offset
		if( $logo_top_offset <> "0" ) $outputlogostyle .= '.js_1170 #header.e #logo, #header.e #logo { top: '. $top .'px; }' . ' #header.e.active #logo { top: '. $topactive .'px; }' . '\n';  // setting up top offset
	}
	elseif ( $settings10['header_section_layout'] == 'layout6' ) {
		$marginleft = -483-(-$logo_right_offset);
		$top = $logo_top_offset;
		//$topactive = 60-(-$logo_top_offset);
		if( $logo_right_offset <> "0" ) $outputlogostyle .= '.js_1170 #header.f #logo, #header.f #logo { margin-left: '. $marginleft .'px; }' . "\n"; // setting up left offset
//		if( $logo_top_offset <> "0" ) $outputlogostyle .= '#header.f #logo { top: '. $top .'px; }' . ' #header.f.active #logo { top: '. $topactive .'px; }' . '\n';  // setting up top offset @v3.5, removed .active class
		if( $logo_top_offset <> "0" ) $outputlogostyle .= '.js_1170 #header.f #logo, #header.f #logo { top: '. $top .'px; }' . '\n';  // setting up top offset
	}
	else {
		$marginleft = -483-(-$logo_right_offset);
		$top = 21-(-$logo_top_offset);
		$topactive = 60-(-$logo_top_offset);
		if( $logo_right_offset <> "0" ) $outputlogostyle .= '.js_1170 #header #logo, #header #logo { margin-left: '. $marginleft .'px; }' . "\n"; // setting up left offset
		if( $logo_top_offset <> "0" ) $outputlogostyle .= '.js_1170 #header #logo, .js_1170 #header.d #logo, #header #logo, #header.d #logo { top: '. $top .'px; }' . ' #header.active #logo { top: '. $topactive .'px; }' . '\n';  // setting up top offset
	}
	

	// Output styles
	if ( $outputlogostyle != '' ) {
		$outputlogostyle = strip_tags($outputlogostyle);
		return stripslashes( $outputlogostyle );
	}
} // End templatation_logo_offset()
}

/*-----------------------------------------------------------------------------------*/
/* Header Height fuction. */
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'templatation_header_height' ) ) {
function templatation_header_height() {
	global $tt_options, $wp_query;
	$tt_post_id = $current_page_template = '';

	// grab current post id
	$tt_post_id = justshop_get_the_id();

    $outputheaderstyle = $headerstyle = $maps_single_height = '';

	//setting up defaults.
	$settings10 = array(
					'headline_gmap' => '1',
					'maps_single_height' => '350',
					'header_height' => '',
					);
	$settings10 = tt_get_dynamic_values( $settings10 );
	if ( !empty($tt_post_id) ) { $current_page_template = get_post_meta($tt_post_id, '_wp_page_template', true); }

	if ( !empty($current_page_template) ) { 
		if( ($current_page_template == "template-contact.php" || $current_page_template == "template-contact-plugin.php") && $settings10['headline_gmap'] == "true" ) {
			 $outputheaderstyle .= '.page-template-template-contact-php #headline { padding: 0px; }' . "\n"; // Headline heading top padding
			 $outputheaderstyle .= '.page-template-template-contact-plugin-php #headline { padding: 0px; }' . "\n"; // Headline heading top padding
			 $outputheaderstyle .= '.widescreen.page-template-template-contact-php #content { margin-top: 0px; }' . "\n"; // Headline heading top padding
			 $outputheaderstyle .= '.widescreen.page-template-template-contact-plugin-php #content { margin-top: 0px; }' . "\n"; // Headline heading top padding
			 $outputheaderstyle .= '.boxed.page-template-template-contact-php #headline.gmap { border-bottom: 4px solid #FFFFFF;  box-shadow: 0 1px 3px #cdcdcd; -moz-box-shadow: 0 1px 3px #cdcdcd; -webkit-box-shadow: 0 1px 3px #cdcdcd; }' . "\n"; // Headline heading top padding
			 $outputheaderstyle .= '.boxed.page-template-template-contact-plugin-php #headline.gmap { border-bottom: 4px solid #FFFFFF;  box-shadow: 0 1px 3px #cdcdcd; -moz-box-shadow: 0 1px 3px #cdcdcd; -webkit-box-shadow: 0 1px 3px #cdcdcd; }' . "\n"; // Headline heading top padding
		}
	} // add styles for contact us page if map is set to be shown in headline section.

	$headerstyle = $settings10['header_height'];
	if ( !empty($headerstyle) && $headerstyle !='0' )
	$outputheaderstyle .= '#header.TThdr { min-height: '. $headerstyle .'px !important; }' . "\n"; // setting up header height overriding everything else

	// Output styles
	if ( $outputheaderstyle != '' ) {
		$outputheaderstyle = strip_tags($outputheaderstyle);
		return stripslashes( $outputheaderstyle );
	}
} // End templatation_logo_offset()
}

/*-----------------------------------------------------------------------------------*/
/* Sidenav function */
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'templatation_sidenav' ) ) {
function templatation_sidenav ( $atts, $content = null ) {
	$defaults = array( 'style' => 'default' );

	extract( shortcode_atts( $defaults, $atts ) );

	return '<aside class="cols-c"><nav class="nav-a ' . esc_attr( $style ) . '">' . do_shortcode( $content ) . '</nav></aside>' . "\n";
} // End templatation_sidenav()
}

/*-----------------------------------------------------------------------------------*/
/* Sidenav function */
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'templatation_sidenav_content' ) ) {
function templatation_sidenav_content ( $atts, $content = null ) {
	$defaults = array( 'style' => 'default' );

	extract( shortcode_atts( $defaults, $atts ) );

	return '<div class="sidenav-right ' . esc_attr( $style ) . '">' . do_shortcode( $content ) . '</div>';
} // End templatation_sidenav()
}

/*-----------------------------------------------------------------------------------*/
/* Allowed tags for html sanitizing */
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'tt_custom_allowedtags' ) ) {
	function tt_custom_allowedtags() {
		$woo_allowedtags = '';
		$woo_allowedtags = array(
			'a'      => array(
				'href'  => array(),
				'title' => array()
			),
			'br'     => array(),
			'em'     => array(),
			'strong' => array(),
		);

		return $woo_allowedtags;
	} // End tt_custom_allowedtags()
}

/*-----------------------------------------------------------------------------------*/
/* Topnav function */
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'templatation_topnav_content' ) ) {
function templatation_topnav_content ( $atts, $content = null ) {
	global $tt_options, $current_user;
	if ( function_exists( 'wc_get_page_id' ) ) { $url_myaccount = get_permalink( wc_get_page_id( 'myaccount' ) ); }
	$output =  "";
	$topsettings = array(
					'enable_topbar' => '1',
					'enable_showhide' => '1',
					'enable_ttext' => '1',
					'ttext_icon' => '',
					'ttext_text' => '',
					'welcome_text_icon' => '',
					'enable_top_social' => '1',
					'enable_lang_dropdown' => '0',
					'enable_top_search' => '1',
					'connect_rss' => '',
					'connect_twitter' => '',
					'connect_facebook' => '',
					'connect_youtube' => '',
					'connect_flickr' => '',
					'connect_linkedin' => '',
					'connect_pinterest' => '',
					'connect_instagram' => '',
					'connect_googleplus' => '',
					'feed_url' => ''
					);

	$topsettings = tt_get_dynamic_values( $topsettings );
	if ( $topsettings['enable_topbar'] == "0" ) return; // do nothing if nav bar is disabled.
	ob_start();
?>
		<nav id="tools" class="<?php if ( $topsettings['enable_showhide'] == "1" ) echo "oc"; else echo "no-oc"; ?>">
			<div id="connect" class="col-inner">
				<ul>
					<!-- Start teaser text block. -->
					<?php if ( $topsettings['enable_ttext'] == "1" ) { ?>
						<li class="c">
						<?php if ( !empty($topsettings['ttext_icon']['url'] )) { ?>
						<img src="<?php echo $topsettings['ttext_icon']['url']; ?>" alt="" />
						<?php } ?>

						<?php if ( $topsettings['ttext_text'] != '' ) {
						 echo stripslashes( $topsettings['ttext_text'] );
						 } ?>
						</li>
					<?php } ?>

					<!-- Start login/welcome text block. -->
					<?php if ( is_woocommerce_activated() ) { ?>
					<?php if ( wc_get_page_id( 'myaccount' ) !== -1 ) { ?>
						<?php if ( !empty($topsettings['welcome_text_icon']['url'] )) { ?>
							<li class="b">
							<?php if ( is_user_logged_in() ) { 
									echo get_avatar( get_current_user_id() );
								  } else { ?>
									<img src="<?php echo $topsettings['welcome_text_icon']['url']; ?>" alt="" />
							<?php  } ?>
							</li>
						<?php } ?>
						<?php } ?>
						<?php if ( ! is_user_logged_in() && wc_get_page_id( 'myaccount' ) !== -1 ) { ?>
							<li class="a"><a href="<?php echo $url_myaccount; ?>"><?php _e( 'Login / Register', 'templatation' ); ?></a></li>
						<?php } if ( is_user_logged_in() ) { ?>
							<li class="a"><?php _e( 'Welcome', 'templatation' ); echo " ".ucfirst($current_user->display_name)." | "; ?> <a href="<?php echo $url_myaccount; ?>"><?php _e( 'My Account', 'templatation' ); ?></a> | <a href="<?php echo wp_logout_url( get_permalink() ); ?>" title="Logout"><?php _e( 'Logout ', 'templatation' ); ?></a></li>
						<?php } ?>
					<?php } ?>
				</ul>

				<!-- Start login/welcome text block. -->
				<?php if ( $topsettings['enable_top_social'] == "1" ) { ?>
					<ul class="social">
						<?php if ( !empty( $topsettings['connect_twitter'] ) ) { ?>
						<li><a href="<?php echo esc_url( $topsettings['connect_twitter'] ); ?>" class="twitter" title="Twitter"></a></li>
						<?php } if ( !empty( $topsettings['connect_facebook'] ) ) { ?>
						<li><a href="<?php echo esc_url( $topsettings['connect_facebook'] ); ?>" class="facebook" title="Facebook"></a></li>
						<?php } if ( !empty( $topsettings['connect_youtube'] ) ) { ?>
						<li><a href="<?php echo esc_url( $topsettings['connect_youtube'] ); ?>" class="youtube" title="YouTube"></a></li>
						<?php } if ( $topsettings['connect_rss' ] == "1" ) { ?>
						<li><a href="<?php if ( $topsettings['feed_url'] ) { echo esc_url( $topsettings['feed_url'] ); } else { echo get_bloginfo_rss('rss2_url'); } ?>" class="subscribe" title="RSS"></a></li>
						<?php } if ( !empty( $topsettings['connect_flickr'] ) ) { ?>
						<li><a href="<?php echo esc_url( $topsettings['connect_flickr'] ); ?>" class="flickr" title="Flickr"></a></li>
						<?php } if ( !empty( $topsettings['connect_linkedin'] ) ) { ?>
						<li><a href="<?php echo esc_url( $topsettings['connect_linkedin'] ); ?>" class="linkedin" title="LinkedIn"></a></li>
						<?php } if ( !empty( $topsettings['connect_pinterest'] ) ) { ?>
						<li><a href="<?php echo esc_url( $topsettings['connect_pinterest'] ); ?>" class="pinterest" title="Pinterest"></a></li>
						<?php } if ( !empty( $topsettings['connect_instagram'] ) ) { ?>
						<li><a href="<?php echo esc_url( $topsettings['connect_instagram'] ); ?>" class="instagram" title="Instagram"></a></li>
						<?php } if ( !empty( $topsettings['connect_googleplus'] ) ) { ?>
						<li><a href="<?php echo esc_url( $topsettings['connect_googleplus'] ); ?>" class="googleplus" title="Google+"></a></li>
						<?php } ?>
					</ul>
				<?php } ?>
 
				<!-- Start language block. -->
				<?php if ( $topsettings['enable_lang_dropdown'] == "1" ) { ?>
					<div id="language">
						<?php do_action('icl_language_selector'); ?>
					</div>
				<?php } ?>

				<!-- Start top search block. -->
				<?php if ( $topsettings['enable_top_search'] == "1" ) { ?>
					<?php if ( is_woocommerce_activated() ) { get_product_search_form(); } else { get_search_form(); } ?>
				<?php } ?>
			</div>
		</nav>
<?php
	$output = ob_get_clean();
	echo $output;
} // End templatation_topnav_content()
}


/*-----------------------------------------------------------------------------------*/
/* Headline shortcode */
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'templatation_headline' ) ) {
function templatation_headline ( $atts, $content = null ) {
	$defaults = array( 'title' => '', 'headstyle' => 'HDborder' );
	$title = $headstyle = "";
	extract( shortcode_atts( $defaults, $atts ) );
	return '<h3 class="'. $headstyle .'">' .$title. '</h3>';
} // End templatation_headline()
}



/*-----------------------------------------------------------------------------------*/
/* Latest products [TT-latestproducts] Shortcode function */
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'templatation_latestproducts' ) ) {
function templatation_latestproducts ( $atts, $content = null ) {
	$defaults = array( 'title' => 'Latest Products' );
	// we do not need title here as included part file already include title defined in theme options
	extract( shortcode_atts( $defaults, $atts ) );
	$latestprods = "";
	if ( ! is_woocommerce_activated() ) return;

	ob_start(); ?>
		<div class="woocommerce woocommerce-wrap woocommerce-columns-4 home-featured">
		<div class="widget">
		<h2><?php echo $title; ?></h2>					
		<?php  echo do_shortcode( '[recent_products per_page="4" columns="4" orderby="date" order="desc"]' );
		 ?>
		</div><!--/.widget-->
		</div><!--/.woocommerce-->
<?php
	$latestprods = ob_get_clean();
	return $latestprods;
} // End templatation_latestproducts()
}

/*-----------------------------------------------------------------------------------*/
/* Featured products [TT-featuredproducts] Shortcode function */
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'templatation_featuredproducts' ) ) {
function templatation_featuredproducts ( $atts, $content = null ) {
	$defaults = array( 'title' => 'Featured Products' );
	// we do not need title here as included part file already include title defined in theme options
	extract( shortcode_atts( $defaults, $atts ) );
	if ( ! is_woocommerce_activated() ) return;

	$featuredprods = "";
	ob_start(); ?>
		<div class="woocommerce woocommerce-wrap woocommerce-columns-4 home-featured">
			<h2><?php echo $title; ?></h2>					
		<?php  the_widget( 'woo_Featured_Products' ); ?>
		</div><!--/.woocommerce-->
<?php
	$featuredprods = ob_get_clean();
	return $featuredprods;
} // End templatation_featuredproducts()
}

/*-----------------------------------------------------------------------------------*/
/* Carousel products [TT-carouselproducts] Shortcode function */
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'templatation_carouselproducts' ) ) {
function templatation_carouselproducts ( $atts, $content = null ) {
	$defaults = array( 'title' => '' );
	// we do not need title here as included part file already include title defined in theme options
	extract( shortcode_atts( $defaults, $atts ) );
	if ( ! is_woocommerce_activated() ) return;
	$carouselproducts = "";
	ob_start();
	get_template_part( 'includes/products-carousel' );
	$carouselproducts = ob_get_clean();
	return $carouselproducts;
} // End templatation_carouselproducts()
}

/*-----------------------------------------------------------------------------------*/
/* extending woocommerce's [product_categories] SC [TT-productcategories] Shortcode function */
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'templatation_productcategories' ) ) {
function templatation_productcategories ( $atts, $content = null ) {
	$defaults = array( 'number' => '3',
					   'orderby' => 'name',
					   'order' => 'ASC',
					   'columns' => '3',
					   'hide_empty' => '1',
					   'parent' => '',
					   'ids' => ''
					    );
	// we do not need title here as user can put it via visual composer 
	extract( shortcode_atts( $defaults, $atts ) );
	$output = "";
	if ( ! is_woocommerce_activated() ) return;
	$output = ""; $columnss = $columns;
	if( !empty($number) ) $number = 'number='. $number;
	if( !empty($parent) ) $parent = 'parent='. $parent;
	if( !empty($orderby) ) $orderby = 'orderby='. $orderby;
	if( !empty($order) ) $order = 'order='. $order;
	if( !empty($columns) ) $columns = 'columns='. $columns;
	if( !empty($hide_empty) ) $hide_empty = 'hide_empty='. $hide_empty;
	if( !empty($parent) ) $parent = 'parent='. $parent;
	if( !empty($ids) ) $ids = 'ids='. $ids;

	$sc = '[product_categories ' . $number .' '. $parent .' '. $orderby .' '. $order .' '. $columns .' '. $hide_empty .' '. $parent .' '. $ids .' ]';

	$output = '<div class="fix woocommerce-columns-'. $columnss .'">'. do_shortcode( $sc ) .'</div>';
	
	return $output;
} // End templatation_productcategories()
}


/*-----------------------------------------------------------------------------------*/
/* extending woocommerce's [product_category] SC [TT-productcategory] Shortcode function */
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'templatation_productcategory' ) ) {
function templatation_productcategory ( $atts, $content = null ) {
	$defaults = array( 'per_page' => '12',
					   'orderby' => 'title',
					   'order' => 'ASC',
					   'columns' => '3',
					   'category' => '',
					    );
	// we do not need title here as user can put it via visual composer 
	extract( shortcode_atts( $defaults, $atts ) );
	$output = "";
	if ( ! is_woocommerce_activated() ) return;

	$output = ""; $columnss = $columns;
	if( !empty($per_page) ) $per_page = 'per_page='. $per_page;
	if( !empty($orderby) ) $orderby = 'orderby='. $orderby;
	if( !empty($order) ) $order = 'order='. $order;
	if( !empty($columns) ) $columns = 'columns='. $columns;
	if( !empty($category) ) $category = 'category='. $category;

	$sc = '[product_category ' . $per_page .' '. $orderby .' '. $order .' '. $columns .' '. $category .' ]';

	$output = '<div class="fix woocommerce-columns-'. $columnss .'">'. do_shortcode( $sc ) .'</div>';
	
	return $output;
} // End templatation_productcategory()
}

/*-----------------------------------------------------------------------------------*/
/* Adding fontawesome icons to menubar
/* Version: 4.0.3.0
/* Author: New Nine Media
/* Author URI: http://www.newnine.com
/* License: GPLv2 or later
/*-----------------------------------------------------------------------------------*/
add_filter( 'wp_nav_menu' , 'templatatio_menu', 10, 2 );
if ( ! function_exists( 'templatatio_menu' ) ) {
function templatatio_menu( $nav ){
	$menu_item = preg_replace_callback(
		'/(<li[^>]+class=")([^"]+)("?[^>]+>[^>]+>)([^<]+)<\/a>/',
		'templatation_replace',
		$nav
	);
	return $menu_item;
}
}
if ( ! function_exists( 'templatation_replace' ) ) {
function templatation_replace( $a ){
	$start = $a[ 1 ];
	$classes = $a[ 2 ];
	$rest = $a[ 3 ];
	$text = $a[ 4 ];
	$before = true;
	
	$class_array = explode( ' ', $classes );
	$fontawesome_classes = array();
	foreach( $class_array as $key => $val ){
		if( 'fa' == substr( $val, 0, 2 ) ){
			if( 'fa' == $val ){
				unset( $class_array[ $key ] );
			} elseif( 'fa-after' == $val ){
				$before = false;
				unset( $class_array[ $key ] );
			} else {
				$fontawesome_classes[] = $val;
				unset( $class_array[ $key ] );
			}
		}
	}
	
	if( !empty( $fontawesome_classes ) ){
		$fontawesome_classes[] = 'fa';
		if( $before ){
			$newtext = '<i class="fa-fw '.implode( ' ', $fontawesome_classes ).'"></i><span class="fontawesome-text"> '.$text.'</span>';
		} else {
			$newtext = '<span class="fontawesome-text">'.$text.' </span><i class="fa-fw '.implode( ' ', $fontawesome_classes ).'"></i>';
		}
	} else {
		$newtext = $text;
	}
	
	$item = $start.implode( ' ', $class_array ).$rest.$newtext.'</a>';
	return $item;
}
}
/* TT-fa shortcode. */
if ( ! function_exists( 'fa_shortcode_icon' ) ) {
function fa_shortcode_icon( $atts ){
	extract( shortcode_atts( array(
		'class' => '',
	), $atts ) );
	if( !empty( $class ) ){
		$fa_exists = false;
		$class_array = explode( ' ', $class );
		foreach( $class_array as $c ){
			if( 'fa' == $c ){
				$fa_exists = true;
			}
		}
		if( !$fa_exists ){
			array_unshift( $class_array, 'fa' );
		}
		return '<i class="'.implode( ' ', $class_array ).'"></i>';
	}
}
}

/*-----------------------------------------------------------------------------------*/
/* Function for Adding Retina support, thanks to C.bavota                            */
/*-----------------------------------------------------------------------------------*/
//add_filter( 'wp_generate_attachment_metadata', 'retina_support_attachment_meta', 10, 2 );
/**
 * Retina images
 *
 * This function is attached to the 'wp_generate_attachment_metadata' filter hook.
 */
if ( ! function_exists( 'retina_support_attachment_meta' ) ) {
function retina_support_attachment_meta( $metadata, $attachment_id ) {
    foreach ( $metadata as $key => $value ) {
        if ( is_array( $value ) ) {
            foreach ( $value as $image => $attr ) {
                if ( is_array( $attr ) )
                    retina_support_create_images( get_attached_file( $attachment_id ), $attr['width'], $attr['height'], true );
            }
        }
    }
 
    return $metadata;
}
}
/**
 * Create retina-ready images
 *
 * Referenced via retina_support_attachment_meta().
 */
if ( ! function_exists( 'retina_support_create_images' ) ) {
function retina_support_create_images( $file, $width, $height, $crop = false ) {
    if ( $width || $height ) {
        $resized_file = wp_get_image_editor( $file );
        if ( ! is_wp_error( $resized_file ) ) {
            $filename = $resized_file->generate_filename( $width . 'x' . $height . '@2x' );
 
            $resized_file->resize( $width * 2, $height * 2, $crop );
            $resized_file->save( $filename );
 
            $info = $resized_file->get_size();
 
            return array(
                'file' => wp_basename( $filename ),
                'width' => $info['width'],
                'height' => $info['height'],
            );
        }
    }
    return false;
}
}
//add_filter( 'delete_attachment', 'delete_retina_support_images' );

/**
 * Delete retina-ready images
 *
 * This function is attached to the 'delete_attachment' filter hook.
 */
if ( ! function_exists( 'delete_retina_support_images' ) ) {
function delete_retina_support_images( $attachment_id ) {
    $meta = wp_get_attachment_metadata( $attachment_id );
    $upload_dir = wp_upload_dir();
	if (isset($meta["file"])) {
		$path = pathinfo( $meta["file"] );
		foreach ( $meta as $key => $value ) {
			if ( "sizes" === $key ) {
				foreach ( $value as $sizes => $size ) {
					$original_filename = $upload_dir['basedir'] . '/' . $path['dirname'] . '/' . $size['file'];
					$retina_filename = substr_replace( $original_filename, '@2x.', strrpos( $original_filename, '.' ), strlen( '.' ) );
					if ( file_exists( $retina_filename ) )
						unlink( $retina_filename );
				}
			}
		}
	}
}
}


// Adding a class to VC so that we can customize vc styles without !important
add_filter('vc_shortcodes_css_class', 'tt_vc_class_name', 10, 2);
function tt_vc_class_name($class_string, $tag) {
   return $class_string.' templatation';
}
// WC update changed class name on cart table, adding old to keep the desired look.
add_filter('woocommerce_cart_item_class', 'tt_add_cart_class', 10, 2);
function tt_add_cart_class( $cart_item ) {
   return $cart_item.' woo_cart_table_item';
}
add_filter( 'get_product_search_form' , 'tt_custom_product_searchform' );
function tt_custom_product_searchform( $form ) {

	$form = '<form role="search" id="searchform" method="get" class="woocommerce-product-search" action="'. esc_url( home_url( '/'  ) ).'">
	<label class="screen-reader-text" for="s">'. __( 'Search for:', 'templatation' ) .'</label>
	<input id="s" type="search" class="search-field" placeholder="'. __( 'Search Products&hellip;', 'templatation' ) .'" value="'. get_search_query().'" name="s" title="'. esc_attr_x( 'Search for:', 'templatation' ).'" />
	<input id="searchsubmit" type="submit" value="'. __( 'Search', 'templatation' ).'" />
	<input type="hidden" name="post_type" value="product" />
</form>
';

	return $form;

}

/*-----------------------------------------------------------------------------------*/
/* Fetch ALT tags for images
/*-----------------------------------------------------------------------------------*/
// returns title based on the requirement.

if (!function_exists( 'justshop_tt_img_alt')) {
function justshop_tt_img_alt( $imgid = '', $postid = '' ){
$alt = '';
if( '' == $imgid && '' != $postid ) // if only post id is given, fetch imgid from it.
$imgid = get_post_thumbnail_id( $postid );

if($imgid) $alt = get_post_meta( $imgid, '_wp_attachment_image_alt', true);

return htmlspecialchars($alt);

}
}

/*-----------------------------------------------------------------------------------*/
/* templatation_post_title function */
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'templatation_post_title' ) ) {
function templatation_post_title ( ) {

	$hide_title_display = $woo_page_title = $titlesettings = ''; $id = get_the_ID();
	$hide_title_display = get_post_meta( $id, '_tt_meta_page_opt', true );
	if( isset($hide_title_display['_hide_title_display'])) $titlesettings = $hide_title_display['_hide_title_display'];

	ob_start(); ?>
		<header class="post-header lc_tt_title">
			<ul>
				<li><?php echo get_the_date(); ?></li>
				<li class="date"><?php if(!comments_open($id)) echo 'Comments Off'; else comments_popup_link( __( 'Zero comments', 'templatation' ), __( '1 Comment', 'templatation' ), __( '% Comments', 'templatation' ) ); ?></li>
			</ul>
			<h1><?php if( strlen( get_the_title()) > 1 ) { ?> <a href="<?php the_permalink(); ?>" title="<?php esc_attr_e( 'Continue Reading &rarr;', 'templatation' ); ?>"><?php the_title(); ?></a> <?php } ?></h1>
		</header>
		<?php

	$tt_post_title = ob_get_clean();
	if( is_singular() ){
		if( empty($titlesettings) || $titlesettings == '0' ) {
			echo $tt_post_title;
		} // display title if not being hidden in single post.
	}
	else { echo $tt_post_title; }
	} // End templatation_post_title()
}

/*-----------------------------------------------------------------------------------*/
/* templatation_page_title function */
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'templatation_page_title' ) ) {
function templatation_page_title ( ) {

	$hide_title_display = $woo_page_title = $titlesettings = '';
	$hide_title_display = get_post_meta( get_the_ID(), '_tt_meta_page_opt', true );
	if( isset($hide_title_display['_hide_title_display'])) $titlesettings = $hide_title_display['_hide_title_display'];

	ob_start();
	if ( empty($titlesettings) || $titlesettings == '0' ) { ?>
		<header class="post-header">
			<h1><?php if( strlen( get_the_title()) > 1 ) the_title(); ?></h1>
		</header>
		<?php
	} // display title if not being hidden in single page/post.

	$woo_page_title = ob_get_clean();
	echo $woo_page_title;

	} // End templatation_page_title()
}


/* adding shortcode for usage with live composer */
add_shortcode('tt_post_thumb', 'templatation_post_thumb');
if ( ! function_exists( 'templatation_post_thumb' ) ) {
	function templatation_post_thumb() {
		global $tt_options, $post;
		$output    = '';
		$id        = get_the_ID();
		$show_fake = false;

		if ( is_singular() ) {
			$show_fake = false;
		}

		if ( get_post_type( $id ) == 'dslc_templates' ) {
			$show_fake = true;
		}

		if ( $show_fake || ! $id ) {
			$output = '<div class="dslc-notification dslc-red">Featured Image Appears Here.</div>';
		} else {
			$settings = array(
				'thumb_single'       => '1',
				'thumb_w'           => array( 'width' => '775px' ),
				'thumb_h'           => array( 'height' => '208px' ),
				'single_w'           => array( 'width' => '775px' ),
				'single_h'           => array( 'height' => '208px' ),
				'thumb_single_align' => 'aligncenter'
			);

			$settings = tt_get_dynamic_values( $settings );
			ob_start();
			if ( $settings['thumb_single'] == '1' && is_singular() ) { // render image for single page
				$singlepostimg = woo_image( 'return=false&width=' . $settings['single_w']['width'] . '&height=' . $settings['single_h']['height'] . '&class=thumbnail ' . $settings['thumb_single_align'] );

				if ( ! empty( $singlepostimg ) ) {
					echo '<figure class="featureimg">' . $singlepostimg . '</figure><div class="fix"></div>';
				}
			}
			else { //render image for blog listing pages.
				$singlepostimg = woo_image( 'return=false&width=' . $settings['thumb_w']['width'] . '&height=' . $settings['thumb_h']['height'] . '&class=thumbnail ' . $settings['thumb_single_align'] );

				if ( ! empty( $singlepostimg ) ) {
					echo '<figure class="featureimg">' . $singlepostimg . '</figure><div class="fix"></div>';
				}

			}

			$output = ob_get_clean();
			if ( get_post_type( $id ) == 'dslc_templates' ) {
				$output = '[tt_post_thumb] Shortcode';
			}
		}

		return $output;
	}
}

add_shortcode('tt_lc_search', 'tt_lc_search_sc');
if ( ! function_exists( 'tt_lc_search_sc' ) ) {
	function tt_lc_search_sc() {
		global $post;
		$output    = '';
		$id        = get_the_ID();
		$show_fake = false;

		if ( get_post_type( $id ) == 'dslc_templates' ) {
			$show_fake = true;
		}

		if ( $show_fake ) {
			return '<div class="dslc-notification dslc-red">Search Form appears here.</div>';
		} else {

			ob_start();
			get_search_form();

			$output = ob_get_clean();
			if ( get_post_type( $id ) == 'dslc_templates' ) {
				$output = '[tt_lc_search] Shortcode';
			}

			return $output;
		}
	}
}

add_shortcode('tt_lc_title', 'templatation_lc_title');
if ( ! function_exists( 'templatation_lc_title' ) ) {
	function templatation_lc_title() {
		global $tt_options, $post;
		$output    = '';
		$post_id   = get_the_ID();
		$show_fake = true;

		$hide_title_display = $titlesettings = "";
		if ( is_singular() ) {
			$show_fake = false;
		}

		if ( get_post_type( $post_id ) == 'dslc_templates' ) {
			$show_fake = true;
		}

		if ( $show_fake ) {
			return '<div class="dslc-notification dslc-red">Post Title Appears Here.</div>';
		} else {
			$hide_title_display = get_post_meta( $post_id, '_tt_meta_post_opt', true );
			if ( is_array( $hide_title_display ) ) {
				$titlesettings = $hide_title_display['_hide_title_display'];
			}
			if ( ! isset( $titlesettings ) || isset( $titlesettings ) || $titlesettings == '0' ) {
				ob_start(); ?>
				<header class="post-header lc_tt_title">
					<ul>
						<li><?php echo get_the_date(); ?></li>
						<li class="date"><?php comments_popup_link( __( 'Zero comments', 'templatation' ), __( '1 Comment', 'templatation' ), __( '% Comments', 'templatation' ) ); ?></li>
					</ul>
					<h1><?php the_title(); ?></h1>
				</header>
			<?php } // display title if not being hidden in single page/post.
			$output = ob_get_clean();

			return $output;
		}
	}
}

add_shortcode( 'woo_numcomments', 'templatation_woo_numComments' );
if ( ! function_exists( 'templatation_woo_numComments' ) ) {
	function templatation_woo_numComments() {
		$woo_numComments = get_comments_number(); // get_comments_number returns only a numeric value

		if ( $woo_numComments == 0 ) {
			$comments = __( 'No comments yet.', 'templatation' );
		} elseif ( $woo_numComments > 1 ) {
			$comments = $num_comments . __( ' Comments', 'templatation' );
		} else {
			$comments = __( '1 Comment', 'templatation' );
		}

		$output = $comments;

		return '<h2><span>' . $output . '</span></h2>';
	}
}

/* Theme auto updates function */

/*
WPUpdates Theme Updater Class
http://wp-updates.com
v2.0

Example Usage:
require_once('wp-updates-theme.php');
new WPUpdatesThemeUpdater_1571( 'http://wp-updates.com/api/2/theme', basename(get_template_directory()) );
*/

if( !class_exists('WPUpdatesThemeUpdater_1571') ) {
    class WPUpdatesThemeUpdater_1571 {

        var $api_url;
    	var $theme_id = 1571;
    	var $theme_slug;
    	var $license_key;

        function __construct( $api_url, $theme_slug, $license_key = null ) {
    		$this->api_url = $api_url;
    		$this->theme_slug = $theme_slug;
	        $this->license_key = $license_key;

    		add_filter( 'pre_set_site_transient_update_themes', array(&$this, 'check_for_update') );

    		// This is for testing only!
    		//set_site_transient('update_themes', null);
    	}

    	function check_for_update( $transient ) {
        	if (empty($transient->checked)) return $transient;

        	$request_args = array(
    		    'id' => $this->theme_id,
    		    'slug' => $this->theme_slug,
    			'version' => $transient->checked[$this->theme_slug]
    		);
    		if ($this->license_key) $request_args['license'] = $this->license_key;

    		$request_string = $this->prepare_request( 'theme_update', $request_args );
    		$raw_response = wp_remote_post( $this->api_url, $request_string );

        	$response = null;
    		if( !is_wp_error($raw_response) && ($raw_response['response']['code'] == 200) )
    			$response = unserialize($raw_response['body']);

    		if( !empty($response) ) // Feed the update data into WP updater
    			$transient->response[$this->theme_slug] = $response;

        	return $transient;
        }

        function prepare_request( $action, $args ) {
    		global $wp_version;

    		return array(
    			'body' => array(
    				'action' => $action,
    				'request' => serialize($args),
    				'api-key' => md5(home_url())
    			),
    			'user-agent' => 'WordPress/'. $wp_version .'; '. home_url()
    		);
    	}

    }
}
$license_key = get_option('tt_options');
if(isset($license_key['tt_lic_key'])) {
//require_once('wp-updates-theme.php');
new WPUpdatesThemeUpdater_1571( 'http://wp-updates.com/api/2/theme', basename( get_template_directory() ), $license_key['tt_lic_key']  );
}

if ( ! function_exists( 'justshop_update_to_icons' ) ) {
	function justshop_update_to_icons() {
	$tt_ttext_icon_url = $tt_welcome_text_icon_url = '';

	$tt_options = get_option( 'tt_options' );
	if( isset($tt_options['tt_ttext_icon']['url']))
	$tt_ttext_icon_url = $tt_options['tt_ttext_icon']['url'];
	if( isset($tt_options['tt_welcome_text_icon']['url']))
	$tt_welcome_text_icon_url = $tt_options['tt_welcome_text_icon']['url'];

	if( strpos($tt_ttext_icon_url,'templatation') ) {
		$tt_options['tt_ttext_icon']['url'] = get_template_directory_uri() . '/images/phone.png';
		update_option( 'tt_options', $tt_options );
	}
	if( strpos($tt_welcome_text_icon_url,'templatation') ) {
		$tt_options['tt_welcome_text_icon']['url'] = get_template_directory_uri() . '/images/user.png';
		update_option( 'tt_options', $tt_options );
	}
	}
	justshop_update_to_icons(); /*function to update icons to use from theme folder native.*/
}

/* Removing redux demo data */
function tt_rm_reduxDemoModeLink() {
    if ( class_exists('ReduxFrameworkPlugin') ) {
        remove_filter( 'plugin_row_meta', array( ReduxFrameworkPlugin::get_instance(), 'plugin_metalinks'), null, 2 );
    }
    if ( class_exists('ReduxFrameworkPlugin') ) {
        remove_action('admin_notices', array( ReduxFrameworkPlugin::get_instance(), 'admin_notices' ) );
    }
}
add_action('init', 'tt_rm_reduxDemoModeLink');


/* Depreciated fn, keeping for compatibility if user using them in child theme. */
if ( ! function_exists( 'woo_title' ) ) {
	function woo_title() {  /* fn no longer needed */
	}
}if ( ! function_exists( 'woo_embed' ) ) {
	function woo_embed() {  /* fn no longer needed */
	}
}
if ( ! function_exists( 'woo_sidebar' ) ) {
function woo_sidebar( $id = 1 ) {
	return dynamic_sidebar( $id );
} // End woo_sidebar()
}

if ( ! function_exists( 'woo_active_sidebar' ) ) {
function woo_active_sidebar( $id ) {
	if( is_active_sidebar( $id ) )
		return true;

	return false;
} // End woo_active_sidebar()
}


/*-----------------------------------------------------------------------------------*/
/* END */
/*-----------------------------------------------------------------------------------*/