<?php
if ( ! defined( 'ABSPATH' ) ) exit;

$tt_options = get_option( 'tt_options' );

/*-----------------------------------------------------------------------------------*/
/* This theme supports WooCommerce, woo! */
/*-----------------------------------------------------------------------------------*/

add_action( 'after_setup_theme', 'woocommerce_support' );
function woocommerce_support() {
	add_theme_support( 'woocommerce' );
	//  WooCommerce 2.7
	if ( version_compare( WOOCOMMERCE_VERSION, "2.7" ) >= 0 ) {
			add_theme_support( 'wc-product-gallery-zoom' );
			add_theme_support( 'wc-product-gallery-lightbox' );
			add_theme_support( 'wc-product-gallery-slider' );
	}

}

global $pagenow;
if ( is_admin() ) add_action( 'init', 'templatation_wc_image_dimensions', 1 );

/**
 * Define woocommerce image sizes
 */
function templatation_wc_image_dimensions() {
	if ( get_option('tt_wc_img_size_set') == '1' ) return;
  	$catalog = array(
		'width' 	=> '280',	// px
		'height'	=> '180',	// px
		'crop'		=> 1 		// true
	);
 
	$single = array(
		'width' 	=> '350',	// px
		'height'	=> '350',	// px
		'crop'		=> 1 		// true
	);
 
	$thumbnail = array(
		'width' 	=> '80',	// px
		'height'	=> '80',	// px
		'crop'		=> 1 		// false
	);
 
	// Image sizes
	update_option( 'shop_catalog_image_size', $catalog ); 		// Product category thumbs
	update_option( 'shop_single_image_size', $single ); 		// Single product image
	update_option( 'shop_thumbnail_image_size', $thumbnail ); 	// Image gallery thumbs
	update_option( 'tt_wc_img_size_set', '1' ); 	// Image gallery thumbs
}


// Disable WooCommerce styles
if ( version_compare( WOOCOMMERCE_VERSION, "2.1" ) >= 0 ) {
	add_filter( 'woocommerce_enqueue_styles', '__return_false' );
} else {
	define( 'WOOCOMMERCE_USE_CSS', false );
}
// Remove default review stuff - the theme overrides it
remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 5 );
$settings = tt_get_dynamic_values( array( 'disable_responsive' => '0' ) );
// Load WooCommerce stylsheet

if ( ! is_admin() ) { add_action( 'wp_enqueue_scripts', 'woo_load_woocommerce_css', 20 ); }
if (  ! is_admin() && isset( $tt_options['tt_disable_responsive'] ) && $tt_options['tt_disable_responsive'] == '1' ) {
	remove_action( 'wp_enqueue_scripts', 'woo_load_woocommerce_css', 20 );
}

if ( ! function_exists( 'woo_load_woocommerce_css' ) ) {
	function woo_load_woocommerce_css () {
		wp_register_style( 'woocommerce', esc_url( get_template_directory_uri() . '/css/woocommerce.css' ) );
		wp_enqueue_style( 'woocommerce' );
	} // End woo_load_woocommerce_css()
}

/*
if ( ! function_exists( 'woo_load_woocommerce_css' ) ) {
	function woo_load_woocommerce_css () {
		$woocommerce_style = '';
		if (is_rtl()) $woocommerce_style = "woocommerce-rtl"; else $woocommerce_style = "woocommerce";
		wp_register_style( 'woocommerce', esc_url( get_template_directory_uri() . '/css/'.$woocommerce_style.'.css' ) );
		wp_enqueue_style( 'woocommerce' );
	} // End woo_load_woocommerce_css()
}
*/

/*-----------------------------------------------------------------------------------*/
/* Products */
/*-----------------------------------------------------------------------------------*/

// Number of columns on product archives
add_filter( 'loop_shop_columns', 'wooFramework_loop_columns' );
if ( ! function_exists( 'wooFramework_loop_columns' ) ) {
	function wooFramework_loop_columns() {
		global $tt_options;
		if ( ! isset( $tt_options['tt_woocommerce_product_columns'] ) ) {
			$cols = 2;
		} else {
			$cols = $tt_options['tt_woocommerce_product_columns'] + 2;
		}
		return $cols;
	} // End wooFramework_loop_columns()
}

// Number of products per page
add_filter( 'loop_shop_per_page', 'wooFramework_products_per_page' );

if ( ! function_exists( 'wooFramework_products_per_page' ) ) {
	function wooFramework_products_per_page() {
		global $tt_options;
		if ( isset( $tt_options['tt_woocommerce_products_per_page'] ) ) {
			return $tt_options['tt_woocommerce_products_per_page'];
		}
	} // End wooFramework_products_per_page()
}

// move image thumbnail below the title for product categories.
remove_action( 'woocommerce_before_subcategory_title', 'woocommerce_subcategory_thumbnail', 10 );
add_action( 'woocommerce_after_subcategory_title', 'woocommerce_subcategory_thumbnail', 10 );
// Add the image wrap
add_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_product_thumbnail_wrap_open', 5, 2);
add_action( 'woocommerce_after_subcategory_title', 'woocommerce_product_thumbnail_wrap_open', 5, 2);

if (!function_exists('woocommerce_product_thumbnail_wrap_open')) {
	function woocommerce_product_thumbnail_wrap_open() {
		echo '<div class="img-wrap">';
	}
}

// Close image wrap
add_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_product_thumbnail_wrap_close', 15, 2);
add_action( 'woocommerce_after_subcategory_title', 'woocommerce_product_thumbnail_wrap_close', 15, 2);
if (!function_exists('woocommerce_product_thumbnail_wrap_close')) {
	function woocommerce_product_thumbnail_wrap_close() {
		echo '</div> <!--/.wrap-->';
	}
}

// Move the price inside the img-wrap
remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_price', 10 );
add_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_price', 10 );
remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart' );
add_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 11 );

// Display product categories in the loop
/*add_action( 'woocommerce_after_shop_loop_item', 'justshop_product_loop_categories', 2 );
*/
if (!function_exists('justshop_product_loop_categories')) {
	function justshop_product_loop_categories() {
		global $post;
		$terms_as_text = get_the_term_list( $post->ID, 'product_cat', '', ', ', '' );
		if ( ! is_product_category() ) {
			echo '<div class="categories">' . $terms_as_text . '</div>';
		}
	}
}

// display out-of-stock on product archive
add_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_stock', 10);
function woocommerce_template_loop_stock() {
	global $product;
 		if ( ! $product->managing_stock() && ! $product->is_in_stock() )
 		echo '<p class="stock out-of-stock">' . __( 'Out of stock', 'templatation' ) . '</p>';
}

// hook description on product category loop
add_action( 'woocommerce_after_subcategory_title', 'tt_prod_cat_desc', 16);
function tt_prod_cat_desc($category) {
			if ( $category->description !== '' ) {
				echo '<div class="description">' . justshop_truncate($category->description,20) . '</div>';
			}
				echo '<a class="readmore" href="'. get_term_link(  $category->slug, 'product_cat' ) .'"><span class="view-more">' .__('View More', 'templatation') . '</span></a>';

}


/*-----------------------------------------------------------------------------------*/
/* Single Product */
/*-----------------------------------------------------------------------------------*/

// Making the elements sorting as required.
remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_price', 10 );
remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_excerpt', 20 );
add_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_excerpt', 10 );
add_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_price', 20 );


function justshop_product_reviews() {
	global $post;

	if ( ! comments_open() )
		return;

	$comments = get_comments(array(
		'post_id' => $post->ID,
		'status' => 'approve'
	));

	//if ( sizeof( $comments ) > 0 ) {

		comments_template();

	//}
}

// Display related products?
add_action( 'wp_head','wooFramework_related_products' );
if ( ! function_exists( 'wooFramework_related_products' ) ) {
	function wooFramework_related_products() {
		global $tt_options;
		if ( isset( $tt_options['tt_woocommerce_related_products'] ) &&  '0' == $tt_options['tt_woocommerce_related_products'] ) {
			remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20);
		}
	} // End wooFramework_related_products()
}

add_filter( 'woocommerce_output_related_products_args', 'tt_related_products' );
function tt_related_products() {
	global $tt_options, $post; $single_layout = '';
	$single_layout2 = get_post_meta( $post->ID, '_tt_meta_page_opt', true );
	if( isset($single_layout2['_layout']) ) $single_layout = $single_layout2['_layout'];
	$products_max = $tt_options['tt_woocommerce_related_products_maximum'] + 2;
	if ( $tt_options[ 'tt_woocommerce_products_fullwidth' ] == '1' && ( $single_layout != 'layout-left-content' && $single_layout != 'layout-right-content' ) ) {
		$products_cols = 4;
	} else {
		$products_cols = 3;
	}
	$args = array(
		'posts_per_page' => $products_max,
		'columns'        => $products_cols,
	);
	return $args;
}


// Upsells
if ( ! function_exists( 'woo_upsell_display' ) ) {
	function woo_upsell_display() {
	    // Display up sells in correct layout.
		global $tt_options;
		if ( isset( $tt_options['tt_layout'] ) && ( $tt_options['tt_layout'] == 'layout-full' ) || $tt_options['tt_woocommerce_products_fullwidth'] == '1' ) {
			$products_cols = 4;
		} else {
			$products_cols = 3;
		}
	    woocommerce_upsell_display( -1, $products_cols );
	}
}

remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15 );
// add_action( 'woocommerce_after_single_product_summary', 'woo_upsell_display', 15 ); // moved in single-product.php


// Custom place holder
add_filter( 'woocommerce_placeholder_img_src', 'wooFramework_wc_placeholder_img_src' );

if ( ! function_exists( 'wooFramework_wc_placeholder_img_src' ) ) {
	function wooFramework_wc_placeholder_img_src( $src ) {
		global $tt_options;
		if ( isset( $tt_options['tt_placeholder_url']['url'] ) && '' != $tt_options['tt_placeholder_url']['url'] ) {
			$src = $tt_options['tt_placeholder_url']['url'];
		}
		else {
			$src = get_template_directory_uri() . '/images/wc-placeholder.gif';
		}
		return esc_url( $src );
	} // End wooFramework_wc_placeholder_img_src()
}

// If theme lightbox is enabled, disable the WooCommerce lightbox and make product images prettyPhoto galleries
add_action( 'wp_footer', 'woocommerce_prettyphoto' );
function woocommerce_prettyphoto() {
	global $tt_options;
	if ( $tt_options['tt_enable_lightbox' ] == "1" ) {
		update_option( 'woocommerce_enable_lightbox', false );
		?>
			<script>
				jQuery(document).ready(function(){
					jQuery('.images a').attr('rel', 'prettyPhoto[product-gallery]');
				});
			</script>
		<?php
	}
}

// Display 40 images in galleries on single pages (to remove unnecessary last class)
add_filter( 'woocommerce_product_thumbnails_columns', 'woocommerce_custom_product_thumbnails_columns' );

if (!function_exists('woocommerce_custom_product_thumbnails_columns')) {
	function woocommerce_custom_product_thumbnails_columns() {
		return 40;
	}
}

// Display the ratings in the loop and on the single page
remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_rating', 10 );
add_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_rating', 12 );
/*
 * add_action( 'woocommerce_single_product_summary', 'templatation_product_rating_overview', 12 );

if (!function_exists('templatation_product_rating_overview')) {
	function templatation_product_rating_overview() {
		global $product;
		$review_total = get_comments_number();
		if ( $review_total > 0 && get_option( 'woocommerce_enable_review_rating' ) !== 'no' ) {
			echo '<div class="rating-wrap">';
					echo $product->get_rating_html();
			echo '</div>';
		}
	}
}
*/
// Change the add to cart text
add_filter('add_to_cart_text', 'justshop_custom_cart_button_text');

function justshop_custom_cart_button_text() {
    return __('Add', 'templatation');
}


/*-----------------------------------------------------------------------------------*/
/* Layout */
/*-----------------------------------------------------------------------------------*/

// Adjust markup on all woocommerce pages
remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10 );
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10 );
add_action( 'woocommerce_before_main_content', 'woocommerce_theme_before_content', 10 );
add_action( 'woocommerce_after_main_content', 'woocommerce_theme_after_content', 20 );

/*moving product-single page bottom out of main wrapper*/
remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_product_data_tabs', 10 );
//remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15 ); // occurs on line 211
remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20 );


if ( ! function_exists( 'woocommerce_theme_before_content' ) ) {
	function woocommerce_theme_before_content() {
		global $tt_options;
		if ( ! isset( $tt_options['tt_woocommerce_product_columns'] ) ) {
			$columns = 'woocommerce-columns-2';
		} else {
			$columns = 'woocommerce-columns-' . ( $tt_options['tt_woocommerce_product_columns'] + 2 );
		}
		?>
		<!-- #content Starts -->
	    <div id="content" class="col-full <?php echo esc_attr( $columns ); ?>">

	        <!-- #main Starts -->
	        <?php woo_main_before(); ?>
	        <div id="main" class="col-left">

	    <?php
	} // End woocommerce_theme_before_content()
}


if ( ! function_exists( 'woocommerce_theme_after_content' ) ) {
	function woocommerce_theme_after_content() {
		?>

			</div><!-- /#main -->
	        <?php woo_main_after(); ?>

	    </div><!-- /#content -->
		<?php woo_content_after(); ?>
	    <?php
	} // End woocommerce_theme_after_content()
}

function templatation_profile() {
	global $current_user;
	$url_myaccount 		= get_permalink( wc_get_page_id( 'myaccount' ) );
	$url_editaddress 	= get_permalink( wc_get_page_id( 'edit_address' ) );
	$url_changepass 	= get_permalink( wc_get_page_id( 'change_password' ) );
	$url_vieworder 		= get_permalink( wc_get_page_id( 'view_order' ) );

	?>
				<?php if ( wc_get_page_id( 'myaccount' ) !== -1 ) { ?>
					<li class="my-account"><a href="<?php echo $url_myaccount; ?>" class="" title="<?php if ( is_user_logged_in() ) {  _e('My Account', 'templatation' ); } else { _e( 'Log In', 'templatation' ); } ?>"><span><?php if ( is_user_logged_in() ) { _e('My Account', 'templatation' ); } else { _e( 'Log In', 'templatation' ); } ?></span></a></li>
				<?php } ?>

				<?php if ( ! is_user_logged_in() && wc_get_page_id( 'myaccount' ) !== -1 && get_option('woocommerce_enable_myaccount_registration')=='yes' ) { ?>
					<li class="register"><a href="<?php echo $url_myaccount; ?>" class="" title="<?php _e( 'Register', 'templatation' ); ?>"><span><?php _e( 'Register', 'templatation' ); ?></span></a></li>
				<?php } ?>

				<?php if ( is_user_logged_in() ) { ?>

					<?php if ( wc_get_page_id( 'edit_address' ) !== -1 ) { ?>
						<li class="edit-address"><a href="<?php echo $url_editaddress; ?>" class="" title="<?php _e( 'Edit Address', 'templatation' ); ?>"><span><?php _e( 'Edit Address', 'templatation' ); ?></span></a></li>
					<?php } ?>

					<?php if ( wc_get_page_id( 'change_password' ) !== -1 ) { ?>
						<li class="edit-password"><a href="<?php echo $url_changepass; ?>" class="" title="<?php _e( 'Change Password', 'templatation' ); ?>"><span><?php _e( 'Change Password', 'templatation' ); ?></span></a></li>
					<?php } ?>

					<?php if ( wc_get_page_id( 'view_order' ) !== -1 ) { ?>
						<li class="logout"><a href="<?php echo wp_logout_url( get_permalink() ); ?>" class="" title="<?php _e( 'Logout', 'templatation' ); ?>"><span><?php _e( 'Logout', 'templatation' ); ?></span></a></li>
					<?php } ?>

				<?php } ?>
	<?php

}


// Remove WC breadcrumb (we're using the wooFramework breadcrumb)
remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20, 0 );

// Customise the breadcrumb
add_filter( 'woo_breadcrumbs_args', 'woo_custom_breadcrumbs_args', 10 );

if (!function_exists('woo_custom_breadcrumbs_args')) {
	function woo_custom_breadcrumbs_args ( $args ) {
		$textdomain = 'templatation';
		$title = get_bloginfo( 'name' );
		$args = array('separator' => ' ', 'show_home' => sprintf( __( "%s", 'templatation' ), $title ));
		return $args;
	} // End woo_custom_breadcrumbs_args()
}

// Remove WC sidebar
remove_action( 'woocommerce_sidebar', 'woocommerce_get_sidebar', 10 );

// Add the WC sidebar in the right place and remove it from shop archives if specified
add_action( 'woo_main_after', 'woocommerce_get_sidebar', 10 );

if ( ! function_exists( 'woocommerce_get_sidebar' ) ) {
	function woocommerce_get_sidebar() {
		global $tt_options;

		if ( is_product() ) {
			return; // do nothing if its single product page, as sidebar is placed in single-product.php @templatation JS v2.5
		}
		// Display the sidebar if full width option is disabled on archives
		if ( is_shop() || is_product_category() || is_product_tag() ) {
			if ( isset( $tt_options['tt_woocommerce_archives_fullwidth'] ) && '0' == $tt_options['tt_woocommerce_archives_fullwidth'] ) {
				get_sidebar('shop');
			}
		}


	} // End woocommerce_get_sidebar()
}

// Remove pagination (we're using the wooFramework default pagination)
remove_action( 'woocommerce_after_shop_loop', 'woocommerce_pagination', 10 );
add_action( 'woocommerce_after_shop_loop', 'woocommerceframework_pagination', 10 );

if ( ! function_exists( 'woocommerceframework_pagination' ) ) {
function woocommerceframework_pagination() {
	if ( is_search() && is_post_type_archive() ) {
		add_filter( 'woo_pagination_args', 'woocommerceframework_add_search_fragment', 10 );
		add_filter( 'woo_pagination_args_defaults', 'woocommerceframework_woo_pagination_defaults', 10 );
	}
	woo_pagination();
} // End woocommerceframework_pagination()
}

if ( ! function_exists( 'woocommerceframework_add_search_fragment' ) ) {
function woocommerceframework_add_search_fragment ( $settings ) {
	$settings['add_fragment'] = '&post_type=product';

	return $settings;
} // End woocommerceframework_add_search_fragment()
}

if ( ! function_exists( 'woocommerceframework_woo_pagination_defaults' ) ) {
function woocommerceframework_woo_pagination_defaults ( $settings ) {
	$settings['use_search_permastruct'] = false;

	return $settings;
} // End woocommerceframework_woo_pagination_defaults()
}

// Add a class to the body if full width shop archives are specified or if the nav should be hidden
add_filter( 'body_class','wooFramework_layout_body_class', 10 );		// Add layout to body_class output
if ( ! function_exists( 'wooFramework_layout_body_class' ) ) {
	function wooFramework_layout_body_class( $wc_classes ) {
		global $tt_options;

		$layout = '';
		$nav_visibility = '';

		// Add layout-full class if full width option is enabled
		if ( isset( $tt_options['tt_woocommerce_archives_fullwidth'] ) && '1' == $tt_options['tt_woocommerce_archives_fullwidth'] && ( is_shop() || is_product_category() || is_product_tag() ) ) {
			$layout = 'layout-full';
		}
		if ( isset( $tt_options['tt_woocommerce_products_fullwidth']) && ($tt_options[ 'tt_woocommerce_products_fullwidth' ] == "1") && ( is_product() ) ) {
			$layout = 'layout-full';
		}

		// Add nav-hidden class if specified in theme options
		if ( isset( $tt_options['tt_woocommerce_hide_nav'] ) && '1' == $tt_options['tt_woocommerce_hide_nav'] && ( is_checkout() ) ) {
			$nav_visibility = 'nav-hidden';
		}

		// Add classes to body_class() output
		$wc_classes[] = $layout;
		$wc_classes[] = $nav_visibility;

		return $wc_classes;
	} // End woocommerce_layout_body_class()
}

// Enable catalog mode if setup in admin.
if ( isset($tt_options['tt_enable_catalog']) && '1' == $tt_options['tt_enable_catalog'] ) {
	/* remove add to cart button */
		remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 11 );
		remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_price', 10 );

		remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart', 30 );
		remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_price', 20 );
}
/*end of add to cart removal code*/

add_filter('woocommerce_add_to_cart_fragments', 'header_add_to_cart_fragment');

function header_add_to_cart_fragment( $fragments ) {
	global $woocommerce;

	ob_start();

	tt_cart_button();

	$fragments['a.cart-contents'] = ob_get_clean();

	return $fragments;

}

function tt_cart_button() {
	global $woocommerce;
	?>
	<a class="cart-contents header-cart" href="<?php echo esc_url( wc_get_cart_url() ); ?>" title="<?php _e( 'View your shopping cart', 'templatation' ); ?>"><?php echo $woocommerce->cart->get_cart_total(); ?></a>
	<?php
}


function tt_mini_cart() {
	global $woocommerce, $tt_options; $settings16 = '';
	$settings16 = tt_get_dynamic_values( array( 'no_hdrcart_popup' => '0' ) );
	if ( $settings16['no_hdrcart_popup'] == '1') tt_cart_button(); // no popup if chosen so in Themeoptions
	else {
		tt_cart_button();
		$tit = $tit1 = "";
		$tit = $woocommerce->cart->cart_contents_count;
		$tit1 = __( ' item(s) in Cart ', 'templatation' );
		$tit = "title=".$tit.$tit1;
		the_widget( 'WC_Widget_Cart', $tit );
	}
}

/* List/Grid view */
/* Author: jameskoster */

/**
 * WC_List_Grid class
 **/
if (!class_exists('WC_List_Grid')) {

	class WC_List_Grid {

		public function __construct() {
			// Hooks
			add_action( 'wp' , array( $this, 'setup_gridlist' ) , 20);

			// Init settings
			$this->settings = array(
				array(
					'name' => __( 'Default catalog view', 'templatation' ),
					'type' => 'title',
					'id' => 'wc_glt_options'
				),
				array(
					'name' 		=> __( 'Default catalog view', 'templatation' ),
					'desc_tip' 	=> __( 'Display products in grid or list view by default', 'templatation' ),
					'id' 		=> 'wc_glt_default',
					'type' 		=> 'select',
					'options' 	=> array(
						'grid'  => __('Grid', 'templatation'),
						'list' 	=> __('List', 'templatation'),
						'disable' 	=> __('Disable', 'templatation')
					)
				),
				array( 'type' => 'sectionend', 'id' => 'wc_glt_options' ),
			);

			// Default options
			add_option( 'wc_glt_default', 'grid' );

			// Admin
			add_action( 'woocommerce_settings_image_options_after', array( $this, 'admin_settings' ), 20);
			add_action( 'woocommerce_update_options_catalog', array( $this, 'save_admin_settings' ) );
			add_action( 'woocommerce_update_options_products', array( $this, 'save_admin_settings' ) );
		}

		/*-----------------------------------------------------------------------------------*/
		/* Class Functions */
		/*-----------------------------------------------------------------------------------*/

		function admin_settings() {
			woocommerce_admin_fields( $this->settings );
		}

		function save_admin_settings() {
			woocommerce_update_options( $this->settings );
		}
		

		// Setup
		function setup_gridlist() {
		$GLoption = ''; $GLoption = get_option( 'wc_glt_default' ); if( $GLoption == 'disable' ) return; // do nothing if disabled.
			if ( is_shop() || is_product_category() || is_product_tag() ) {
				add_action( 'wp_enqueue_scripts', array( $this, 'setup_scripts_script' ), 20);
				add_action( 'woocommerce_before_shop_loop', array( $this, 'gridlist_toggle_button' ), 30);
				add_action( 'woocommerce_after_shop_loop_item', array( $this, 'gridlist_buttonwrap_open' ), 9);
				add_action( 'woocommerce_after_shop_loop_item', array( $this, 'gridlist_buttonwrap_close' ), 11);
				//add_action( 'woocommerce_after_subcategory', array( $this, 'gridlist_cat_desc' ) );
			}
		}

		// Scripts
		function setup_scripts_script() {
			if ( is_shop() || is_product_category() || is_product_tag() ) {
				wp_enqueue_script( 'cookie', get_template_directory_uri() . '/includes/js/jquery.cookie.js', array( 'jquery' ),false,true );
				wp_enqueue_script( 'grid-list-scripts', get_template_directory_uri() . '/includes/js/jquery.gridlistview.js', array( 'jquery' ),false,true );
				add_action( 'wp_footer', array(&$this, 'gridlist_set_default_view'), 99 );
			}
		}

		// Toggle button
		function gridlist_toggle_button() {
			?>
				<nav class="gridlist-toggle">
					<a href="#" id="grid" title="<?php _e('Grid view', 'templatation'); ?>"> <span><?php _e('Grid view', 'templatation'); ?></span></a><a href="#" id="list" title="<?php _e('List view', 'templatation'); ?>"> <span><?php _e('List view', 'templatation'); ?></span></a>
				</nav>
			<?php
		}

		// Button wrap
		function gridlist_buttonwrap_open() {
			?>
				<div class="gridlist-buttonwrap">
			<?php
		}
		function gridlist_buttonwrap_close() {
			?>
				</div>
			<?php
		}

		// hr
		function gridlist_hr() {
			?>
				<hr />
			<?php
		}

		function gridlist_set_default_view() {
			$default = get_option( 'wc_glt_default' );
			?>
				<script>
					if (jQuery.cookie('gridcookie') == null) {
						jQuery('ul.products').addClass('<?php echo $default; ?>');
						jQuery('.gridlist-toggle #<?php echo $default; ?>').addClass('active');
					}
				</script>
			<?php
		}

		function gridlist_cat_desc( $category ) {
			global $woocommerce;
			echo '<div itemprop="description">';
				echo $category->description;
			echo '</div>';

		}
	}
	$WC_List_Grid = new WC_List_Grid();
}

// overriding woocommerce function to link images too.
if ( ! function_exists( 'woocommerce_subcategory_thumbnail' ) ) {

	/**
	 * Show subcategory thumbnails.
	 *
	 * @access public
	 * @param mixed $category
	 * @subpackage	Loop
	 * @return void
	 */
	function woocommerce_subcategory_thumbnail( $category ) {
		global $woocommerce, $tt_options;

		$small_thumbnail_size  	= apply_filters( 'single_product_small_thumbnail_size', 'shop_catalog' );
		$dimensions    			= wc_get_image_size( $small_thumbnail_size );
		$thumbnail_id  			= get_woocommerce_term_meta( $category->term_id, 'thumbnail_id', true  );

		if ( $thumbnail_id ) {
			$image = wp_get_attachment_image_src( $thumbnail_id, $small_thumbnail_size  );
			$image = $image[0];
		} else {
			$image = woocommerce_placeholder_img_src();
		}
			$woo_imagg = "";
			$woo_imagg = '<a href="' .get_term_link( $category->slug, 'product_cat' ). '"><img src="' . $image . '" alt="' . $category->name . '" width="' . $dimensions['width'] . '" height="' . $dimensions['height'] . '" /></a>';

			$settngg = tt_get_dynamic_values( array('link_prod_thumb' => 'false') ) ;
			if( $settngg['link_prod_thumb'] == 'false' ) 
			$woo_imagg = '<img src="' . $image . '" alt="' . $category->name . '" width="' . $dimensions['width'] . '" height="' . $dimensions['height'] . '" />';
 

		if ( $image )
			echo $woo_imagg;
	}
}

// overriding woocommerce function to link images too.
if ( ! function_exists( 'woocommerce_get_product_thumbnail' ) ) {

	/**
	 * Get the product thumbnail, or the placeholder if not set.
	 *
	 * @access public
	 * @subpackage	Loop
	 * @param string $size (default: 'shop_catalog')
	 * @param int $placeholder_width (default: 0)
	 * @param int $placeholder_height (default: 0)
	 * @return string
	 */
	function woocommerce_get_product_thumbnail( $size = 'shop_catalog', $placeholder_width = 0, $placeholder_height = 0  ) {
		global $post, $tt_options; $prod_imgg = "";

		if ( has_post_thumbnail() )
			$prod_imgg = get_the_post_thumbnail( $post->ID, $size );
		elseif ( woocommerce_placeholder_img_src() )
			$prod_imgg = woocommerce_placeholder_img( $size );
			
		$settngg = tt_get_dynamic_values( array('link_prod_thumb' => 'false') ) ;
		if( $settngg['link_prod_thumb'] == '1' )
		$prod_imgg = '<a href="' .get_permalink(). '">' .$prod_imgg. '</a>';
		
		return $prod_imgg;
	}
}
