<?php
/**
 * The template for displaying archive pages
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Justshoppe
 */

// Prevent direct access.
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Header
 */
get_header();

if ( justshoppe_is_fresh_install() ) {

	/**
	 * Primary - opening tag
	 */
	justshoppe_primary_open();

	/**
	 * Hook: justshoppe/frontend/before_main
	 *
	 * @hooked justshoppe_archive_header - 10
	 */
	do_action( 'justshoppe/frontend/before_main' );

	if ( have_posts() ) :

		/**
		 * Hook: justshoppe/frontend/before_loop
		 */
		do_action( 'justshoppe/frontend/before_loop' );

		?>
		<div id="loop" class="<?php echo esc_attr( implode( ' ', apply_filters( 'justshoppe/frontend/loop_classes', array( 'justshoppe-loop' ) ) ) ); ?>">
			<?php
			// Start the loop.
			while ( have_posts() ) : the_post();

				// Render post content using selected layout on Customizer.
				justshoppe_get_template_part( 'entry', justshoppe_get_theme_mod( 'blog_index_loop_mode' ) );

			endwhile;
			?>
		</div>
		<?php

		/**
		 * Hook: justshoppe/frontend/after_loop
		 */
		do_action( 'justshoppe/frontend/after_loop' );

	else :

		// Render not-found message.
		esc_html_e( 'Nothing found.', 'justshoppe' );

	endif;

	/**
	 * Hook: justshoppe/frontend/after_main
	 *
	 * @hooked justshoppe_archive_navigation - 10
	 */
	do_action( 'justshoppe/frontend/after_main' );

	/**
	 * Primary - closing tag
	 */
	justshoppe_primary_close();

	/**
	 * Sidebar
	 */
	get_sidebar();

} else {
	?>
	<div id="primary" class="content-area">
		<main id="main" class="site-main" role="main">

			<?php if ( have_posts() ) : ?>

				<header class="page-header">
					<?php
					the_archive_title( '<h1 class="page-title">', '</h1>' );
					the_archive_description( '<div class="taxonomy-description">', '</div>' );
					?>
				</header><!-- .page-header -->

				<?php
				get_template_part( 'template-parts/loop' );

			else :

				get_template_part( 'template-parts/content', 'none' );

			endif;
			?>

		</main><!-- #main -->
	</div><!-- #primary -->

	<?php
	do_action( 'justshoppe_sidebar' );

}
get_footer();