<?php
/**
 * The template for displaying comments
 *
 * This is the template that displays the area of the page that contains both the current comments
 * and the comment form.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Justshoppe
 */

// Prevent direct access.
if ( ! defined( 'ABSPATH' ) ) exit;

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() ) {
	return;
}
?>

<?php if ( justshoppe_is_fresh_install() ) { ?>

	<div id="comments" class="comments-area">
		<?php
		/**
		 * Hook: justshoppe/frontend/before_comments
		 */
		do_action( 'justshoppe/frontend/before_comments' );

		// You can start editing here -- including this comment!
		if ( have_comments() ) :

			/**
			 * Hook: justshoppe/frontend/before_comments_list
			 *
			 * @hooked justshoppe_comments_title - 10
			 * @hooked justshoppe_comments_navigation - 20
			 */
			do_action( 'justshoppe/frontend/before_comments_list' );
			?>

			<ol class="comment-list">
				<?php
				wp_list_comments( array(
					'style'       => 'ol',
					'short_ping'  => true,
					'avatar_size' => 50,
				) );
				?>
			</ol>

			<?php
			/**
			 * Hook: justshoppe/frontend/after_comments_list
			 *
			 * @hooked justshoppe_comments_navigation - 10
			 * @hooked justshoppe_comments_closed - 20
			 */
			do_action( 'justshoppe/frontend/after_comments_list' );

		endif; // Check for have_comments().

		// Print comment form.
		comment_form( apply_filters( 'justshoppe/frontend/comment_form_args', array() ) );

		/**
		 * Hook: justshoppe/frontend/after_comments
		 */
		do_action( 'justshoppe/frontend/after_comments' );
		?>
	</div>

<?php
} else {
	?>

	<section id="comments" class="comments-area" aria-label="<?php esc_html_e( 'Post Comments', 'justshoppe' ); ?>">

		<?php
		if ( have_comments() ) :
			?>
			<h2 class="comments-title">
				<?php
				printf( // WPCS: XSS OK.
				/* translators: 1: number of comments, 2: post title */
					esc_html( _nx( '%1$s thought on &ldquo;%2$s&rdquo;', '%1$s thoughts on &ldquo;%2$s&rdquo;', get_comments_number(), 'comments title', 'justshoppe' ) ),
					number_format_i18n( get_comments_number() ),
					'<span>' . get_the_title() . '</span>'
				);
				?>
			</h2>

			<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : // Are there comments to navigate through. ?>
			<nav id="comment-nav-above" class="comment-navigation" role="navigation" aria-label="<?php esc_html_e( 'Comment Navigation Above', 'justshoppe' ); ?>">
				<span class="screen-reader-text"><?php esc_html_e( 'Comment navigation', 'justshoppe' ); ?></span>
				<div class="nav-previous"><?php previous_comments_link( __( '&larr; Older Comments', 'justshoppe' ) ); ?></div>
				<div class="nav-next"><?php next_comments_link( __( 'Newer Comments &rarr;', 'justshoppe' ) ); ?></div>
			</nav><!-- #comment-nav-above -->
		<?php endif; // Check for comment navigation. ?>

			<ol class="comment-list">
				<?php
				wp_list_comments(
					array(
						'style'      => 'ol',
						'short_ping' => true,
						'callback'   => 'justshoppe_comment',
					)
				);
				?>
			</ol><!-- .comment-list -->

			<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : // Are there comments to navigate through. ?>
			<nav id="comment-nav-below" class="comment-navigation" role="navigation" aria-label="<?php esc_html_e( 'Comment Navigation Below', 'justshoppe' ); ?>">
				<span class="screen-reader-text"><?php esc_html_e( 'Comment navigation', 'justshoppe' ); ?></span>
				<div class="nav-previous"><?php previous_comments_link( __( '&larr; Older Comments', 'justshoppe' ) ); ?></div>
				<div class="nav-next"><?php next_comments_link( __( 'Newer Comments &rarr;', 'justshoppe' ) ); ?></div>
			</nav><!-- #comment-nav-below -->
		<?php
		endif; // Check for comment navigation.

		endif;

		if ( ! comments_open() && 0 !== intval( get_comments_number() ) && post_type_supports( get_post_type(), 'comments' ) ) :
			?>
			<p class="no-comments"><?php esc_html_e( 'Comments are closed.', 'justshoppe' ); ?></p>
		<?php
		endif;

		$args = apply_filters(
			'justshoppe_comment_form_args', array(
				'title_reply_before' => '<span id="reply-title" class="gamma comment-reply-title">',
				'title_reply_after'  => '</span>',
			)
		);

		comment_form( $args );
		?>

	</section><!-- #comments -->
<?php
}
