<?php
/**
 * Justshoppe Customizer Class
 *
 * @package  justshoppe
 * @since    2.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Justshoppe_Customizer' ) ) :

	/**
	 * The Justshoppe Customizer class
	 */
	class Justshoppe_Customizer {

		/**
		 * Setup class.
		 *
		 * @since 1.0
		 */
		public function __construct() {
			add_action( 'customize_register', array( $this, 'customize_register' ), 10 );
			add_filter( 'body_class', array( $this, 'layout_class' ) );
			add_action( 'wp_enqueue_scripts', array( $this, 'add_customizer_css' ), 130 );
			add_action( 'customize_controls_print_styles', array( $this, 'customizer_custom_control_css' ) );
			add_action( 'customize_register', array( $this, 'edit_default_customizer_settings' ), 99 );
			add_action( 'enqueue_block_editor_assets', array( $this, 'block_editor_customizer_css' ) );
			add_action( 'init', array( $this, 'default_theme_mod_values' ), 10 );
		}

		/**
		 * Returns an array of the desired default Justshoppe Options
		 *
		 * @return array
		 */
		public function get_justshoppe_default_setting_values() {
			return apply_filters(
				'justshoppe_setting_default_values', $args = array(
					'justshoppe_heading_color'           => '#333333',
					'justshoppe_text_color'              => '#6d6d6d',
					'justshoppe_accent_color'            => '#e75a39',
					'justshoppe_hero_heading_color'      => '#000000',
					'justshoppe_hero_text_color'         => '#000000',
					'justshoppe_button_background_color' => '#e75a39',
					'justshoppe_button_text_color'       => '#ffffff',
					'justshoppe_button_alt_background_color' => '#333333',
					'justshoppe_button_alt_text_color'   => '#ffffff',
					'justshoppe_layout'                  => 'right',
					'background_color'                   => 'ffffff',
				)
			);
		}

		/**
		 * Adds a value to each Justshoppe setting if one isn't already present.
		 *
		 * @uses get_justshoppe_default_setting_values()
		 */
		public function default_theme_mod_values() {
			foreach ( $this->get_justshoppe_default_setting_values() as $mod => $val ) {
				add_filter( 'theme_mod_' . $mod, array( $this, 'get_theme_mod_value' ), 10 );
			}
		}

		/**
		 * Get theme mod value.
		 *
		 * @param string $value Theme modification value.
		 * @return string
		 */
		public function get_theme_mod_value( $value ) {
			$key = substr( current_filter(), 10 );

			$set_theme_mods = get_theme_mods();

			if ( isset( $set_theme_mods[ $key ] ) ) {
				return $value;
			}

			$values = $this->get_justshoppe_default_setting_values();

			return isset( $values[ $key ] ) ? $values[ $key ] : $value;
		}

		/**
		 * Set Customizer setting defaults.
		 * These defaults need to be applied separately as child themes can filter justshoppe_setting_default_values
		 *
		 * @param  array $wp_customize the Customizer object.
		 * @uses   get_justshoppe_default_setting_values()
		 */
		public function edit_default_customizer_settings( $wp_customize ) {
			foreach ( $this->get_justshoppe_default_setting_values() as $mod => $val ) {
				$wp_customize->get_setting( $mod )->default = $val;
			}
		}

		/**
		 * Add postMessage support for site title and description for the Theme Customizer along with several other settings.
		 *
		 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
		 * @since  1.0.0
		 */
		public function customize_register( $wp_customize ) {

			// Move background color setting alongside background image.
			$wp_customize->get_control( 'background_color' )->section  = 'background_image';
			$wp_customize->get_control( 'background_color' )->priority = 20;

			// Change background image section title & priority.
			$wp_customize->get_section( 'background_image' )->title    = __( 'Body Background', 'justshoppe' );
			$wp_customize->get_section( 'background_image' )->priority = 30;

			// Selective refresh.
			if ( function_exists( 'add_partial' ) ) {
				$wp_customize->get_setting( 'blogname' )->transport        = 'postMessage';
				$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

				$wp_customize->selective_refresh->add_partial(
					'custom_logo', array(
						'selector'        => '.site-branding',
						'render_callback' => array( $this, 'get_site_logo' ),
					)
				);

				$wp_customize->selective_refresh->add_partial(
					'blogname', array(
						'selector'        => '.site-title.beta a',
						'render_callback' => array( $this, 'get_site_name' ),
					)
				);

				$wp_customize->selective_refresh->add_partial(
					'blogdescription', array(
						'selector'        => '.site-description',
						'render_callback' => array( $this, 'get_site_description' ),
					)
				);
			}

			/**
			 * Custom controls
			 */
			require_once dirname( __FILE__ ) . '/class-theme-customizer-control-radio-image.php';
			require_once dirname( __FILE__ ) . '/class-theme-customizer-control-arbitrary.php';


			/**
			 * Add the typography section
			 */
			$wp_customize->add_section(
				'justshoppe_typography', array(
					'title'    => __( 'Typography', 'justshoppe' ),
					'panel'       => 'js_panel1',
					'priority' => 45,
				)
			);

			/**
			 * Heading color
			 */
			$wp_customize->add_setting(
				'justshoppe_heading_color', array(
					'default'           => apply_filters( 'justshoppe_default_heading_color', '#484c51' ),
					'sanitize_callback' => 'sanitize_hex_color',
				)
			);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize, 'justshoppe_heading_color', array(
						'label'    => __( 'Heading color', 'justshoppe' ),
						'section'  => 'justshoppe_typography',
						'settings' => 'justshoppe_heading_color',
						'priority' => 20,
					)
				)
			);

			/**
			 * Text Color
			 */
			$wp_customize->add_setting(
				'justshoppe_text_color', array(
					'default'           => apply_filters( 'justshoppe_default_text_color', '#43454b' ),
					'sanitize_callback' => 'sanitize_hex_color',
				)
			);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize, 'justshoppe_text_color', array(
						'label'    => __( 'Text color', 'justshoppe' ),
						'section'  => 'justshoppe_typography',
						'settings' => 'justshoppe_text_color',
						'priority' => 30,
					)
				)
			);

			/**
			 * Accent Color
			 */
			$wp_customize->add_setting(
				'justshoppe_accent_color', array(
					'default'           => apply_filters( 'justshoppe_default_accent_color', '#e75a39' ),
					'sanitize_callback' => 'sanitize_hex_color',
				)
			);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize, 'justshoppe_accent_color', array(
						'label'    => __( 'Link / accent color', 'justshoppe' ),
						'section'  => 'justshoppe_typography',
						'settings' => 'justshoppe_accent_color',
						'priority' => 40,
					)
				)
			);

			/**
			 * Hero Heading Color
			 */
			$wp_customize->add_setting(
				'justshoppe_hero_heading_color', array(
					'default'           => apply_filters( 'justshoppe_default_hero_heading_color', '#000000' ),
					'sanitize_callback' => 'sanitize_hex_color',
				)
			);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize, 'justshoppe_hero_heading_color', array(
						'label'           => __( 'Hero heading color', 'justshoppe' ),
						'section'         => 'justshoppe_typography',
						'settings'        => 'justshoppe_hero_heading_color',
						'priority'        => 50,
						'active_callback' => array( $this, 'is_homepage_template' ),
					)
				)
			);

			/**
			 * Hero Text Color
			 */
			$wp_customize->add_setting(
				'justshoppe_hero_text_color', array(
					'default'           => apply_filters( 'justshoppe_default_hero_text_color', '#000000' ),
					'sanitize_callback' => 'sanitize_hex_color',
				)
			);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize, 'justshoppe_hero_text_color', array(
						'label'           => __( 'Hero text color', 'justshoppe' ),
						'section'         => 'justshoppe_typography',
						'settings'        => 'justshoppe_hero_text_color',
						'priority'        => 60,
						'active_callback' => array( $this, 'is_homepage_template' ),
					)
				)
			);

			/**
			 * Buttons section
			 */
			$wp_customize->add_section(
				'justshoppe_buttons', array(
					'title'       => __( 'Buttons', 'justshoppe' ),
					'panel'       => 'js_panel1',
					'priority'    => 45,
					'description' => __( 'Customize the look & feel of your website buttons.', 'justshoppe' ),
				)
			);

			/**
			 * Button background color
			 */
			$wp_customize->add_setting(
				'justshoppe_button_background_color', array(
					'default'           => apply_filters( 'justshoppe_default_button_background_color', '#e75a39' ),
					'sanitize_callback' => 'sanitize_hex_color',
				)
			);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize, 'justshoppe_button_background_color', array(
						'label'    => __( 'Background color', 'justshoppe' ),
						'section'  => 'justshoppe_buttons',
						'settings' => 'justshoppe_button_background_color',
						'priority' => 10,
					)
				)
			);

			/**
			 * Button text color
			 */
			$wp_customize->add_setting(
				'justshoppe_button_text_color', array(
					'default'           => apply_filters( 'justshoppe_default_button_text_color', '#ffffff' ),
					'sanitize_callback' => 'sanitize_hex_color',
				)
			);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize, 'justshoppe_button_text_color', array(
						'label'    => __( 'Text color', 'justshoppe' ),
						'section'  => 'justshoppe_buttons',
						'settings' => 'justshoppe_button_text_color',
						'priority' => 20,
					)
				)
			);

			/**
			 * Button alt background color
			 */
			$wp_customize->add_setting(
				'justshoppe_button_alt_background_color', array(
					'default'           => apply_filters( 'justshoppe_default_button_alt_background_color', '#2c2d33' ),
					'sanitize_callback' => 'sanitize_hex_color',
				)
			);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize, 'justshoppe_button_alt_background_color', array(
						'label'    => __( 'Alternate button background color', 'justshoppe' ),
						'section'  => 'justshoppe_buttons',
						'settings' => 'justshoppe_button_alt_background_color',
						'priority' => 30,
					)
				)
			);

			/**
			 * Button alt text color
			 */
			$wp_customize->add_setting(
				'justshoppe_button_alt_text_color', array(
					'default'           => apply_filters( 'justshoppe_default_button_alt_text_color', '#ffffff' ),
					'sanitize_callback' => 'sanitize_hex_color',
				)
			);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize, 'justshoppe_button_alt_text_color', array(
						'label'    => __( 'Alternate button text color', 'justshoppe' ),
						'section'  => 'justshoppe_buttons',
						'settings' => 'justshoppe_button_alt_text_color',
						'priority' => 40,
					)
				)
			);

			/**
			 * Layout
			 */
			$wp_customize->add_section(
				'justshoppe_layout', array(
					'title'    => __( 'Layout', 'justshoppe' ),
					'panel'       => 'js_panel1',
					'priority' => 50,
				)
			);

			$wp_customize->add_setting(
				'justshoppe_layout', array(
					'default'           => apply_filters( 'justshoppe_default_layout', $layout = is_rtl() ? 'left' : 'right' ),
					'sanitize_callback' => 'justshoppe_sanitize_choices',
				)
			);

			$wp_customize->add_control(
				new Justshoppe_Custom_Radio_Image_Control(
					$wp_customize, 'justshoppe_layout', array(
						'settings' => 'justshoppe_layout',
						'section'  => 'justshoppe_layout',
						'label'    => __( 'General Layout', 'justshoppe' ),
						'priority' => 1,
						'choices'  => array(
							'right' => get_template_directory_uri() . '/assets/fallback/images/customizer/controls/2cr.png',
							'left'  => get_template_directory_uri() . '/assets/fallback/images/customizer/controls/2cl.png',
						),
					)
				)
			);

		}

		/**
		 * Get all of the Justshoppe theme mods.
		 *
		 * @return array $justshoppe_theme_mods The Justshoppe Theme Mods.
		 */
		public function get_justshoppe_theme_mods() {
			$justshoppe_theme_mods = array(
				'background_color'            => justshoppe_get_content_background_color(),
				'accent_color'                => get_theme_mod( 'justshoppe_accent_color' ),
				'hero_heading_color'          => get_theme_mod( 'justshoppe_hero_heading_color' ),
				'hero_text_color'             => get_theme_mod( 'justshoppe_hero_text_color' ),
				'text_color'                  => get_theme_mod( 'justshoppe_text_color' ),
				'heading_color'               => get_theme_mod( 'justshoppe_heading_color' ),
				'button_background_color'     => get_theme_mod( 'justshoppe_button_background_color' ),
				'button_text_color'           => get_theme_mod( 'justshoppe_button_text_color' ),
				'button_alt_background_color' => get_theme_mod( 'justshoppe_button_alt_background_color' ),
				'button_alt_text_color'       => get_theme_mod( 'justshoppe_button_alt_text_color' ),
			);

			return apply_filters( 'justshoppe_theme_mods', $justshoppe_theme_mods );
		}

		/**
		 * Get Customizer css.
		 *
		 * @see get_justshoppe_theme_mods()
		 * @return array $styles the css
		 */
		public function get_css() {
			$justshoppe_theme_mods = $this->get_justshoppe_theme_mods();
			$brighten_factor       = apply_filters( 'justshoppe_brighten_factor', 25 );
			$darken_factor         = apply_filters( 'justshoppe_darken_factor', -25 );

			$styles = '

			.pink_more, .entry-title > a, a.remove::before{ color: '. get_theme_mod( 'blv_accent_color' ) .'; }


			table th {
				background-color: ' . justshoppe_adjust_color_brightness( $justshoppe_theme_mods['background_color'], -7 ) . ';
			}

			table tbody td {
				background-color: ' . justshoppe_adjust_color_brightness( $justshoppe_theme_mods['background_color'], -2 ) . ';
			}

			table tbody tr:nth-child(2n) td,
			fieldset,
			fieldset legend {
				background-color: ' . justshoppe_adjust_color_brightness( $justshoppe_theme_mods['background_color'], -4 ) . ';
			}


			h1, h2, h3, h4, h5, h6 {
				color: ' . $justshoppe_theme_mods['heading_color'] . ';
			}

			.widget h1 {
				border-bottom-color: ' . $justshoppe_theme_mods['heading_color'] . ';
			}

			body,
			.secondary-navigation a {
				color: ' . $justshoppe_theme_mods['text_color'] . ';
			}

			.widget-area .widget a,
			.hentry .entry-header .posted-on a,
			.hentry .entry-header .post-author a,
			.hentry .entry-header .post-comments a,
			.hentry .entry-header .byline a {
				color: ' . justshoppe_adjust_color_brightness( $justshoppe_theme_mods['text_color'], 5 ) . ';
			}

			a  {
				color: ' . $justshoppe_theme_mods['accent_color'] . ';
			}

			a:focus,
			.button:focus,
			.button.alt:focus,
			button:focus,
			input[type="button"]:focus,
			input[type="reset"]:focus,
			input[type="submit"]:focus {
				outline-color: ' . $justshoppe_theme_mods['accent_color'] . ';
			}

			button, input[type="button"], input[type="reset"], input[type="submit"], .button, .widget a.button {
				background-color: ' . $justshoppe_theme_mods['button_background_color'] . ';
				border-color: ' . $justshoppe_theme_mods['button_background_color'] . ';
				color: ' . $justshoppe_theme_mods['button_text_color'] . ';
			}

			button:hover, input[type="button"]:hover, input[type="reset"]:hover, input[type="submit"]:hover, .button:hover, .widget a.button:hover {
				background-color: ' . justshoppe_adjust_color_brightness( $justshoppe_theme_mods['button_background_color'], $darken_factor ) . ';
				border-color: ' . justshoppe_adjust_color_brightness( $justshoppe_theme_mods['button_background_color'], $darken_factor ) . ';
				color: ' . $justshoppe_theme_mods['button_text_color'] . ';
			}

			button.alt, input[type="button"].alt, input[type="reset"].alt, input[type="submit"].alt, .button.alt, .widget-area .widget a.button.alt {
				background-color: ' . $justshoppe_theme_mods['button_alt_background_color'] . ';
				border-color: ' . $justshoppe_theme_mods['button_alt_background_color'] . ';
				color: ' . $justshoppe_theme_mods['button_alt_text_color'] . ';
			}

			button.alt:hover, input[type="button"].alt:hover, input[type="reset"].alt:hover, input[type="submit"].alt:hover, .button.alt:hover, .widget-area .widget a.button.alt:hover {
				background-color: ' . justshoppe_adjust_color_brightness( $justshoppe_theme_mods['button_alt_background_color'], $darken_factor ) . ';
				border-color: ' . justshoppe_adjust_color_brightness( $justshoppe_theme_mods['button_alt_background_color'], $darken_factor ) . ';
				color: ' . $justshoppe_theme_mods['button_alt_text_color'] . ';
			}

			.pagination .page-numbers li .page-numbers.current {
				background-color: ' . justshoppe_adjust_color_brightness( $justshoppe_theme_mods['background_color'], $darken_factor ) . ';
				color: ' . justshoppe_adjust_color_brightness( $justshoppe_theme_mods['text_color'], -10 ) . ';
			}

			#comments .comment-list .comment-content .comment-text {
				background-color: ' . justshoppe_adjust_color_brightness( $justshoppe_theme_mods['background_color'], -7 ) . ';
			}

			@media screen and ( min-width: 768px ) {
				.secondary-navigation ul.menu a:hover {
					color: ' . justshoppe_adjust_color_brightness( $justshoppe_theme_mods['header_text_color'], $brighten_factor ) . ';
				}

				.secondary-navigation ul.menu a {
					color: ' . $justshoppe_theme_mods['header_text_color'] . ';
				}

				.main-navigation ul.menu ul.sub-menu,
				.main-navigation ul.nav-menu ul.children {
					background-color: ' . justshoppe_adjust_color_brightness( $justshoppe_theme_mods['header_background_color'], -15 ) . ';
				}

				.site-header {
					border-bottom-color: ' . justshoppe_adjust_color_brightness( $justshoppe_theme_mods['header_background_color'], -15 ) . ';
				}
			}';

			return apply_filters( 'justshoppe_customizer_css', $styles );
		}

		/**
		 * Get Gutenberg Customizer css.
		 *
		 * @see get_justshoppe_theme_mods()
		 * @return array $styles the css
		 */
		public function gutenberg_get_css() {
			$justshoppe_theme_mods = $this->get_justshoppe_theme_mods();
			$darken_factor         = apply_filters( 'justshoppe_darken_factor', -25 );

			// Gutenberg.
			$styles = '
				.wp-block-button__link:not(.has-text-color) {
					color: ' . $justshoppe_theme_mods['button_text_color'] . ';
				}

				.wp-block-button__link:not(.has-text-color):hover,
				.wp-block-button__link:not(.has-text-color):focus,
				.wp-block-button__link:not(.has-text-color):active {
					color: ' . $justshoppe_theme_mods['button_text_color'] . ';
				}

				.wp-block-button__link:not(.has-background) {
					background-color: ' . $justshoppe_theme_mods['button_background_color'] . ';
				}

				.wp-block-button__link:not(.has-background):hover,
				.wp-block-button__link:not(.has-background):focus,
				.wp-block-button__link:not(.has-background):active {
					border-color: ' . justshoppe_adjust_color_brightness( $justshoppe_theme_mods['button_background_color'], $darken_factor ) . ';
					background-color: ' . justshoppe_adjust_color_brightness( $justshoppe_theme_mods['button_background_color'], $darken_factor ) . ';
				}

				.wp-block-quote footer,
				.wp-block-quote cite,
				.wp-block-quote__citation {
					color: ' . $justshoppe_theme_mods['text_color'] . ';
				}

				.wp-block-pullquote cite,
				.wp-block-pullquote footer,
				.wp-block-pullquote__citation {
					color: ' . $justshoppe_theme_mods['text_color'] . ';
				}

				.wp-block-image figcaption {
					color: ' . $justshoppe_theme_mods['text_color'] . ';
				}

				.wp-block-separator.is-style-dots::before {
					color: ' . $justshoppe_theme_mods['heading_color'] . ';
				}

				.wp-block-file a.wp-block-file__button {
					color: ' . $justshoppe_theme_mods['button_text_color'] . ';
					background-color: ' . $justshoppe_theme_mods['button_background_color'] . ';
					border-color: ' . $justshoppe_theme_mods['button_background_color'] . ';
				}

				.wp-block-file a.wp-block-file__button:hover,
				.wp-block-file a.wp-block-file__button:focus,
				.wp-block-file a.wp-block-file__button:active {
					color: ' . $justshoppe_theme_mods['button_text_color'] . ';
					background-color: ' . justshoppe_adjust_color_brightness( $justshoppe_theme_mods['button_background_color'], $darken_factor ) . ';
				}

				.wp-block-code,
				.wp-block-preformatted pre {
					color: ' . $justshoppe_theme_mods['text_color'] . ';
				}

				.wp-block-table:not( .is-style-stripes ) tbody tr:nth-child(2n) td {
					background-color: ' . justshoppe_adjust_color_brightness( $justshoppe_theme_mods['background_color'], -2 ) . ';
				}
			';

			return apply_filters( 'justshoppe_gutenberg_customizer_css', $styles );
		}

		/**
		 * Enqueue dynamic colors to use editor blocks.
		 *
		 * @since 2.4.0
		 */
		public function block_editor_customizer_css() {
			$justshoppe_theme_mods = $this->get_justshoppe_theme_mods();

			$styles = '
			.editor-styles-wrapper table th {
				background-color: ' . justshoppe_adjust_color_brightness( $justshoppe_theme_mods['background_color'], -7 ) . ';
			}

			.editor-styles-wrapper table tbody td {
				background-color: ' . justshoppe_adjust_color_brightness( $justshoppe_theme_mods['background_color'], -2 ) . ';
			}

			.editor-styles-wrapper table tbody tr:nth-child(2n) td,
			.editor-styles-wrapper fieldset,
			.editor-styles-wrapper fieldset legend {
				background-color: ' . justshoppe_adjust_color_brightness( $justshoppe_theme_mods['background_color'], -4 ) . ';
			}

			.editor-post-title__block .editor-post-title__input,
			.editor-styles-wrapper h1,
			.editor-styles-wrapper h2,
			.editor-styles-wrapper h3,
			.editor-styles-wrapper h4,
			.editor-styles-wrapper h5,
			.editor-styles-wrapper h6 {
				color: ' . $justshoppe_theme_mods['heading_color'] . ';
			}

			.editor-styles-wrapper .editor-block-list__block {
				color: ' . $justshoppe_theme_mods['text_color'] . ';
			}

			.editor-styles-wrapper a,
			.wp-block-freeform.block-library-rich-text__tinymce a {
				color: ' . $justshoppe_theme_mods['accent_color'] . ';
			}

			.editor-styles-wrapper a:focus,
			.wp-block-freeform.block-library-rich-text__tinymce a:focus {
				outline-color: ' . $justshoppe_theme_mods['accent_color'] . ';
			}

			body.post-type-post .editor-post-title__block::after {
				content: "";
			}';

			$styles .= $this->gutenberg_get_css();

			wp_add_inline_style( 'justshoppe-editor-block-styles', apply_filters( 'justshoppe_gutenberg_block_editor_customizer_css', $styles ) );
		}

		/**
		 * Add CSS in <head> for styles handled by the theme customizer
		 *
		 * @since 1.0.0
		 * @return void
		 */
		public function add_customizer_css() {
			wp_add_inline_style( 'justshoppe-style', $this->get_css() );
			//wp_add_inline_style( 'justshoppe-style', $this->add_blv_customizer_css() );
			wp_add_inline_style( 'justshoppe-gutenberg-blocks', $this->gutenberg_get_css() );
		}


		/**
		 * Get Customizer css.
		 *
		 * @see get_justshoppe_theme_mods()
		 * @return array $styles the css
		 */
		public function add_blv_customizer_css() {

			$accent_color = get_theme_mod( 'accent_color' );

			$styles = '

			.entry-title > a{ color: '. $accent_color .'; }
			';

			return apply_filters( 'justshoppe_custom_css', $styles );
		}
		/**
		 * Layout classes
		 * Adds 'right-sidebar' and 'left-sidebar' classes to the body tag
		 *
		 * @param  array $classes current body classes.
		 * @return string[]          modified body classes
		 * @since  1.0.0
		 */
		public function layout_class( $classes ) {
			$left_or_right = get_theme_mod( 'justshoppe_layout' );

			$classes[] = $left_or_right . '-sidebar';

			return $classes;
		}

		/**
		 * Add CSS for custom controls
		 *
		 * This function incorporates CSS from the Kirki Customizer Framework
		 *
		 * The Kirki Customizer Framework, Copyright Aristeides Stathopoulos (@aristath),
		 * is licensed under the terms of the GNU GPL, Version 2 (or later)
		 *
		 * @link https://github.com/reduxframework/kirki/
		 * @since  1.5.0
		 */
		public function customizer_custom_control_css() {
			?>
			<style>
				.customize-control-radio-image input[type=radio] {
					display: none;
				}

				.customize-control-radio-image label {
					display: block;
					width: 48%;
					float: left;
					margin-right: 4%;
				}

				.customize-control-radio-image label:nth-of-type(2n) {
					margin-right: 0;
				}

				.customize-control-radio-image img {
					opacity: .5;
				}

				.customize-control-radio-image input[type=radio]:checked + label img,
				.customize-control-radio-image img:hover {
					opacity: 1;
				}

			</style>
		<?php
		}

		/**
		 * Get site logo.
		 *
		 * @since 2.1.5
		 * @return string
		 */
		public function get_site_logo() {
			return justshoppe_site_title_or_logo( false );
		}

		/**
		 * Get site name.
		 *
		 * @since 2.1.5
		 * @return string
		 */
		public function get_site_name() {
			return get_bloginfo( 'name', 'display' );
		}

		/**
		 * Get site description.
		 *
		 * @since 2.1.5
		 * @return string
		 */
		public function get_site_description() {
			return get_bloginfo( 'description', 'display' );
		}

		/**
		 * Check if current page is using the Homepage template.
		 *
		 * @since 2.3.0
		 * @return bool
		 */
		public function is_homepage_template() {
			$template = get_post_meta( get_the_ID(), '_wp_page_template', true );

			if ( ! $template || 'template-homepage.php' !== $template || ! has_post_thumbnail( get_the_ID() ) ) {
				return false;
			}

			return true;
		}

		/**
		 * Setup the WordPress core custom header feature.
		 *
		 * @deprecated 2.4.0
		 * @return void
		 */
		public function custom_header_setup() {
			if ( function_exists( 'wc_deprecated_function' ) ) {
				wc_deprecated_function( __FUNCTION__, '2.4.0' );
			} else {
				_deprecated_function( __FUNCTION__, '2.4.0' );
			}
		}

		/**
		 * Get Customizer css associated with WooCommerce.
		 *
		 * @deprecated 2.4.0
		 * @return void
		 */
		public function get_woocommerce_css() {
			if ( function_exists( 'wc_deprecated_function' ) ) {
				wc_deprecated_function( __FUNCTION__, '2.3.1' );
			} else {
				_deprecated_function( __FUNCTION__, '2.3.1' );
			}
		}

		/**
		 * Assign Justshoppe styles to individual theme mods.
		 *
		 * @deprecated 2.3.1
		 * @return void
		 */
		public function set_justshoppe_style_theme_mods() {
			if ( function_exists( 'wc_deprecated_function' ) ) {
				wc_deprecated_function( __FUNCTION__, '2.3.1' );
			} else {
				_deprecated_function( __FUNCTION__, '2.3.1' );
			}
		}
	}

endif;

return new Justshoppe_Customizer();
