<?php
/**
 * Justshoppe WooCommerce hooks
 *
 * @package justshoppe
 */

/**
 * Sidebar
 *
 */
add_action( 'justshoppe_shop_sidebar', 'justshoppe_get_shop_sidebar', 10 );
add_action( 'justshoppe_product_sidebar', 'justshoppe_get_product_sidebar', 10 );

/**
 * Homepage
 *
 * @see  justshoppe_product_categories()
 * @see  justshoppe_recent_products()
 * @see  justshoppe_featured_products()
 * @see  justshoppe_popular_products()
 * @see  justshoppe_on_sale_products()
 * @see  justshoppe_best_selling_products()
 */
add_action( 'homepage', 'justshoppe_product_categories', 20 );
add_action( 'homepage', 'justshoppe_recent_products', 30 );
add_action( 'homepage', 'justshoppe_featured_products', 40 );
add_action( 'homepage', 'justshoppe_popular_products', 50 );
add_action( 'homepage', 'justshoppe_on_sale_products', 60 );
add_action( 'homepage', 'justshoppe_best_selling_products', 70 );

/**
 * Layout
 *
 * @see  justshoppe_before_content()
 * @see  justshoppe_after_content()
 * @see  woocommerce_breadcrumb()
 * @see  justshoppe_shop_messages()
 */
remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20 );
remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10 );
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10 );
remove_action( 'woocommerce_sidebar', 'woocommerce_get_sidebar', 10 );
remove_action( 'woocommerce_after_shop_loop', 'woocommerce_pagination', 10 );
add_action( 'woocommerce_before_main_content', 'justshoppe_before_content', 10 );
add_action( 'woocommerce_after_main_content', 'justshoppe_after_content', 10 );
add_action( 'justshoppe_content_top', 'justshoppe_shop_messages', 15 );

add_action( 'woocommerce_after_shop_loop', 'justshoppe_sorting_wrapper', 9 );
add_action( 'woocommerce_after_shop_loop', 'woocommerce_pagination', 30 );
add_action( 'woocommerce_after_shop_loop', 'justshoppe_sorting_wrapper_close', 31 );

add_action( 'woocommerce_before_shop_loop', 'justshoppe_sorting_wrapper', 9 );
add_action( 'woocommerce_before_shop_loop', 'justshoppe_woocommerce_pagination', 30 );
add_action( 'woocommerce_before_shop_loop', 'justshoppe_sorting_wrapper_close', 31 );

add_action( 'justshoppe_footer', 'justshoppe_handheld_footer_bar', 999 );

// Legacy WooCommerce columns filter.
if ( defined( 'WC_VERSION' ) && version_compare( WC_VERSION, '3.3', '<' ) ) {
	add_filter( 'loop_shop_columns', 'justshoppe_loop_columns' );
	add_action( 'woocommerce_before_shop_loop', 'justshoppe_product_columns_wrapper', 40 );
	add_action( 'woocommerce_after_shop_loop', 'justshoppe_product_columns_wrapper_close', 40 );
}

/**
 * Products
 *
 * @see justshoppe_upsell_display()
 */
remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15 );
add_action( 'woocommerce_after_single_product_summary', 'justshoppe_upsell_display', 15 );


add_action( 'woocommerce_after_single_product_summary', 'justshoppe_single_product_pagination', 30 );
add_action( 'justshoppe_after_footer', 'justshoppe_sticky_single_add_to_cart', 999 );

/**
 * Header
 *
 * @see justshoppe_product_search()
 * @see justshoppe_header_cart()
 */

/**
 * Cart fragment
 *
 * @see justshoppe_cart_link_fragment()
 */
if ( defined( 'WC_VERSION' ) && version_compare( WC_VERSION, '2.3', '>=' ) ) {
	add_filter( 'woocommerce_add_to_cart_fragments', 'justshoppe_cart_link_fragment' );
} else {
	add_filter( 'add_to_cart_fragments', 'justshoppe_cart_link_fragment' );
}

/**
 * Integrations
 *
 * @see justshoppe_woocommerce_brands_archive()
 * @see justshoppe_woocommerce_brands_single()
 * @see justshoppe_woocommerce_brands_homepage_section()
 */
if ( class_exists( 'WC_Brands' ) ) {
	add_action( 'woocommerce_archive_description', 'justshoppe_woocommerce_brands_archive', 5 );
	add_action( 'woocommerce_single_product_summary', 'justshoppe_woocommerce_brands_single', 4 );
	add_action( 'homepage', 'justshoppe_woocommerce_brands_homepage_section', 80 );
}
