<?php
/**
 * Customizer settings: WooCommerce > Other Elements
 *
 * @package Justshoppe
 **/

// Prevent direct access.
if ( ! defined( 'ABSPATH' ) ) exit;

$section = 'justshoppe_section_woocommerce_elements';

/**
 * ====================================================
 * Breadcrumb
 * ====================================================
 */

// Heading: Breadcrumb
$wp_customize->add_control( new Justshoppe_Customize_Control_Heading( $wp_customize, 'heading_woocommerce_elements_breadcrumb', array(
	'section'     => $section,
	'settings'    => array(),
	'label'       => esc_html__( 'Breadcrumb', 'justshoppe' ),
	'priority'    => 10,
) ) );

// Cross-sells
$key = 'woocommerce_breadcrumb_use_theme_module';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'toggle' ),
) );
$wp_customize->add_control( new Justshoppe_Customize_Control_Toggle( $wp_customize, $key, array(
	'section'     => $section,
	'label'       => esc_html__( 'Integrate with theme\'s breadcrumb module', 'justshoppe' ),
    'description' => esc_html__( 'When enabled, the theme\'s breadcrumb module will replace the WooCommerce\'s original breadcrumb.', 'justshoppe' ),
	'priority'    => 10,
) ) );

/**
 * ====================================================
 * Sale Badge
 * ====================================================
 */

// Heading: Sale badge
$wp_customize->add_control( new Justshoppe_Customize_Control_Heading( $wp_customize, 'heading_woocommerce_elements_sale_badge', array(
	'section'     => $section,
	'settings'    => array(),
	'label'       => esc_html__( 'Sale badge', 'justshoppe' ),
	'priority'    => 20,
) ) );

// Colors
$colors = array(
	'woocommerce_sale_badge_bg_color'   => esc_html__( 'Badge background color', 'justshoppe' ),
	'woocommerce_sale_badge_text_color' => esc_html__( 'Badge text color', 'justshoppe' ),
);
foreach ( $colors as $key => $label ) {
	$wp_customize->add_setting( $key, array(
		'default'     => justshoppe_array_value( $defaults, $key ),
		'transport'   => 'postMessage',
		'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'color' ),
	) );
	$wp_customize->add_control( new Justshoppe_Customize_Control_Color( $wp_customize, $key, array(
		'section'     => $section,
		'label'       => $label,
		'priority'    => 20,
	) ) );
}

/**
 * ====================================================
 * Review Star
 * ====================================================
 */

// Heading: Review star
$wp_customize->add_control( new Justshoppe_Customize_Control_Heading( $wp_customize, 'heading_woocommerce_elements_star', array(
	'section'     => $section,
	'settings'    => array(),
	'label'       => esc_html__( 'Review star', 'justshoppe' ),
	'priority'    => 30,
) ) );

// Review star color
$key = 'woocommerce_review_star_color';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'transport'   => 'postMessage',
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'color' ),
) );
$wp_customize->add_control( new Justshoppe_Customize_Control_Color( $wp_customize, $key, array(
	'section'     => $section,
	'label'       => esc_html__( 'Rating (&#9733;) color', 'justshoppe' ),
	'priority'    => 30,
) ) );

/**
 * ====================================================
 * Alt Button
 * ====================================================
 */

// Heading: Alt Button
$wp_customize->add_control( new Justshoppe_Customize_Control_Heading( $wp_customize, 'heading_woocommerce_elements_alt_button', array(
	'section'     => $section,
	'settings'    => array(),
	'label'       => esc_html__( 'Alt Button', 'justshoppe' ),
	'description' => esc_html__( 'Used for single product\'s "Add to Cart" button and Checkout button.', 'justshoppe' ),
	'priority'    => 40,
) ) );

// Colors
$colors = array(
	'woocommerce_alt_button_bg_color'           => esc_html__( 'Background color', 'justshoppe' ),
	'woocommerce_alt_button_border_color'       => esc_html__( 'Border color', 'justshoppe' ),
	'woocommerce_alt_button_text_color'         => esc_html__( 'Text color', 'justshoppe' ),
	'woocommerce_alt_button_hover_bg_color'     => esc_html__( 'Background color :hover', 'justshoppe' ),
	'woocommerce_alt_button_hover_border_color' => esc_html__( 'Border color :hover', 'justshoppe' ),
	'woocommerce_alt_button_hover_text_color'   => esc_html__( 'Text color :hover', 'justshoppe' ),
);
foreach ( $colors as $key => $label ) {
	$wp_customize->add_setting( $key, array(
		'default'     => justshoppe_array_value( $defaults, $key ),
		'transport'   => 'postMessage',
		'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'color' ),
	) );
	$wp_customize->add_control( new Justshoppe_Customize_Control_Color( $wp_customize, $key, array(
		'section'     => $section,
		'label'       => $label,
		'priority'    => 40,
	) ) );
}