<?php
/**
 * Customizer settings: WooCommerce > Single Product
 *
 * @package Justshoppe
 **/

// Prevent direct access.
if ( ! defined( 'ABSPATH' ) ) exit;

$section = 'woocommerce_product_single'; // Assumed

/**
 * ====================================================
 * Content Header
 * ====================================================
 */

// Heading: Content Header
$wp_customize->add_control( new Justshoppe_Customize_Control_Heading( $wp_customize, 'heading_product_single_content_header', array(
	'section'     => $section,
	'settings'    => array(),
	'label'       => esc_html__( 'Content Header', 'justshoppe' ),
	'priority'    => 10,
) ) );

// Elements
$key = 'product_single_content_header';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'multiselect' ),
) );
$wp_customize->add_control( new Justshoppe_Customize_Control_Sortable( $wp_customize, $key, array(
	'section'     => $section,
	// 'label'       => esc_html__( 'Elements', 'justshoppe' ),
	'choices'     => apply_filters( 'justshoppe/dataset/product_single_content_header_elements', array(
		'title'          => esc_html__( 'Title', 'justshoppe' ),
		'breadcrumb'     => esc_html__( 'Breadcrumb', 'justshoppe' ),
		'product-rating' => esc_html__( 'Rating', 'justshoppe' ),
	) ),
	'priority'    => 10,
) ) );

// Alignment
$key = 'product_single_content_header_alignment';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'transport'   => 'postMessage',
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'select' ),
) );
$wp_customize->add_control( new Justshoppe_Customize_Control_RadioImage( $wp_customize, $key, array(
	'section'     => $section,
	// 'label'       => esc_html__( 'Alignment', 'justshoppe' ),
	'choices'     => array(
		'left'   => array(
			'label' => '<span class="dashicons dashicons-editor-align' . ( is_rtl() ? 'right' : 'left' ) . '"></span>',
		),
		'center' => array(
			'label' => '<span class="dashicons dashicons-editor-aligncenter"></span>',
		),
		'right'  => array(
			'label' => '<span class="dashicons dashicons-editor-align' . ( is_rtl() ? 'left' : 'right' ) . '"></span>',
		),
	),
	'priority'    => 10,
) ) );

/**
 * ====================================================
 * Images
 * ====================================================
 */

// Heading: Gallery
$wp_customize->add_control( new Justshoppe_Customize_Control_Heading( $wp_customize, 'heading_woocommerce_single_gallery', array(
	'section'     => $section,
	'settings'    => array(),
	'label'       => esc_html__( 'Gallery', 'justshoppe' ),
	'priority'    => 20,
) ) );

// Show gallery
$key = 'woocommerce_single_gallery';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'toggle' ),
) );
$wp_customize->add_control( new Justshoppe_Customize_Control_Toggle( $wp_customize, $key, array(
	'section'     => $section,
	'label'       => esc_html__( 'Show gallery', 'justshoppe' ),
	'priority'    => 20,
) ) );

// Gallery column width
$key = 'woocommerce_single_gallery_width';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	// 'transport'   => 'postMessage',
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'dimension' ),
) );
$wp_customize->add_control( new Justshoppe_Customize_Control_Slider( $wp_customize, $key, array(
	'section'     => $section,
	'label'       => esc_html__( 'Gallery column Width', 'justshoppe' ),
	'units'       => array(
		'%' => array(
			'min'  => 25,
			'max'  => 75,
			'step' => 0.01,
		),
	),
	'priority'    => 20,
) ) );

// Gallery column gap
$key = 'woocommerce_single_gallery_gap';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'transport'   => 'postMessage',
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'dimension' ),
) );
$wp_customize->add_control( new Justshoppe_Customize_Control_Slider( $wp_customize, $key, array(
	'section'     => $section,
	'label'       => esc_html__( 'Gap with summary column', 'justshoppe' ),
	'units'       => array(
		'%' => array(
			'min'  => 0,
			'max'  => 10,
			'step' => 0.01,
		),
		'px' => array(
			'min'  => 0,
			'max'  => 100,
			'step' => 1,
		),
	),
	'priority'    => 20,
) ) );

// Enable zoom
$key = 'woocommerce_single_gallery_zoom';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'toggle' ),
) );
$wp_customize->add_control( new Justshoppe_Customize_Control_Toggle( $wp_customize, $key, array(
	'section'     => $section,
	'label'       => esc_html__( 'Enable zoom', 'justshoppe' ),
	'priority'    => 20,
) ) );

// Enable lightbox
$key = 'woocommerce_single_gallery_lightbox';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'toggle' ),
) );
$wp_customize->add_control( new Justshoppe_Customize_Control_Toggle( $wp_customize, $key, array(
	'section'     => $section,
	'label'       => esc_html__( 'Enable lightbox', 'justshoppe' ),
	'priority'    => 20,
) ) );

/**
 * ====================================================
 * Tabs
 * ====================================================
 */

// Heading: Tabs
$wp_customize->add_control( new Justshoppe_Customize_Control_Heading( $wp_customize, 'heading_woocommerce_single_tabs', array(
	'section'     => $section,
	'settings'    => array(),
	'label'       => esc_html__( 'Tabs', 'justshoppe' ),
	'priority'    => 40,
) ) );

// Show tabs
$key = 'woocommerce_single_tabs';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'toggle' ),
) );
$wp_customize->add_control( new Justshoppe_Customize_Control_Toggle( $wp_customize, $key, array(
	'section'     => $section,
	'label'       => esc_html__( 'Show tabs', 'justshoppe' ),
	'priority'    => 40,
) ) );


/**
 * ====================================================
 * Up-Sells
 * ====================================================
 */

// Heading: Up-Sells
$wp_customize->add_control( new Justshoppe_Customize_Control_Heading( $wp_customize, 'heading_woocommerce_single_up_sells', array(
	'section'     => $section,
	'settings'    => array(),
	'label'       => esc_html__( 'Up-Sells', 'justshoppe' ),
	'priority'    => 50,
) ) );

// Show up-sells
$key = 'woocommerce_single_up_sells';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'toggle' ),
) );
$wp_customize->add_control( new Justshoppe_Customize_Control_Toggle( $wp_customize, $key, array(
	'section'     => $section,
	'label'       => esc_html__( 'Show up-sells', 'justshoppe' ),
	'description' => esc_html__( 'Display up-sells as configured on Edit Product page > Product Data > Linked Products > Up-sells.', 'justshoppe' ),
	'priority'    => 50,
) ) );

// Up-sells columns
$key = 'woocommerce_single_up_sells_grid_columns';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'dimension' ),
) );
$wp_customize->add_control( new Justshoppe_Customize_Control_Slider( $wp_customize, $key, array(
	'section'     => $section,
	'label'       => esc_html__( 'Columns', 'justshoppe' ),
	'units'       => array(
		'' => array(
			'min'  => 1,
			'max'  => 6,
			'step' => 1,
			'label' => 'col',
		),
	),
	'priority'    => 50,
) ) );

/**
 * ====================================================
 * Related
 * ====================================================
 */

// Heading: Related Products
$wp_customize->add_control( new Justshoppe_Customize_Control_Heading( $wp_customize, 'heading_woocommerce_single_related', array(
	'section'     => $section,
	'settings'    => array(),
	'label'       => esc_html__( 'Related Products', 'justshoppe' ),
	'priority'    => 60,
) ) );

// Show related products
$key = 'woocommerce_single_related';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'toggle' ),
) );
$wp_customize->add_control( new Justshoppe_Customize_Control_Toggle( $wp_customize, $key, array(
	'section'     => $section,
	'label'       => esc_html__( 'Show related products', 'justshoppe' ),
	'description' => esc_html__( 'Display linked products and similar products within same categories or tags. Products that have been displayed on "Up-sells" section will not be included.', 'justshoppe' ),
	'priority'    => 60,
) ) );

// Related products posts per page
$key = 'woocommerce_single_related_posts_per_page';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'number' ),
) );
$wp_customize->add_control( $key, array(
	'type'        => 'number',
	'section'     => $section,
	'label'       => esc_html__( 'Max products shown', 'justshoppe' ),
	'description' => esc_html__( '0 = disabled; -1 = show all.', 'justshoppe' ),
	'input_attrs' => array(
		'min'  => -1,
		'max'  => 12,
		'step' => 1,
	),
	'priority'    => 60,
) );

// Related products columns
$key = 'woocommerce_single_related_grid_columns';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'dimension' ),
) );
$wp_customize->add_control( new Justshoppe_Customize_Control_Slider( $wp_customize, $key, array(
	'section'     => $section,
	'label'       => esc_html__( 'Columns', 'justshoppe' ),
	'units'       => array(
		'' => array(
			'min'  => 1,
			'max'  => 6,
			'step' => 1,
			'label' => 'col',
		),
	),
	'priority'    => 60,
) ) );

/**
 * ====================================================
 * Justshoppe Pro Upsell
 * ====================================================
 */

if ( justshoppe_show_pro_teaser() ) {
	$wp_customize->add_control( new Justshoppe_Customize_Control_Pro_Teaser( $wp_customize, 'pro_teaser_woocommerce_single', array(
		'section'     => $section,
		'settings'    => array(),
		'label'       => esc_html_x( 'More Options Available', 'Justshoppe Pro upsell', 'justshoppe' ),
		'url'         => esc_url( add_query_arg( array( 'utm_source' => 'justshoppe-customizer', 'utm_medium' => 'learn-more', 'utm_campaign' => 'theme-upsell' ), JUSTSHOPPE_PRO_WEBSITE_URL ) ),
		'features'    => array(
			esc_html_x( 'AJAX Add To Cart', 'Justshoppe Pro upsell', 'justshoppe' ),
			esc_html_x( 'More Gallery Layouts', 'Justshoppe Pro upsell', 'justshoppe' ),
		),
		'priority'    => 190,
	) ) );
}