<?php
/**
 * Customizer settings: Blog > Post Layout: Grid
 *
 * @package Justshoppe
 **/

// Prevent direct access.
if ( ! defined( 'ABSPATH' ) ) exit;

$section = 'justshoppe_section_entry_grid';

/**
 * ====================================================
 * Layout
 * ====================================================
 */

// Grid columns
$key = 'blog_index_grid_columns';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'transport'   => 'postMessage',
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'dimension' ),
) );
$wp_customize->add_control( new Justshoppe_Customize_Control_Slider( $wp_customize, $key, array(
	'section'     => $section,
	'label'       => esc_html__( 'Columns', 'justshoppe' ),
	'units'       => array(
		'' => array(
			'min'  => 2,
			'max'  => 4,
			'step' => 1,
			'label' => 'col',
		),
	),
	'priority'    => 10,
) ) );

// Rows gutter
$key = 'blog_index_grid_rows_gutter';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'transport'   => 'postMessage',
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'dimension' ),
) );
$wp_customize->add_control( new Justshoppe_Customize_Control_Slider( $wp_customize, $key, array(
	'section'     => $section,
	'label'       => esc_html__( 'Rows gutter', 'justshoppe' ),
	'units'       => array(
		'px' => array(
			'min'  => 0,
			'max'  => 40,
			'step' => 1,
		),
		'em' => array(
			'min'  => 0,
			'max'  => 3,
			'step' => 0.01,
		),
	),
	'priority'    => 10,
) ) );

// Columns gutter
$key = 'blog_index_grid_columns_gutter';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'transport'   => 'postMessage',
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'dimension' ),
) );
$wp_customize->add_control( new Justshoppe_Customize_Control_Slider( $wp_customize, $key, array(
	'section'     => $section,
	'label'       => esc_html__( 'Columns gutter', 'justshoppe' ),
	'units'       => array(
		'px' => array(
			'min'  => 0,
			'max'  => 40,
			'step' => 1,
		),
		'em' => array(
			'min'  => 0,
			'max'  => 3,
			'step' => 0.01,
		),
	),
	'priority'    => 10,
) ) );

/**
 * ====================================================
 * Entry Wrapper
 * ====================================================
 */

// Heading: Entry Wrapper
$wp_customize->add_control( new Justshoppe_Customize_Control_Heading( $wp_customize, 'heading_entry_grid_item', array(
	'section'     => $section,
	'settings'    => array(),
	'label'       => esc_html__( 'Entry Wrapper', 'justshoppe' ),
	'priority'    => 20,
) ) );

// Padding
$key = 'entry_grid_padding';
$settings = array(
	$key,
	$key . '__tablet',
	$key . '__mobile',
);
foreach ( $settings as $setting ) {
	$wp_customize->add_setting( $setting, array(
		'default'     => justshoppe_array_value( $defaults, $setting ),
		'transport'   => 'postMessage',
		'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'dimensions' ),
	) );
}
$wp_customize->add_control( new Justshoppe_Customize_Control_Dimensions( $wp_customize, $key, array(
	'settings'    => $settings,
	'section'     => $section,
	'label'       => esc_html__( 'Padding', 'justshoppe' ),
	'units'       => array(
		'px' => array(
			'min'  => 0,
			'step' => 1,
		),
		'em' => array(
			'min'  => 0,
			'step' => 0.01,
		),
	),
	'priority'    => 20,
) ) );

// Border
$key = 'entry_grid_border';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'transport'   => 'postMessage',
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'dimensions' ),
) );
$wp_customize->add_control( new Justshoppe_Customize_Control_Dimensions( $wp_customize, $key, array(
	'section'     => $section,
	'label'       => esc_html__( 'Border', 'justshoppe' ),
	'units'       => array(
		'px' => array(
			'min'  => 0,
			'step' => 1,
		),
	),
	'priority'    => 20,
) ) );

// Border radius
$key = 'entry_grid_border_radius';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'transport'   => 'postMessage',
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'dimension' ),
) );
$wp_customize->add_control( new Justshoppe_Customize_Control_Slider( $wp_customize, $key, array(
	'section'     => $section,
	'label'       => esc_html__( 'Border radius', 'justshoppe' ),
	'units'       => array(
		'px' => array(
			'min'  => 0,
			'max'  => 40,
			'step' => 1,
		),
	),
	'priority'    => 20,
) ) );

// Make items in a row to be in same height
$key = 'entry_grid_same_height';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'toggle' ),
) );
$wp_customize->add_control( new Justshoppe_Customize_Control_Toggle( $wp_customize, $key, array(
	'section'     => $section,
	'label'       => esc_html__( 'Same height items in a row', 'justshoppe' ),
	'priority'    => 20,
) ) );

/**
 * ====================================================
 * Entry Header
 * ====================================================
 */

// Heading: Entry Header
$wp_customize->add_control( new Justshoppe_Customize_Control_Heading( $wp_customize, 'heading_entry_grid_header', array(
	'section'     => $section,
	'settings'    => array(),
	'label'       => esc_html__( 'Entry Header', 'justshoppe' ),
	'priority'    => 30,
) ) );

// Elements
$key = 'entry_grid_header';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'multiselect' ),
) );
$wp_customize->add_control( new Justshoppe_Customize_Control_Sortable( $wp_customize, $key, array(
	'section'     => $section,
	// 'label'       => esc_html__( 'Elements', 'justshoppe' ),
	'choices'     => apply_filters( 'justshoppe/dataset/entry_grid_header_elements', array(
		'header-meta' => esc_html__( 'Header Meta', 'justshoppe' ),
		'title'       => esc_html__( 'Title', 'justshoppe' ),
	) ),
	'priority'    => 30,
) ) );

// Alignment
$key = 'entry_grid_header_alignment';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'transport'   => 'postMessage',
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'select' ),
) );
$wp_customize->add_control( new Justshoppe_Customize_Control_RadioImage( $wp_customize, $key, array(
	'section'     => $section,
	// 'label'       => esc_html__( 'Alignment', 'justshoppe' ),
	'choices'     => array(
		'left'   => array(
			'label' => '<span class="dashicons dashicons-editor-align' . ( is_rtl() ? 'right' : 'left' ) . '"></span>',
		),
		'center' => array(
			'label' => '<span class="dashicons dashicons-editor-aligncenter"></span>',
		),
		'right'  => array(
			'label' => '<span class="dashicons dashicons-editor-align' . ( is_rtl() ? 'left' : 'right' ) . '"></span>',
		),
	),
	'priority'    => 30,
) ) );

// Header meta text
$key = 'entry_grid_header_meta';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'text' ),
) );
$wp_customize->add_control( $key, array(
	'section'     => $section,
	'label'       => esc_html__( 'Header meta text', 'justshoppe' ),
	'description' => esc_html__( 'Available tags: {{date}}, {{categories}}, {{tags}}, {{author}}, {{avatar}}, {{comments}}.', 'justshoppe' ),
	'priority'    => 30,
) );

/**
 * ====================================================
 * Entry Thumbnail
 * ====================================================
 */

// Heading: Entry Thumbnail
$wp_customize->add_control( new Justshoppe_Customize_Control_Heading( $wp_customize, 'heading_entry_grid_thumbnail', array(
	'section'     => $section,
	'settings'    => array(),
	'label'       => esc_html__( 'Entry Thumbnail', 'justshoppe' ),
	'priority'    => 40,
) ) );

// Display
$key = 'entry_grid_thumbnail_position';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'select' ),
) );
$wp_customize->add_control( $key, array(
	'type'        => 'select',
	'section'     => $section,
	'label'       => esc_html__( 'Display', 'justshoppe' ),
	'choices'     => array(
		''       => esc_html__( 'Disabled', 'justshoppe' ),
		'before' => esc_html__( 'Before Content Header', 'justshoppe' ),
		'after'  => esc_html__( 'After Content Header', 'justshoppe' ),
	),
	'priority'    => 40,
) );

// Image size
$key = 'entry_grid_thumbnail_size';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'select' ),
) );
$wp_customize->add_control( $key, array(
	'type'        => 'select',
	'section'     => $section,
	'label'       => esc_html__( 'Image size', 'justshoppe' ),
	'choices'     => justshoppe_get_all_image_sizes(),
	'priority'    => 40,
) );

// Ignore padding
$key = 'entry_grid_thumbnail_ignore_padding';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'toggle' ),
) );
$wp_customize->add_control( new Justshoppe_Customize_Control_Toggle( $wp_customize, $key, array(
	'section'     => $section,
	'label'       => esc_html__( 'Ignore padding', 'justshoppe' ),
	'priority'    => 40,
) ) );

/**
 * ====================================================
 * Entry Content
 * ====================================================
 */

// Heading: Entry Content
$wp_customize->add_control( new Justshoppe_Customize_Control_Heading( $wp_customize, 'heading_entry_grid_content', array(
	'section'     => $section,
	'settings'    => array(),
	'label'       => esc_html__( 'Entry Content', 'justshoppe' ),
	'priority'    => 50,
) ) );

// Entry grid excerpt length
$key = 'entry_grid_excerpt_length';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'dimension' ),
) );
$wp_customize->add_control( new Justshoppe_Customize_Control_Slider( $wp_customize, $key, array(
	'section'     => $section,
	'label'       => esc_html__( 'Excerpt words limit', 'justshoppe' ),
	'description' => esc_html__( 'Fill with 0 to disable excerpt.', 'justshoppe' ),
	'units'       => array(
		'' => array(
			'min'  => 0,
			'max'  => 200,
			'step' => 1,
			'label' => 'wrd',
		),
	),
	'priority'    => 50,
) ) );

// Read more
$key = 'entry_grid_read_more_display';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'select' ),
) );
$wp_customize->add_control( $key, array(
	'type'        => 'select',
	'section'     => $section,
	'label'       => esc_html__( 'Read more', 'justshoppe' ),
	'choices'     => array(
		''       => esc_html__( 'None', 'justshoppe' ),
		'text'   => esc_html__( 'Text', 'justshoppe' ),
		'button' => esc_html__( 'Button', 'justshoppe' ),
	),
	'priority'    => 50,
) );

// Read more text
$key = 'entry_grid_read_more_text';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'text' ),
) );
$wp_customize->add_control( $key, array(
	'section'     => $section,
	'label'       => esc_html__( 'Read more text', 'justshoppe' ),
	'input_attrs' => array(
		'placeholder' => esc_html__( 'Read more', 'justshoppe' ),
	),
	'priority'    => 50,
) );

/**
 * ====================================================
 * Entry Footer
 * ====================================================
 */

// Heading: Entry Footer
$wp_customize->add_control( new Justshoppe_Customize_Control_Heading( $wp_customize, 'heading_entry_grid_meta', array(
	'section'     => $section,
	'settings'    => array(),
	'label'       => esc_html__( 'Entry Footer', 'justshoppe' ),
	'priority'    => 60,
) ) );

// Elements
$key = 'entry_grid_footer';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'multiselect' ),
) );
$wp_customize->add_control( new Justshoppe_Customize_Control_Sortable( $wp_customize, $key, array(
	'section'     => $section,
	// 'label'       => esc_html__( 'Elements', 'justshoppe' ),
	'choices'     => apply_filters( 'justshoppe/dataset/entry_grid_footer_elements', array(
		'footer-meta' => esc_html__( 'Footer Meta', 'justshoppe' ),
	) ),
	'priority'    => 60,
) ) );

// Alignment
$key = 'entry_grid_footer_alignment';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'transport'   => 'postMessage',
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'select' ),
) );
$wp_customize->add_control( new Justshoppe_Customize_Control_RadioImage( $wp_customize, $key, array(
	'section'     => $section,
	// 'label'       => esc_html__( 'Alignment', 'justshoppe' ),
	'choices'     => array(
		'left'   => array(
			'label' => '<span class="dashicons dashicons-editor-align' . ( is_rtl() ? 'right' : 'left' ) . '"></span>',
		),
		'center' => array(
			'label' => '<span class="dashicons dashicons-editor-aligncenter"></span>',
		),
		'right'  => array(
			'label' => '<span class="dashicons dashicons-editor-align' . ( is_rtl() ? 'left' : 'right' ) . '"></span>',
		),
	),
	'priority'    => 60,
) ) );

// Footer meta text
$key = 'entry_grid_footer_meta';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'text' ),
) );
$wp_customize->add_control( $key, array(
	'section'     => $section,
	'label'       => esc_html__( 'Footer meta text', 'justshoppe' ),
	'description' => esc_html__( 'Available tags: {{date}}, {{categories}}, {{tags}}, {{author}}, {{avatar}}, {{comments}}', 'justshoppe' ),
	'priority'    => 60,
) );

/**
 * ====================================================
 * Colors
 * ====================================================
 */

// Heading: Colors
$wp_customize->add_control( new Justshoppe_Customize_Control_Heading( $wp_customize, 'heading_entry_grid_colors', array(
	'section'     => $section,
	'settings'    => array(),
	'label'       => esc_html__( 'Colors', 'justshoppe' ),
	'priority'    => 80,
) ) );

// Colors
$colors = array(
	'entry_grid_bg_color'     => esc_html__( 'Background color', 'justshoppe' ),
	'entry_grid_border_color' => esc_html__( 'Border color', 'justshoppe' ),
);
foreach ( $colors as $key => $label ) {
	$wp_customize->add_setting( $key, array(
		'default'     => justshoppe_array_value( $defaults, $key ),
		'transport'   => 'postMessage',
		'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'color' ),
	) );
	$wp_customize->add_control( new Justshoppe_Customize_Control_Color( $wp_customize, $key, array(
		'section'     => $section,
		'label'       => $label,
		'priority'    => 80,
	) ) );
}

// Shadow
$key = 'entry_grid_shadow';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'transport'   => 'postMessage',
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'shadow' ),
) );
$wp_customize->add_control( new Justshoppe_Customize_Control_Shadow( $wp_customize, $key, array(
	'section'     => $section,
	'label'       => esc_html__( 'Shadow', 'justshoppe' ),
	'exclude'     => array( 'position' ),
	'priority'    => 80,
) ) );