<?php
/**
 * Customizer settings: Hero Section
 *
 * @package Justshoppe
 **/

// Prevent direct access.
if ( ! defined( 'ABSPATH' ) ) exit;

$section = 'justshoppe_section_hero';

/**
 * ====================================================
 * Enable / Disable
 * ====================================================
 */

// Enable hero section
$key = 'hero';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'toggle' ),
) );
$wp_customize->add_control( new Justshoppe_Customize_Control_Toggle( $wp_customize, $key, array(
	'section'     => $section,
	'label'       => esc_html__( 'Enable hero section', 'justshoppe' ) . ' <span class="justshoppe-global-default-badge justshoppe-tooltip" tabindex="0" data-tooltip="' . esc_attr__( 'You can override this option on each individual page.', 'justshoppe' ) . '"><span class="dashicons dashicons-admin-site-alt3"></span> ' . esc_html__( 'Global', 'justshoppe' ) . '</span>',
	'priority'    => 10,
) ) );

/**
 * ====================================================
 * Layout
 * ====================================================
 */

// Heading: Layout
$wp_customize->add_control( new Justshoppe_Customize_Control_Heading( $wp_customize, 'heading_hero_layout', array(
	'section'     => $section,
	'settings'    => array(),
	'label'       => esc_html__( 'Layout', 'justshoppe' ),
	'priority'    => 20,
) ) );

// Container width
$key = 'hero_container';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'transport'   => 'postMessage',
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'select' ),
) );
$wp_customize->add_control( new Justshoppe_Customize_Control_RadioImage( $wp_customize, $key, array(
	'section'     => $section,
	'label'       => esc_html__( 'Container width', 'justshoppe' ) . ' <span class="justshoppe-global-default-badge justshoppe-tooltip" tabindex="0" data-tooltip="' . esc_attr__( 'You can override this option on each individual page.', 'justshoppe' ) . '"><span class="dashicons dashicons-admin-site-alt3"></span> ' . esc_html__( 'Global', 'justshoppe' ) . '</span>',
	'choices'     => array(
		'default'    => array(
			'label' => esc_html__( 'Normal', 'justshoppe' ),
			'image' => JUSTSHOPPE_IMAGES_URL . '/customizer/hero-container--default.svg',
		),
		'full-width' => array(
			'label' => esc_html__( 'Full width', 'justshoppe' ),
			'image' => JUSTSHOPPE_IMAGES_URL . '/customizer/hero-container--full-width.svg',
		),
		'narrow'     => array(
			'label' => esc_html__( 'Narrow', 'justshoppe' ),
			'image' => JUSTSHOPPE_IMAGES_URL . '/customizer/hero-container--narrow.svg',
		),
	),
	'priority'    => 20,
) ) );

// Minimal height
$key = 'hero_height';
$settings = array(
	$key,
	$key . '__tablet',
	$key . '__mobile',
);
foreach ( $settings as $setting ) {
	$wp_customize->add_setting( $setting, array(
		'default'     => justshoppe_array_value( $defaults, $setting ),
		'transport'   => 'postMessage',
		'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'dimension' ),
	) );
}
$wp_customize->add_control( new Justshoppe_Customize_Control_Slider( $wp_customize, $key, array(
	'settings'    => $settings,
	'section'     => $section,
	'label'       => esc_html__( 'Minimal height', 'justshoppe' ),
	'units'       => array(
		'px' => array(
			'min'  => 0,
			'max'  => 1000,
			'step' => 1,
		),
		'vh' => array(
			'min'  => 0,
			'max'  => 100,
			'step' => 0.01,
		),
	),
	'priority'    => 20,
) ) );

// Padding
$key = 'hero_padding';
$settings = array(
	$key,
	$key . '__tablet',
	$key . '__mobile',
);
foreach ( $settings as $setting ) {
	$wp_customize->add_setting( $setting, array(
		'default'     => justshoppe_array_value( $defaults, $setting ),
		'transport'   => 'postMessage',
		'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'dimensions' ),
	) );
}
$wp_customize->add_control( new Justshoppe_Customize_Control_Dimensions( $wp_customize, $key, array(
	'settings'    => $settings,
	'section'     => $section,
	'label'       => esc_html__( 'Padding', 'justshoppe' ),
	'units'       => array(
		'px' => array(
			'min'  => 0,
			'step' => 1,
		),
		'em' => array(
			'min'  => 0,
			'step' => 0.01,
		),
		'%' => array(
			'min'  => 0,
			'step' => 0.01,
		),
	),
	'priority'    => 20,
) ) );

// Border
$key = 'hero_border';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'transport'   => 'postMessage',
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'dimensions' ),
) );
$wp_customize->add_control( new Justshoppe_Customize_Control_Dimensions( $wp_customize, $key, array(
	'section'     => $section,
	'label'       => esc_html__( 'Border', 'justshoppe' ),
	'units'       => array(
		'px' => array(
			'min'  => 0,
			'step' => 1,
		),
	),
	'priority'    => 20,
) ) );

/**
 * ====================================================
 * Typography
 * ====================================================
 */

// Heading: Typography
$wp_customize->add_control( new Justshoppe_Customize_Control_Heading( $wp_customize, 'heading_hero_typography', array(
	'section'     => $section,
	'settings'    => array(),
	'label'       => esc_html__( 'Typography', 'justshoppe' ),
	'priority'    => 40,
) ) );

// Text typography
$settings = array(
	'font_family'    => 'hero_font_family',
	'font_weight'    => 'hero_font_weight',
	'font_style'     => 'hero_font_style',
	'text_transform' => 'hero_text_transform',
	'font_size'      => 'hero_font_size',
	'line_height'    => 'hero_line_height',
	'letter_spacing' => 'hero_letter_spacing',

	'font_size__tablet'      => 'hero_font_size__tablet',
	'line_height__tablet'    => 'hero_line_height__tablet',
	'letter_spacing__tablet' => 'hero_letter_spacing__tablet',

	'font_size__mobile'      => 'hero_font_size__mobile',
	'line_height__mobile'    => 'hero_line_height__mobile',
	'letter_spacing__mobile' => 'hero_letter_spacing__mobile',
);
foreach ( $settings as $key ) {
	$wp_customize->add_setting( $key, array(
		'default'     => justshoppe_array_value( $defaults, $key ),
		'transport'   => 'postMessage',
		'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'typography' ),
	) );
}
$wp_customize->add_control( new Justshoppe_Customize_Control_Typography( $wp_customize, 'hero_typography', array(
	'settings'    => $settings,
	'section'     => $section,
	'label'       => esc_html__( 'Text typography', 'justshoppe' ),
	'priority'    => 40,
) ) );

// Title typography
$settings = array(
	'font_family'    => 'hero_title_font_family',
	'font_weight'    => 'hero_title_font_weight',
	'font_style'     => 'hero_title_font_style',
	'text_transform' => 'hero_title_text_transform',
	'font_size'      => 'hero_title_font_size',
	'line_height'    => 'hero_title_line_height',
	'letter_spacing' => 'hero_title_letter_spacing',

	'font_size__tablet'      => 'hero_title_font_size__tablet',
	'line_height__tablet'    => 'hero_title_line_height__tablet',
	'letter_spacing__tablet' => 'hero_title_letter_spacing__tablet',

	'font_size__mobile'      => 'hero_title_font_size__mobile',
	'line_height__mobile'    => 'hero_title_line_height__mobile',
	'letter_spacing__mobile' => 'hero_title_letter_spacing__mobile',
);
foreach ( $settings as $key ) {
	$wp_customize->add_setting( $key, array(
		'default'     => justshoppe_array_value( $defaults, $key ),
		'transport'   => 'postMessage',
		'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'typography' ),
	) );
}
$wp_customize->add_control( new Justshoppe_Customize_Control_Typography( $wp_customize, 'hero_title_typography', array(
	'settings'    => $settings,
	'section'     => $section,
	'label'       => esc_html__( 'Title typography', 'justshoppe' ),
	'priority'    => 40,
) ) );

// Breadcrumb typography
$settings = array(
	'font_family'    => 'hero_breadcrumb_font_family',
	'font_weight'    => 'hero_breadcrumb_font_weight',
	'font_style'     => 'hero_breadcrumb_font_style',
	'text_transform' => 'hero_breadcrumb_text_transform',
	'font_size'      => 'hero_breadcrumb_font_size',
	'line_height'    => 'hero_breadcrumb_line_height',
	'letter_spacing' => 'hero_breadcrumb_letter_spacing',

	'font_size__tablet'      => 'hero_breadcrumb_font_size__tablet',
	'line_height__tablet'    => 'hero_breadcrumb_line_height__tablet',
	'letter_spacing__tablet' => 'hero_breadcrumb_letter_spacing__tablet',

	'font_size__mobile'      => 'hero_breadcrumb_font_size__mobile',
	'line_height__mobile'    => 'hero_breadcrumb_line_height__mobile',
	'letter_spacing__mobile' => 'hero_breadcrumb_letter_spacing__mobile',
);
foreach ( $settings as $key ) {
	$wp_customize->add_setting( $key, array(
		'default'     => justshoppe_array_value( $defaults, $key ),
		'transport'   => 'postMessage',
		'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'typography' ),
	) );
}
$wp_customize->add_control( new Justshoppe_Customize_Control_Typography( $wp_customize, 'hero_breadcrumb_typography', array(
	'settings'    => $settings,
	'section'     => $section,
	'label'       => esc_html__( 'Breadcrumb typography', 'justshoppe' ),
	'priority'    => 40,
) ) );

/**
 * ====================================================
 * Colors
 * ====================================================
 */

// Heading: Colors
$wp_customize->add_control( new Justshoppe_Customize_Control_Heading( $wp_customize, 'heading_hero_colors', array(
	'section'     => $section,
	'settings'    => array(),
	'label'       => esc_html__( 'Colors', 'justshoppe' ),
	'priority'    => 50,
) ) );

// Colors
$colors = array(
	'hero_bg_color'                         => esc_html__( 'Background color', 'justshoppe' ),
	'hero_border_color'                     => esc_html__( 'Border color', 'justshoppe' ),
	'hero_text_color'                       => esc_html__( 'Text color', 'justshoppe' ),
	'hero_link_text_color'                  => esc_html__( 'Link text color', 'justshoppe' ),
	'hero_link_hover_text_color'            => esc_html__( 'Link text color :hover', 'justshoppe' ),
	'hero_title_text_color'                 => esc_html__( 'Title text color', 'justshoppe' ),
	'hero_breadcrumb_text_color'            => esc_html__( 'Breadcrumb text color', 'justshoppe' ),
	'hero_breadcrumb_link_text_color'       => esc_html__( 'Breadcrumb link text color', 'justshoppe' ),
	'hero_breadcrumb_link_hover_text_color' => esc_html__( 'Breadcrumb link text color :hover', 'justshoppe' ),
);
foreach ( $colors as $key => $label ) {
	$wp_customize->add_setting( $key, array(
		'default'     => justshoppe_array_value( $defaults, $key ),
		'transport'   => 'postMessage',
		'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'color' ),
	) );
	$wp_customize->add_control( new Justshoppe_Customize_Control_Color( $wp_customize, $key, array(
		'section'     => $section,
		'label'       => $label,
		'priority'    => 50,
	) ) );
}

/**
 * ====================================================
 * Background
 * ====================================================
 */

// Heading: Background Image
$wp_customize->add_control( new Justshoppe_Customize_Control_Heading( $wp_customize, 'heading_hero_background', array(
	'section'     => $section,
	'settings'    => array(),
	'label'       => esc_html__( 'Background Image', 'justshoppe' ),
	'priority'    => 60,
) ) );

// Default background image
$key = 'hero_bg';
$settings = array(
	'image'      => $key . '_image',
	'attachment' => $key . '_attachment',
);
foreach ( $settings as $setting ) {
	$wp_customize->add_setting( $setting, array(
		'default'     => justshoppe_array_value( $defaults, $setting ),
		// 'transport'   => 'postMessage',
		'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'background' ),
	) );
}
$wp_customize->add_control( new Justshoppe_Customize_Control_Background( $wp_customize, $key, array(
	'settings'    => $settings,
	'section'     => $section,
	'label'       => esc_html__( 'Default background image', 'justshoppe' ) . ' <span class="justshoppe-global-default-badge justshoppe-tooltip" tabindex="0" data-tooltip="' . esc_attr__( 'You can set different background image on each individual page.', 'justshoppe' ) . '"><span class="dashicons dashicons-admin-site-alt3"></span> ' . esc_html__( 'Global', 'justshoppe' ) . '</span>',
	'priority'    => 60,
) ) );

// Colors
$key = 'hero_bg_overlay_color';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'transport'   => 'postMessage',
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'color' ),
) );
$wp_customize->add_control( new Justshoppe_Customize_Control_Color( $wp_customize, $key, array(
	'section'     => $section,
	'label'       => esc_html__( 'Background overlay color', 'justshoppe' ),
	'priority'    => 60,
) ) );