<?php
/**
 * Customizer settings: Content & Sidebar > Content Section
 *
 * @package Justshoppe
 **/

// Prevent direct access.
if ( ! defined( 'ABSPATH' ) ) exit;

$section = 'justshoppe_section_content';

/**
 * ====================================================
 * Layout
 * ====================================================
 */

// Container width
$key = 'content_container';
$wp_customize->add_setting( $key, array(
	'default'     => justshoppe_array_value( $defaults, $key ),
	'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'select' ),
) );
$wp_customize->add_control( new Justshoppe_Customize_Control_RadioImage( $wp_customize, $key, array(
	'section'     => $section,
	'label'       => esc_html__( 'Container width', 'justshoppe' ) . ' <span class="justshoppe-global-default-badge justshoppe-tooltip" tabindex="0" data-tooltip="' . esc_attr__( 'You can override this option on each individual page.', 'justshoppe' ) . '"><span class="dashicons dashicons-admin-site-alt3"></span> ' . esc_html__( 'Global', 'justshoppe' ) . '</span>',
	'choices'     => array(
		'narrow'     => array(
			'label' => esc_html__( 'Narrow', 'justshoppe' ),
			'image' => JUSTSHOPPE_IMAGES_URL . '/customizer/content-container--narrow.svg',
		),
		'default'    => array(
			'label' => esc_html__( 'Normal', 'justshoppe' ),
			'image' => JUSTSHOPPE_IMAGES_URL . '/customizer/content-container--default.svg',
		),
		'full-width' => array(
			'label' => esc_html__( 'Full width', 'justshoppe' ),
			'image' => JUSTSHOPPE_IMAGES_URL . '/customizer/content-container--full-width.svg',
		),
	),
	'columns'     => 3,
	'priority'    => 10,
) ) );

// Info
$wp_customize->add_control( new Justshoppe_Customize_Control_Blank( $wp_customize, 'notice_narrow_content_layout', array(
	'section'     => $section,
	'settings'    => array(),
	'description' => '<div class="notice notice-info notice-alt inline"><p>' . esc_html__( 'Narrow content layout doesn\'t support Sidebar.', 'justshoppe' ) . '</p></div>',
	'priority'    => 10,
) ) );

// ------
$wp_customize->add_control( new Justshoppe_Customize_Control_HR( $wp_customize, 'hr_content_layout', array(
	'section'     => $section,
	'settings'    => array(),
	'priority'    => 10,
) ) );

// Padding
$key = 'content_padding';
$settings = array(
	$key,
	$key . '__tablet',
	$key . '__mobile',
);
foreach ( $settings as $setting ) {
	$wp_customize->add_setting( $setting, array(
		'default'     => justshoppe_array_value( $defaults, $setting ),
		'transport'   => 'postMessage',
		'sanitize_callback' => array( 'Justshoppe_Customizer_Sanitization', 'dimensions' ),
	) );
}
$wp_customize->add_control( new Justshoppe_Customize_Control_Dimensions( $wp_customize, $key, array(
	'settings'    => $settings,
	'section'     => $section,
	'label'       => esc_html__( 'Padding', 'justshoppe' ),
	'units'       => array(
		'px' => array(
			'min'  => 0,
			'step' => 1,
		),
		'em' => array(
			'min'  => 0,
			'step' => 0.01,
		),
		'%' => array(
			'min'  => 0,
			'step' => 0.01,
		),
	),
	'priority'    => 10,
) ) );