<?php
/**
 * Justshoppe setup
 *
 * @package justshoppe
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Elementor\Controls_Manager;
add_filter('justshoppe_add_contents_fields', 'justshoppe_theme_contents_fields');

function justshoppe_theme_contents_fields() {

	/* List the post types.*/
	global $wp_post_types;
	$posttypes = array_keys( $wp_post_types );
	// Remove _builtins or others
	$pt_remove = array("attachment","nav_menu_item","customize_changeset","revision","elementor_icons","elementor_font","justshoppe_block","wpcf7_contact_form","acf-field","acf-field-group","elementskit_content","elementskit_template","elementor_snippet","user_request","oembed_cache","custom_css");

	foreach ( $posttypes as $posttype ):
		if ( in_array($posttype, $pt_remove) ) continue;
		$postLabel = get_post_type_object($posttype);
		if ($postLabel) {
			//$posts[ $posttype ] = $posttype;
			$posts[ $posttype ] = $postLabel->labels->singular_name;
		}
	endforeach;

	/* List the categories names.*/
	$post_categories = get_terms();

	$post_options = [];
	foreach ( $post_categories as $category ) {
		$post_options[ $category->slug ] = $category->name;
	}


	$contents_type_fields = [
		'label' => sprintf( esc_html__( '%1$s Add Content', 'justshoppe' ), ucfirst(get_template() ) ),
		'controls' => [
			'posts_per_page' => [
				'label' => esc_html__( 'Number of posts displayed', 'justshoppe' ),
				'type' => Controls_Manager::TEXT,
				'default' => '5',
				'description' => esc_html__( 'The number of posts you want to show.', 'justshoppe' ),
				'label_block' => true,
			],
			'post_type' => [
				'label' => esc_html__( 'Content Type', 'justshoppe' ),
				'type' => Controls_Manager::SELECT,
				'description' =>esc_html__( 'Not all content type will be listed here. We list only those we have template in this theme for.', 'justshoppe' ),
				'default'  => 'post',
				'options'  => [
					'post'                 => esc_html__(' Posts', 'justshoppe'),
					'tt_portfolio'         => esc_html__(' Gallery/Portfolio', 'justshoppe'),
				],
			],

			'select_cpt' => [
				'label'       => esc_html__( 'Select Posts(Advanced users only)', 'justshoppe' ),
				'description' => esc_html__( 'Please leave as it is if you are not sure what it means. If you select this, the above selection becomes void.', 'justshoppe' ),
				'type'        => Controls_Manager::SELECT2,
				'options'     => $posts,
				'default'     => [],
				'label_block' => true,
			],

			'post_categories' => [
				'label'       => esc_html__( 'Categories(Advanced users only)', 'justshoppe' ),
				'description' => esc_html__( 'Filter posts by the category, make sure you select categories only from the selected post type.', 'justshoppe' ),
				'type'        => Controls_Manager::SELECT2,
				'options'     => $post_options,
				'default'     => [],
				'label_block' => true,
				'multiple'    => true,
			],

			'orderby' => [
				'label' => esc_html__( 'Order by', 'justshoppe' ),
				'type' => Controls_Manager::SELECT,
				'description' =>esc_html__( 'Order this content by...', 'justshoppe' ),
				'default'  => 'date',
				'options'  => [
					'date'            =>      esc_html__(' Date', 'justshoppe'),
					'ID'              =>      esc_html__(' Post ID', 'justshoppe'),
					'author'          =>      esc_html__(' Author', 'justshoppe'),
					'title'           =>      esc_html__(' Title', 'justshoppe'),
					'name'            =>      esc_html__(' Post name (post slug)', 'justshoppe'),
					'modified'        =>      esc_html__(' Last modified date', 'justshoppe'),
					'rand'            =>      esc_html__(' Random order', 'justshoppe'),
					'comment_count'   =>      esc_html__(' Number of comments', 'justshoppe'),
				],
			],

			'order' => [
				'label' => esc_html__( 'Order', 'justshoppe' ),
				'type' => Controls_Manager::SELECT,
				'default'  => 'DESC',
				'options'  => [
					'DESC'            =>      esc_html__(' DESC', 'justshoppe'),
					'ASC'             =>      esc_html__(' ASC', 'justshoppe'),
				],
			],

			'tt_id' => [
				'label' => esc_html__( 'Post Ids', 'justshoppe' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'description' => esc_html__( 'If you want to display particular posts, enter their IDs comma separated. eg 101,202,300. Recommended: Leave blank', 'justshoppe' ),
				'label_block' => true,
			],

			'tt_template' => [
				'label' => esc_html__( 'Display Template', 'justshoppe' ),
				'type' => Controls_Manager::SELECT,
				'description' => esc_html__( 'There are prebuilt templates to display certain content in this theme. You are requested not to edit this.', 'justshoppe' ),
				'default'  => 'default',
				'options'  => apply_filters( 'add_content_templates', [
					'default'                   =>  esc_html__(' Default', 'justshoppe'),
					'blog-grid'                 =>  esc_html__(' Blog Grid', 'justshoppe'),
					'portfolio-masonry'         =>  esc_html__(' Portfolio', 'justshoppe'),
				]),
			],

			'enable_filter' => [
				'label' => esc_html__( 'Enable Filter ?', 'justshoppe' ),
				'type' => Controls_Manager::SWITCHER,
				'description' => esc_html__( 'If set to yes, the gallery is filterable by the category. Not applicable to all cases. Page refresh needed to apply changes.', 'justshoppe' ),
				'default' => 'true',
				'prefix_class' => 'elementor-',
				'label_on' => 'Yes',
				'label_off' => 'No',
				'return_value' => 'true',
				'condition' => [
					'tt_template' => [ 'isotop-tmpl', 'gallery-page' ],
				],
			],

			'enable_all_btn' => [
				'label' => esc_html__( 'Enable ALL button ?', 'justshoppe' ),
				'type' => Controls_Manager::SWITCHER,
				'description' => esc_html__( 'If set to yes, All link appears first that displays all items. Not applicable to all cases. Page refresh needed to apply changes.', 'justshoppe' ),
				'default' => 'true',
				'prefix_class' => 'elementor-',
				'label_on' => 'Yes',
				'label_off' => 'No',
				'return_value' => 'true',
				'condition' => [
					'tt_template' => [ 'isotop-tmpl', 'gallery-page' ],
				],
			],
			/* The param name should not be changed. */
			/* spl_title */
			'spl_field1' => [
				'label' => esc_html__( 'Title (Optional)', 'justshoppe' ),
				'type' => Controls_Manager::TEXT,
				'description' => esc_html__( 'Enter the title for the entire block. Leave blank to disable.', 'justshoppe' ),
				'label_block' => true,
				'condition' => [
					'tt_template' => [ 'default' ],
				],
			],
			/* spl_button */
			'spl_field2' => [
				"label" => esc_html__("Button Label (Optional)", 'justshoppe'),
				'type' => Controls_Manager::TEXT,
				'description' => esc_html__( 'Leave blank to disable button.', 'justshoppe' ),
				'label_block' => true,
				'condition' => [
					'tt_template' => [ 'blog3' ],
				],
			],
			/* spl_target */
			'spl_field3' => [
				"label" => esc_html__("Open links in:",'justshoppe'),
				'type' => Controls_Manager::SELECT,
				'label_block' => true,
				'options'  => [
					'_self'           =>  esc_html__(' Same window', 'justshoppe'),
					'_blank'   =>  esc_html__(' New window', 'justshoppe'),
				],
				'condition' => [
					'tt_template' => [ 'blog3' ],
				],
			],
			/* spl_link */
			'spl_field4' => [
				"label" => esc_html__("Button Link:",'justshoppe'),
				'type' => Controls_Manager::TEXT,
				'description' => esc_html__( 'The link for the above button.', 'justshoppe' ),
				'label_block' => true,
				'condition' => [
					'tt_template' => [ 'blog3' ],
				],
			],

			'spl_field5' => [
				'label' => esc_html__( 'Subtitle (Optional)', 'justshoppe' ),
				'type' => Controls_Manager::TEXT,
				'description' => esc_html__( 'Enter the subtitle for the entire block. Leave blank to disable.', 'justshoppe' ),
				'label_block' => true,
				'condition' => [
					'tt_template' => [ 'default' ],
				],
			],

			'spl_field6' => [
				'label' => esc_html__( 'Description (Optional)', 'justshoppe' ),
				'type' => Controls_Manager::TEXTAREA,
				'description' => esc_html__( 'Enter the description for the entire block. Leave blank to disable. Plain text only, new line or html will not work.', 'justshoppe' ),
				'label_block' => true,
				'condition' => [
					'tt_template' => [ 'default' ],
				],
			],

		],
	];

	return $contents_type_fields;

}
