<?php
/**
 * The main template file.
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Justshoppe
 */

// Prevent direct access.
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Header
 */
get_header();

if ( justshoppe_is_fresh_install() ) {


/**
 * Primary - opening tag
 */
justshoppe_primary_open();

/**
 * Hook: justshoppe/frontend/before_main
 */
do_action( 'justshoppe/frontend/before_main' );

while ( have_posts() ) : the_post();

	// Render post content using "content" layout.
	justshoppe_get_template_part( 'entry' );

endwhile;

/**
 * Hook: justshoppe/frontend/after_main
 */
do_action( 'justshoppe/frontend/after_main' );

/**
 * Primary - closing tag
 */
justshoppe_primary_close();

/**
 * Sidebar
 */
get_sidebar();

} else {
?>

	<div id="primary" class="content-area">
		<main id="main" class="site-main" role="main">

		<?php
		if ( have_posts() ) :

			get_template_part( 'template-parts/loop' );

		else :

			get_template_part( 'template-parts/content', 'none' );

		endif;
		?>

		</main><!-- #main -->
	</div><!-- #primary -->

<?php
do_action( 'justshoppe_sidebar' );
 }
get_footer();