<?php
/**
 * The template for displaying search results pages.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/#search-result
 *
 * @package Justshoppe
 */

// Prevent direct access.
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Header
 */
get_header();

if ( justshoppe_is_fresh_install() ) {

	/**
	 * Primary - opening tag
	 */
	justshoppe_primary_open();

	/**
	 * Hook: justshoppe/frontend/before_main
	 *
	 * @hooked justshoppe_content_header - 10
	 */
	do_action( 'justshoppe/frontend/before_main' );

	if ( have_posts() ) :

		?>
		<div id="loop" class="justshoppe-loop justshoppe-loop-search">
			<?php
			// Start the loop.
			while ( have_posts() ) : the_post();

				// Render post content using "content-search" layout on Customizer.
				justshoppe_get_template_part( 'entry', 'search' );

			endwhile;
			?>
		</div>
	<?php

	else :

		// Render not-found message.
		$not_found_message = justshoppe_get_theme_mod( 'search_results_not_found_text' );
		if ( empty( $not_found_message ) ) {
			$not_found_message = esc_html__( 'Sorry, but nothing matched your search terms. Please try again with some different keywords.', 'justshoppe' );
		}
		echo wp_kses_post( wpautop( $not_found_message ) );

	endif;

	/**
	 * Hook: justshoppe/frontend/after_main
	 *
	 * @hooked justshoppe_loop_navigation - 10
	 */
	do_action( 'justshoppe/frontend/after_main' );

	/**
	 * Primary - closing tag
	 */
	justshoppe_primary_close();

	/**
	 * Sidebar
	 */
	get_sidebar();

} else {
	?>

	<div id="primary" class="content-area">
		<main id="main" class="site-main" role="main">

			<?php if ( have_posts() ) : ?>

				<header class="page-header">
					<h1 class="page-title">
						<?php
						/* translators: %s: search term */
						printf( esc_attr__( 'Search Results for: %s', 'justshoppe' ), '<span>' . get_search_query() . '</span>' );
						?>
					</h1>
				</header><!-- .page-header -->

				<?php
				get_template_part( 'template-parts/loop' );

			else :

				get_template_part( 'template-parts/content', 'none' );

			endif;
			?>

		</main>
		<!-- #main -->
	</div><!-- #primary -->

	<?php
	do_action( 'justshoppe_sidebar' );
}

/**
 * Footer
 */
get_footer();